<?php
namespace admin;

use common\libraries\EqualityCondition;
use common\libraries\AndCondition;
use common\libraries\Utilities;
use common\libraries\Configuration;
use common\libraries\CommonDataManager;

/**
 *
 * @package admin.lib
 * @author Hans De Bisschop
 * @author Dieter De Neef
 */
class AdminDataManager
{
    
    /**
     * Instance of this class for the singleton pattern.
     */
    private static $instance;

    /**
     * Uses a singleton pattern and a factory pattern to return the data manager. The configuration determines which
     * data manager class is to be instantiated.
     * 
     * @return AdminDataManagerInterface The data manager.
     */
    static function get_instance()
    {
        if (! isset(self :: $instance))
        {
            $type = Configuration :: get_instance()->get_parameter('general', 'data_manager');
            $class = __NAMESPACE__ . '\\' . Utilities :: underscores_to_camelcase($type) . 'AdminDataManager';
            self :: $instance = new $class();
        }
        return self :: $instance;
    }

    static function set_instance($instance)
    {
        self :: $instance = $instance;
    }

    static function get_languages($use_folder_name_as_key = true)
    {
        $options = array();
        
        $languages = self :: get_instance()->retrieve_languages();
        while ($language = $languages->next_result())
        {
            // if (self :: is_language_active($language->get_isocode()))
            // {
            if ($use_folder_name_as_key)
            {
                $key = $language->get_isocode();
            }
            else
            {
                $key = $language->get_id();
            }
            $options[$key] = $language->get_original_name();
            // }
        }
        
        return $options;
    }

    static function is_language_active($language_name)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(Language :: PROPERTY_ISOCODE, $language_name);
        $conditions[] = new EqualityCondition(Language :: PROPERTY_AVAILABLE, 1);
        return (self :: get_instance()->count_languages(new AndCondition($conditions)) == 1);
    }

    /**
     * Retrieves a remote package with given context
     * 
     * @param $context string
     * @return RemotePackage
     */
    static function retrieve_remote_package_by_context($context)
    {
        $condition = new EqualityCondition(RemotePackage :: PROPERTY_CONTEXT, $context);
        return self :: get_instance()->retrieve_remote_packages($condition)->next_result();
    }

}
?>