<?php
namespace admin;

use common\libraries\CommonDataManager;
use core\lynx\PackageList;
use common\libraries\PlatformSetting;
use common\libraries\Utilities;
use common\libaries\Import;
use common\libraries\Application;
use common\libraries\CoreApplication;
use common\libraries\WebApplication;
use common\libraries\Translation;
use common\libraries\Request;
use common\libraries\DynamicAction;
use common\libraries\Theme;
use common\libraries\Redirect;
use common\libraries\BreadcrumbTrail;
use common\libraries\Display;
use repository\content_object\system_announcement\SystemAnnouncement;
use repository\RepositoryManager;
use user\UserManager;
use group\GroupManager;
use help\HelpManager;
use migration\MigrationManager;
use menu\MenuManager;
use reporting\ReportingManager;
use home\HomeManager;
use tracking\TrackingManager;
use webservice\WebserviceManager;
use rights\RightsManager;
use metadata\MetadataManager;

/**
 * $Id: admin_manager.class.php 205 2009-11-13 12:57:33Z vanpouckesven $
 *
 * @package admin.lib.admin_manager
 * @author Hans De Bisschop
 * @author Dieter De Neef
 */

/**
 * The admin allows the platform admin to configure certain aspects of his platform
 */
class AdminManager extends CoreApplication
{
    const APPLICATION_NAME = 'admin';
    const PARAM_WEB_APPLICATION = 'web_application';
    const PARAM_CONTEXT = 'context';
    const PARAM_SYSTEM_ANNOUNCEMENT_ID = 'announcement';
    const PARAM_DELETE_SELECTED = 'delete_selected';
    const PARAM_EDIT_SELECTED = 'edit_selected';
    const ACTION_ADMIN_BROWSER = 'browser';
    const ACTION_LANGUAGE = 'language';
    const ACTION_CONFIGURE_PLATFORM = 'configurer';
    const ACTION_MANAGE_PACKAGES = 'packager';
    const ACTION_CREATE_SYSTEM_ANNOUNCEMENT = 'system_announcement_creator';
    const ACTION_BROWSE_SYSTEM_ANNOUNCEMENTS = 'system_announcement_browser';
    const ACTION_EDIT_SYSTEM_ANNOUNCEMENT = 'system_announcement_editor';
    const ACTION_DELETE_SYSTEM_ANNOUNCEMENT = 'system_announcement_deleter';
    const ACTION_VIEW_SYSTEM_ANNOUNCEMENT = 'system_announcement_viewer';
    const ACTION_VIEW_SYSTEM_ANNOUNCEMENT_ADMIN = 'system_announcement_viewer_admin';
    const ACTION_HIDE_SYSTEM_ANNOUNCEMENT = 'system_announcement_hider';
    const ACTION_MANAGE_CATEGORIES = 'category_manager';
    const ACTION_WHOIS_ONLINE = 'whois_online';
    const ACTION_DIAGNOSE = 'diagnoser';
    const ACTION_VIEW_LOGS = 'log_viewer';
    const ACTION_IMPORTER = 'importer';
    const ACTION_EDIT_RIGHTS = 'rights_editor';
    const ACTION_MANAGE_RESOURCE_CACHE = 'resource_cache_manager';
    const DEFAULT_ACTION = self :: ACTION_ADMIN_BROWSER;

    /**
     * Constructor
     *
     * @param $user User The current user
     */
    function __construct($user = null)
    {
        parent :: __construct($user);
    }

    public static function get_application_platform_admin_links($application = self :: APPLICATION_NAME)
    {
        $links = array();

        $settings_url = Redirect :: get_link(self :: APPLICATION_NAME,
                array(self :: PARAM_ACTION => self :: ACTION_CONFIGURE_PLATFORM));

        $links[] = new DynamicAction(Translation :: get('Settings'), Translation :: get('SettingsDescription'),
                Theme :: get_image_path() . 'admin/settings.png', $settings_url);

        $links[] = new DynamicAction(Translation :: get('Importer'), Translation :: get('ImporterDescription'),
                Theme :: get_image_path() . 'admin/import.png',
                Redirect :: get_link(self :: APPLICATION_NAME, array(self :: PARAM_ACTION => self :: ACTION_IMPORTER),
                        array(), false, Redirect :: TYPE_CORE));

        $package_management = PlatformSetting :: get('enable_package_management');

        if ($package_management == '1')
        {
            $links[] = new DynamicAction(Translation :: get('ManagePackages'),
                    Translation :: get('ManagePackagesDescription'), Theme :: get_image_path() . 'admin/build.png',
                    Redirect :: get_link(\core\lynx\Manager :: APPLICATION_NAME, array(), array(), false, Redirect :: TYPE_CORE));
        }

        $links[] = new DynamicAction(Translation :: get('SystemAnnouncements'),
                Translation :: get('SystemAnnouncementsDescription'), Theme :: get_image_path() . 'admin/list.png',
                Redirect :: get_link(self :: APPLICATION_NAME,
                        array(self :: PARAM_ACTION => self :: ACTION_BROWSE_SYSTEM_ANNOUNCEMENTS), array(), false,
                        Redirect :: TYPE_CORE));

        $links[] = new DynamicAction(Translation :: get('TranslationsImport'),
                Translation :: get('TranslationsImportDescription'),
                Theme :: get_image_path(\admin\language\Manager :: context()) . 'logo/32.png',
                Redirect :: get_link(self :: APPLICATION_NAME, array(self :: PARAM_ACTION => self :: ACTION_LANGUAGE)));

        $links[] = new DynamicAction(Translation :: get('ManageCategories'),
                Translation :: get('ManageCategoriesDescription'), Theme :: get_image_path() . 'admin/list.png',
                Redirect :: get_link(self :: APPLICATION_NAME,
                        array(self :: PARAM_ACTION => self :: ACTION_MANAGE_CATEGORIES), array(), false,
                        Redirect :: TYPE_CORE));

        $links[] = new DynamicAction(Translation :: get('CacheManagement'),
                Translation :: get('CacheManagementDescription'), Theme :: get_image_path() . 'admin/cache.png',
                Redirect :: get_link(self :: APPLICATION_NAME,
                        array(self :: PARAM_ACTION => self :: ACTION_MANAGE_RESOURCE_CACHE), array(), false,
                        Redirect :: TYPE_CORE));

        $links[] = new DynamicAction(Translation :: get('Diagnose'), Translation :: get('DiagnoseDescription'),
                Theme :: get_image_path() . 'admin/information.png',
                Redirect :: get_link(self :: APPLICATION_NAME, array(self :: PARAM_ACTION => self :: ACTION_DIAGNOSE),
                        array(), false, Redirect :: TYPE_CORE));

        $links[] = new DynamicAction(Translation :: get('LogsViewer'), Translation :: get('LogsViewerDescription'),
                Theme :: get_image_path() . 'admin/information.png',
                Redirect :: get_link(self :: APPLICATION_NAME, array(self :: PARAM_ACTION => self :: ACTION_VIEW_LOGS),
                        array(), false, Redirect :: TYPE_CORE));

        $admin_info = parent :: get_application_platform_admin_links(self :: APPLICATION_NAME);
        $admin_info['links'] = $links;

        return $admin_info;
    }

    static function get_application_platform_import_links()
    {
        // 1. Admin-core components
        $links = array();

        // 2. Repository
        $links = array_merge($links, RepositoryManager :: get_application_platform_import_links());

        // 3. UserManager
        $links = array_merge($links, UserManager :: get_application_platform_import_links());

        // 4. Roles'n'Rights
        $links = array_merge($links, RightsManager :: get_application_platform_import_links());

        // 5. Groups
        $links = array_merge($links, GroupManager :: get_application_platform_import_links());

        // 6. Webservices
        $links = array_merge($links, WebserviceManager :: get_application_platform_import_links());

        // 7. Tracking
        $links = array_merge($links, TrackingManager :: get_application_platform_import_links());

        // 8. Reporting
        $links = array_merge($links, ReportingManager :: get_application_platform_import_links());

        // 9. Home
        $links = array_merge($links, HomeManager :: get_application_platform_import_links());

        // 10. Menu
        $links = array_merge($links, MenuManager :: get_application_platform_import_links());

        // 11. Migration
        /*
         * $migration_manager = new MigrationManager($user->get_id()); $links[] =
         * $migration_manager->get_application_platform_admin_links();
         */

        $links = array_merge($links, HelpManager :: get_application_platform_import_links());

        // 12.The links for the plugin applications running on top of the
        // essential Chamilo components
        $applications = WebApplication :: load_all();

        foreach ($applications as $index => $application_name)
        {
            $application_links = call_user_func(
                    array(
                            'application\\' . $application_name . '\\' . WebApplication :: get_application_class_name(
                                    $application_name), 'get_application_platform_import_links'));

            $links = array_merge($links, $application_links);
        }

        return $links;
    }

    /**
     * Count the system announcements
     *
     * @param $condition Condition
     * @return int
     */
    function count_system_announcement_publications($condition = null)
    {
        $pmdm = AdminDataManager :: get_instance();
        return $pmdm->count_system_announcement_publications($condition);
    }

    function count_remote_packages($condition = null)
    {
        $pmdm = AdminDataManager :: get_instance();
        return $pmdm->count_remote_packages($condition);
    }

    /**
     * Retrieve a system announcement
     *
     * @param $id int
     * @return SystemAnnouncementPublication
     */
    function retrieve_system_announcement_publication($id)
    {
        $pmdm = AdminDataManager :: get_instance();
        return $pmdm->retrieve_system_announcement_publication($id);
    }

    function retrieve_remote_package($id)
    {
        $adm = AdminDataManager :: get_instance();
        return $adm->retrieve_remote_package($id);
    }

    function retrieve_remote_packages($condition = null, $order_by = array (), $offset = 0, $max_objects = -1)
    {
        $adm = AdminDataManager :: get_instance();
        return $adm->retrieve_remote_packages($condition, $order_by, $offset, $max_objects);
    }

    /**
     * Retrieve a series of system announcements
     *
     * @param $condition Condition
     * @param $order_by array
     * @param $offset int
     * @param $max_objects int
     * @return SystemAnnouncementPublicationResultSet
     */
    function retrieve_system_announcement_publications($condition = null, $order_by = array (), $offset = 0, $max_objects = -1)
    {
        $pmdm = AdminDataManager :: get_instance();
        return $pmdm->retrieve_system_announcement_publications($condition, $order_by, $offset, $max_objects);
    }

    function get_system_announcement_publication_deleting_url($system_announcement_publication)
    {
        return $this->get_url(
                array(self :: PARAM_ACTION => self :: ACTION_DELETE_SYSTEM_ANNOUNCEMENT,
                        self :: PARAM_SYSTEM_ANNOUNCEMENT_ID => $system_announcement_publication->get_id()));
    }

    function get_system_announcement_publication_visibility_url($system_announcement_publication)
    {
        return $this->get_url(
                array(self :: PARAM_ACTION => self :: ACTION_HIDE_SYSTEM_ANNOUNCEMENT,
                        self :: PARAM_SYSTEM_ANNOUNCEMENT_ID => $system_announcement_publication->get_id()));
    }

    function get_system_announcement_publication_viewing_url($system_announcement_publication, $admin = true)
    {
        return $this->get_url(
                array(self :: ACTION_VIEW_SYSTEM_ANNOUNCEMENT => $action,
                        self :: PARAM_SYSTEM_ANNOUNCEMENT_ID => $system_announcement_publication->get_id()));
    }

    function get_admin_system_announcement_publication_viewing_url($system_announcement_publication)
    {
        return $this->get_url(
                array(self :: PARAM_ACTION => self :: ACTION_VIEW_SYSTEM_ANNOUNCEMENT_ADMIN,
                        self :: PARAM_SYSTEM_ANNOUNCEMENT_ID => $system_announcement_publication->get_id()));
    }

    function get_system_announcement_publication_editing_url($system_announcement_publication)
    {
        return $this->get_url(
                array(self :: PARAM_ACTION => self :: ACTION_EDIT_SYSTEM_ANNOUNCEMENT,
                        self :: PARAM_SYSTEM_ANNOUNCEMENT_ID => $system_announcement_publication->get_id()));
    }

    function get_system_announcement_publication_creating_url()
    {
        return $this->get_url(array(self :: PARAM_ACTION => self :: ACTION_CREATE_SYSTEM_ANNOUNCEMENT));
    }

    function get_rights_editor_url()
    {
        return $this->get_url(array(self :: PARAM_ACTION => self :: ACTION_EDIT_RIGHTS));
    }

    /**
     * Renders the users block and returns it.
     */
    function render_block($block)
    {
        $admin_block = AdminBlock :: factory($this, $block);
        return $admin_block->run();
    }

    /*
     * Inherited
     */
    static function get_content_object_publication_attributes($object_id, $type = null, $offset = null, $count = null,
            $order_property = null)
    {
        return AdminDataManager :: get_instance()->get_content_object_publication_attributes($object_id, $type, $offset,
                $count, $order_property);
    }

    /*
     * Inherited
     */
    static function get_content_object_publication_attribute($publication_id)
    {
        return AdminDataManager :: get_instance()->get_content_object_publication_attribute($publication_id);
    }

    public static function any_content_object_is_published($object_ids)
    {
        $adm = AdminDataManager :: get_instance();
        return $adm->any_content_object_is_published($object_ids);
    }

    public static function count_publication_attributes($user, $type = null, $condition = null)
    {
        $adm = AdminDataManager :: get_instance();
        return $adm->count_publication_attributes($type, $condition);
    }

    public static function delete_content_object_publications($object_id)
    {
        $adm = AdminDataManager :: get_instance();
        return $adm->delete_content_object_publications($object_id);
    }

    public static function delete_content_object_publication($publication_id)
    {
        $adm = AdminDataManager :: get_instance();
        return $adm->delete_content_object_publication($publication_id);
    }

    /**
     * Helper function for the Application class, pending access to class constants via variables in PHP 5.3 e.g. $name
     * = $class :: APPLICATION_NAME DO NOT USE IN THIS APPLICATION'S CONTEXT Instead use: - self :: APPLICATION_NAME in
     * the context of this class - YourApplicationManager :: APPLICATION_NAME in all other application classes
     */
    function get_application_name()
    {
        return self :: APPLICATION_NAME;
    }

    /**
     * Used to publish system announcements
     */
    static function get_content_object_publication_locations($content_object)
    {
        $user = \user\DataManager :: retrieve(\user\User :: class_name(),
                (int) \common\libraries\Session :: get_user_id());

        if ($user->is_platform_admin())
        {
            $allowed_types = array(SystemAnnouncement :: get_type_name());

            $type = $content_object->get_type();
            if (in_array($type, $allowed_types))
            {
                $locations = array(Translation :: get('SystemAnnouncements'));
                return $locations;
            }
        }

        return array();
    }

    /**
     * Used to publish system announcements
     */
    static function publish_content_object($content_object, $location)
    {
        $pub = new SystemAnnouncementPublication();
        $pub->set_content_object_id($content_object->get_id());
        $pub->set_publisher($content_object->get_owner_id());
        $pub->create();

        return Translation :: get('ObjectCreated', array('OBJECT' => Translation :: get('Publication')),
                Utilities :: COMMON_LIBRARIES);
    }

    static function add_publication_attributes_elements()
    {
    }

    /**
     * Helper function for the Application class, pending access to class constants via variables in PHP 5.3 e.g. $name
     * = $class :: DEFAULT_ACTION DO NOT USE IN THIS APPLICATION'S CONTEXT Instead use: - self :: DEFAULT_ACTION in the
     * context of this class - YourApplicationManager :: DEFAULT_ACTION in all other application classes
     */
    function get_default_action()
    {
        return self :: DEFAULT_ACTION;
    }

    static function get_installable_application_packages($include_installed = false)
    {
        $package_list = new PackageList(self :: context(), Translation :: get('TypeName', null, __NAMESPACE__),
                Theme :: get_image_path() . 'logo/16.png');

        if (! CommonDataManager :: get_registration(\admin\language\Manager :: context()) || $include_installed)
        {

            $package_list->add_package(\admin\language\Manager :: context());
        }

        return $package_list;
    }
}
?>
