<?php
namespace admin;

use core\lynx\PackageList;

use common\libraries\Utilities;
use common\libraries\Path;
use common\libraries\Translation;
use common\libraries\Request;
use common\libraries\ResourceManager;
use common\libraries\EqualityCondition;
use common\libraries\BreadcrumbTrail;
use common\libraries\Breadcrumb;
use common\libraries\DynamicTabsRenderer;
use common\libraries\DynamicAction;
use common\libraries\DynamicActionsTab;
use common\libraries\Theme;
use common\libraries\Application;
use common\libraries\PlatformSetting;
/**
 * $Id: browser.class.php 168 2009-11-12 11:53:23Z vanpouckesven $
 *
 * @package admin.lib.admin_manager.component
 */
/**
 * Admin component
 */
class AdminManagerBrowserComponent extends AdminManager
{
    const PARAM_TAB = 'tab';
    private $tab;

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        if (! $this->get_user()->get_platformadmin())
        {
            $this->display_header();
            $this->display_error_message(Translation :: get('NotAllowed', array(), Utilities :: COMMON_LIBRARIES));
            $this->display_footer();
            exit();
        }
        
        $breadcrumbtrail = BreadcrumbTrail :: get_instance();
        $breadcrumbtrail->truncate(true);
        $breadcrumbtrail->add(new Breadcrumb($this->get_url(), Translation :: get('Administration')));
        $breadcrumbtrail->add_help('administration general');
        
        $this->tab = Request :: get(self :: PARAM_TAB);
        if (! $this->tab)
        {
            $this->tab = 'core';
        }
        $tab_name = Translation :: get(Utilities :: underscores_to_camelcase($this->tab));
        
        $breadcrumbtrail->add(new Breadcrumb($this->get_url(array(
                DynamicTabsRenderer :: PARAM_SELECTED_TAB => $this->tab)), $tab_name));
        
        $links = $this->get_application_platform_admin_links();
        $this->display_header();
        
        echo '<div style="float: left; width: 10%;">';
        echo $this->get_menu();
        
        echo '</div>';
        
        echo '<div style="float: right; width: 89%;">';
        echo $this->get_tabs();
        echo '</div>';
        
        echo ResourceManager :: get_instance()->get_resource_html(self :: get_application_path($this->get_application_name()) . 'resources/javascript/admin_browser.js');
        $this->display_footer();
    }

    function get_menu()
    {
        $menu = new PackageTypeLinksMenu($this->tab, $this->get_url(array(self :: PARAM_TAB => '__type__')));
        
        return $menu->render_as_tree();
    }

    function get_tabs()
    {
        $tabs = new DynamicTabsRenderer('admin');
        
        $package_list = PackageList :: get();
        $packages = $package_list->get_all_packages();
        foreach ($packages[$this->tab] as $package)
        {
            $manager_class = $package . '\Manager';
            if (! class_exists($manager_class))
            {
                $manager_class = $package . '\\' . Utilities :: get_package_name_from_namespace($package, true) . 'Manager';
                if (! class_exists($manager_class))
                {
                    continue;
                }
            }
            
            if (method_exists($manager_class, 'get_application_platform_admin_links'))
            {
                $links = $manager_class :: get_application_platform_admin_links();
                
                $index = 0;
                if (count($links['links']))
                {
                    $index ++;
                    $actions_tab = new DynamicActionsTab(Utilities :: get_package_name_from_namespace($package), Translation :: get('TypeName', null, $package), Theme :: get_image_path($package) . 'logo/22.png');
                    
                    if (isset($links['search']))
                    {
                        $search_form = new AdminSearchForm($this, $links['search'], $index);
                        $actions_tab->add_action(new DynamicAction(null, $search_form->display(), Theme :: get_image_path() . 'admin/search.png'));
                    }
                    
                    foreach ($links['links'] as $action)
                    {
                        $actions_tab->add_action($action);
                    }
                    
                    $tabs->add_tab($actions_tab);
                }
            }
        }
        return $tabs->render();
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add_help('admin_browser');
    }
}
?>
