<?php
namespace admin;

use common\libraries\BreadcrumbTrail;

use common\libraries\PlatformSetting;

use core\lynx\PackageList;

use common\libraries\CommonDataManager;

use common\libraries\Theme;

use common\libraries\Utilities;
use common\libraries\Application;
use common\libraries\BasicApplication;
use common\libraries\Translation;
use common\libraries\Request;
use common\libraries\Breadcrumb;
use common\libraries\DynamicVisualTabsRenderer;
use common\libraries\DynamicVisualTab;

/**
 * $Id: configurer.class.php 168 2009-11-12 11:53:23Z vanpouckesven $
 * 
 * @package admin.lib.admin_manager.component
 */
/**
 * Admin component
 */
class AdminManagerConfigurerComponent extends AdminManager
{
    const PARAM_TAB = 'tab';

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        $context = $this->get_context();
        
        if (! $this->get_user()->get_platformadmin())
        {
            $this->display_header();
            $this->display_error_message(Translation :: get('NotAllowed', array(), Utilities :: COMMON_LIBRARIES));
            $this->display_footer();
            exit();
        }
        
        $form = new ConfigurationForm($this->get_context(), 'config', 'post', $this->get_url(array(
                AdminManager :: PARAM_CONTEXT => $this->get_context(), self :: PARAM_TAB => $this->get_tab())));
        
        if ($form->validate())
        {
            $success = $form->update_configuration();
            $this->redirect(Translation :: get($success ? 'ObjectUpdated' : 'ObjectNotUpdated', array(
                    'OBJECT' => Translation :: get('Setting')), Utilities :: COMMON_LIBRARIES), ($success ? false : true), array(
                    Application :: PARAM_ACTION => AdminManager :: ACTION_CONFIGURE_PLATFORM, 
                    AdminManager :: PARAM_CONTEXT => $this->get_context()));
        }
        else
        {
            BreadcrumbTrail :: get_instance()->add(new Breadcrumb($this->get_url(array(
                    DynamicVisualTabsRenderer :: PARAM_SELECTED_TAB => $this->get_context())), Translation :: get('TypeName', null, $this->get_context())));
            
            $this->display_header();
            echo '<div style="float: left; width: 15%;">';
            echo $this->get_menu();
            
            echo '</div>';
            
            echo '<div style="float: right; width: 84%;">';
            $packages = PackageList :: get()->get_all_packages();
            
            $tabs = new DynamicVisualTabsRenderer('settings', $form->toHtml());
            foreach ($packages[$this->get_tab()] as $package)
            {
                if (PlatformSetting :: application_has_settings($package))
                {
                    $tabs->add_tab(new DynamicVisualTab($package, Translation :: get('TypeName', null, $package), Theme :: get_image_path($package) . 'logo/22.png', $this->get_url(array(
                            self :: PARAM_TAB => $this->get_tab(), self :: PARAM_CONTEXT => $package)), $this->get_context() == $package));
                }
            }
            echo $tabs->render();
            echo '</div>';
            
            echo '<script type="text/javascript">';
            echo '$(document).ready(function() {';
            echo '$(\':checkbox\').iphoneStyle({ checkedLabel: \'' . Translation :: get('ConfirmOn', array(), Utilities :: COMMON_LIBRARIES) . '\', uncheckedLabel: \'' . Translation :: get('ConfirmOff', array(), Utilities :: COMMON_LIBRARIES) . '\'});';
            echo '});';
            echo '</script>';
            
            $this->display_footer();
        }
    }

    function get_menu()
    {
        $menu = new PackageTypeSettingsMenu($this->get_tab(), $this->get_url(array(self :: PARAM_TAB => '__type__', 
                self :: PARAM_CONTEXT => null)));
        return $menu->render_as_tree();
    }

    function get_additional_parameters()
    {
        return array(AdminManager :: PARAM_CONTEXT);
    }

    function get_context()
    {
        $context = Request :: get(AdminManager :: PARAM_CONTEXT);
        if (! isset($context))
        {
            $packages = PackageList :: get()->get_all_packages();
            foreach ($packages[$this->get_tab()] as $package)
            {
                if (PlatformSetting :: application_has_settings($package))
                {
                    return $package;
                }
            }
        }
        else
        {
            return $context;
        }
    }

    function get_tab()
    {
        $tab = Request :: get(self :: PARAM_TAB);
        if (! isset($tab))
        {
            return 'core';
        }
        else
        {
            return $tab;
        }
    }

}
?>
