<?php
namespace admin;

use repository\ContentObjectRendition;
use repository\ContentObjectRenditionImplementation;
use repository\ContentObjectForm;

use common\libraries\Utilities;
use common\libraries\Breadcrumb;
use common\libraries\Display;
use common\libraries\Application;
use common\libraries\Translation;
use common\libraries\Request;
use common\libraries\AdministrationComponent;
/**
 * $Id: system_announcement_editor.class.php 168 2009-11-12 11:53:23Z vanpouckesven $
 * 
 * @package admin.lib.admin_manager.component
 */

class AdminManagerSystemAnnouncementEditorComponent extends AdminManager implements AdministrationComponent
{

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        $id = Request :: get(AdminManager :: PARAM_SYSTEM_ANNOUNCEMENT_ID);
        
        $user = $this->get_user();
        
        if (! $user->is_platform_admin())
        {
            Display :: not_allowed();
            exit();
        }
        
        if ($id)
        {
            $system_announcement_publication = $this->retrieve_system_announcement_publication($id);
            
            $content_object = $system_announcement_publication->get_publication_object();
            
            $form = ContentObjectForm :: factory(ContentObjectForm :: TYPE_EDIT, $content_object, 'edit', 'post', $this->get_url(array(
                    Application :: PARAM_ACTION => AdminManager :: ACTION_EDIT_SYSTEM_ANNOUNCEMENT, 
                    AdminManager :: PARAM_SYSTEM_ANNOUNCEMENT_ID => $system_announcement_publication->get_id())));
            if ($form->validate() || Request :: get('validated'))
            {
                $form->update_content_object();
                if ($form->is_version())
                {
                    $system_announcement_publication->set_content_object_id($content_object->get_latest_version_id());
                    $system_announcement_publication->update();
                }
                
                $publication_form = new SystemAnnouncementPublicationForm(SystemAnnouncementPublicationForm :: TYPE_SINGLE, $system_announcement_publication->get_publication_object(), $this->get_user(), $this->get_url(array(
                        Application :: PARAM_ACTION => AdminManager :: ACTION_EDIT_SYSTEM_ANNOUNCEMENT, 
                        AdminManager :: PARAM_SYSTEM_ANNOUNCEMENT_ID => $system_announcement_publication->get_id(), 
                        'validated' => '1')));
                $publication_form->set_system_announcement_publication($system_announcement_publication);
                
                if ($publication_form->validate())
                {
                    $success = $publication_form->update_content_object_publication();
                    $this->redirect(Translation :: get($success ? 'ObjectUpdated' : 'ObjectNotUpdated', array(
                            'OBJECT' => Translation :: get('SystemAnnouncementPublication')), Utilities :: COMMON_LIBRARIES), ($success ? false : true), array(
                            Application :: PARAM_ACTION => AdminManager :: ACTION_BROWSE_SYSTEM_ANNOUNCEMENTS));
                }
                else
                {
                    $this->display_header();
                    echo ContentObjectRenditionImplementation :: launch($system_announcement_publication->get_publication_object(), ContentObjectRendition :: FORMAT_HTML, ContentObjectRendition :: VIEW_FULL, $this);
                    $publication_form->display();
                    $this->display_footer();
                    exit();
                }
            }
            else
            {
                $this->display_header();
                $form->display();
                $this->display_footer();
            }
        }
        else
        {
            $this->display_error_page(htmlentities(Translation :: get('NoObjectSelected', array(
                    'OBJECT' => Translation :: get('SystemAnnouncement')), Utilities :: COMMON_LIBRARIES)));
        }
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add(new Breadcrumb($this->get_url(array(
                AdminManager :: PARAM_ACTION => AdminManager :: ACTION_BROWSE_SYSTEM_ANNOUNCEMENTS)), Translation :: get('AdminManagerSystemAnnouncementBrowserComponent')));
        $breadcrumbtrail->add_help('admin_system_announcements_editor');
    }

    function get_additional_parameters()
    {
        return array(AdminManager :: PARAM_SYSTEM_ANNOUNCEMENT_ID);
    }
}
?>