<?php
namespace admin;

use common\libraries\Theme;
use common\libraries\ToolbarItem;
use common\libraries\Toolbar;
use common\libraries\DatetimeUtilities;
use common\libraries\Utilities;
use common\libraries\Translation;
/**
 * $Id: system_announcement_publication_browser_table_cell_renderer.class.php 168 2009-11-12 11:53:23Z vanpouckesven $
 * 
 * @package admin.lib.admin_manager.component.system_announcement_publication_table
 */
/**
 * Cell renderer for the learning object browser table
 */
class SystemAnnouncementPublicationBrowserTableCellRenderer extends DefaultSystemAnnouncementPublicationTableCellRenderer
{
    /**
     * The repository browser component
     */
    private $browser;

    /**
     * Constructor
     * 
     * @param $browser ProfileManagerBrowserComponent
     */
    function __construct($browser)
    {
        parent :: __construct();
        $this->browser = $browser;
    }
    
    // Inherited
    function render_cell($column, $system_announcement_publication)
    {
        if ($column === SystemAnnouncementPublicationBrowserTableColumnModel :: get_modification_column())
        {
            return $this->get_modification_links($system_announcement_publication);
        }
        
        // Add special features here
        switch ($column->get_name())
        {
            case SystemAnnouncementPublication :: PROPERTY_PUBLISHED :
                return DatetimeUtilities :: format_locale_date(Translation :: get('DateFormatShort', array(), Utilities :: COMMON_LIBRARIES) . ', ' . Translation :: get('TimeNoSecFormat', array(), Utilities :: COMMON_LIBRARIES), $system_announcement_publication->get_published());
                break;
            case SystemAnnouncementPublication :: PROPERTY_CONTENT_OBJECT_ID :
                $title = parent :: render_cell($column, $system_announcement_publication);
                $title_short = $title;
                // if(strlen($title_short) > 53)
                // {
                // $title_short = mb_substr($title_short,0,50).'&hellip;';
                // }
                $title_short = Utilities :: truncate_string($title_short, 53, false);
                return '<a href="' . htmlentities($this->browser->get_admin_system_announcement_publication_viewing_url($system_announcement_publication)) . '" title="' . $title . '">' . $title_short . '</a>';
                break;
        }
        return parent :: render_cell($column, $system_announcement_publication);
    }

    /**
     * Gets the action links to display
     * 
     * @param $profile ContentObject The profile object for which the action links should be returned
     * @return string A HTML representation of the action links
     */
    private function get_modification_links($system_announcement_publication)
    {
        
        $toolbar = new Toolbar();
        
        if ($this->browser->get_user()->is_platform_admin() || $system_announcement_publication->get_publisher() == $this->browser->get_user()->get_id())
        {
            $toolbar->add_item(new ToolbarItem(Translation :: get('Edit', array(), Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_edit.png', $this->browser->get_system_announcement_publication_editing_url($system_announcement_publication), ToolbarItem :: DISPLAY_ICON));
            
            $toolbar->add_item(new ToolbarItem(Translation :: get('Delete', array(), Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_delete.png', $this->browser->get_system_announcement_publication_deleting_url($system_announcement_publication), ToolbarItem :: DISPLAY_ICON, true));
            
            if ($system_announcement_publication->is_hidden())
            {
                $visibility_img = 'action_invisible.png';
            }
            elseif ($system_announcement_publication->is_forever())
            {
                $visibility_img = 'action_visible.png';
            }
            else
            {
                $visibility_img = 'action_period.png';
            }
            
            $toolbar->add_item(new ToolbarItem(Translation :: get('Hide', array(), Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . $visibility_img, $this->browser->get_system_announcement_publication_visibility_url($system_announcement_publication), ToolbarItem :: DISPLAY_ICON));
        
        }
        return $toolbar->as_html();
    }
}
?>