<?php
namespace admin;

use core\lynx\PackageList;

use common\libraries\TreeMenuRenderer;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\OptionsMenuRenderer;
use common\libraries\Utilities;
use common\libraries\Translation;

use HTML_Menu;
use HTML_Menu_ArrayRenderer;

class PackageTypeLinksMenu extends HTML_Menu
{
    private $format;
    private $array_renderer;

    function __construct($current_type, $format)
    {
        $this->format = $format;
        
        parent :: __construct(array($this->get_items(PackageList :: get())));
        
        $this->array_renderer = new HTML_Menu_ArrayRenderer();
        $this->forceCurrentUrl($this->get_url($current_type));
    }

    private function get_items(PackageList $package_list)
    {
        $item = array();
        $item['class'] = 'category';
        
        if (! is_null($package_list->get_type_icon()))
        {
            $item['style'] = 'background-image: url(' . $package_list->get_type_icon() . ')';
        }
        
        $item['title'] = $package_list->get_type_name();
        $item['url'] = $this->get_url($package_list->get_type());
        $item[OptionsMenuRenderer :: KEY_ID] = $package_list->get_type();
        
        $sub_items = array();
        
        foreach ($package_list->get_children() as $child)
        {
            $children = $this->get_items($child);
            if ($children)
            {
                $sub_items[] = $children;
            }
        }
        
        if (count($sub_items) > 0)
        {
            $item['sub'] = $sub_items;
        }
        
        $has_links = false;
        $packages = $package_list->get_packages();
        foreach ($packages as $package)
        {
            $manager_class = $package . '\Manager';
            if (! class_exists($manager_class))
            {
                $manager_class = $package . '\\' . Utilities :: get_package_name_from_namespace($package, true) . 'Manager';
                if (! class_exists($manager_class))
                {
                    continue;
                }
            }
            
            if (method_exists($manager_class, 'get_application_platform_admin_links'))
            {
                $links = $manager_class :: get_application_platform_admin_links();
                if (count($links['links']) > 0)
                {
                    $has_links = true;
                    break;
                }
            }
        }
        
        if ($has_links || (count($sub_items) > 0))
        {
            if (! $has_links)
            {
                unset($item['url']);
            }
            return $item;
        }
        
        return false;
    }

    private function get_url($type)
    {
        return (str_replace('__type__', $type, $this->format));
    }

    function get_breadcrumbs()
    {
        $trail = BreadcrumbTrail :: get_instance();
        // $this->render($this->array_renderer, 'urhere');
        // $breadcrumbs = $this->array_renderer->toArray();
        // foreach ($breadcrumbs as $crumb)
        // {
        // $str = Translation :: get('MyRepository');
        // if (substr($crumb['title'], 0, strlen($str)) == $str)
        // continue;
        // $trail->add(new Breadcrumb($crumb['url'], substr($crumb['title'], 0, strpos($crumb['title'], '('))));
        // }
        return $trail;
    }

    function render_as_tree()
    {
        $renderer = new TreeMenuRenderer(Utilities :: get_classname_from_namespace(__CLASS__, true));
        $this->render($renderer, 'sitemap');
        return $renderer->toHTML();
    }
}
?>