<?php

namespace admin;

use common\libraries\MessageLogger;
use common\libraries\Theme;
use common\libraries\Translation;
use common\libraries\Utilities;

/**
 * Abstract class that describes an action for a package. Makes use of the message logger to log messages.
 * 
 * @author Sven Vanpoucke
 */
abstract class PackageAction extends MessageLogger
{

    /**
     * Verifies the package dependencies
     * 
     * @param $package_attributes
     * @return boolean
     */
    function verify_dependencies($package_attributes)
    {
        $verifier = new PackageDependencyVerifier($package_attributes);
        
        $success = $this->execute_dependency_check($verifier);
        
        $this->add_message($verifier->get_logger()->render());
        
        if (! $success)
        {
            return $this->action_failed('dependencies', Translation :: get('PackageDependenciesFailed'));
        }
        
        return $this->action_successful('dependencies', Translation :: get('PackageDependenciesVerified'));
    }

    /**
     * Sets the action as failed for a given block with a given message
     * 
     * @param $type String
     * @param $error_message String
     *
     * @return false
     */
    function action_failed($type, $error_message = null)
    {
        $this->process_result($type, $error_message, self :: TYPE_ERROR);
        return false;
    }

    /**
     * Sets the action for a given block as success with a given message
     * 
     * @param $type String
     * @param $message String
     *
     * @return true
     */
    function action_successful($type, $message = null)
    {
        $this->process_result($type, $message);
        return true;
    }

    /**
     * Processes a result for a given block
     * 
     * @param $type String
     */
    function process_result($type = '', $final_message = null, $final_message_type = self :: TYPE_CONFIRM)
    {
        if ($final_message)
        {
            $this->add_message($final_message, $final_message_type);
        }
        
        $html[] = '<div class="content_object" style="padding: 15px 15px 15px 76px; background-image: url(' . Theme :: get_image_path() . 'place_' . $type . '.png);">';
        $html[] = '<div class="title">' . Translation :: get(Utilities :: underscores_to_camelcase($type)) . '</div>';
        $html[] = '<div class="description">';
        $html[] = $this->render();
        $html[] = '</div>';
        $html[] = '</div>';
        
        echo implode("\n", $html);
        
        flush();
    }

    /**
     * Executes the check on the dependency verifier for the current action
     * 
     * @param $package_dependency_verifier PackageDependencyVerifier
     */
    abstract function execute_dependency_check(PackageDependencyVerifier $package_dependency_verifier);

}

?>
