<?php
namespace admin;

use common\libraries\CommonDataManager;

use common\libraries\Translation;
use common\libraries\Request;

set_time_limit(0);

/**
 * Package installation
 * 
 * @author Hans De Bisschop - Erasmus Hogeschool Brussel
 * @author Magali Gillard - Erasmus Hogeschool Brussel
 * @author Sven Vanpoucke - Hogeschool Gent - Cleanup, code refactoring and bugfixes, comments
 * @package admin.lib.package_installer
 */
class PackageInstaller extends PackageSourceAction
{

    /**
     * Runs the package installer
     * 
     * @return boolean
     */
    function run()
    {
        if (parent :: run())
        {
            return $this->action_successful('finished', Translation :: get('PackageCompletelyInstalled'));
        }
        else
        {
            return $this->action_failed('failed', Translation :: get('PackageInstallFailed'));
        }
    }

    /**
     * Initializes the package installer
     * 
     * @return boolean
     */
    function initialize()
    {
        if (! parent :: initialize())
        {
            return false;
        }
        
        // Check registration
        if ($this->is_package_registered())
        {
            return $this->action_failed('initialization', Translation :: get('PackageIsAlreadyRegistered'));
        }
        else
        {
            $this->add_message(Translation :: get('PackageNotYetRegistered'));
        }
        
        return $this->action_successful('initialization', Translation :: get('PackageInstallInitialized'));
    }

    /**
     * Checks if the package is registered
     * 
     * @return boolean
     */
    function is_package_registered()
    {
        return CommonDataManager :: is_registered($this->get_package_source()->get_attributes()->get_context());
    }

    /**
     * Executes the installable check on the package dependency verifier
     * 
     * @param $package_dependency_verifier PackageDependencyVerifier
     *
     * @return boolean
     */
    function execute_dependency_check(PackageDependencyVerifier $package_dependency_verifier)
    {
        return $package_dependency_verifier->is_installable();
    }

    /**
     * Installs the package
     * 
     * @return boolean
     */
    function process()
    {
        $package_source = $this->get_package_source();
        $package_attributes = $package_source->get_attributes();
        
        $package = PackageInstallerType :: factory($this, $package_attributes->get_section(), $package_source);
        
        return $package->install();
    }

    /**
     * Returns the name and type of the package
     * 
     * @param String[]
     */
    function get_package_type_and_name()
    {
        return Request :: get(PackageManager :: PARAM_CONTEXT);
    }

}
?>