<?php
namespace admin;

use common\libraries\CommonDataManager;
use common\libraries\ArrayResultSet;

use menu\ItemTitles;
use menu\ItemTitle;
use menu\ApplicationItem;

use common\libraries\Utilities;
use common\libraries\Application;
use common\libraries\BasicApplication;
use common\libraries\Translation;
use common\libraries\package\Installer;
use common\libraries\EqualityCondition;
use common\libraries\AndCondition;
use common\libraries\Path;
use menu\NavigationItem;

/**
 * $Id: application.class.php 179 2009-11-12 13:51:39Z vanpouckesven $
 * 
 * @package admin.lib.package_installer.type
 */

class PackageInstallerApplicationType extends PackageInstallerType
{

    function install()
    {
        $source = $this->get_source();
        $attributes = $source->get_attributes();
        $application_name = $attributes->get_code();
        
        $installer = Installer :: factory($attributes->get_context(), array());
        if (! $installer->install())
        {
            return $this->get_parent()->action_failed('database', Translation :: get('ApplicationInitilizationFailed'));
        }
        else
        {
            $this->add_message($installer->retrieve_message());
            $this->action_successful('database');
        }
        
        $installer->set_message(array());
        
        if (! $installer->post_process())
        {
            return $this->get_parent()->action_failed('processing', Translation :: get('ApplicationPostProcessingFailed'));
        }
        
        $this->add_message('<span class="subtitle">' . Translation :: get('Settings') . '</span>');
        
        if (! $this->set_version())
        {
            $this->get_parent()->add_message(Translation :: get('ApplicationVersionNotSet'), PackageInstaller :: TYPE_WARNING);
        }
        else
        {
            $this->get_parent()->add_message(Translation :: get('ApplicationVersionSet'));
        }
        
        if (! $this->add_navigation_item())
        {
            $this->get_parent()->add_message(Translation :: get('ObjectNotAdded', array(
                    'OBJECT' => Translation :: get('ApplicationMenuItem')), Utilities :: COMMON_LIBRARIES), PackageInstaller :: TYPE_WARNING);
        }
        else
        {
            $this->get_parent()->add_message(Translation :: get('ObjectAdded', array(
                    'OBJECT' => Translation :: get('ApplicationMenuItem')), Utilities :: COMMON_LIBRARIES));
        }
        
        $this->add_message('');
        
        $this->add_message($installer->retrieve_message());
        
        $this->action_successful('processing');
        
        return true;
    }

    static function get_path($application_name)
    {
        return BasicApplication :: get_application_path($application_name);
    }

    function set_version()
    {
        $source = $this->get_source();
        $attributes = $source->get_attributes();
        
        // We need to do this to make sure that the latest registration is also
        // cached.
        CommonDataManager :: init_registrations();
        
        $registration = CommonDataManager :: get_registration($attributes->get_context());
        $registration->set_version($attributes->get_version());
        return $registration->update();
    }

    function add_navigation_item()
    {
        $attributes = $this->get_source()->get_attributes();
        
        $menu_item = new ApplicationItem();
        $item_title = new ItemTitle();
        $item_title->set_title(Translation :: get('TypeName', null, $attributes->get_context(), Translation :: get_instance()->get_language()));
        $item_title->set_isocode(Translation :: get_instance()->get_language());
        $item_titles = new ItemTitles(new ArrayResultSet(array($item_title)));
        
        $menu_item->set_titles($item_titles);
        $menu_item->set_application($attributes->get_code());
        $menu_item->set_parent(0);
        $menu_item->set_use_translation(1);
        
        return $menu_item->create();
    }
}
?>