<?php
namespace admin;

use common\libraries\Registration;
use common\libraries\CommonDataManager;
use common\libraries\Utilities;
use common\libraries\Application;
use common\libraries\Translation;
use common\libraries\Request;
use common\libraries\Breadcrumb;

/**
 *
 * @package admin.lib.package_manager.component
 * @author Hans De Bisschop
 */
class PackageManagerActivatorComponent extends PackageManager
{

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        if (! AdminRights :: is_allowed(AdminRights :: RIGHT_VIEW))
        {
            $this->display_header();
            $this->display_error_message(Translation :: get('NotAllowed', array(), Utilities :: COMMON_LIBRARIES));
            $this->display_footer();
            exit();
        }
        
        $ids = Request :: get(PackageManager :: PARAM_REGISTRATION);
        $failures = 0;
        
        if (! empty($ids))
        {
            if (! is_array($ids))
            {
                $ids = array($ids);
            }
            
            foreach ($ids as $id)
            {
                $registration = CommonDataManager :: retrieve(Registration :: class_name(), (int) $id);
                
                if ($registration->can_be_activated())
                {
                    $registration->set_status(Registration :: STATUS_ACTIVE);
                    if (! $registration->update())
                    {
                        $failures ++;
                    }
                }
                else
                {
                    $failures ++;
                }
            }
            
            if ($failures)
            {
                if (count($ids) == 1)
                {
                    $message = 'ObjectNotActivated';
                    $parameter = array('OBJECT' => Translation :: get('Registration'));
                }
                else
                {
                    $message = 'ObjectsNotActivated';
                    $parameter = array('OBJECTS' => Translation :: get('Registrations'));
                }
            }
            else
            {
                if (count($ids) == 1)
                {
                    $message = 'ObjectActivated';
                    $parameter = array('OBJECT' => Translation :: get('Registration'));
                }
                else
                {
                    $message = 'ObjectsActivated';
                    $parameter = array('OBJECTS' => Translation :: get('Registrations'));
                }
            }
            
            $this->redirect(Translation :: get($message, $parameter, Utilities :: COMMON_LIBRARIES), ($failures ? true : false), array(
                    Application :: PARAM_ACTION => AdminManager :: ACTION_MANAGE_PACKAGES, 
                    PackageManager :: PARAM_PACKAGE_ACTION => PackageManager :: ACTION_BROWSE_PACKAGES));
        }
        else
        {
            $this->display_error_page(htmlentities(Translation :: get('NoObjectSelected', array(
                    'OBJECT' => Translation :: get('Registration')), Utilities :: COMMON_LIBRARIES)));
        }
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add(new Breadcrumb($this->get_url(array(
                PackageManager :: PARAM_PACKAGE_ACTION => PackageManager :: ACTION_BROWSE_PACKAGES)), Translation :: get('PackageManagerBrowserComponent')));
        $breadcrumbtrail->add_help('admin_package_manager_activator');
    }

    function get_additional_parameters()
    {
        return array(PackageManager :: PARAM_REGISTRATION);
    }
}
?>