<?php
namespace admin;

use common\libraries\Registration;

use common\libraries\Utilities;
use common\libraries\Translation;
use common\libraries\Path;
use common\libraries\Toolbar;
use common\libraries\ToolbarItem;
use common\libraries\Theme;
use common\libraries\PlatformSetting;
/**
 * $Id: language_registration_browser_table_cell_renderer.class.php 168 2009-11-12 11:53:23Z vanpouckesven $
 * 
 * @package admin.lib.package_manager.component.registration_browser
 */
/**
 * Cell rendere for the learning object browser table
 */
class LanguageRegistrationBrowserTableCellRenderer extends DefaultRegistrationTableCellRenderer
{
    /**
     * The repository browser component
     */
    private $browser;

    /**
     * Constructor
     * 
     * @param $browser RepositoryManagerBrowserComponent
     */
    function __construct($browser)
    {
        parent :: __construct();
        $this->browser = $browser;
    }
    
    // Inherited
    function render_cell($column, $registration)
    {
        if ($column === LanguageRegistrationBrowserTableColumnModel :: get_modification_column())
        {
            return $this->get_modification_links($registration);
        }
        
        switch ($column->get_name())
        {
            case Registration :: PROPERTY_NAME :
                $language = AdminDataManager :: get_instance()->retrieve_language_from_isocode($registration->get_name());
                return $language->get_original_name();
        }
        
        return parent :: render_cell($column, $registration);
    }

    function get_browser()
    {
        return $this->browser;
    }

    /**
     * Gets the action links to display
     * 
     * @param $content_object ContentObject The learning object for which the action links should be returned
     * @return string A HTML representation of the action links
     */
    private function get_modification_links($registration)
    {
        $toolbar = new Toolbar();
        
        $toolbar->add_item(new ToolbarItem(Translation :: get('ViewRegistration'), Theme :: get_common_image_path() . 'action_details.png', $this->browser->get_registration_view_url($registration), ToolbarItem :: DISPLAY_ICON));
        
        if (! $registration->is_up_to_date())
        {
            $toolbar->add_item(new ToolbarItem(Translation :: get('Update', array(), Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_update.png', $this->browser->get_registration_update_url($registration), ToolbarItem :: DISPLAY_ICON));
        }
        else
        {
            $toolbar->add_item(new ToolbarItem(Translation :: get('PackageIsAlreadyUpToDate'), Theme :: get_common_image_path() . 'action_update_na.png', '', ToolbarItem :: DISPLAY_ICON));
        }
        
        if (Utilities :: camelcase_to_underscores($registration->get_name()) == PlatformSetting :: get('platform_language'))
        {
            return $toolbar->as_html();
        }
        
        if ($registration->is_active())
        {
            $toolbar->add_item(new ToolbarItem(Translation :: get('Deactivate', array(), Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_deactivate.png', $this->browser->get_registration_deactivation_url($registration), ToolbarItem :: DISPLAY_ICON));
        }
        else
        {
            $toolbar->add_item(new ToolbarItem(Translation :: get('Activate', array(), Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_activate.png', $this->browser->get_registration_activation_url($registration), ToolbarItem :: DISPLAY_ICON));
        
        }
        $toolbar->add_item(new ToolbarItem(Translation :: get('Deinstall', array(), Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_deinstall.png', $this->browser->get_registration_removal_url($registration), ToolbarItem :: DISPLAY_ICON, true));
        
        return $toolbar->as_html();
    }
}
?>