<?php
namespace admin;

use common\libraries\CommonDataManager;
use common\libraries\Utilities;
use common\libraries\Translation;
use common\libraries\Path;
use common\libraries\Toolbar;
use common\libraries\ToolbarItem;
use common\libraries\Theme;
/**
 * $Id: remote_package_browser_table_cell_renderer.class.php 168 2009-11-12 11:53:23Z vanpouckesven $
 * 
 * @package admin.lib.package_manager.component.remote_package_browser
 */
/**
 * Cell rendere for the learning object browser table
 */
class RemotePackageBrowserTableCellRenderer extends DefaultRemotePackageTableCellRenderer
{
    /**
     * The repository browser component
     */
    private $browser;

    /**
     * Constructor
     * 
     * @param $browser RepositoryManagerBrowserComponent
     */
    function __construct($browser)
    {
        parent :: __construct();
        $this->browser = $browser;
    }
    
    // Inherited
    function render_cell($column, $remote_package)
    {
        if ($column === RemotePackageBrowserTableColumnModel :: get_modification_column())
        {
            return $this->get_modification_links($remote_package);
        }
        
        // Add special features here
        switch ($column->get_name())
        {
            case RemotePackage :: PROPERTY_DESCRIPTION :
                $description = strip_tags(parent :: render_cell($column, $remote_package));
                return Utilities :: truncate_string($description);
        }
        
        return parent :: render_cell($column, $remote_package);
    }

    /**
     * Gets the action links to display
     * 
     * @param $content_object ContentObject The learning object for which the action links should be returned
     * @return string A HTML representation of the action links
     */
    private function get_modification_links($remote_package)
    {
        $toolbar = new Toolbar();
        
        if (! CommonDataManager :: is_registered($remote_package->get_context()))
        {
            $toolbar->add_item(new ToolbarItem(Translation :: get('Install', array(), Utilities :: COMMON_LIBRARIES), Theme :: get_image_path() . 'action_install.png', $this->browser->get_remote_package_installation_url($remote_package), ToolbarItem :: DISPLAY_ICON));
        }
        
        return $toolbar->as_html();
    }
}
?>