<?php
namespace admin;

use common\libraries\CommonDataManager;

use repository\ContentObject;

use common\libraries\Path;
use common\libraries\Translation;
use common\libraries\Database;
use common\libraries\Filesystem;

use repository\RepositoryManager;
use repository\RepositoryDataManager;

use DOMDocument;

/**
 * $Id: content_object.class.php 168 2009-11-12 11:53:23Z vanpouckesven $
 * 
 * @package admin.lib.package_remover.type
 */
class PackageContentObjectRemover extends PackageRemover
{

    /**
     * Deletes the actual package
     * 
     * @return boolean
     */
    function delete()
    {
        if (! $this->delete_content_objects())
        {
            return $this->action_failed('repository', Translation :: get('ContentObjectDeletionFailed'));
        }
        else
        {
            $this->action_successful('repository', Translation :: get('ContentObjectSuccessfullyDeleted'));
        }
        
        if (! $this->remove_storage_units())
        {
            return $this->action_failed('database', Translation :: get('StorageUnitsDeletionFailed'));
        }
        else
        {
            return $this->action_successful('database', Translation :: get('StorageUnitsSuccessfullyDeleted'));
        }
    }

    /**
     * Initializes the remover
     * 
     * @return boolean
     */
    function initialize()
    {
        if (! parent :: initialize(false))
        {
            return false;
        }
        
        $registration = $this->get_registration();
        
        // Disable content object creation
        $setting = CommonDataManager :: retrieve_setting_from_variable_name('allow_' . $registration->get_name() . '_creation', ContentObject :: get_content_object_type_namespace($registration->get_name()));
        if ($setting)
        {
            if (! $setting->delete())
            {
                return $this->action_failed('initilization', Translation :: get('CouldNotDisableContentObjectCreation'));
            }
        }
        
        $this->add_message(Translation :: get('DisabledContentObjectCreation'));
        
        return $this->action_successful('initilization', Translation :: get('PackageRemovalInitialized'));
    }

    /**
     * Deletes all the created content objects from this type
     * 
     * @return boolean
     */
    function delete_content_objects()
    {
        $registration = $this->get_registration();
        
        $rdm = RepositoryDataManager :: get_instance();
        $content_objects = $rdm->retrieve_type_content_objects($registration->get_name());
        
        while ($content_object = $content_objects->next_result())
        {
            $versions = $content_object->get_content_object_versions();
            
            foreach ($versions as $version)
            {
                if (! $version->delete_links())
                {
                    return $this->action_failed('repository', Translation :: get('CouldNotDeleteContentObjectLinks'));
                }
                
                if (! $version->delete())
                {
                    return $this->action_failed('repository', Translation :: get('CouldNotDeleteContentObject'));
                }
            }
            
            $this->add_message(Translation :: get('DeletedContentObject', array(
                    'OBJECT' => $content_object->get_title())));
        }
        
        return true;
    }

    /**
     * Removes the content object's storage units
     * 
     * @return boolean
     */
    function remove_storage_units()
    {
        $registration = $this->get_registration();
        $database = RepositoryDataManager :: get_instance();
        
        $path = Path :: get_repository_content_object_path() . $registration->get_name() . '/php/install/';
        $files = Filesystem :: get_directory_content($path, Filesystem :: LIST_FILES);
        
        foreach ($files as $file)
        {
            if ((substr($file, - 3) == 'xml'))
            {
                $doc = new DOMDocument();
                $doc->load($file);
                $object = $doc->getElementsByTagname('object')->item(0);
                $name = $object->getAttribute('name');
                
                if (! $database->drop_storage_unit($name))
                {
                    return $this->action_failed('repository', Translation :: get('CouldNotDropStorageUnit', array(
                            'STORAGE_UNIT' => $name)));
                }
                
                $this->add_message(Translation :: get('DroppedStorageUnit', array('STORAGE_UNIT' => $name)));
            
            }
        }
        
        return true;
    }

    /**
     * Returns the path to the package folder
     * 
     * @return String or null if nothing has to be removed
     */
    function get_package_folder_path()
    {
        return Path :: get(SYS_PATH) . 'repository/content_object/' . $this->get_registration()->get_name() . '/';
    }
}
?>