<?php
namespace admin;

use common\libraries\Path;
use common\libraries\Utilities;

use PEAR;
use XML_Unserializer;
use Exception;

class PackageInfo
{
    private $context;
    private $package;

    function __construct($context)
    {
        $this->context = $context;
    }

    function get_package_info()
    {
        $path = Path :: namespace_to_full_path($this->get_context()) . 'php/package/package.info';
        
        if (file_exists($path))
        {
            $xml_data = file_get_contents($path);
            if ($xml_data)
            {
                $unserializer = new XML_Unserializer();
                $unserializer->setOption(XML_UNSERIALIZER_OPTION_COMPLEXTYPE, 'array');
                $unserializer->setOption(XML_UNSERIALIZER_OPTION_ATTRIBUTES_PARSE, true);
                $unserializer->setOption(XML_UNSERIALIZER_OPTION_RETURN_RESULT, true);
                $unserializer->setOption(XML_UNSERIALIZER_OPTION_GUESS_TYPES, true);
                $unserializer->setOption(XML_UNSERIALIZER_OPTION_FORCE_ENUM, array('dependency', 'author'));
                
                // userialize the document
                $status = $unserializer->unserialize($xml_data);
                
                if (PEAR :: isError($status))
                {
                    throw new Exception($status->getMessage());
                }
                else
                {
                    return $unserializer->getUnserializedData();
                }
            }
            else
            {
                return false;
            }
        }
        else
        {
            return false;
        }
    }

    function get_context()
    {
        return $this->context;
    }

    function get_package()
    {
        if (! isset($this->package))
        {
            $package_info = $this->get_package_info();
            
            $package_info['package']['authors'] = serialize($package_info['package']['authors']['author']);
            $package_info['package']['cycle'] = serialize($package_info['package']['cycle']);
            $package_info['package']['dependencies'] = serialize($package_info['package']['dependencies']);
            
            if (isset($package_info['package']['extra']))
            {
                $package_info['package']['extra'] = serialize($package_info['package']['extra']);
            }
            
            $this->package = new RemotePackage();
            $this->package->set_default_properties($package_info['package']);
        }
        return $this->package;
    }

    static function get($context)
    {
        $package_info = new self($context);
        return $package_info->get_package();
    }
}
?>
