<?php
namespace admin;

use core\lynx\package\Package;

use common\libraries\CommonDataManager;

use common\libraries\Registration;

use common\libraries\Utilities;
use common\libraries\Translation;
use common\libraries\package\Installer;
use common\libraries\Filesystem;
use common\libraries\Path;
/**
 * $Id: admin_installer.class.php 168 2009-11-12 11:53:23Z vanpouckesven $
 *
 * @package admin.install
 */
/**
 * This installer can be used to create the storage structure for the users application.
 */
class AdminInstaller extends Installer
{

    /**
     * Constructor
     */
    function __construct($values)
    {
        parent :: __construct($values, AdminDataManager :: get_instance());
    }

    /**
     * Runs the install-script.
     */
    function install_extra()
    {

        // Add the default language entries in the database
        if (! $this->create_languages())
        {
            return false;
        }
        else
        {
            $this->add_message(self :: TYPE_NORMAL,
                    Translation :: get('ObjectsAdded', array('OBJECTS' => Translation :: get('Languages')),
                            Utilities :: COMMON_LIBRARIES));
        }

        // Update the default settings to the database
        if (! $this->update_settings())
        {
            return false;
        }
        else
        {
            $this->add_message(self :: TYPE_NORMAL,
                    Translation :: get('ObjectsAdded', array('OBJECTS' => Translation :: get('DefaultSettings')),
                            Utilities :: COMMON_LIBRARIES));
        }

        return true;
    }

    function create_languages()
    {
        $language_path = Path :: get_common_libraries_path() . 'resources/i18n/';
        $language_files = Filesystem :: get_directory_content($language_path, Filesystem :: LIST_FILES, false);

        foreach ($language_files as $language_file)
        {
            $file_info = pathinfo($language_file);
            $language_info_file = $language_path . $file_info['filename'] . '.info';

            if (file_exists($language_info_file) && $file_info['extension'] == 'info')
            {
                $dom_document = new \DOMDocument('1.0', 'UTF-8');
                $dom_document->load($language_info_file);
                $dom_xpath = new \DOMXPath($dom_document);

                $language_node = $dom_xpath->query('/packages/package')->item(0);

                $language = new Language();
                $language->set_original_name($dom_xpath->query('name', $language_node)->item(0)->nodeValue);
                $language->set_english_name($dom_xpath->query('extra/english', $language_node)->item(0)->nodeValue);
                $language->set_family($dom_xpath->query('category', $language_node)->item(0)->nodeValue);
                $language->set_isocode($dom_xpath->query('extra/isocode', $language_node)->item(0)->nodeValue);
                $language->set_available('1');

                if ($language->create())
                {
                    $this->add_message(self :: TYPE_NORMAL,
                            Translation :: get('ObjectAdded', array('OBJECT' => Translation :: get('Language')),
                                    Utilities :: COMMON_LIBRARIES) . ' ' . $language->get_english_name());
                }
                else
                {
                    return false;
                }
            }
        }

        return true;
    }

    function update_settings()
    {
        $values = $this->get_form_values();

        $settings = array();
        $settings[] = array('admin', 'site_name', $values['platform_name']);
        $settings[] = array('admin', 'server_type', 'production');
        $settings[] = array('admin', 'platform_language', $values['platform_language']);
        $settings[] = array('admin', 'version', '3.1');
        $settings[] = array('admin', 'theme', 'aqua');

        $settings[] = array('admin', 'institution', $values['organization_name']);
        $settings[] = array('admin', 'institution_url', $values['organization_url']);

        $settings[] = array('admin', 'show_administrator_data', 'true');
        $settings[] = array('admin', 'administrator_firstname', $values['admin_firstname']);
        $settings[] = array('admin', 'administrator_surname', $values['admin_surname']);
        $settings[] = array('admin', 'administrator_email', $values['admin_email']);
        $settings[] = array('admin', 'administrator_telephone', $values['admin_phone']);

        // $settings[] = array('user', 'allow_password_retrieval',
        // $values['encrypt_password']);
        $settings[] = array('user', 'allow_registration', $values['self_reg']);

        foreach ($settings as $setting)
        {
            $setting_object = CommonDataManager :: retrieve_setting_from_variable_name($setting[1], $setting[0]);
            $setting_object->set_application($setting[0]);
            $setting_object->set_variable($setting[1]);
            $setting_object->set_value($setting[2]);

            if (! $setting_object->update())
            {
                return false;
            }
        }

        return true;
    }

    function get_additional_installers()
    {
        $installers = array();
        $installers[] = new \admin\language\Installer($this->get_form_values());
        return $installers;
    }
}
?>