<?php
namespace admin;

use common\libraries\CommonDataManager;

use common\libraries\Registration;

use common\libraries\WebApplication;

use common\libraries\PlatformSetting;

use repository\ContentObject;
use repository\RepositoryDataManager;

use common\libraries\Utilities;
use common\libraries\Translation;
use common\libraries\Session;
use common\libraries\EqualityCondition;
use common\libraries\AndCondition;
use common\libraries\Theme;
use common\libraries\Application;
/**
 * Simple connector class to facilitate rendering settings forms by preprocessing data from the datamanagers to a simple
 * array format.
 * 
 * @author Hans De Bisschop
 * @package admin.settings $Id: settings_admin_connector.class.php 168 2009-11-12 11:53:23Z vanpouckesven $
 */

class SettingsConnector
{

    function get_languages()
    {
        return AdminDataManager :: get_languages();
    }

    function get_themes()
    {
        $options = Theme :: get_themes();
        
        return $options;
    }

    function get_portal_homes()
    {
        $options = array();
        $rdm = RepositoryDataManager :: get_instance();
        $condition = new EqualityCondition(ContentObject :: PROPERTY_OWNER_ID, Session :: get_user_id());
        $objects = $rdm->retrieve_type_content_objects('portal_home', $condition);
        
        if ($objects->size() == 0)
        {
            $options[0] = Translation :: get('CreatePortalHomeFirst');
        }
        else
        {
            while ($object = $objects->next_result())
            {
                $options[$object->get_id()] = $object->get_title();
            }
        }
        
        return $options;
    }

    function get_time_zones()
    {
        $content = file_get_contents(dirname(__FILE__) . '/timezones.txt');
        $content = explode("\n", $content);
        
        $timezones = array();
        
        foreach ($content as $timezone)
        {
            $timezone = trim($timezone);
            $timezones[$timezone] = $timezone;
        }
        
        return $timezones;
    }

    function get_active_applications()
    {
        $registrations = CommonDataManager :: get_registrations_by_type(Registration :: TYPE_APPLICATION);
        
        $options = array();
        $options['home'] = Translation :: get('Homepage', array(), 'home');
        
        foreach ($registrations as $registration)
        {
            if ($registration->is_active())
            {
                $options[$registration->get_name()] = Translation :: get('TypeName', null, $registration->get_context());
            }
        }
        
        asort($options);
        
        return $options;
    }

    function get_working_hours()
    {
        $start = 0;
        $end = 24;
        $working_hours = array();
        
        for($i = $start; $i <= $end; $i ++)
        {
            $working_hours[$i] = $i;
        }
        
        return $working_hours;
    }

    function is_allowed_to_change_platform_language()
    {
        return PlatformSetting :: get('allow_user_change_platform_language', 'user') == 1;
    }

    function is_allowed_to_change_platform_timezone()
    {
        return PlatformSetting :: get('allow_user_change_platform_timezone', 'user') == 1;
    }

    function is_allowed_to_change_theme()
    {
        return PlatformSetting :: get('allow_user_theme_selection', 'user') == 1;
    }
}
?>