<?php
namespace admin;

use common\libraries\Utilities;
use common\libraries\InequalityCondition;
use common\libraries\EqualityCondition;
use common\libraries\PlatformSetting;

use tracking\SimpleTracker;
/**
 *
 * @package admin.trackers
 */
class OnlineTracker extends SimpleTracker
{
    const CLASS_NAME = __CLASS__;
    
    const PARAM_USER = 'user';
    const PARAM_TIME = 'time';
    
    const PROPERTY_USER_ID = 'user_id';
    const PROPERTY_LAST_ACCESS_DATE = 'last_access_date';

    /**
     * Inherited
     */
    static function get_default_property_names()
    {
        return array(self :: PROPERTY_USER_ID, self :: PROPERTY_LAST_ACCESS_DATE);
    }

    function run(array $parameters = array())
    {
        $time = time();
        $parameters[self :: PARAM_TIME] = $time;
        
        $this->remove_old_trackers($time);
        
        $condition = new EqualityCondition(self :: PROPERTY_USER_ID, $parameters[self :: PARAM_USER]);
        $existing_online_tracker = $this->retrieve_tracker_items_result_set($condition)->next_result();
        
        if ($existing_online_tracker)
        {
            $this->validate_parameters($parameters, $existing_online_tracker);
            return $existing_online_tracker->update();
        }
        else
        {
            $this->validate_parameters($parameters, $this);
            return $this->create();
        }
    }

    function validate_parameters(array $parameters = array(), OnlineTracker $object = null)
    {
        $object->set_user_id($parameters[self :: PARAM_USER]);
        $object->set_last_access_date($parameters[self :: PARAM_TIME]);
    }

    function remove_old_trackers($time)
    {
        $active_time = PlatformSetting :: get('timelimit');
        $past_time = strtotime('-' . $active_time . ' seconds', $time);
        
        $this->empty_tracker_before_date($past_time);
    }

    function empty_tracker($event)
    {
        return $this->remove();
    }

    /**
     * Inherited
     * 
     * @see MainTracker :: empty_tracker
     */
    function empty_tracker_before_date($date)
    {
        $condition = new InEqualityCondition(self :: PROPERTY_LAST_ACCESS_DATE, InEqualityCondition :: LESS_THAN_OR_EQUAL, $date);
        return $this->remove($condition);
    }

    function update()
    {
        $condition = new EqualityCondition(self :: PROPERTY_USER_ID, $this->get_user_id());
        return $this->get_data_manager()->update_tracker_item_with_condition($this, $condition);
    }
    
    // Properties getters and setters
    function get_user_id()
    {
        return $this->get_default_property(self :: PROPERTY_USER_ID);
    }

    function set_user_id($user_id)
    {
        $this->set_default_property(self :: PROPERTY_USER_ID, $user_id);
    }

    function get_last_access_date()
    {
        return $this->get_default_property(self :: PROPERTY_LAST_ACCESS_DATE);
    }

    function set_last_access_date($last_access_date)
    {
        $this->set_default_property(self :: PROPERTY_LAST_ACCESS_DATE, $last_access_date);
    }

    static function get_table_name()
    {
        return Utilities :: get_classname_from_namespace(self :: CLASS_NAME, true);
    }
}
?>