<?php

namespace application\personal_calendar;

use common\libraries\DelegateComponent;

use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Utilities;
use repository\ContentObjectForm;
use common\libraries\Application;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
/**
 * $Id: editor.class.php 201 2009-11-13 12:34:51Z chellee $
 * 
 * @package application.personal_calendar.personal_calendar_manager.component
 */
class PersonalCalendarManagerEditorComponent extends PersonalCalendarManager implements DelegateComponent
{

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        
        $user = $this->get_user();
        
        $id = Request :: get(PersonalCalendarManager :: PARAM_PERSONAL_CALENDAR_ID);
        if ($id)
        {
            $calendar_event_publication = $this->retrieve_personal_calendar_publication($id);
            
            if (! $user->is_platform_admin() && $calendar_event_publication->get_publisher() != $user->get_id())
            {
                $this->display_header();
                $this->display_error_message(Translation :: get('NotAllowed', null, Utilities :: COMMON_LIBRARIES));
                $this->display_footer();
                exit();
            }
            
            $content_object = $calendar_event_publication->get_publication_object();
            BreadcrumbTrail::get_instance()->add(new Breadcrumb(null, Translation :: get('Edit', array('TITLE' => $content_object->get_title()))));
            
            $form = ContentObjectForm :: factory(ContentObjectForm :: TYPE_EDIT, $content_object, 'edit', 'post', $this->get_url(array(
                    Application :: PARAM_ACTION => PersonalCalendarManager :: ACTION_EDIT_PUBLICATION, 
                    PersonalCalendarManager :: PARAM_PERSONAL_CALENDAR_ID => $calendar_event_publication->get_id())));
            
            if ($form->validate() || Request :: get('validated'))
            {
                if (! Request :: get('validated'))
                {
                    $success = $form->update_content_object();
                }
                
                if ($form->is_version())
                {
                    $calendar_event_publication->set_content_object($content_object->get_latest_version());
                    $calendar_event_publication->update();
                }
                
                $publication_form = new PersonalCalendarPublicationForm(PersonalCalendarPublicationForm :: TYPE_SINGLE, $content_object, $user, $this->get_url(array(
                        PersonalCalendarManager :: PARAM_PERSONAL_CALENDAR_ID => $calendar_event_publication->get_id(), 
                        'validated' => 1)));
                $publication_form->set_publication($calendar_event_publication);
                
                if ($publication_form->validate())
                {
                    $success = $publication_form->update_calendar_event_publication();
                    $message = $success ? Translation :: get('ObjectUpdated', array(
                            'OBJECT' => Translation :: get('PersonalCalendar')), Utilities :: COMMON_LIBRARIES) : Translation :: get('ObjectNotUpdated', array(
                            'OBJECT' => Translation :: get('PersonalCalendar')), Utilities :: COMMON_LIBRARIES);
                    
                    $this->redirect($message, ($success ? false : true), array(
                            Application :: PARAM_ACTION => PersonalCalendarManager :: ACTION_BROWSE_CALENDAR));
                }
                else
                {
                    $this->display_header();
                    $publication_form->display();
                    $this->display_footer();
                }
            }
            else
            {
                $this->display_header();
                $form->display();
                $this->display_footer();
            }
        }
        else
        {
            $this->display_error_page(\htmlentities(Translation :: get('NoObjectsSelected', null, Utilities :: COMMON_LIBRARIES)));
        }
    }

    function get_additional_parameters()
    {
        return array(self :: PARAM_PERSONAL_CALENDAR_ID);
    }
}
?>