<?php
namespace application\personal_calendar;

use repository\ImportParameters;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\extensions\repo_viewer\RepoViewer;
use common\libraries\Breadcrumb;
use common\libraries\Application;
use common\libraries\FormValidator;
use common\libraries\FileProperties;
use repository\ContentObjectImport;
use repository\ContentObjectImportController;

/**
 * $Id: ical_importer.class.php 201 2009-11-13 12:34:51Z chellee $
 *
 * @package application.personal_calendar.personal_calendar_manager.component
 */
class PersonalCalendarManagerIcalImporterComponent extends PersonalCalendarManager
{

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        $form = $this->build_importing_form();
        if ($form->validate())
        {
            $object = $this->import_ical($form);

            $this->redirect(Translation :: get('IcalImported'), false,
                    array(
                            PersonalCalendarManager :: PARAM_ACTION => PersonalCalendarManager :: ACTION_CREATE_PUBLICATION,
                            RepoViewer :: PARAM_ID => $object,
                            RepoViewer :: PARAM_ACTION => RepoViewer :: ACTION_PUBLISHER));
        }
        else
        {
            $this->display_header();

            echo $form->toHtml();
            $this->display_footer();
        }
    }

    function build_importing_form()
    {
        $url = $this->get_url(
                array(PersonalCalendarManager :: PARAM_ACTION => PersonalCalendarManager :: ACTION_IMPORT_ICAL));
        $form = new FormValidator('ical_import', 'post', $url);

        $form->addElement('file', 'file',
                sprintf(Translation :: get('FileName', null, 'repository\content_object\document'),
                        ini_get('upload_max_filesize', null, 'repository\content_object\document')));

        $allowed_upload_types = array('ics');
        $form->addRule('file', Translation :: get('ThisFieldIsRequired', null, Utilities :: COMMON_LIBRARIES), 'required');
        $form->addRule('file', Translation :: get('OnlyIcsAllowed'), 'filetype', $allowed_upload_types);

        $buttons = array();
        $buttons[] = $form->createElement('style_submit_button', 'submit',
                Translation :: get('Import', null, Utilities :: COMMON_LIBRARIES),
                array('class' => 'positive import'));

        $form->addGroup($buttons, 'buttons', null, '&nbsp;', false);
        return $form;
    }

    function import_ical($form)
    {
        $parameters = ImportParameters :: factory(ContentObjectImport :: FORMAT_ICAL, $this->get_user_id(), 0, FileProperties :: from_upload($_FILES['file']));
        $controller = ContentObjectImportController :: factory($parameters);
        return $controller->run();
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        // $breadcrumbtrail->add(new Breadcrumb($this->get_url(array(
        // Application :: PARAM_ACTION => PersonalCalendarManager :: ACTION_BROWSE_CALENDAR)), Translation ::
        // get('PersonalCalendarManagerBrowserComponent')));
        $breadcrumbtrail->add_help('personal_calendar_ical_importer');
    }
}
?>