<?php
namespace application\personal_messenger;

use common\libraries\AjaxManager;
use common\libraries\JsonAjaxResult;
use common\libraries\Request;
use common\libraries\Session;

/** * ***************************************************************************
 * This class handles the AJAX call for the creation of a new quick reply.
 *
 * @name Chamilo Personal Messenger > PersonalMessengerAjaxQuickReply
 * @version 1.0.0
 * @author Stijn Van Hoecke
 * **************************************************************************** */
class PersonalMessengerAjaxQuickReply extends AjaxManager
{
    const PARAM_MESSAGE_IDENTIFIER = 'message_id';
    const PARAM_MESSAGE_CONTENT = 'content';

    const PROPERTY_CREATED = 'was_created';

    /* (non-PHPdoc)
     * @see common\libraries.AjaxManager::required_parameters()
     */
    function required_parameters()
    {
        return array(self :: PARAM_MESSAGE_IDENTIFIER, self :: PARAM_MESSAGE_CONTENT);
    }

    /* (non-PHPdoc)
     * @see common\libraries.AjaxManager::run()
     */
    function run()
    {
        // construct result
        $result = new JsonAjaxResult(200);
        
        // get the original message
        $original_message = PersonalMessengerDataManager :: retrieve_message_by_id($this->get_parameter(self :: PARAM_MESSAGE_IDENTIFIER));
        
        if($original_message)
        {
            // new message
            $message = new Message();
            
            // get defaults from original message
            $message->set_target_users($original_message->get_target_users());
            $message->set_target_groups($original_message->get_target_groups());
            $message->set_author_id(Session :: get_user_id());
            $message->set_parent_id($original_message->get_id());
            $message->set_reply_id($original_message->get_id());
            
            // add own quick reply
            $message->set_content($this->get_escaped_text());
            
            // create
            $created = $message->create(false);
            
            // determine result
            $result->set_result_code($created ? 200 : 500);
            $result->set_property(self :: PROPERTY_CREATED, $created ? true : false);
            $result->display();
        }
        
        // false
        $result->set_result_code(500);
        $result->set_property(self :: PROPERTY_CREATED, false);
        $result->display();
    }
    
    function get_escaped_text()
    {
        // unfiltered text
        $text = $this->get_parameter(self :: PARAM_MESSAGE_CONTENT);
        
        //TODO do some escaping
        $escaped_text = $text;
        
        // return escaped text
        return $escaped_text;
    }
}
?>