<?php

namespace application\personal_messenger;

use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use common\libraries\GenericTree;
use common\libraries\ObjectTableOrder;
use common\libraries\OptionsMenuRenderer;
use common\libraries\Path;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\TreeMenuRenderer;
use common\libraries\Utilities;

class UserCategoryRenderer extends GenericTree
{
    //**************************************************************************
    // GENERAL CONSTANTS
    //**************************************************************************
    const TREE_NAME = __CLASS__;
    const PATH_TO_XML_FEED = 'application/personal_messenger/php/xml_feeds/xml_user_category_tree_feed.php';
    const ROOT_NODE_CLASS = 'category';
    const NODE_CLASS = 'category';

    //**************************************************************************
    // VARIABLES
    //**************************************************************************
    /**
     * The browser holding additional data.
     * @var PersonalMessengerManager
     */
    private $browser;

    //**************************************************************************
    // CONSTRUCTOR
    //**************************************************************************
    /**
     * Constructor.
     * Creates a new category navigation menu based on the user defined categories of the user.
     * @param PersonalMessengerManager $browser The browser
     */
    function __construct($browser)
    {
        $this->browser = $browser;
        parent :: __construct();
    }

    //**************************************************************************
    // INHERITED FUNCTIONS
    //**************************************************************************
    /**
     * Returns the url of a node
     * @param int $node_id
     * @return string
     */
    public function get_node_url($node_id)
    {
        return $this->browser->get_browser_url($this->browser->get_folder(), $node_id);
    }

    /**
     * Returns the current node id.
     * @return int
     */
    public function get_current_node_id()
    {
        return $this->browser->get_category_id();
    }

    /**
     * Returns the node based on the given node_id.
     * @param int $node_id The id of the node
     * @return Node
     */
    public function get_node($node_id)
    {
        // construct conditions
        $conditions = array();
        $conditions[] = new EqualityCondition(
                        UserCategory :: PROPERTY_USER_CATEGORY_USER_ID,
                        $this->browser->get_user_id()
        );
        $conditions[] = new EqualityCondition(
                        UserCategory :: PROPERTY_USER_CATEGORY_FOLDER,
                        $this->browser->get_folder()
        );
        $conditions[] = new EqualityCondition(
                        UserCategory :: PROPERTY_ID,
                        $node_id
        );
        $condition = new AndCondition($conditions);

        // fetch user_category
        return PersonalMessengerDataManager :: get_instance()->retrieve_user_category($condition);
    }

    /**
     * Returns the nodes below the given parent(_id).
     * @param int $parent_node_id The parent id
     * @return UserCategoryResultSet
     */
    public function get_node_children($parent_node_id)
    {
        // construct conditions
        $conditions = array();
        $conditions[] = new EqualityCondition(
                        UserCategory :: PROPERTY_USER_CATEGORY_USER_ID, $this->browser->get_user_id()
        );
        $conditions[] = new EqualityCondition(
                        UserCategory :: PROPERTY_USER_CATEGORY_FOLDER, $this->browser->get_folder()
        );
        $conditions[] = new EqualityCondition(
                        UserCategory :: PROPERTY_PARENT, $parent_node_id
        );
        $condition = new AndCondition($conditions);

        // fetch user_category
        return PersonalMessengerDataManager :: get_instance()->retrieve_all_user_categories($condition);
    }

    /**
     * Returns if the node has children.
     * @param int $node_id The node id
     * @return boolean
     */
    public function node_has_children($node_id)
    {
        // construct conditions
        $conditions = array();
        $conditions[] = new EqualityCondition(
                        UserCategory :: PROPERTY_USER_CATEGORY_USER_ID, $this->browser->get_user_id()
        );
        $conditions[] = new EqualityCondition(
                        UserCategory :: PROPERTY_USER_CATEGORY_FOLDER, $this->browser->get_folder()
        );
        $conditions[] = new EqualityCondition(
                        UserCategory :: PROPERTY_PARENT, $node_id
        );
        $condition = new AndCondition($conditions);

        // fetch user_category
        return (PersonalMessengerDataManager :: get_instance()->count_user_category($condition) > 0);
    }

    /**
     * Returns the url to the xml feed.
     * @return string
     */
    public function get_search_url()
    {
        return Path :: get(WEB_PATH) . self :: PATH_TO_XML_FEED;
    }

    public function get_url_format()
    {
        $url_format = '?application=personal_messenger';
        $url_format .= '&' . PersonalMessengerManager :: PARAM_FOLDER . '=' . $this->browser->get_folder();
        $url_format .= '&' . PersonalMessengerManager :: PARAM_CATEGORY_ID . '=';
        return $url_format;
    }

    public function get_root_node_class()
    {
        return self :: ROOT_NODE_CLASS;
    }

    public function get_node_class($node)
    {
        return self :: NODE_CLASS;
    }

    public function get_root_node_title()
    {
        return Translation :: get(Utilities :: underscores_to_camelcase(
                        PersonalMessengerFolder :: get_folder_name($this->browser->get_folder()))
        );
    }

    public function get_node_title($node)
    {
        return $node->get_name();
    }

    public function get_node_id($node)
    {
        return $node->get_id();
    }

    public function get_node_parent($node)
    {
        return $node->get_parent();
    }

}

?>