<?php

namespace application\personal_messenger;

use common\libraries\FormValidator;
use common\libraries\Path;
use common\libraries\ResourceManager;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\WebApplication;

require_once Path :: get_plugin_path() . 'html2text/class.html2text.inc';

/**
 * * *************************************************************************** This form offers the functionality to
 * quickly reply on a message, for combination with AJAX to send the reply to the server, and polling for new messages
 * WITHOUT refreshing the page. The functionality to send the message is included in the reply.js javascript.
 *
 * @name Chamilo Personal Messenger > QuickReplyFormAjax
 * @version 1.0.0
 * @author Stijn Van Hoecke ****************************************************************************
 */
class QuickReplyFormAjax
{
    // **************************************************************************
    // VARIABLES
    // **************************************************************************
    /**
     * The original message on which we reply.
     *
     * @var Message
     */
    private $original_message;

    // **************************************************************************
    // CONSTRUCTOR
    // **************************************************************************
    /**
     * Constructor.
     */
    function __construct($original_message)
    {
        $this->original_message = $original_message;
    }

    /**
     * Generates the HTML of the AJAX quick reply form.
     *
     * @return string HTML
     */
    function toHtml()
    {
        $html = array();
        // script with needed values
        $html[] = '<script type="text/javascript"> var origId=' . $this->original_message->get_id() . '; </script>';

        // form
        $html[] = '<input type="text" id="quick_reply" style="display: block; width: 98%; border: none;" onKeyPress="sendReplyOnEnterCheck(event, \'quick_reply\')" />';

        // script with process function
        $html[] = ResourceManager :: get_instance()->get_resource_html(
                WebApplication :: get_application_web_path('personal_messenger') . 'resources/javascript/quick_reply.js');

        return implode("\n", $html);
    }

    /**
     * Don't need to process the form, so never validate.
     */
    function validate()
    {
        return false;
    }

    // **************************************************************************
    // FORM FUNCTIONS
    // **************************************************************************
    /**
     * Builds the quick reply form.
     */
    function build_quick_form()
    {
        /*
         * HTML EDITOR DOESN'T LOAD => to fix // html_editor for quick message $this->add_html_editor(Message ::
         * PROPERTY_MESSAGE_CONTENT, null, true);
         */

        $this->add_textfield(Message :: PROPERTY_MESSAGE_CONTENT, null, true);

        // send - clear buttons
        $buttons[] = $this->createElement('style_submit_button', 'submit',
                Translation :: get('Send', null, Utilities :: COMMON_LIBRARIES), array('class' => 'positive send'));
        // $buttons[] = $this->createElement(
        // 'style_reset_button',
        // 'reset',
        // Translation :: get('Reset', null, Utilities :: COMMON_LIBRARIES),
        // array('class' => 'normal empty')
        // );

        $this->addGroup($buttons, 'buttons', null, '&nbsp;', false);
    }
}

?>