<?php

namespace application\personal_messenger;

use common\libraries\Utilities;
use group\Group;

/** * ***************************************************************************
 * This class represents a personal message (PM) relation with an entire group
 * (PM_REL_GROUP).
 *
 * PM_REL_GROUP objects only have 1 default property, because they link a
 * message to a group binding the message's recipients using an interface.
 * - group_id: the numeric ID identifying the group;
 *
 * @name Chamilo Personal Messenger > MessageGroupRecipient
 * @version 1.0.0
 * @author Stijn Van Hoecke
 * **************************************************************************** */
class MessageGroupRecipient extends MessageRecipient
{
    //**************************************************************************
    // GENERAL CONSTANTS
    //**************************************************************************
    const CLASS_NAME = __CLASS__;

    //**************************************************************************
    // PROPERTY CONSTANTS
    //**************************************************************************
    const PROPERTY_MESSAGE_GROUP_RECIPIENT_GROUP_ID = 'group_id';

    //**************************************************************************
    // GENERAL GETTERS
    //**************************************************************************
    /**
     * Get the default properties of all group relations.
     * @return array The property names
     */
    static function get_default_property_names()
    {
        return parent :: get_default_property_names(array(
            self :: PROPERTY_MESSAGE_GROUP_RECIPIENT_GROUP_ID));
    }

    //**************************************************************************
    // PROPERTY GETTERS
    //**************************************************************************
    /**
     * Returns the numeric ID of the group to which this message is linked.
     * @return int The ID of the group
     */
    function get_group_id()
    {
        return $this->get_default_property(self :: PROPERTY_MESSAGE_GROUP_RECIPIENT_GROUP_ID);
    }

    //**************************************************************************
    // PROPERTY SETTERS
    //**************************************************************************
    /**
     * Sets the numeric ID of the group to which this message is linked.
     * @param int $user_id The ID of the group
     */
    function set_group_id($group_id)
    {
        $this->set_default_property(self :: PROPERTY_MESSAGE_GROUP_RECIPIENT_GROUP_ID, $group_id);
    }

    //TODO comment
    function get_recipient_name()
    {
        return $this->get_optional_property(Group :: PROPERTY_NAME);
    }

    //**************************************************************************
    // DATABASE FUNCTIONS
    //**************************************************************************
    /**
     * Gets the table name for this class.
     */
    static function get_table_name()
    {
        return Utilities :: get_classname_from_namespace(self :: CLASS_NAME, true);
    }

}

?>
