<?php

namespace application\personal_messenger;

use common\libraries\Utilities;
use user\User;

/** * ***************************************************************************
 * This class represents a personal message (PM) relation with the user
 * (PM_REL_USER).
 *
 * PM_REL_USER objects only have 1 default property, because they link a
 * message to a user binding the message's recipients using an interface.
 * - user_id: the numeric ID identifying the user;
 *
 * @name Chamilo Personal Messenger > MessageUserRecipient
 * @version 1.0.0
 * @author Stijn Van Hoecke
 * **************************************************************************** */
class MessageUserRecipient extends MessageRecipient
{
    //**************************************************************************
    // GENERAL CONSTANTS
    //**************************************************************************
    const CLASS_NAME = __CLASS__;

    //**************************************************************************
    // PROPERTY CONSTANTS
    //**************************************************************************
    const PROPERTY_MESSAGE_USER_RECIPIENT_USER_ID = 'user_id';

    //**************************************************************************
    // GENERAL GETTERS
    //**************************************************************************
    /**
     * Get the default properties of all user relations.
     * @return array The property names
     */
    static function get_default_property_names()
    {
        return parent :: get_default_property_names(array(
            self :: PROPERTY_MESSAGE_USER_RECIPIENT_USER_ID));
    }

    //**************************************************************************
    // PROPERTY GETTERS
    //**************************************************************************
    /**
     * Returns the numeric ID of the user to which this message is linked.
     * @return int The ID of the user
     */
    function get_user_id()
    {
        return $this->get_default_property(self :: PROPERTY_MESSAGE_USER_RECIPIENT_USER_ID);
    }

    //**************************************************************************
    // PROPERTY SETTERS
    //**************************************************************************
    /**
     * Sets the numeric ID of the user to which this message is linked.
     * @param int $user_id The ID of the user
     */
    function set_user_id($user_id)
    {
        $this->set_default_property(self :: PROPERTY_MESSAGE_USER_RECIPIENT_USER_ID, $user_id);
    }

    //TODO comment
    function get_recipient_name()
    {
        $name = $this->get_optional_property(User :: PROPERTY_FIRSTNAME);
        $name .= ' ';
        $name .= $this->get_optional_property(User :: PROPERTY_LASTNAME);
        return $name;
    }

    //**************************************************************************
    // DATABASE FUNCTIONS
    //**************************************************************************
    /**
     * Gets the table name for this class.
     */
    static function get_table_name()
    {
        return Utilities :: get_classname_from_namespace(self :: CLASS_NAME, true);
    }

}

?>
