<?php

namespace application\personal_messenger;

use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Display;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\extensions\category_manager\CategoryManager;

/** * ***************************************************************************
 * This class manages the categories for the personal messenger.
 *
 * @name Chamilo Personal Messenger > PersonalMessengerManagerCategoryManagerComponent
 * @version 1.0.0
 * @author Stijn Van Hoecke
 * **************************************************************************** */
class PersonalMessengerManagerCategoryManagerComponent extends PersonalMessengerManager
{

    //**************************************************************************
    // RUN
    //**************************************************************************
    /**
     * Runs this component.
     */
    function run()
    {
        if (PersonalMessengerFolder :: supports_subcategories(Request :: get(self :: PARAM_FOLDER)))
        {
            $category_manager = new UserCategoryManager($this);
            $category_manager->run();
        }
        else
        {
            $this->display_header();
            Display :: error_message(Translation :: get('NotAllowed', null, Utilities :: COMMON_LIBRARIES));
            $this->display_footer();
            exit();
        }
    }

    /**
     * Adds the additional breadcrumbs for navigation.
     * @param BreadcrumbTrail $breadcrumbtrail
     */
    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $browser_folder_url = $this->get_browser_url($this->get_folder(), $this->get_category_id());

        // browser
        $breadcrumbtrail->add(new Breadcrumb(
                        $browser_folder_url,
                        Translation :: get('PersonalMessengerManagerBrowserComponent')
        ));

        // folder
        $breadcrumbtrail->add(new Breadcrumb(
                        $browser_folder_url,
                        Translation :: get(Utilities:: underscores_to_camelcase(
                                        PersonalMessengerFolder :: get_folder_name($this->get_folder())
                        ))));
    }

}

?>