<?php

namespace application\personal_messenger;

use common\libraries\ActionBarRenderer;
use common\libraries\Application;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Utilities;

/** * ***************************************************************************
 * This component offers the functionality to create a message.
 *
 * @name Chamilo Personal Messenger > PersonalMessengerManagerCreatorComponent
 * @version 1.0.0
 * @author Stijn Van Hoecke
 * @uses MessageForm
 * **************************************************************************** */
class PersonalMessengerManagerCreatorComponent extends PersonalMessengerManager
{

    //**************************************************************************
    // VARIABLES
    //**************************************************************************
    /**
     * Variable holding the message
     */
    protected $message;

    //**************************************************************************
    // RUN
    //**************************************************************************
    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        if (!$this->message)
        {
            $this->message = new Message();
        }

        $form = new MessageForm(
                        MessageForm :: TYPE_CREATE,
                        $this->message,
                        $this->get_url(),
                        $this->get_user(),
                        $this
        );

        if ($form->validate())
        {
            $success = $form->create_message();

            // go back
            $go_back_parameters = array();
            if (Request :: get(self :: PARAM_REFERER))
            {
                $go_back_parameters[Application :: PARAM_ACTION] = Request :: get(self :: PARAM_REFERER);
                $go_back_parameters[self :: PARAM_MESSAGE_ID] = $this->message->get_id();
            }
            else
            {
                $go_back_parameters[Application :: PARAM_ACTION] = self :: DEFAULT_ACTION;
            }

            $this->redirect(
                    Translation :: get(
                            ($success ? 'ObjectCreated' : 'ObjectNotCreated'),
                            array('OBJECT' => Translation :: get('Message')),
                            Utilities :: COMMON_LIBRARIES
                    ),
                    ($success ? false : true),
                    $go_back_parameters
            );
        }
        else
        {
            $this->display_header();
            $form->display();
            $this->display_footer();
        }
    }

    //**************************************************************************
    // ADDITIONAL FUNCTIONS
    //**************************************************************************
    /**
     * Adds the additional parameters to the URL.
     * @return array
     */
    function get_additional_parameters()
    {
        return array(self :: PARAM_REFERER);
    }

    /**
     * Adds the additional breadcrumbs for navigation.
     * @param BreadcrumbTrail $breadcrumbtrail
     */
    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $browser_folder_url = $this->get_browser_url($this->get_folder(), $this->get_category_id());

        // browser
        $breadcrumbtrail->add(new Breadcrumb(
                        $browser_folder_url,
                        Translation :: get('PersonalMessengerManagerBrowserComponent')
        ));

        // folder
        $breadcrumbtrail->add(new Breadcrumb(
                        $browser_folder_url,
                        Translation :: get(Utilities:: underscores_to_camelcase(
                                        PersonalMessengerFolder :: get_folder_name($this->get_folder())
                        ))));
    }

}

?>