<?php

namespace application\personal_messenger;

use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\EqualityCondition;
use common\libraries\Theme;
use common\libraries\ToolbarItem;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\extensions\repo_viewer\RepoViewer;
use repository\ContentObjectAttachment;
use repository\ContentObjectGroupShare;
use repository\ContentObjectUserShare;
use repository\RepositoryDataManager;
use repository\content_object\personal_message\PersonalMessage;

/** * ***************************************************************************
 * This component shows the repoviewer to select a template and returns to the
 * general creator.
 *
 * @name Chamilo Personal Messenger > PersonalMessengerManagerCreatorFromTemplateComponent
 * @version 1.0.0
 * @author Stijn Van Hoecke
 * @uses MessageForm
 * **************************************************************************** */
class PersonalMessengerManagerCreatorFromTemplateComponent extends PersonalMessengerManagerCreatorComponent
{

    //**************************************************************************
    // RUN
    //**************************************************************************
    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        if (!RepoViewer :: is_ready_to_be_published())
        {
            $repo_viewer = RepoViewer :: construct($this);
            $repo_viewer->set_maximum_select(RepoViewer :: SELECT_SINGLE);
            $repo_viewer->run();
        }
        else
        {
            // get the template
            $template_id = RepoViewer :: get_selected_objects();
            $repository_dm = RepositoryDataManager :: get_instance();
            $template = $repository_dm->retrieve_content_object($template_id, PersonalMessage :: get_type_name());

            // create the message
            $this->message = $this->create_message($template);

            // continue
            parent :: run();
        }
    }

    //**************************************************************************
    // GENERAL FUNCTIONS
    //**************************************************************************
    /**
     * Returns a message based on the given template.
     * @param PersonalMessegeContentObject $template
     * @return Message
     */
    function create_message($template)
    {
        $message = new Message();
        $message->set_author_id($template->get_owner_id());
        $message->set_title($template->get_title());
        $message->set_content($template->get_description());
        return $message;
    }

    //**************************************************************************
    // ADDITIONAL FUNCTIONS
    //**************************************************************************
    /**
     * Determines the types the repoviewer can select.
     */
    function get_allowed_content_object_types()
    {
        return array(PersonalMessage :: get_type_name());
    }

    /**
     * Adds the additional parameters to the URL.
     * @return array
     */
    function get_additional_parameters()
    {
        return array(RepoViewer :: PARAM_ACTION, RepoViewer :: PARAM_ID);
    }

    /**
     * Adds the additional breadcrumbs for navigation.
     * @param BreadcrumbTrail $breadcrumbtrail
     */
    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $browser_folder_url = $this->get_browser_url($this->get_folder(), $this->get_category_id());

        // browser
        $breadcrumbtrail->add(new Breadcrumb(
                        $browser_folder_url,
                        Translation :: get('PersonalMessengerManagerBrowserComponent')
        ));

        // folder
        $breadcrumbtrail->add(new Breadcrumb(
                        $browser_folder_url,
                        Translation :: get(Utilities:: underscores_to_camelcase(
                                        PersonalMessengerFolder :: get_folder_name($this->get_folder())
                        ))));
    }

}

?>