<?php

namespace application\personal_messenger;

use common\libraries\Application;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Utilities;

/** * ***************************************************************************
 * This component offers the functionality to delete a (series of) message(s) or
 * discussions depending on the actual implementation.
 *
 * @name Chamilo Personal Messenger > PersonalMessengerManagerDeleterComponent
 * @version 1.0.0
 * @author Stijn Van Hoecke
 * **************************************************************************** */
abstract class PersonalMessengerManagerDeleterComponent extends PersonalMessengerManager
{

    //**************************************************************************
    // RUN
    //**************************************************************************
    /**
     * Runs this component.
     */
    function run()
    {
        $failures = 0;

        // get the IDs
        $message_ids = Request :: get(self :: PARAM_MESSAGE_ID);

        // checks
        if (!empty($message_ids))
        {
            // construct array if id is single element
            if (!is_array($message_ids))
            {
                $message_ids = array($message_ids);
            }

            // for each message, update
            foreach ($message_ids as $message_id)
            {
                // delete the UserMessage / Message
                $object = $this->get_object($message_id);
                if (!$object)
                {
                    $failures++;
                }
                elseif (!$object->delete())
                {
                    $failures++;
                }
            }
        }

        // feedback
        if ($failures)
        {
            $feedback_message = Translation :: get(
                            count($message_ids) == 1 ? 'ObjectNotDeleted' : 'ObjectsNotDeleted',
                            array('OBJECT' => Translation :: get(count($message_ids) == 1 ? 'Message' : 'Messages')),
                            Utilities :: COMMON_LIBRARIES
            );
        }
        else
        {
            $feedback_message = Translation :: get(
                            count($message_ids) == 1 ? 'ObjectDeleted' : 'ObjectsDeleted',
                            array('OBJECT' => Translation :: get(count($message_ids) == 1 ? 'Message' : 'Messages')),
                            Utilities :: COMMON_LIBRARIES
            );
        }

        // go back
        $go_back_parameters = array();
        if (Request :: get(PersonalMessengerManager :: PARAM_REFERER))
        {
            $go_back_parameters[Application :: PARAM_ACTION] = Request :: get(self :: PARAM_REFERER);
            // in case of delete, if you have a referer it is the (viewer) of the original message -> return to the original message
            $go_back_parameters[self :: PARAM_MESSAGE_ID] = Request :: get(self :: PARAM_REPLY_ID);
        }
        else
        {
            $go_back_parameters[Application :: PARAM_ACTION] = self :: DEFAULT_ACTION;
        }

        $this->redirect($feedback_message, ($failures ? true : false), $go_back_parameters);
    }

    //**************************************************************************
    // ADDITIONAL FUNCTIONS
    //**************************************************************************
    /**
     * Adds the additional parameters to the URL.
     * @return array
     */
    function get_additional_parameters()
    {
        return array(self :: PARAM_REFERER, self :: PARAM_MESSAGE_ID, self :: PARAM_REPLY_ID);
    }

    //**************************************************************************
    // ABSTRACT FUNCTIONS
    //**************************************************************************
    /**
     * Returns the object to delete.
     * @param $object_id The id of the object to delete
     * @return Message The discussion to delete
     */
    abstract function get_object($object_id);
}

?>