<?php

namespace application\personal_messenger;

use common\libraries\ObjectTable;
use common\libraries\ObjectTableFormAction;
use common\libraries\ObjectTableFormActions;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Utilities;

/** * ***************************************************************************
 * Table to display the users inside a discussion.
 *
 * @name Chamilo Personal Messenger > DiscussionUserTable
 * @version 1.0.0
 * @author Stijn Van Hoecke
 * **************************************************************************** */
class DiscussionUserTable extends ObjectTable
{
    //**************************************************************************
    // GENERAL CONSTANTS
    //**************************************************************************
    const DEFAULT_NAME = 'discussion_user_table';
    const DEFAULT_ROW_COUNT = 10;

    //**************************************************************************
    // GENERAL VARIABLES
    //**************************************************************************
    /**
     * The user manager component
     */
    private $user_manager;
    /**
     * The message.
     */
    private $message;

    //**************************************************************************
    // CONSTRUCTOR
    //**************************************************************************
    /**
     * Constructor
     */
    function __construct($user_manager, $message, $parameters, $condition)
    {
        $this->user_manager = $user_manager;
        $this->message = $message;

        // create model, renderer and data provider
        $model = new DiscussionUserTableColumnModel();
        $renderer = new DiscussionUserTableCellRenderer($user_manager, $message);
        $data_provider = new DiscussionUserTableDataProvider($user_manager, $condition);

        // construct (parent)
        parent :: __construct($data_provider, DiscussionUserTable :: DEFAULT_NAME, $model, $renderer);

        // actions
        $this->set_form_actions($this->get_table_actions());

        // default row count
        $this->set_default_row_count(self :: DEFAULT_ROW_COUNT);
    }

    /**
     * Returns the actions for the table.
     */
    function get_table_actions()
    {
        $actions = new ObjectTableFormActions(__NAMESPACE__);

        // general available actions
        if ($this->message->get_author_id() == $this->user_manager->get_user_id())
        {
            // UNSUBSCRIBE SELECTED
            $delete_selected_action = new ObjectTableFormAction(
                            PersonalMessengerManager :: ACTION_DELETE_USER,
                            Translation :: get('RemoveParticipantSelected'),
                            false
            );

            $actions->add_form_action($delete_selected_action);
        }

        return $actions;
    }

    static function handle_table_action()
    {
        $class = Utilities :: get_classname_from_namespace(__CLASS__, true);
        $ids = self :: get_selected_ids($class);
        Request :: set_get(PersonalMessengerManager :: PARAM_USER_ID, $ids);
    }

}

?>