<?php

namespace application\personal_messenger;

use common\libraries\ObjectTable;
use common\libraries\ObjectTableFormAction;
use common\libraries\ObjectTableFormActions;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Utilities;

/** * ***************************************************************************
 * Table to display the ignored users.
 *
 * @name Chamilo Personal Messenger > IgnoredUserTable
 * @version 1.0.0
 * @author Stijn Van Hoecke
 * **************************************************************************** */
class IgnoredUserTable extends ObjectTable
{
    //**************************************************************************
    // GENERAL CONSTANTS
    //**************************************************************************
    const DEFAULT_NAME = 'ignored_user_table';
    const DEFAULT_ROW_COUNT = 10;

    //**************************************************************************
    // CONSTRUCTOR
    //**************************************************************************
    /**
     * Constructor
     */
    function __construct($user_manager, $parameters, $condition)
    {
        // create model, renderer and data provider
        $model = new IgnoredUserTableColumnModel();
        $renderer = new IgnoredUserTableCellRenderer($user_manager);
        $data_provider = new IgnoredUserTableDataProvider($user_manager, $condition);

        // construct (parent)
        parent :: __construct($data_provider, IgnoredUserTable :: DEFAULT_NAME, $model, $renderer);

        // actions
        $this->set_form_actions($this->get_table_actions());

        // default row count
        $this->set_default_row_count(self :: DEFAULT_ROW_COUNT);
    }

    /**
     * Returns the actions for the table.
     */
    function get_table_actions()
    {
        // UNIGNORE SELECTED
        $unignore_selected_action = new ObjectTableFormAction(
                        PersonalMessengerManager :: ACTION_UNIGNORE_USER,
                        Translation :: get('UnignoreUserSelected'),
                        false
        );

        $actions = new ObjectTableFormActions(__NAMESPACE__);
        $actions->add_form_action($unignore_selected_action);

        return $actions;
    }

    static function handle_table_action()
    {
        $class = Utilities :: get_classname_from_namespace(__CLASS__, true);
        $ids = self :: get_selected_ids($class);
        Request :: set_get(PersonalMessengerManager :: PARAM_USER_ID, $ids);
    }

}

?>