<?php

namespace application\personal_messenger;

use common\libraries\Theme;
use common\libraries\Toolbar;
use common\libraries\ToolbarItem;
use common\libraries\Translation;
use common\libraries\Utilities;

/** * ***************************************************************************
 * Cell renderer for the ignored user table.
 *
 * @name Chamilo Personal Messenger > IgnoredUserTableCellRenderer
 * @version 1.0.0
 * @author Stijn Van Hoecke
 * **************************************************************************** */
class IgnoredUserTableCellRenderer extends DefaultUserTableCellRenderer
{

    //**************************************************************************
    // GENERAL VARIABLES
    //**************************************************************************
    /**
     * The user manager component.
     */
    private $user_manager;

    //**************************************************************************
    // CONSTRUCTOR
    //**************************************************************************
    /**
     * Constructor
     * @param PersonalMessengerManagerComponent $user_manager The user manager component
     */
    function __construct($user_manager)
    {
        parent :: __construct();
        $this->user_manager = $user_manager;
    }

    //**************************************************************************
    // GENERAL FUNCTIONS
    //**************************************************************************
    /**
     * Renders a table cell based on the given parameters column and user.
     * @param MessageTableColumn $column The column which should be rendered
     * @param User $ignored_user The ignored user to render
     * @return String A HTML representation of the rendered table cell
     */
    function render_cell($column, $user)
    {
        // get action links
        if ($column === IgnoredUserTableColumnModel :: get_modification_column())
        {
            return $this->get_modification_links($user);
        }

        // return parent
        return parent :: render_cell($column, $user);
    }

    /**
     * Gets the action links to display.
     * @param User $user The user for which the action links should be returned
     * @return String A HTML representation of the action links
     */
    private function get_modification_links($user)
    {
        // ACTION UNIGNORE
        $unignore_url = $this->user_manager->get_user_unignore_url(
                        $user->get_id(),
                        PersonalMessengerManager :: ACTION_MANAGE_USERS_IGNORED
        );
        $unignore_item = new ToolbarItem(
                        Translation :: get('UnignoreUser'),
                        Theme :: get_image_path() . 'action_restore_user.png',
                        $unignore_url,
                        ToolbarItem :: DISPLAY_ICON_AND_LABEL,
                        false
        );

        // CONSTRUCT TOOLBAR
        $toolbar = new Toolbar(Toolbar :: TYPE_HORIZONTAL);
        $toolbar->add_item($unignore_item);
        return $toolbar->as_html();
    }

}

?>