<?php

namespace application\personal_messenger;

use common\libraries\ObjectTable;
use common\libraries\ObjectTableFormAction;
use common\libraries\ObjectTableFormActions;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Utilities;

/** * ***************************************************************************
 * Table to display a series of messages.
 *
 * @name Chamilo Personal Messenger > MessageBrowserTable
 * @version 1.0.0
 * @author Stijn Van Hoecke
 * **************************************************************************** */
class MessageBrowserTable extends ObjectTable
{
    //**************************************************************************
    // GENERAL CONSTANTS
    //**************************************************************************
    const DEFAULT_NAME = 'message_browser_table';
    const DEFAULT_ROW_COUNT = 10;

    //**************************************************************************
    // VARIABLES
    //**************************************************************************
    /**
     * The browser.
     */
    private $browser;

    //**************************************************************************
    // CONSTRUCTOR
    //**************************************************************************
    /**
     * Constructor
     */
    function __construct($browser, $parameters, $condition)
    {
        $this->browser = $browser;

        // create model, renderer and data provider
        $model = new MessageBrowserTableColumnModel($this->browser->get_folder());
        $renderer = new MessageBrowserTableCellRenderer($this->browser);
        $data_provider = new MessageBrowserTableDataProvider($this->browser, $condition);

        // construct (parent)
        parent :: __construct($data_provider, MessageBrowserTable :: DEFAULT_NAME, $model, $renderer);

        // actions
        $this->set_form_actions($this->get_table_actions());

        // default row count
        $this->set_default_row_count(self :: DEFAULT_ROW_COUNT);
    }

    /**
     * Returns the actions for the table.
     */
    function get_table_actions()
    {
        // MARK SELECTED READ
        $read_selected_action = new ObjectTableFormAction(
                        PersonalMessengerManager :: ACTION_MARK_MESSAGE_READ,
                        Translation :: get('MarkSelectedRead'),
                        false
        );

        // MARK SELECTED UNREAD
        $unread_selected_action = new ObjectTableFormAction(
                        PersonalMessengerManager :: ACTION_MARK_MESSAGE_UNREAD,
                        Translation :: get('MarkSelectedUnread'),
                        false
        );

        // IGNORE SELECTED
        $ignore_selected_action = new ObjectTableFormAction(
                        PersonalMessengerManager :: ACTION_MARK_MESSAGE_IGNORE,
                        Translation :: get('IgnoreSelected'),
                        false
        );

        // UNIGNORE SELECTED
        $unignore_selected_action = new ObjectTableFormAction(
                        PersonalMessengerManager :: ACTION_MARK_MESSAGE_READ,
                        Translation :: get('UnignoreSelected'),
                        false
        );

        // TRASH SELECTED
        $trash_selected_action = new ObjectTableFormAction(
                        PersonalMessengerManager :: ACTION_MARK_MESSAGE_TRASH,
                        Translation :: get('TrashSelected'),
                        false
        );

        // UNTRASH SELECTED
        $untrash_selected_action = new ObjectTableFormAction(
                        PersonalMessengerManager :: ACTION_MARK_MESSAGE_UNTRASH,
                        Translation :: get('UntrashSelected'),
                        false
        );

        // DELETE SELECTED
        $delete_selected_action = new ObjectTableFormAction(
                        PersonalMessengerManager :: ACTION_DELETE_USER_MESSAGE,
                        Translation :: get('DeleteSelected', null, Utilities :: COMMON_LIBRARIES),
                        true
        );

        // MOVE SELECTED
        $move_selected_action = new ObjectTableFormAction(
                        PersonalMessengerManager :: ACTION_MOVE_MESSAGE,
                        Translation :: get('MoveSelected', null, Utilities :: COMMON_LIBRARIES),
                        false
        );

        $actions = new ObjectTableFormActions(__NAMESPACE__);

        // folder specific actions
        switch ($this->browser->get_folder())
        {
            case PersonalMessengerFolder :: INBOX :
                $actions->add_form_action($read_selected_action);
                $actions->add_form_action($unread_selected_action);
                $actions->add_form_action($ignore_selected_action);
                $actions->add_form_action($trash_selected_action);
                break;

            case PersonalMessengerFolder :: DISCUSSIONS :
                $actions->add_form_action($read_selected_action);
                $actions->add_form_action($unread_selected_action);
                $actions->add_form_action($ignore_selected_action);
                $actions->add_form_action($trash_selected_action);
                break;

            case PersonalMessengerFolder :: OUTBOX :
                $actions->add_form_action($delete_selected_action);
                break;

            case PersonalMessengerFolder :: IGNORED :
                $actions->add_form_action($unignore_selected_action);
                $actions->add_form_action($delete_selected_action);
                break;

            case PersonalMessengerFolder :: TRASH :
                $actions->add_form_action($untrash_selected_action);
                $actions->add_form_action($delete_selected_action);
                break;
        }

        // move action depending on is_allowed
        if (PersonalMessengerFolder :: supports_subcategories($this->browser->get_folder())
                && UserCategoryManager :: user_has_categories_in_folder(
                        $this->browser->get_user_id(),
                        $this->browser->get_folder()
                )
        )
        {
            $actions->add_form_action($move_selected_action);
        }

        return $actions;
    }

    static function handle_table_action()
    {
        $class = Utilities :: get_classname_from_namespace(__CLASS__, true);
        $ids = self :: get_selected_ids($class);
        Request :: set_get(PersonalMessengerManager :: PARAM_MESSAGE_ID, $ids);
    }

}

?>