<?php

namespace application\personal_messenger;

use common\libraries\Application;
use common\libraries\BreadcrumbTrail;
use common\libraries\Breadcrumb;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Utilities;

/** * ***************************************************************************
 * This component offers the functionality to add a recipient (user or group) to
 * a message.
 *
 * @name Chamilo Personal Messenger > PersonalMessengerManagerUserAdderComponent
 * @version 1.0.0
 * @author Stijn Van Hoecke
 * **************************************************************************** */
class PersonalMessengerManagerUserAdderComponent extends PersonalMessengerManager
{

    //**************************************************************************
    // RUN
    //**************************************************************************
    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        // get the message
        $message = $this->get_message();

        // get the IDs
        $group_ids = Request :: get(self :: PARAM_GROUP_ID);
        $user_ids = Request :: get(self :: PARAM_USER_ID);

        $failures = $this->add_users($message, $user_ids, $group_ids);

        // feedback
        if ($failures)
        {
            $feedback_message = Translation :: get(
                            count($user_ids) == 1 ? 'ObjectNotCreated' : 'ObjectsNotCreated',
                            array('OBJECT' => Translation :: get(count($user_ids) == 1 ? 'Participant' : 'Participants')),
                            Utilities :: COMMON_LIBRARIES
            );
        }
        else
        {
            $feedback_message = Translation :: get(
                            count($user_ids) == 1 ? 'ObjectCreated' : 'ObjectsCreated',
                            array('OBJECT' => Translation :: get(count($user_ids) == 1 ? 'Participant' : 'Participants')),
                            Utilities :: COMMON_LIBRARIES
            );
        }

        // go back
        $go_back_parameters = array();
        if (Request :: get(self :: PARAM_REFERER))
        {
            $go_back_parameters[Application :: PARAM_ACTION] = Request :: get(self :: PARAM_REFERER);
            $go_back_parameters[self :: PARAM_MESSAGE_ID] = Request :: get(self :: PARAM_MESSAGE_ID);
        }
        else
        {
            $go_back_parameters[Application :: PARAM_ACTION] = self :: DEFAULT_ACTION;
        }

        $this->redirect($feedback_message, ($failures ? true : false), $go_back_parameters);
    }

    //**************************************************************************
    // GENERAL FUNCTIONS
    //**************************************************************************
    /**
     * Returns the message after performing some checks.
     * @return Message
     */
    function get_message()
    {
        // get message id
        $message_id = Request :: get(self :: PARAM_MESSAGE_ID);
        if (!$message_id)
        {
            $this->display_header();
            Display :: error_message(Translation :: get('NoMessageSelected'));
            $this->display_footer();
            exit();
        }
        else
        {
            // retrieve the message
            $message = $this->retrieve_message_by_id($message_id);

            // if there is no message
            if (!$message)
            {
                $this->display_header();
                Display :: error_message(Translation :: get('NoMessageSelected'));
                $this->display_footer();
                exit();
            }
            else
            {
                // create user message conditions
                $conditions = array();
                $conditions[] = new EqualityCondition(
                                UserMessage :: PROPERTY_USER_MESSAGE_MESSAGE_ID,
                                $message->get_id());
                $conditions[] = new EqualityCondition(
                                UserMessage :: PROPERTY_USER_MESSAGE_USER_ID,
                                $this->get_user_id());
                $user_message_condition = new AndCondition($conditions);

                // retrieve the user message
                $user_message = $this->retrieve_user_message($user_message_condition);

                // check if there is a user message
                if (!$user_message)
                {
                    $this->display_header();
                    Display :: error_message(Translation :: get('NotAllowed', null, Utilities :: COMMON_LIBRARIES));
                    $this->display_footer();
                    exit();
                }
                else
                {
                    // return the message
                    return $message;
                }
            }
        }
    }

}

?>