<?php

namespace application\personal_messenger;

use common\libraries\ObjectTableColumn;
use common\libraries\ObjectTableColumnModel;

/** * ***************************************************************************
 * This class is the default table column model for messages.
 *
 * @name Chamilo Personal Messenger > DefaultMessageTableColumnModel
 * @version 1.0.0
 * @author Stijn Van Hoecke
 * **************************************************************************** */
class DefaultMessageTableColumnModel extends ObjectTableColumnModel
{
    //**************************************************************************
    // GENERAL CONSTANTS
    //**************************************************************************
    const DEFAULT_SORT_COLUMN = 0; // date column
    const DEFAULT_SORT_ORDER = SORT_DESC; // descending order
    //**************************************************************************
    // TABLE HEADER PROPERTIES -> used for fields that are calculated
    //**************************************************************************
    const TABLE_HEADER_ATTACHMENT = 'Attachments';
    const TABLE_HEADER_TYPE = 'Type';

    //**************************************************************************
    // CONSTRUCTOR
    //**************************************************************************
    /**
     * Constructor
     * Creates a model based on the given folder
     */
    function __construct($folder)
    {
        parent :: __construct(self :: get_default_columns($folder), self :: DEFAULT_SORT_COLUMN, self :: DEFAULT_SORT_ORDER);
    }

    //**************************************************************************
    // STATIC FUNCTIONS
    //**************************************************************************
    /**
     * Gets the default columns for this model
     * @return ContentObjectTableColumn[]
     */
    private static function get_default_columns($folder)
    {
        $columns = array();
        $dm = PersonalMessengerDataManager :: get_instance();
        $user_message_alias = $dm->get_alias(UserMessage :: get_table_name());

        //fixed first column DATE
        $columns[] = new ObjectTableColumn(Message :: PROPERTY_MESSAGE_MODIFICATION_TIME);

        // fixed second column STATUS
        $columns[] = new ObjectTableColumn(UserMessage :: PROPERTY_USER_MESSAGE_STATUS, true, $user_message_alias);

        // fixed third column ATTACHMENTS
        $columns[] = new ObjectTableColumn(self :: TABLE_HEADER_ATTACHMENT, false);

        // variable fourth column AUTHOR or RECIPIENT(S)
        switch ($folder)
        {
            // in case of outbox -> display the recipient(s) who are not sortable
            case PersonalMessengerFolder :: OUTBOX :
                $columns[] = new ObjectTableColumn(MessageRecipient :: RECIPIENT_NAME, false);
                break;
            // in case of inbox/discussions/ignores/trash/default -> display author
            case PersonalMessengerFolder :: INBOX :
            case PersonalMessengerFolder :: DISCUSSIONS :
            case PersonalMessengerFolder :: IGNORED :
            case PersonalMessengerFolder :: TRASH :
            default :
                $columns[] = new ObjectTableColumn(Message :: PROPERTY_MESSAGE_AUTHOR_ID);
                break;
        }

        //fixed fifth column TITLE
        $columns[] = new ObjectTableColumn(Message :: PROPERTY_MESSAGE_TITLE);

        //fixed sixth volumn TYPE
        $columns[] = new ObjectTableColumn(self :: TABLE_HEADER_TYPE);

        return $columns;
    }

}

?>