<?php

namespace application\personal_messenger;

use common\libraries\AndCondition;
use common\libraries\Authentication;
use common\libraries\EqualityCondition;
use common\libraries\ObjectTableOrder;
use common\libraries\Request;
use common\libraries\Session;

require_once dirname(__FILE__) . '/../../../../common/global.inc.php';

$categories_tree = array();

if (Authentication :: is_valid())
{
    // construct conditions
    $conditions = array();
    $conditions[] = new EqualityCondition(UserCategory :: PROPERTY_PARENT, Request :: get('parent_id'));
    $conditions[] = new EqualityCondition(UserCategory :: PROPERTY_USER_CATEGORY_USER_ID, Session :: get_user_id());
    $condition = new AndCondition($conditions);

    // fetch categories
    $categories_tree = PersonalMessengerDataManager :: get_instance()->retrieve_all_user_categories($condition)->as_array();
}

// send data back
header('Content-Type: text/xml');
echo '<?xml version="1.0" encoding="UTF-8"?>' . "\n", '<tree>' . "\n";
echo dump_tree($categories_tree);
echo '</tree>';

function dump_tree($categories)
{
    $html = array();

    if (contains_results($categories))
    {
        dump_categories_tree($categories);
    }
}

function dump_categories_tree($categories)
{
    foreach ($categories as $category)
    {
        $has_children = has_sub_categories($category->get_id()) ? 1 : 0;
        $string = '<leaf id="';
        $string .= $category->get_id();
        $string .= '" classes="category" has_children="';
        $string .= $has_children;
        $string .= '" title="';
        $string .= htmlspecialchars($category->get_name());
        $string .= '" description="';
        $string .= htmlspecialchars($category->get_name());
        $string .= '"/>';
        echo $string . "\n";
    }
}

function contains_results($objects)
{
    if (count($objects))
    {
        return true;
    }
    return false;
}

function has_sub_categories($category_id)
{
    $conditions = array();
    $conditions[] = new EqualityCondition(UserCategory :: PROPERTY_PARENT, $category_id);
    $conditions[] = new EqualityCondition(UserCategory :: PROPERTY_USER_CATEGORY_USER_ID, Session :: get_user_id());
    $condition = new AndCondition($conditions);

    if (PersonalMessengerDataManager :: get_instance()->count_user_category($condition) > 0)
    {
        return true;
    }
    else
    {
        return false;
    }
}

?>
