<?php
namespace application\portfolio;

use common\libraries\EqualityCondition;
use common\libraries\Translation;
use application\portfolio\PortfolioManager;
use repository\content_object\bookmark\Bookmark;
use repository\ContentObjectRenditionImplementation;
use repository\RepositoryDataManager;
use common\libraries\StringUtilities;
use repository\ContentObjectRendition;
use repository\ContentObjectBlock;

/**
 * Block to display all bookmarks for the portfolios application
 */
class PortfolioBookmarkDisplay extends ContentObjectBlock
{

    function __construct($parent, $block_info, $configuration)
    {
        parent :: __construct($parent, $block_info, $configuration);
        $this->default_title = Translation :: get('PortfolioBookmarks');
    }

    function is_configured()
    {
        // no configuration needed for now
        return true;
    
    }

    function is_visible()
    {
        if ($this->is_empty() && ! $this->show_when_empty())
        {
            return false;
        }
        
        return true; // i.e.display on homepage when anonymous
    }

    function is_hidable()
    {
        return true;
    }

    function is_deletable()
    {
        return true;
    }

    /**
     * Returns the html to display when the block is configured.
     *
     * @return string
     */
    function display_content()
    {
        
        $condition = new EqualityCondition(Bookmark :: PROPERTY_APPLICATION, PortfolioManager :: APPLICATION_NAME, Bookmark :: get_type_name(), false);
        
        $bookmarks_resultset = RepositoryDataManager :: get_instance()->retrieve_type_content_objects(Bookmark :: get_type_name(), $condition);
        
        while ($bookmarks_resultset && $bm = $bookmarks_resultset->next_result())
        {
            $html[] = ContentObjectRenditionImplementation :: launch($bm, ContentObjectRendition :: FORMAT_HTML, ContentObjectRendition :: VIEW_SHORT, $this);
            $html[] = '</br>';
        }
        return implode(StringUtilities :: NEW_LINE, $html);
    }

    function show_when_empty()
    {
        $configuration = $this->get_configuration();
        $result = isset($configuration['show_when_empty']) ? $configuration['show_when_empty'] : true;
        $result = (bool) $result;
        return $result;
    }

    function is_empty()
    {
        $bookmarks = $this->get_bookmarks();
        return $bookmarks->size() == 0;
    }

    function get_bookmarks()
    {
        $condition = new EqualityCondition(Bookmark :: PROPERTY_APPLICATION, PortfolioManager :: APPLICATION_NAME, Bookmark :: get_type_name(), false);
        
        $bookmarks_resultset = RepositoryDataManager :: get_instance()->retrieve_type_content_objects(Bookmark :: get_type_name(), $condition);
        
        return $bookmarks_resultset;
    }

}

?>
