<?php
namespace application\portfolio;

use common\libraries\Request;
use common\extensions\repo_viewer\RepoViewer;
use common\libraries\BreadcrumbTrail;
use common\libraries\Breadcrumb;
use user\UserDataManager;
use repository\ContentObject;
use repository\RepositoryDataManager;
use repository\content_object\portfolio_item\PortfolioItem;
use repository\ComplexContentObjectItem;
use common\libraries\Translation;
use common\libraries\Utilities;
use repository\content_object\link\Link;
use common\libraries\EqualityCondition;
use repository\content_object\youtube\Youtube;
use repository\content_object\rss_feed\RssFeed;
use repository\content_object\portfolio\Portfolio;
use common\extensions\repo_viewer\RepoViewerInterface;
use common\extensions\repo_viewer\RepoViewerBrowserComponent;
use repository\content_object\bookmark\BookmarkForm;
use repository\content_object\bookmark\Bookmark;
use common\libraries\Display;
use common\libraries\Application;

/**
 * Component to create a new portfolio bookmark
 */
class PortfolioManagerPortfolioBookmarkCreatorComponent extends PortfolioManager implements RepoViewerInterface
{

    private $parents;

    private $items = array();

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        $portfolio_owner_id = Request :: get(PortfolioManager :: PARAM_PORTFOLIO_OWNER_ID);

        $content_object = new Bookmark();

        // set title
        $bookmarked_user = UserDataManager :: get_instance()->retrieve_user($portfolio_owner_id);
        $content_object->set_title(Translation :: get('PortfolioBookmark') . ' ' . $bookmarked_user->get_fullname());

        // set application
        $content_object->set_application(self :: APPLICATION_NAME);

        // set url
        $params_bookmark = array();
        $params_bookmark[Application :: PARAM_APPLICATION] = PortfolioManager :: APPLICATION_NAME;
        $params_bookmark[PortfolioManager :: PARAM_ACTION] = PortfolioManager :: ACTION_VIEW_PORTFOLIO;
        $params_bookmark[PortfolioManager :: PARAM_PORTFOLIO_OWNER_ID] = $portfolio_owner_id;
        $url_bookmark = $this->get_url($params_bookmark);
        $content_object->set_url($url_bookmark);

        $params_form = array();
        $params_form[Application :: PARAM_APPLICATION] = PortfolioManager :: APPLICATION_NAME;
        $params_form[PortfolioManager :: PARAM_ACTION] = PortfolioManager :: ACTION_CREATE_BOOKMARK;
        $params_form[PortfolioManager :: PARAM_PORTFOLIO_OWNER_ID] = $portfolio_owner_id;

        $method = 'post';
        $action = $this->get_url($params_form);
        $extra = null;
        $additional_elements = null;
        $allow_new_version = false;
        $form = new BookmarkForm(BookmarkForm :: TYPE_CREATE, $content_object, $form_name, $method, $action, $extra,
                $additional_elements, $allow_new_version);

        if ($form->validate())
        {
            $values = $form->exportValues();
            // create bookmark
            $bookmark = new Bookmark();
            $bookmark->set_title($values[ContentObject :: PROPERTY_TITLE]);
            $bookmark->set_description($values[ContentObject :: PROPERTY_DESCRIPTION]);
            $bookmark->set_application($values[Bookmark :: PROPERTY_APPLICATION]);
            $bookmark->set_url($values[Bookmark :: PROPERTY_URL]);
            $bookmark->set_owner_id($this->get_user_id());

            $success = $bookmark->create();

            $this->display_header();

            if ($success)
            {
                // TODO what to do when successfull: show message (user has to close popup)
                // or just close window?
                echo Translation :: get('CreatingBookmarkSuccess');
                echo '<script type="text/javascript">window.close()</script>';
            }
            else
            {
                // TODO: what to do when not successfull
                // --> reload form with message?
                echo Translation :: get('CreatingBookmarkFailure');
            }

            $this->display_footer();
        }
        else
        {

            // set title
            $bookmarked_item = RepositoryDataManager :: get_instance()->retrieve_content_object($portfolio_selection_id);
            if ($bookmarked_item && $bookmarked_item->get_type() == PortfolioItem :: get_type_name())
            {
                $bookmarked_item = RepositoryDataManager :: get_instance()->retrieve_content_object(
                        $bookmarked_item->get_reference());
            }

            if ($bookmarked_item)
            {
                $content_object->set_title($bookmarked_item->get_title());
            }
            $html[] = $form->toHtml();

            $this->display_header();
            echo implode("\n", $html);
            $this->display_footer();
        }
    }

    function get_allowed_content_object_types()
    {
        return Portfolio :: get_allowed_content();
    }

    function display_header()
    {
        Display :: small_header();
    }

    function display_footer()
    {
        Display :: small_footer();
    }
}

?>