<?php
namespace application\weblcms\course;

use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\BreadcrumbTrail;
use common\libraries\Breadcrumb;
use common\libraries\Request;
use common\libraries\ObjectNotExistException;
use application\weblcms\CourseManagementRights;

/**
 * This class describes an action to unsubscribe from a course
 *
 * @package \application\weblcms\course
 *         
 * @author Yannick & Tristan
 * @author Sven Vanpoucke - Hogeschool Gent - Refactoring
 */
class CourseManagerUnsubscribeComponent extends CourseManager
{

    /**
     * **************************************************************************************************************
     * Inherited Functionality *
     * **************************************************************************************************************
     */
    
    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        $failures = 0;

        $course_management_rights = CourseManagementRights :: get_instance();
        $courses = $this->get_selected_courses();

        while($course = $courses->next_result())
        {
            $course_id = $course->get_id();
            
            if (CourseDataManager :: is_user_direct_subscribed_to_course($this->get_user_id(),
                $course->get_id()) && $course_management_rights->is_allowed(
                CourseManagementRights :: DIRECT_UNSUBSCRIBE_RIGHT, $course->get_id()) &&
                !$course->is_subscribed_as_course_admin($this->get_user()))
            {
                if(!CourseDataManager :: delete_course_user_relations_for_user_and_courses($this->get_user_id(),
                        $course_id))
                {
                    $failures++;
                }
            }
            else
            {
                $failures++;
            }
        }
        
        $message = $this->get_result($failures,
                                     $courses->size(),
                                     'UserNotUnsubscribedFromSelectedCourses',
                                     'UserNotUnsubscribedFromSelectedCourse',
                                     'UserUnsubscribedFromSelectedCourses',
                                     'UserUnsubscribedFromSelectedCourse'
                                    );
        
        $this->redirect($message, ($failures > 0), array(
                self :: PARAM_ACTION => self :: ACTION_BROWSE_SUBSCRIBED_COURSES), array(self :: PARAM_COURSE_ID));
    }

    /**
     * Breadcrumbs are built semi automatically with the given application,
     * subapplication, component...
     * Use this function to add other breadcrumbs between the application /
     * subapplication and the current component
     *
     * @param $breadcrumbtrail \common\libraries\BreadcrumbTrail           
     */
    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add_help('weblcms_course_unsubscriber');
        $breadcrumbtrail->add(new Breadcrumb($this->get_browse_course_url(), Translation :: get('CourseManagerBrowseSubscribedCoursesComponent')));
    }

    /**
     * Returns additional parameters that need to be registered and are used in
     * every url generated by this component
     *
     * @return String[]
     */
    function get_additional_parameters()
    {
        return array(self :: PARAM_COURSE_ID);
    }
}

?>