<?php

namespace application\weblcms\course;

/**
 * Interface that describes the required functionality for a course data manager
 * implementation
 *
 * @package \application\weblcms\course
 *         
 * @author Sven Vanpoucke - Hogeschool Gent
 */
interface CourseDataManagerInterface
{

    /**
     * **************************************************************************************************************
     * Course Dataclass Functionality *
     * **************************************************************************************************************
     */
    
    /**
     * Retrieves a course with the given id
     *
     * @param $id int           
     *
     * @return Course
     */
    function retrieve_course($id);

    /**
     * Retrieves a list of available courses
     *
     * @param $condition \common\libraries\Condition           
     * @param $offset int           
     * @param $max_objects int           
     * @param $order_by \common\libraries\ObjectTableOrder           
     *
     * @return \common\libraries\ResultSet <Coursee>
     */
    function retrieve_courses($condition = null, $offset = null, $max_objects = null, $order_by = null);

    /**
     * Counts the courses
     *
     * @param $condition \common\libraries\Condition           
     *
     * @return int
     */
    function count_courses($condition = null);

    /**
     * **************************************************************************************************************
     * CourseRelCourseSetting Dataclass Functionality *
     * **************************************************************************************************************
     */
    
    /**
     * Retrieves a course rel course setting with the given id
     *
     * @param $id int           
     *
     * @return CourseRelCourseSetting
     */
    function retrieve_course_rel_course_setting($id);

    /**
     * Retrieves a list of available course rel course settings
     *
     * @param $condition \common\libraries\Condition           
     * @param $offset int           
     * @param $max_objects int           
     * @param $order_by \common\libraries\ObjectTableOrder           
     *
     * @return \common\libraries\ResultSet <CourseRelCourseSetting>
     */
    function retrieve_course_rel_course_settings($condition = null, $offset = null, $max_objects = null, $order_by = null);

    /**
     * Counts the course rel course settings
     *
     * @param $condition \common\libraries\Condition           
     *
     * @return int
     */
    function count_course_rel_course_settings($condition = null);

    /**
     * **************************************************************************************************************
     * CourseRelCourseSettingValue Dataclass Functionality *
     * **************************************************************************************************************
     */
    
    /**
     * Retrieves a course rel course setting value with the given id
     *
     * @param $id int           
     *
     * @return CourseRelCourseSettingValue
     */
    function retrieve_course_rel_course_setting_value($id);

    /**
     * Retrieves a list of available course rel course setting values
     *
     * @param $condition \common\libraries\Condition           
     * @param $offset int           
     * @param $max_objects int           
     * @param $order_by \common\libraries\ObjectTableOrder           
     *
     * @return \common\libraries\ResultSet <CourseRelCourseSettingValue>
     */
    function retrieve_course_rel_course_setting_values($condition = null, $offset = null, $max_objects = null, $order_by = null);

    /**
     * Counts the course rel course setting values
     *
     * @param $condition \common\libraries\Condition           
     *
     * @return int
     */
    function count_course_rel_course_setting_values($condition = null);
}

?>