<?php
namespace application\weblcms\course;

use common\libraries\Toolbar;
use common\libraries\ToolbarItem;
use common\libraries\Theme;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\NewObjectTableCellRenderer;
use common\libraries\NewObjectTableCellRendererActionsColumnSupport;

use application\weblcms\WeblcmsManager;

/**
 * This class describes the default cell renderer for the course table
 *
 * @package \application\weblcms\course
 *         
 * @author Yannick & Tristan
 * @author Sven Vanpoucke - Hogeschool Gent - Refactoring
 */
class CourseTableCellRenderer extends NewObjectTableCellRenderer implements 
        NewObjectTableCellRendererActionsColumnSupport
{

    /**
     * **************************************************************************************************************
     * Inherited Functionality *
     * **************************************************************************************************************
     */
    
    /**
     * Renders a cell for a given object
     *
     * @param $column \common\libraries\ObjectTableColumn           
     *
     * @param $course Course           
     *
     * @return String
     */
    function render_cell($column, $course)
    {
        switch ($column->get_name())
        {
            case Course :: PROPERTY_TITLE:
                $course_title = parent :: render_cell($column, $course);
                $course_home_url = $this->get_view_course_home_url($course);
                return '<a href="' . $course_home_url . '">' . $course_title . '</a>';
            case Course :: PROPERTY_COURSE_TYPE_ID :
                return $course->get_course_type_title();
            case Course :: PROPERTY_TITULAR_ID :
                return \user\DataManager :: get_fullname_from_user(
                        $course->get_titular_id(), Translation :: get('TitularUnknown'));
        }
        
        return parent :: render_cell($column, $course);
    }

    /**
     * Returns the actions toolbar
     *
     * @param $course Course           
     *
     * @return String
     */
    public function get_object_actions($course)
    {
        $toolbar = new Toolbar(Toolbar :: TYPE_HORIZONTAL);

        $toolbar->add_item(new ToolbarItem(
                Translation :: get('ViewCourseHome'),
                Theme :: get_common_image_path() . 'action_home.png',
                $this->get_view_course_home_url($course),
                ToolbarItem :: DISPLAY_ICON));

        $toolbar->add_item(new ToolbarItem(
                Translation :: get('Edit', null, Utilities :: COMMON_LIBRARIES),
                Theme :: get_common_image_path() . 'action_edit.png',
                $this->get_component()->get_update_course_url($course->get_id()),
                ToolbarItem :: DISPLAY_ICON));
        
        $toolbar->add_item(new ToolbarItem(
                Translation :: get('Delete', null, Utilities :: COMMON_LIBRARIES),
                Theme :: get_common_image_path() . 'action_delete.png',
                $this->get_component()->get_delete_course_url($course->get_id()),
                ToolbarItem :: DISPLAY_ICON,
                true));
        
        return $toolbar->as_html();
    }

     /***************************************************************************************************************
     * Inherited Functionality                                                                                      *
     ***************************************************************************************************************/

    /**
     * Builds the view course home url
     *
     * @param Course $course
     *
     * @return string
     */
    private function get_view_course_home_url(Course $course)
    {
        return $this->get_component()->get_url(array(
                        WeblcmsManager :: PARAM_ACTION => WeblcmsManager :: ACTION_VIEW_COURSE,
                        WeblcmsManager :: PARAM_COURSE => $course->get_id()
                    ),array(
                        CourseManager :: PARAM_ACTION
                    ));
    }
}
?>