<?php
namespace application\weblcms\course;

use common\libraries\Toolbar;
use common\libraries\ToolbarItem;
use common\libraries\Theme;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\NewObjectTableCellRenderer;

use application\weblcms\CourseManagementRights;
use application\weblcms\WeblcmsDataManager;

/**
 * This class describes the default cell renderer for the subscribed course
 * table
 *
 * @package \application\weblcms\course
 *         
 * @author Yannick & Tristan
 * @author Sven Vanpoucke - Hogeschool Gent - Refactoring
 */
class SubscribedCourseTableCellRenderer extends CourseTableCellRenderer
{
    /****************************************************************************************************************
    * Inherited Functionality											    *
    ****************************************************************************************************************/

    /**
     * Returns the actions toolbar
     *
     * @param $course Course           
     *
     * @return String
     */
    public function get_object_actions($course)
    {
        if (CourseDataManager :: is_user_direct_subscribed_to_course($this->get_component()->get_user_id(),
                $course->get_id()) && CourseManagementRights :: get_instance()->is_allowed(
                        CourseManagementRights :: DIRECT_UNSUBSCRIBE_RIGHT, $course->get_id()) &&
                        !$course->is_subscribed_as_course_admin($this->get_component()->get_user()))
        {
            $toolbar = new Toolbar(Toolbar :: TYPE_HORIZONTAL);
            
            $toolbar->add_item(new ToolbarItem(
                    Translation :: get('Unsubscribe', null, Utilities :: COMMON_LIBRARIES),
                    Theme :: get_common_image_path() . 'action_unsubscribe.png',
                    $this->get_component()->get_unsubscribe_from_course_url($course->get_id()),
                    ToolbarItem :: DISPLAY_ICON));
            
            return $toolbar->as_html();
        }
    
    }
}
?>