<?php
namespace application\weblcms\course_type;

use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\BreadcrumbTrail;
use common\libraries\Breadcrumb;
use common\libraries\Request;

/**
 * This class describes an action to delete a course type
 *
 * @package \application\weblcms\course_type
 *         
 * @author Yannick & Tristan
 * @author Sven Vanpoucke - Hogeschool Gent - Refactoring
 */
class CourseTypeManagerDeleteComponent extends CourseTypeManager
{

    /**
     * **************************************************************************************************************
     * Inherited Functionality *
     * **************************************************************************************************************
     */
    
    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        $course_type_ids = $this->get_selected_course_type_ids();
        
        foreach ($course_type_ids as $course_type_id)
        {
            $course_type = CourseTypeDataManager :: get_instance()->retrieve_course_type($course_type_id);
            
            if (! $course_type)
            {
                throw new ObjectNotExistException(Translation :: get('Course'), $course_id);
            }
            
            if (! CourseTypeDataManager :: has_course_type_courses($course_type->get_id()))
            {
                if (! $course_type->delete())
                {
                    $failures ++;
                }
            }
            else
            {
                $failures ++;
            }
        }
        
        $message = $this->get_result($failures, count($course_type_ids), 'SelectedCourseTypeNotDeleted', 'SelectedCourseTypesNotDeleted', 'SelectedCourseTypeDeleted', 'SelectedCourseTypesDeleted');
        
        $this->redirect($message, ($failures > 0), array(self :: PARAM_ACTION => self :: ACTION_BROWSE), array(
                self :: PARAM_COURSE_TYPE_ID));
    }

    /**
     * Breadcrumbs are built semi automatically with the given application,
     * subapplication, component...
     * Use this function to add other breadcrumbs between the application /
     * subapplication and the current component
     *
     * @param $breadcrumbtrail \common\libraries\BreadcrumbTrail           
     */
    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add_help('weblcms_course_type_deleter');
        $breadcrumbtrail->add(new Breadcrumb($this->get_browse_course_type_url(), Translation :: get('CourseTypeManagerBrowseComponent')));
    }

    /**
     * Returns additional parameters that need to be registered and are used in
     * every url generated by this component
     *
     * @return String[]
     */
    function get_additional_parameters()
    {
        return array(self :: PARAM_COURSE_TYPE_ID);
    }

}

?>