<?php
namespace application\weblcms\course_type;

use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\Request;
use common\libraries\Breadcrumb;

/**
 * This class describes an action to move a course type (change the display
 * order).
 * This class should be implemented to provide the direction
 *
 * @package \application\weblcms\course_type
 *         
 * @author Sven Vanpoucke - Hogeschool Gent
 */
class CourseTypeManagerMoverComponent extends CourseTypeManager
{

    /**
     * **************************************************************************************************************
     * Inherited Functionality *
     * **************************************************************************************************************
     */
    
    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        $course_types = $this->get_selected_course_types();
        $direction = Request :: get(self :: PARAM_MOVE_DIRECTION);
        
        $move_counter = ($direction == self :: MOVE_DIRECTION_UP) ? - 1 : 1;
        
        while ($course_type = $course_types->next_result())
        {
            $course_type->update_display_order_with_count($move_counter);
            
            if (! $course_type->update())
            {
                $failures ++;
            }
        }
        
        $message = $this->get_result($failures, count($course_type_id), 'CourseTypeNotMoved', 'CourseTypesNotMoved', 'CourseTypeMoved', 'CourseTypesMoved');
        
        $this->redirect($message, ($failures > 0), array(self :: PARAM_ACTION => self :: ACTION_BROWSE), array(
                self :: PARAM_COURSE_TYPE_ID));
    }

    /**
     * Breadcrumbs are built semi automatically with the given application,
     * subapplication, component...
     * Use this function to add other breadcrumbs between the application /
     * subapplication and the current component
     *
     * @param $breadcrumbtrail \common\libraries\BreadcrumbTrail           
     */
    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add_help('weblcms_course_type_activation_changer');
        $breadcrumbtrail->add(new Breadcrumb($this->get_browse_course_type_url(), Translation :: get('CourseTypeManagerBrowseComponent')));
    }

    /**
     * Returns additional parameters that need to be registered and are used in
     * every url generated by this component
     *
     * @return String[]
     */
    function get_additional_parameters()
    {
        return array(self :: PARAM_COURSE_TYPE_ID);
    }
}
?>