<?php

namespace application\weblcms\course_type;

/**
 * Interface that describes the required functionality for a course type data
 * manager implementation
 *
 * @package \application\weblcms\course_type
 *         
 * @author Sven Vanpoucke - Hogeschool Gent
 */
interface CourseTypeDataManagerInterface
{

    /**
     * **************************************************************************************************************
     * CourseType Dataclass Functionality *
     * **************************************************************************************************************
     */
    
    /**
     * Retrieves a course type with the given id
     *
     * @param $id int           
     *
     * @return CourseType
     */
    function retrieve_course_type($id);

    /**
     * Retrieves a list of available course types
     *
     * @param $condition \common\libraries\Condition           
     * @param $offset int           
     * @param $max_objects int           
     * @param $order_by \common\libraries\ObjectTableOrder           
     *
     * @return \common\libraries\ResultSet <CourseType>
     */
    function retrieve_course_types($condition = null, $offset = null, $max_objects = null, $order_by = null);

    /**
     * Retrieves a list of available course types joined with course type user
     * order table
     *
     * @param $condition \common\libraries\Condition           
     * @param $offset int           
     * @param $max_objects int           
     * @param $order_by \common\libraries\ObjectTableOrder           
     *
     * @return \common\libraries\ResultSet <CourseType>
     */
    function retrieve_course_types_with_user_order($condition = null, $offset = null, $max_objects = null, $order_by = null);

    /**
     * Counts the course types
     *
     * @param $condition \common\libraries\Condition           
     *
     * @return int
     */
    function count_course_types($condition = null);

    /**
     * **************************************************************************************************************
     * CourseTypeRelCourseSetting Dataclass Functionality *
     * **************************************************************************************************************
     */
    
    /**
     * Retrieves a course type rel course setting with the given id
     *
     * @param $id int           
     *
     * @return CourseTypeRelCourseSetting
     */
    function retrieve_course_type_rel_course_setting($id);

    /**
     * Retrieves a list of available course type rel course settings
     *
     * @param $condition \common\libraries\Condition           
     * @param $offset int           
     * @param $max_objects int           
     * @param $order_by \common\libraries\ObjectTableOrder           
     *
     * @return \common\libraries\ResultSet <CourseTypeRelCourseSetting>
     */
    function retrieve_course_type_rel_course_settings($condition = null, $offset = null, $max_objects = null, $order_by = null);

    /**
     * Counts the course type rel course settings
     *
     * @param $condition \common\libraries\Condition           
     *
     * @return int
     */
    function count_course_type_rel_course_settings($condition = null);

    /**
     * **************************************************************************************************************
     * CourseTypeRelCourseSettingValue Dataclass Functionality *
     * **************************************************************************************************************
     */
    
    /**
     * Retrieves a course type rel course setting value with the given id
     *
     * @param $id int           
     *
     * @return CourseTypeRelCourseSettingValue
     */
    function retrieve_course_type_rel_course_setting_value($id);

    /**
     * Retrieves a list of available course type rel course setting values
     *
     * @param $condition \common\libraries\Condition           
     * @param $offset int           
     * @param $max_objects int           
     * @param $order_by \common\libraries\ObjectTableOrder           
     *
     * @return \common\libraries\ResultSet <CourseTypeRelCourseSettingValue>
     */
    function retrieve_course_type_rel_course_setting_values($condition = null, $offset = null, $max_objects = null, $order_by = null);

    /**
     * Counts the course type rel course setting values
     *
     * @param $condition \common\libraries\Condition           
     *
     * @return int
     */
    function count_course_type_rel_course_setting_values($condition = null);

    /**
     * **************************************************************************************************************
     * CourseTypeUserOrder Dataclass Functionality *
     * **************************************************************************************************************
     */
    
    /**
     * Retrieves a course type user order with the given id
     *
     * @param $id int           
     *
     * @return CourseType
     */
    function retrieve_course_type_user_order($id);

    /**
     * Retrieves a list of available course type user orders
     *
     * @param $condition \common\libraries\Condition           
     * @param $offset int           
     * @param $max_objects int           
     * @param $order_by \common\libraries\ObjectTableOrder           
     *
     * @return \common\libraries\ResultSet<CourseType>
     */
    function retrieve_course_type_user_orders($condition = null, $offset = null, $max_objects = null, $order_by = null);

    /**
     * Counts the course type user orders
     *
     * @param $condition \common\libraries\Condition           
     *
     * @return int
     */
    function count_course_type_user_orders($condition = null);
}

?>