<?php

namespace application\weblcms;

use common\libraries\AjaxManager;
use common\libraries\JsonAjaxResult;
use common\libraries\Path;

use common\libraries\Request;

use common\libraries\PatternMatchCondition;
use common\libraries\EqualityCondition;
use common\libraries\ObjectTableOrder;
use common\libraries\AndCondition;
use common\libraries\InCondition;

use common\libraries\AdvancedElementFinderElement;

use user\User;
use user\UserDataManager;
use common\libraries\CommonAjaxGroupsFeed;

/**
 * Feed to return the course groups of this course
 *
 * @author Sven Vanpoucke
 * @package application.weblcms
 */
class WeblcmsAjaxCourseGroupsFeed extends CommonAjaxGroupsFeed
{
    const PARAM_COURSE_ID = 'course_id';

    /**
     * Returns the required parameters
     * 
     * @return Array
     */
    function required_parameters()
    {
        return array(self :: PARAM_COURSE_ID);
    }

    /**
     * Returns all the groups for this feed
     * 
     * @return ResultSet
     */
    function retrieve_groups()
    {
        // Set the conditions for the search query
        $search_query = Request :: post(self :: PARAM_SEARCH_QUERY);
        if ($search_query && $search_query != '')
        {
            $q = '*' . $search_query . '*';
            $conditions[] = new PatternMatchCondition(CourseGroup :: PROPERTY_NAME, $q);
        }
        
        // Set the course code
        $course_id = $this->get_parameter(self :: PARAM_COURSE_ID);
        
        // Set the filter conditions
        $filter = Request :: post(self :: PARAM_FILTER);
        $filter_id = substr($filter, 2);
        
        if ($filter_id)
        {
            $conditions[] = new EqualityCondition(CourseGroup :: PROPERTY_PARENT_ID, $filter_id);
        }
        else
        {
            $root_course_group = WeblcmsDataManager :: get_instance()->retrieve_course_group_root($course_id);
            $conditions[] = new EqualityCondition(CourseGroup :: PROPERTY_PARENT_ID, $root_course_group->get_id());
        }
        
        $conditions[] = new EqualityCondition(CourseGroup :: PROPERTY_COURSE_CODE, $course_id);
        
        // Combine the conditions
        $count = count($conditions);
        if ($count > 1)
        {
            $condition = new AndCondition($conditions);
        }
        
        if ($count == 1)
        {
            $condition = $conditions[0];
        }
        
        return WeblcmsDataManager :: get_instance()->retrieve_course_groups($condition, null, null, array(
                new ObjectTableOrder(CourseGroup :: PROPERTY_NAME)));
    }

    /**
     * Retrieves all the users for the selected group
     */
    function get_user_ids()
    {
        $filter = Request :: post(self :: PARAM_FILTER);
        $filter_id = substr($filter, 2);
        
        if (! $filter_id)
        {
            return;
        }
        
        $condition = new EqualityCondition(CourseGroupUserRelation :: PROPERTY_COURSE_GROUP, $filter_id);
        $relations = WeblcmsDataManager :: get_instance()->retrieve_course_group_user_relations($condition);
        
        $user_ids = array();
        
        while ($relation = $relations->next_result())
        {
            $user_ids[] = $relation->get_user();
        }
        
        return $user_ids;
    }

    /**
     * Returns the element for a specific group
     * 
     * @return AdvancedElementFinderElement
     */
    function get_group_element($group)
    {
        return new AdvancedElementFinderElement(CourseGroupEntity :: ENTITY_TYPE . '_' . $group->get_id(), 'type type_group', $group->get_name(), $group->get_description(), AdvancedElementFinderElement :: TYPE_SELECTABLE_AND_FILTER);
    }

    /**
     * Returns the element for a specific user
     * 
     * @return AdvancedElementFinderElement
     */
    function get_user_element($user)
    {
        return new AdvancedElementFinderElement(CourseUserEntity :: ENTITY_TYPE . '_' . $user->get_id(), 'type type_user', $user->get_fullname(), $user->get_official_code());
    }

}

?>