<?php

namespace application\weblcms;

use common\libraries\Request;

use group\Group;
use group\GroupDataManager;
use group\GroupRelUser;

use common\libraries\PatternMatchCondition;
use common\libraries\EqualityCondition;
use common\libraries\InCondition;
use common\libraries\AndCondition;
use common\libraries\ObjectTableOrder;

use common\libraries\AdvancedElementFinderElement;
use common\libraries\CommonAjaxGroupsFeed;

use application\weblcms\course\CourseGroupRelation;

/**
 * Feed to return the platform groups of this course
 *
 * @author Sven Vanpoucke
 * @package application.weblcms
 */
class WeblcmsAjaxPlatformGroupsFeed extends CommonAjaxGroupsFeed
{
    const PARAM_COURSE_ID = 'course_id';

    /**
     * Returns the required parameters
     * 
     * @return Array
     */
    function required_parameters()
    {
        return array(self :: PARAM_COURSE_ID);
    }

    /**
     * Returns all the groups for this feed
     * 
     * @return ResultSet
     */
    function retrieve_groups()
    {
        // Set the conditions for the search query
        $search_query = Request :: post(self :: PARAM_SEARCH_QUERY);
        if ($search_query && $search_query != '')
        {
            $q = '*' . $search_query . '*';
            $conditions[] = new PatternMatchCondition(Group :: PROPERTY_NAME, $q);
        }
        
        // Set the filter conditions
        $filter = Request :: post(self :: PARAM_FILTER);
        
        // Javascript filter
        if (! is_null($filter))
        {
            $filter_id = substr($filter, 2);
            $conditions[] = new EqualityCondition(Group :: PROPERTY_PARENT, $filter_id);
        
        }
        else
        {
            $course_id = $this->get_parameter(self :: PARAM_COURSE_ID);
            $group_condition = new EqualityCondition(CourseGroupRelation :: PROPERTY_COURSE_ID, $course_id);
            $subscribed_groups = WeblcmsDataManager :: get_instance()->retrieve_course_group_relations($group_condition);
            
            $subscribed_group_ids = array();
            while ($subscribed_group = $subscribed_groups->next_result())
            {
                $subscribed_group_ids[] = $subscribed_group->get_group_id();
            }
            
            if (count($subscribed_group_ids) == 0)
            {
                return;
            }
            
            $conditions[] = new InCondition(Group :: PROPERTY_ID, $subscribed_group_ids);
        }
        
        // Combine the conditions
        $count = count($conditions);
        if ($count > 1)
        {
            $condition = new AndCondition($conditions);
        }
        
        if ($count == 1)
        {
            $condition = $conditions[0];
        }
        
        return GroupDataManager :: get_instance()->retrieve_groups($condition, null, null, array(
                new ObjectTableOrder(Group :: PROPERTY_NAME)));
    }

    /**
     * Retrieves all the users for the selected group
     */
    function get_user_ids()
    {
        $filter = Request :: post(self :: PARAM_FILTER);
        $filter_id = substr($filter, 2);
        
        if (! $filter_id)
        {
            return;
        }
        
        $condition = new EqualityCondition(GroupRelUser :: PROPERTY_GROUP_ID, $filter_id);
        $relations = GroupDataManager :: get_instance()->retrieve_group_rel_users($condition);
        
        $user_ids = array();
        
        while ($relation = $relations->next_result())
        {
            $user_ids[] = $relation->get_user_id();
        }
        
        return $user_ids;
    }

    /**
     * Returns the element for a specific group
     * 
     * @return AdvancedElementFinderElement
     */
    function get_group_element($group)
    {
        return new AdvancedElementFinderElement(CoursePlatformGroupEntity :: ENTITY_TYPE . '_' . $group->get_id(), 'type type_group', $group->get_name(), $group->get_code(), AdvancedElementFinderElement :: TYPE_SELECTABLE_AND_FILTER);
    }

    /**
     * Returns the element for a specific user
     * 
     * @return AdvancedElementFinderElement
     */
    function get_user_element($user)
    {
        return new AdvancedElementFinderElement(CourseUserEntity :: ENTITY_TYPE . '_' . $user->get_id(), 'type type_user', $user->get_fullname(), $user->get_official_code());
    }

}

?>