<?php

namespace application\weblcms;

use common\libraries\Block;
use common\libraries\WebApplication;
use application\weblcms\WeblcmsBlock;
use common\libraries\EqualityCondition;
use common\libraries\ObjectTableOrder;
use repository\content_object\assignment\Assignment;
use common\libraries\AndCondition;
use common\libraries\InequalityCondition;
use tracking\TrackingDataManager;
use common\libraries\Translation;
use repository\ContentObjectRenderer;
use application\weblcms\tool\assignment\AssignmentTool;
use common\libraries\Application;
use common\libraries\Redirect;


/**
 * A notificationblock for new assignment submissions (assignmenttool)
 */
class WeblcmsAssignmentSubmissions extends WeblcmsBlock
{

    function display_content()
    {
        $user_id = $this->get_user_id();
        
        // Retrieve the last login
        $last_login = $this->get_last_login($user_id);
        
        // Retrieve the assignments of the user
        $conditions = array();
        $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_PUBLISHER_ID, $user_id);
        $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_TOOL, Assignment :: get_type_name());
        $condition = new AndCondition($conditions);
        $weblcms_data_manager = WeblcmsDataManager :: get_instance();
        $assignment_publications_resultset = $weblcms_data_manager->retrieve_content_object_publications($condition);
        if ($assignment_publications_resultset->size() == 0)
        {
            return Translation :: get('YouDoNotOwnAnyAssignments');
        }
        
        $tracking_data_manager = TrackingDataManager :: get_instance();
        $items = array();
        while ($publication = $assignment_publications_resultset->next_result())
        {
            $item = array();
            $conditions = array();
            $conditions[] = new EqualityCondition(WeblcmsAssignmentSubmissionsTracker :: PROPERTY_PUBLICATION_ID, $publication->get_id());
            $conditions[] = new InequalityCondition(WeblcmsAssignmentSubmissionsTracker :: PROPERTY_DATE_SUBMITTED, InequalityCondition :: GREATER_THAN, $last_login);
            $condition = new AndCondition($conditions);
            $submissions_resultset = $tracking_data_manager->retrieve_tracker_items(WeblcmsAssignmentSubmissionsTracker :: get_table_name(), $condition, null, null, null, WeblcmsAssignmentSubmissionsTracker :: CLASS_NAME);
            $object = $publication->get_content_object();
            $item[title] = $object->get_title();
            $parameters = array(WeblcmsManager :: PARAM_COURSE => $publication->get_course_id(), 
                    Application :: PARAM_ACTION => WeblcmsManager :: ACTION_VIEW_COURSE, 
                    WeblcmsManager :: PARAM_TOOL => Assignment :: get_type_name(), 
                    WeblcmsManager :: PARAM_TOOL_ACTION => AssignmentTool :: ACTION_BROWSE_SUBMITTERS, 
                    Tool :: PARAM_BROWSER_TYPE => ContentObjectRenderer :: TYPE_TABLE, 
                    Tool :: PARAM_PUBLICATION_ID => $publication->get_id());
            $item[link] = Redirect :: get_link(WeblcmsManager :: APPLICATION_NAME, $parameters);
            
            $counter = 0;
            while ($submission = $submissions_resultset->next_result())
            {
                $submissions[] = $submission;
                $counter ++;
            }
            if ($counter > 0)
            {
                $item[count] = $counter;
                $items[] = $item;
            }
        }
        
        $html = $this->display_new_items($items);
        if (count($html) == 0)
        {
            return Translation :: get('NoNewSubmissionsSinceLastVisit');
        }
        return implode('', $html);
    }

    function display_new_items($items)
    {
        $html = array();
        foreach ($items as $item)
        {
            $html[] = '<a href="' . $item[link] . '">' . $item[title] . '</a>: ';
            $html[] = $item[count] . ' ' . Translation :: get('New') . '<br />';
        }
        return $html;
    }
}

?>
