<?php
namespace application\weblcms;

use repository\ContentObject;
use common\libraries\SubselectCondition;
use repository\RepositoryDataManager;
use common\libraries\WebApplication;
use common\libraries\ObjectTableOrder;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use common\libraries\Path;
use common\libraries\Translation;
use repository\content_object\announcement\Announcement;
use common\libraries\Theme;
use common\libraries\Application;
use common\libraries\Redirect;
use common\libraries\InequalityCondition;
use common\libraries\InCondition;
use common\libraries\OrCondition;
use rights\TemplateEntity;

/**
 * $Id: new_announcements.class.php 216 2009-11-13 14:08:06Z kariboe $
 * @package application.lib.weblcms.block
 */

/**
 * This class represents a calendar repo_viewer component which can be used
 * to browse through the possible learning objects to publish.
 */
class WeblcmsNewAnnouncements extends WeblcmsNewBlock
{
    //const TOOL_ANNOUNCEMENT = 'announcement';

    function display_content()
    {
        $publications = $this->get_content(self::TOOL_ANNOUNCEMENT);
        ksort($publications);
        $icon = $this->get_new_announcements_icon();
        
        $html = array();
        $html[] = '<ul style="padding: 0px; margin: 0px 0px 0px 15px;">';
        
        $current_course_id = -1;
        foreach($publications as $publication)
        {
            if($publication->get_course_id() != $current_course_id)
            {
                if($current_course_id != -1)
                {
                    $html[] = '</ul>';
                }
                $current_course_id = $publication->get_course_id();
                $html[] = '<li>' . $this->get_course_by_id($current_course_id)->get_title() . '</li>';
                $html[] = '<ul style="padding: 0px; margin: 2px 2px 2px 20px;">';
            }
            $title = htmlspecialchars($publication->get_content_object()->get_title());
            $link = $this->get_course_viewer_link($this->get_course_by_id($publication->get_course_id()), $publication);
            $html[] = '<li style="list-style: none; list-style-image: url(' . $icon . ');">' . '<a href="' . $link . '" ' . $target . '>' . $title . '</a></li>';
        }
        if($current_course_id != -1)
        {
            $html[] = '</ul>';
        }
        $html[] = '</ul>';
        
        if (count($html) < 3)
        {
            return Translation :: get('NoNewAnnouncementsSinceLastVisit');
        }
       
        return implode("\n", $html);
    }

    private function get_new_announcements_icon()
    {
        return Theme :: get_image_path(Tool :: get_tool_type_namespace(self :: TOOL_ANNOUNCEMENT)) . 'logo/' . Theme :: ICON_MINI . '_new.png';
    }

    private function get_course_viewer_link($course, $publication)
    {
        $params[WeblcmsManager :: PARAM_APPLICATION] = WeblcmsManager :: APPLICATION_NAME;
        $params[WeblcmsManager :: PARAM_ACTION] = WeblcmsManager :: ACTION_VIEW_COURSE;
        $params[WeblcmsManager :: PARAM_COURSE] = $course->get_id();
        $params[WeblcmsManager :: PARAM_TOOL] = self :: TOOL_ANNOUNCEMENT;
        $params[Tool :: PARAM_ACTION] = Tool :: ACTION_VIEW;
        $params[Tool :: PARAM_PUBLICATION_ID] = $publication->get_id();
        return Redirect :: get_link(WeblcmsManager :: APPLICATION_NAME, $params);
    }

    private function get_publication_conditions($course)
    {
        $last_visit_date = WeblcmsDataManager :: get_instance()->get_last_visit_date($course->get_id(), $this->get_user_id(), self :: TOOL_ANNOUNCEMENT, 0);

        $conditions = array();
        $conditions[] = WeblcmsDataManager :: get_publications_condition($course, $this->get_user(), self :: TOOL_ANNOUNCEMENT, Announcement :: get_type_name());
        $conditions[] = new InEqualityCondition(ContentObjectPublication :: PROPERTY_PUBLICATION_DATE, InequalityCondition :: GREATER_THAN_OR_EQUAL, $last_visit_date);

        return new AndCondition($conditions);
    }

}

?>
