<?php

namespace application\weblcms;

use common\libraries\Block;
use common\libraries\WebApplication;
use application\weblcms\WeblcmsBlock;
use common\libraries\EqualityCondition;
use common\libraries\ObjectTableOrder;
use group\Mdb2GroupDataManager;
use repository\content_object\assignment\Assignment;
use common\libraries\AndCondition;
use common\libraries\InCondition;
use common\libraries\InequalityCondition;
use common\libraries\Translation;
use repository\ContentObjectRenderer;
use application\weblcms\tool\assignment\AssignmentTool;
use common\libraries\Application;
use common\libraries\Redirect;
use application\weblcms\tool\assignment\AssignmentToolBrowserComponent;
use repository\ContentObject;
use common\libraries\SubselectCondition;
use repository\RepositoryDataManager;
use common\libraries\Utilities;
use common\libraries\DatetimeUtilities;
use application\weblcms\course\CourseGroupRelation;
use application\weblcms\course\CourseUserRelation;
use common\libraries\Theme;


/**
 * A notificationblock for new assignment submissions (assignmenttool)
 */
class WeblcmsNewAssignments extends WeblcmsNewBlock
{

    function display_content()
    {
        $publications = $this->get_content(self::TOOL_ASSIGNMENT);
        $html = $this->display_new_items($publications);
        
        if (count($html) < 3)
        {
            return Translation :: get('NoNewAssignmentsSinceLastVisit');
        }
        return implode("\n", $html);
    }

    function display_new_items($publications)
    {
        ksort($publications);
        $icon = '<img src="' . $this->get_new_assignments_icon() . '"/>';
        
        $html = array();
        $html[] = '<ul style="padding: 0px; margin: 0px 0px 0px 15px;">';
        $current_course_id = -1;
        foreach ($publications as $publication)
        {
            if($publication->get_course_id() != $current_course_id)
            {
                $current_course_id = $publication->get_course_id();
                $html[] = '<li>' . $this->get_course_by_id($current_course_id)->get_title() . '</li>';
            }
            
            $parameters = array(WeblcmsManager :: PARAM_COURSE => $publication->get_course_id(), 
                    Application :: PARAM_ACTION => WeblcmsManager :: ACTION_VIEW_COURSE, 
                    WeblcmsManager :: PARAM_TOOL => Assignment :: get_type_name(), 
                    WeblcmsManager :: PARAM_TOOL_ACTION => AssignmentTool :: ACTION_BROWSE_SUBMITTERS, 
                    Tool :: PARAM_BROWSER_TYPE => ContentObjectRenderer :: TYPE_TABLE, 
                    Tool :: PARAM_PUBLICATION_ID => $publication->get_id());
            $link = Redirect :: get_link(WeblcmsManager :: APPLICATION_NAME, $parameters);
            
            $start_date = DatetimeUtilities :: format_locale_date(Translation :: get('DateFormatShort', null, Utilities :: COMMON_LIBRARIES), $publication->get_content_object()->get_start_time());
            $end_date = DatetimeUtilities :: format_locale_date(Translation :: get('DateFormatShort', null, Utilities :: COMMON_LIBRARIES), $publication->get_content_object()->get_end_time());
            $html[] = '<a href="' . $link . '">' . $icon . ' ' . $publication->get_content_object()->get_title() . '</a>: ' . Translation :: get('From') . ' ' . $start_date . ' ' . Translation :: get('Until') . ' ' . $end_date . '<br />';
        }
        $html[] = '</ul>';
        return $html;
    }
    
    private function get_new_assignments_icon()
    {
        return Theme :: get_image_path(Tool :: get_tool_type_namespace(self :: TOOL_ASSIGNMENT)) . 'logo/' . Theme :: ICON_MINI . '_new.png';
    }
}

?>
