<?php
namespace application\weblcms;

use common\libraries\Block;
use common\libraries\WebApplication;
use application\weblcms\WeblcmsBlock;
use common\libraries\EqualityCondition;
use common\libraries\ObjectTableOrder;
use repository\content_object\document\Document;
use common\libraries\AndCondition;
use common\libraries\InequalityCondition;
use common\libraries\Translation;
use repository\ContentObjectRenderer;
use application\weblcms\tool\document\DocumentTool;
use common\libraries\Application;
use common\libraries\Redirect;
use application\weblcms\tool\document\DocumentToolBrowserComponent;
use repository\ContentObject;
use common\libraries\SubselectCondition;
use repository\RepositoryDataManager;
use common\libraries\Utilities;
use common\libraries\DatetimeUtilities;
use application\weblcms\course\CourseUserRelation;
use common\libraries\Theme;

/**
 * A notification block for new document submissions (document tool)
 * based on new_assignments.class.php
 * @author Parcifal Aertssen (Howest)
 */
class WeblcmsNewDocuments extends WeblcmsNewBlock
{

    function display_content()
    {
        $publications = $this->get_content(self::TOOL_DOCUMENT);
        $html = $this->display_new_items($publications);
        
        if (count($html) < 3)
        {
            return Translation :: get('NoNewDocumentsSinceLastVisit');
        }
        return implode("\n", $html);
    }

    function display_new_items($publications)
    {
        ksort($publications);
        $icon = '<img src="' . $this->get_new_documents_icon() . '"/>';
        
        $html = array();
        $html[] = '<ul style="padding: 0px; margin: 0px 0px 0px 15px;">';
        $current_course_id = -1;
        foreach ($publications as $publication)
        {
            if($publication->get_course_id() != $current_course_id)
            {
                $current_course_id = $publication->get_course_id();
                $html[] = '<li>' . $this->get_course_by_id($current_course_id)->get_title() . '</li>';
            }
            
            $parameters = array(WeblcmsManager :: PARAM_COURSE => $publication->get_course_id(), 
                    Application :: PARAM_ACTION => WeblcmsManager :: ACTION_VIEW_COURSE, 
                    WeblcmsManager :: PARAM_TOOL => Document :: get_type_name(), 
                    WeblcmsManager :: PARAM_TOOL_ACTION => DocumentTool :: ACTION_VIEW_DOCUMENTS, 
                    Tool :: PARAM_BROWSER_TYPE => ContentObjectRenderer :: TYPE_TABLE, 
                    Tool :: PARAM_PUBLICATION_ID => $publication->get_id());
            $link = Redirect :: get_link(WeblcmsManager :: APPLICATION_NAME, $parameters);
            
            $html[] = '<a href="' . $link . '">' . $icon . ' ' . $publication->get_content_object()->get_title() . '</a><br />';
        }
        $html[] = '</ul>';
        return $html;
    }
    
    private function get_new_documents_icon()
    {
        return Theme :: get_image_path(Tool :: get_tool_type_namespace(self :: TOOL_DOCUMENT)) . 'logo/' . Theme :: ICON_MINI . '_new.png';
    }
}

?>