<?php
namespace application\weblcms;

use common\libraries\ComplexContentObjectSupport;
use common\libraries\ResourceManager;
use admin\AdminDataManager;
use common\libraries\Display;
use common\libraries\Theme;
use common\libraries\Utilities;
use common\libraries\Request;
use common\libraries\Path;
use common\libraries\Translation;
use Pager;
use repository\ContentObject;

/**
 * $Id: list_content_object_publication_list_renderer.class.php 216 2009-11-13
 * 14:08:06Z kariboe $
 *
 * @package application.lib.weblcms.browser.list_renderer
 */

/**
 * Renderer to display a list of learning object publications
 */
class ListContentObjectPublicationListRenderer extends ContentObjectPublicationListRenderer
{

    /**
     * The page to display
     */
    private $page_nr;

    /**
     * Number of items to display per page
     */
    private $per_page;

    /**
     * The pager object to split the data in several pages
     */
    private $pager;

    /**
     * A prefix for the URL-parameters, can be used on pages with multiple
     * Pagers
     */
    private $param_prefix;

    /**
     * The total number of items in the list
     */
    private $total_number_of_items;

    /**
     * The default number of objects per page
     */
    const DEFAULT_PER_PAGE = 5;

    /**
     * Returns the HTML output of this renderer.
     *
     * @return string The HTML output
     */
    function as_html()
    {
        // prepares the pager
        $this->prepare_pager();

        $publications = $this->get_page_publications();

        if (count($publications) == 0)
        {
            return Display :: normal_message(Translation :: get('NoPublications', null, Utilities :: COMMON_LIBRARIES), true);
        }

        $html[] = ResourceManager :: get_instance()->get_resource_html(Path :: get(WEB_LIB_PATH) . 'libraries/resources/javascript/publications_list.js');

        if ($this->get_actions() && $this->is_allowed(WeblcmsRights :: EDIT_RIGHT))
        {
            $html[] = '<div style="clear: both;">';
            $html[] = '<form class="publication_list" name="publication_list" action="' . $this->get_url() . '" method="POST" >';
        }
        $i = 0;

        // add top page navigation
        $html[] = $this->get_navigation_html();

        foreach ($publications as $index => $publication)
        {
            $first = ($index == 0);
            $last = ($index == count($publications) - 1);
            $html[] = $this->render_publication($publication, $first, $last, $i);
            $i ++;
        }

        if ($this->get_actions() && count($publications) > 0 && $this->is_allowed(WeblcmsRights :: EDIT_RIGHT))
        {
            $table_name = Utilities :: get_classname_from_namespace(__CLASS__, true);
            foreach ($_GET as $parameter => $value)
            {
                if ($parameter == 'message')
                    continue;

                $html[] = '<input type="hidden" name="' . $parameter . '" value="' . $value . '" />';
            }
            $html[] = '<script type="text/javascript">
							/* <![CDATA[ */
							function setCheckbox(formName, value) {
								var d = document[formName];
								for (i = 0; i < d.elements.length; i++) {
									if (d.elements[i].type == "checkbox") {
									     d.elements[i].checked = value;
									}
								}
							}
							/* ]]> */
							</script>';

            $html[] = '<div style="text-align: right;">';
            $html[] = '<a href="?" onclick="setCheckbox(\'publication_list\', true); return false;">' . Translation :: get('SelectAll', null, Utilities :: COMMON_LIBRARIES) . '</a>';
            $html[] = '- <a href="?" onclick="setCheckbox(\'publication_list\', false); return false;">' . Translation :: get('UnselectAll', null, Utilities :: COMMON_LIBRARIES) . '</a><br />';
            $html[] = '<select id="tool_actions" name="' . $table_name . '_action_value">';
            foreach ($this->get_actions()->get_form_actions() as $form_action)
            {
                $html[] = '<option value="' . $form_action->get_action() . '" class="' . ($form_action->get_confirm() ? 'confirm' : '') . '">' . $form_action->get_title() . '</option>';
            }
            $html[] = '</select>';
            $html[] = '<input type="hidden" name="' . $table_name . '_action_name" value="' . $this->get_actions()->get_action() . '"/>';
            $html[] = '<input type="hidden" name="table_name" value="' . $table_name . '"/>';
            $html[] = '<input type="hidden" name="' . $table_name . '_namespace" value="' . __NAMESPACE__ . '"/>';
            $html[] = ' <input type="submit" value="' . Translation :: get('Ok', null, Utilities :: COMMON_LIBRARIES) . '"/>';
            $html[] = '</div>';
            
            // add bottom page navigation
            $html[] = $this->get_navigation_html();
            $html[] = '</form>';
            $html[] = '</div>';
        }

        return implode("\n", $html);
    }

    static function handle_table_action()
    {
        $selected_ids = Request :: post(WeblcmsManager :: PARAM_PUBLICATION);

        if (empty($selected_ids))
        {
            $selected_ids = array();
        }
        elseif (! is_array($selected_ids))
        {
            $selected_ids = array($selected_ids);
        }
        Request :: set_get(Tool :: PARAM_PUBLICATION_ID, $selected_ids);
    }

    /**
     * Renders a single publication.
     *
     * @param $publication ContentObjectPublication
     *            The publication.
     * @param $first boolean
     *            True if the publication is the first in the list
     *            it is a part of.
     * @param $last boolean
     *            True if the publication is the last in the list
     *            it is a part of.
     * @return string The rendered HTML.
     */
    function render_publication($publication, $first = false, $last = false, $position)
    {
        // TODO: split into separate overrideable methods
        $html = array();
        $last_visit_date = $this->get_tool_browser()->get_last_visit_date();
        $icon_suffix = '';
        if ($publication->is_hidden())
        {
            $icon_suffix = '_na';
        }
        else
        {
            if ($publication->get_publication_date() >= $last_visit_date)
            {
                $icon_suffix = '_new';
            }
            else
            {
                $feedbacks = AdminDataManager :: get_instance()->retrieve_feedback_publications($publication->get_id(), null, WeblcmsManager :: APPLICATION_NAME);
                while ($feedback = $feedbacks->next_result())
                {
                    if ($feedback->get_modification_date() >= $last_visit_date)
                    {
                        $icon_suffix = '_new';
                        break;
                    }
                }
            }
        }

        $left = $position % 2;
        switch ($left)
        {
            case 0 :
                $level = 'level_1';
                break;
            case 1 :
                $level = 'level_2';
                break;

            // case 2: $level = 'level_3'; break;
            // case 3: $level = 'level_4'; break;
        }

        if ($publication->get_content_object() instanceof ComplexContentObjectSupport)
        {
            $title_url = $this->get_url(array(Tool :: PARAM_PUBLICATION_ID => $publication->get_id(),
                    Tool :: PARAM_ACTION => Tool :: ACTION_DISPLAY_COMPLEX_CONTENT_OBJECT));
        }
        else
        {
            $title_url = $this->get_url(array(Tool :: PARAM_PUBLICATION_ID => $publication->get_id(),
                    Tool :: PARAM_ACTION => Tool :: ACTION_VIEW), array(), true);
        }

        $html[] = '<div class="announcements ' . $level . '" style="background-image: url(' . str_replace('.png', $icon_suffix . '.png', $publication->get_content_object()->get_icon_path()) . ');">';
        $html[] = '<div class="title' . ($publication->is_visible_for_target_users() ? '' : ' invisible') . '">';
        $html[] = '<a href="' . $title_url . '">' . $this->render_title($publication) . '</a>';
        $html[] = '</div>';
        $html[] = '<div class="topactions' . ($publication->is_visible_for_target_users() ? '' : ' invisible') . '">';
        $html[] = $this->render_top_action($publication);
        $html[] = '</div><div class="clear">&nbsp;</div>';
        // $html[] = '<div class="description' .
        // ($publication->is_visible_for_target_users() ? '' : ' invisible') .
        // '">';
        // $html[] = $publication->get_content_object()->get_description();
        $html[] = $this->render_description($publication);
        // $html[] = '</div>';
        $html[] = '<div class="publication_info' . ($publication->is_visible_for_target_users() ? '' : ' invisible') . '">';
        $html[] = $this->render_publication_information($publication);
        $html[] = '</div>';
        $html[] = '<div class="publication_actions">';
        if ($this->get_actions() && $this->is_allowed(WeblcmsRights :: EDIT_RIGHT, $publication))
        {
            $html[] = '<input style="display: inline; float: right;" class="pid" type="checkbox" name="' . WeblcmsManager :: PARAM_PUBLICATION . '[]" value="' . $publication->get_id() . '"/>';
        }
        $html[] = $this->get_publication_actions($publication, false)->as_html();
        $html[] = '<div class="clear"></div>';
        $html[] = '</div>';
        $html[] = '</div><br />';

        return implode("\n", $html);
    }

    /**
     * Prepares the pager (counts objects, sets page, etc)
     */
    function prepare_pager()
    {
        // set the prefix
        $this->param_prefix = ContentObjectPublication :: get_table_name() . '_';

        // count the total number of objects
        $this->total_number_of_items = $this->get_publication_count();

        // set the page number
        $this->page_nr = isset($_SESSION[$this->param_prefix . 'page_nr']) ? $_SESSION[$this->param_prefix . 'page_nr'] : 1;
        $this->page_nr = Request :: get($this->param_prefix . 'page_nr') ? Request :: get($this->param_prefix . 'page_nr') : $this->page_nr;
        $_SESSION[$this->param_prefix . 'page_nr'] = $this->page_nr;

        // set the number of objects per page
        $this->per_page = self :: DEFAULT_PER_PAGE;
    }

    /**
     * Get the Pager object to split the showed data in several pages
     */
    function get_pager()
    {
        if (is_null($this->pager))
        {
            $total_number_of_items = $this->total_number_of_items;
            $params['mode'] = 'Sliding';
            $params['perPage'] = $this->per_page;
            $params['totalItems'] = $total_number_of_items;
            $params['urlVar'] = $this->param_prefix . 'page_nr';
            $params['prevImg'] = '<img src="' . Theme :: get_common_image_path() . 'action_prev.png"  style="vertical-align: middle;"/>';
            $params['nextImg'] = '<img src="' . Theme :: get_common_image_path() . 'action_next.png"  style="vertical-align: middle;"/>';
            $params['firstPageText'] = '<img src="' . Theme :: get_common_image_path() . 'action_first.png"  style="vertical-align: middle;"/>';
            $params['lastPageText'] = '<img src="' . Theme :: get_common_image_path() . 'action_last.png"  style="vertical-align: middle;"/>';
            $params['firstPagePre'] = '';
            $params['lastPagePre'] = '';
            $params['firstPagePost'] = '';
            $params['lastPagePost'] = '';
            $params['spacesBeforeSeparator'] = '';
            $params['spacesAfterSeparator'] = '';
            $params['currentPage'] = $this->page_nr;

            $params['extraVars'] = $this->get_tool_browser()->get_parameters();
            $params['excludeVars'] = array('message');

            $this->pager = Pager :: factory($params);
        }
        return $this->pager;
    }

    /**
     * Get the HTML-code with the navigational buttons to browse through the
     * data-pages.
     */
    function get_navigation_html()
    {
        $pager = $this->get_pager();
        $pager_links = $pager->getLinks();
        $showed_items = $pager->getOffsetByPageId();
        return $pager_links['first'] . ' ' . $pager_links['back'] . ' ' . $pager->getCurrentPageId() . ' / ' . $pager->numPages() . ' ' . $pager_links['next'] . ' ' . $pager_links['last'];
    }

    function get_page_publications()
    {
        $pager = $this->get_pager();
        if ($pager)
        {
            $offset = $pager->getOffsetByPageId();
            $from = $offset[0] - 1;
            $count = $this->per_page;
        }
        else
        {
            $from = 0;
            $count = - 1;
        }

        return $this->get_publications($from, $count);
    }
}
?>
