<?php

namespace application\weblcms;

use group\GroupDataManager;
use common\libraries\DatetimeUtilities;
use repository\ContentObject;
use user\UserDataManager;
use common\libraries\Theme;
use common\libraries\Path;
use repository\DefaultContentObjectTableCellRenderer;
use common\libraries\Translation;
use common\libraries\ComplexContentObjectSupport;
use common\libraries\Utilities;
use admin\AdminDataManager;
use rights\RightsDataManager;
use rights\TemplateEntity;

/**
 * $Id: object_publication_table_cell_renderer.class.php 216 2009-11-13
 * 14:08:06Z kariboe $
 *
 * @package application.lib.weblcms.browser.object_publication_table
 */

/**
 * This class is a cell renderer for a publication candidate table
 */
class ObjectPublicationTableCellRenderer extends DefaultContentObjectTableCellRenderer
{

    protected $table_renderer;
    private $object_count;
    private $last_visit_date;

    function __construct($table_renderer)
    {
        $this->table_renderer = $table_renderer;
        $this->last_visit_date = $this->table_renderer->get_tool_browser()->get_last_visit_date();

    }

    function set_object_count($count)
    {
        $this->object_count = $count;
    }

    function get_object_count()
    {
        return $this->object_count;
    }

    /*
     * Inherited
     */

    function render_cell($column, $publication)
    {
        if ($column === ObjectPublicationTableColumnModel :: get_action_column())
        {
            return $this->get_actions($publication)->as_html();
        }

        switch ($column->get_name())
        {
            case Translation :: get('Status', null, Utilities :: COMMON_LIBRARIES) :
                $title = Translation :: get('TypeName', array(), ContentObject :: get_content_object_type_namespace($publication->get_optional_property(ContentObject :: PROPERTY_TYPE)));

                $icon_suffix = '';
                if ($publication->is_hidden())
                {
                    $icon_suffix = '_na';
                    $title .= ' ' . Translation :: get('NotAvailable') . ')';
                }
                else
                {
                    if ($publication->get_publication_date() >= $this->last_visit_date)
                    {
                        $icon_suffix = '_new';
                        $title .= ' (' . Translation :: get('New') . ')';
                    }
                    else
                    {
                        $feedbacks = AdminDataManager :: get_instance()->retrieve_feedback_publications($publication->get_id(), null, WeblcmsManager :: APPLICATION_NAME);
                        while ($feedback = $feedbacks->next_result())
                        {
                            if ($feedback->get_modification_date() >= $this->last_visit_date)
                            {
                                $icon_suffix = '_new';
                                $title .= ' (' . Translation :: get('New') . ')';
                                break;
                            }
                        }
                    }
                }

                return '<img title="' . $title . '" src="' . str_replace('.png', $icon_suffix . '.png', $publication->get_content_object(true)->get_icon_path(Theme :: ICON_MINI)) . '" />';
                break;
            case ContentObject :: PROPERTY_TITLE :

                if ($publication->get_content_object() instanceof ComplexContentObjectSupport)
                {
                    $details_url = $this->table_renderer->get_url(array(
                            Tool :: PARAM_PUBLICATION_ID => $publication->get_id(),
                            Tool :: PARAM_ACTION => Tool :: ACTION_DISPLAY_COMPLEX_CONTENT_OBJECT));
                    return '<a href="' . $details_url . '">' . DefaultContentObjectTableCellRenderer :: render_cell($column, $publication->get_content_object()) . '</a>';
                }

                $details_url = $this->table_renderer->get_url(array(
                        Tool :: PARAM_PUBLICATION_ID => $publication->get_id(),
                        Tool :: PARAM_ACTION => Tool :: ACTION_VIEW));
                return '<a href="' . $details_url . '">' . parent :: render_cell($column, $publication->get_content_object()) . '</a>';
                break;
            case ContentObjectPublication :: PROPERTY_PUBLICATION_DATE :
                $date_format = Translation :: get('DateTimeFormatLong', null, Utilities :: COMMON_LIBRARIES);
                $data = DatetimeUtilities :: format_locale_date($date_format, $publication->get_publication_date());
                break;
            case ContentObjectPublication :: PROPERTY_PUBLISHER_ID :
                $user = $this->retrieve_user($publication->get_publisher_id());
                if (! $user)
                {
                    $data = '<i>' . Translation :: get('UserUnknown') . '</i>';
                }
                else
                {
                    $data = $user->get_fullname();
                }
                break;
            case 'published_for' :
                if ($publication->is_email_sent())
                {
                    $email_icon = ' - <img src="' . Theme :: get_common_image_path() . 'action_email.png" alt=""
                        style="vertical-align: middle;" title="' . Translation :: get('SentByEmail') . '"/>';
                }
                $data = '<div style="float: left;">' . $this->render_publication_targets($publication) . '</div>' . $email_icon;
                break;
            case ContentObjectPublication :: PROPERTY_DISPLAY_ORDER_INDEX :
                return $publication->get_display_order_index();

            case ContentObject :: PROPERTY_DESCRIPTION :
                $data = $publication->get_optional_property(ContentObject :: PROPERTY_DESCRIPTION);
        }

        if ($publication->is_hidden())
        {
            return '<span style="color: gray">' . $data . '</span>';
        }
        else
        {
            return $data;
        }
    }

    function render_publication_targets($publication)
    {
        if ($publication->is_email_sent())
        {
            $email_suffix = ' - <img src="' . Theme :: get_common_image_path() . 'action_email.png" alt="" style="vertical-align: middle;"/>';
        }

        $target_entities = WeblcmsRights :: get_instance()->get_target_entities(WeblcmsRights :: VIEW_RIGHT, WeblcmsManager :: APPLICATION_NAME, $publication->get_id(), WeblcmsRights :: TYPE_PUBLICATION, $this->table_renderer->get_tool_browser()->get_course_id(), WeblcmsRights :: TREE_TYPE_COURSE);

        // if ($publication->is_for_everybody())
        // {
        // return htmlentities(Translation :: get('Everybody', null, Utilities
        // :: COMMON_LIBRARIES)) . $email_suffix;
        // }
        // else
        // {

        $wdm = WeblcmsDatamanager :: get_instance();
        $gdm = GroupDataManager :: get_instance();
        $rdm = RightsDataManager :: get_instance();

        $target_list = array();

        // don't display each individual user if it is published for
        // everybody...
        // if a name is alfabetically before "everybody" this would be the
        // selected
        // item in the dropdownlist which works confusing when you expect
        // "everybody"
        if (array_key_exists(0, $target_entities[0]))
        {
            $target_list[] = Translation :: get('Everybody', null, Utilities :: COMMON_LIBRARIES);
        }
        else
        {
            $target_list[] = '<select>';

            foreach ($target_entities as $entity_type => $entity_ids)
            {
                switch ($entity_type)
                {
                    case CoursePlatformGroupEntity :: ENTITY_TYPE :
                        foreach ($entity_ids as $group_id)
                        {
                            $group = $gdm->retrieve_group($group_id);
                            if ($group)
                            {
                                $target_list[] = '<option>' . $group->get_name() . '</option>';
                            }
                        }
                        break;
                    case CourseUserEntity :: ENTITY_TYPE :
                        foreach ($entity_ids as $user_id)
                        {
                            $user = $this->retrieve_user($user_id);
                            if ($user)
                            {
                                $target_list[] = '<option>' . $user->get_fullname() . '</option>';
                            }
                        }
                        break;
                    case CourseGroupEntity :: ENTITY_TYPE :
                        foreach ($entity_ids as $course_group_id)
                        {
                            $course_group = $wdm->retrieve_course_group($course_group_id);
                            if ($course_group)
                            {
                                $target_list[] = '<option>' . $course_group->get_name() . '</option>';
                            }
                        }

                        break;
                    case TemplateEntity :: ENTITY_TYPE :
                        foreach ($entity_ids as $template_id)
                        {
                            $template = $rdm->retrieve_template($template_id);
                            if ($template)
                            {
                                $target_list[] = '<option>' . $template->get_name() . '</option>';
                            }
                        }
                        break;
                    case 0 :
                        $target_list[] = '<option>Everyone</option>';
                        break;
                }
            }
            $target_list[] = '</select>';
        }

        return implode("\n", $target_list);

        // $users = $publication->get_target_users();
        // $course_groups = $publication->get_target_course_groups();
        // $groups = $publication->get_target_groups();
        // if (count($users) + count($course_groups) + count($groups) == 1)
        // {
        // if (count($users) == 1)
        // {
        // $user = $this->retrieve_user($users[0]);
        // return $user->get_firstname() . ' ' . $user->get_lastname() .
    // $email_suffix;
        // }
        // elseif (count($groups) == 1)
        // {
        // $group = $gdm->retrieve_group($groups[0]);
        // return $group->get_name();
        // }
        // else
        // {
        // $wdm = WeblcmsDatamanager :: get_instance();
        // $course_group = $wdm->retrieve_course_group($course_groups[0]);
        // return $course_group->get_name();
        // }
        // }
        // $target_list = array();
        // $target_list[] = '<select>';
        // foreach ($users as $user_id)
        // {
        // $user = $this->retrieve_user($user_id);
        // $target_list[] = '<option>' . $user->get_fullname() . '</option>';
        // }
        // foreach ($course_groups as $course_group_id)
        // {
        // $wdm = WeblcmsDatamanager :: get_instance();
        // $course_group = $wdm->retrieve_course_group($course_group_id);
        // $target_list[] = '<option>' . $course_group->get_name() .
    // '</option>';
        // }
        // foreach ($groups as $index => $group_id)
        // {
        // $gdm = GroupDataManager :: get_instance();
        // //Todo: make this more efficient. Get all course_groups using a
    // single query
        // $group = $gdm->retrieve_group($group_id);
        // $target_list[] = '<option>' . $group->get_name() . '</option>';
        // }
        // $target_list[] = '</select>';
        // return implode("\n", $target_list) . $email_suffix;
        // }
    }

    function retrieve_user($user_id)
    {
        return UserDataManager :: get_instance()->retrieve_user($user_id);
    }

    function get_actions($publication)
    {
        $toolbar = $this->table_renderer->get_publication_actions($publication, $this->is_display_order_column());
        return $toolbar;
    }

}

?>