<?php
namespace application\weblcms;

use common\libraries\StaticTableColumn;
use repository\ContentObject;
use common\libraries\ObjectTableColumn;
use common\libraries\ObjectTableColumnModel;
use common\libraries\Translation;
use common\libraries\Utilities;
use repository\RepositoryDataManager;

/**
 * $Id: object_publication_table_column_model.class.php 216 2009-11-13 14:08:06Z
 * kariboe $
 *
 * @package application.lib.weblcms.browser.object_publication_table
 */
/**
 * This class represents a column model for a publication candidate table
 */
class ObjectPublicationTableColumnModel extends ObjectTableColumnModel
{
    /**
     * The column with the action buttons.
     */
    private static $action_column;

    /**
     * Constructor.
     */
    function __construct($columns)
    {
        if ($columns)
        {
            parent :: __construct($columns, 5, SORT_ASC);
        }
        else
        {
            parent :: __construct(self :: get_columns(), 5, SORT_ASC);
        }

    }

    /**
     * Gets the columns of this table.
     *
     * @return array An array of all columns in this table.
     * @see ContentObjectTableColumn
     */
    function get_columns()
    {
        $columns = $this->get_basic_columns();
        $columns[] = self :: get_action_column();
        return $columns;
    }

    function get_basic_columns()
    {
        $wdm = WeblcmsDataManager :: get_instance();
        $rdm = RepositoryDataManager :: get_instance();

        $columns = array();
        $columns[] = new StaticTableColumn('Status');
        $columns[] = new ObjectTableColumn(ContentObject :: PROPERTY_TITLE, true, $rdm->get_alias(ContentObject :: get_table_name()));
        $columns[] = new ObjectTableColumn(ContentObject :: PROPERTY_DESCRIPTION, true, $rdm->get_alias(ContentObject :: get_table_name()));
        $columns[] = new ObjectTableColumn(ContentObjectPublication :: PROPERTY_PUBLICATION_DATE, true, $wdm->get_alias(ContentObjectPublication :: get_table_name()));
        $columns[] = new ObjectTableColumn(ContentObjectPublication :: PROPERTY_PUBLISHER_ID, true, $wdm->get_alias(ContentObjectPublication :: get_table_name()));
        $columns[] = new ObjectTableColumn('published_for', false);
        $columns[] = new ObjectTableColumn(ContentObjectPublication :: PROPERTY_DISPLAY_ORDER_INDEX, true, $wdm->get_alias(ContentObjectPublication :: get_table_name()));
        return $columns;
    }

    /**
     * Gets the column wich contains the action buttons.
     *
     * @return ContentObjectTableColumn The action column.
     */
    static function get_action_column()
    {
        if (! isset(self :: $action_column))
        {
            self :: $action_column = new StaticTableColumn(Translation :: get('Actions', null, Utilities :: COMMON_LIBRARIES));
        }
        return self :: $action_column;
    }

    function get_display_order_column_property()
    {
        return ContentObjectPublication :: PROPERTY_DISPLAY_ORDER_INDEX;
    }
}
?>