<?php

namespace application\weblcms;

use common\libraries\ObjectTableDataProvider;
use common\libraries\Request;

/**
 * $Id: object_publication_table_data_provider.class.php 216 2009-11-13
 * 14:08:06Z kariboe $
 *
 * @package application.lib.weblcms.browser.object_publication_table
 */

/**
 * This class represents a data provider for a publication candidate table
 */
class ObjectPublicationTableDataProvider extends ObjectTableDataProvider
{
    /*
     * Inherited
     */

    function get_objects($offset, $count, $order_property = null)
    {
        if (!$order_property)
        {
            $order_property = $this->get_browser()->get_tool_browser()->get_default_order_property();
        }
        $order_property = $this->get_order_property($order_property);
        $type = $this->get_browser()->get_tool_browser()->get_publication_type();
        switch ($type)
        {
            case Tool :: PUBLICATION_TYPE_FROM_ME :
                return WeblcmsDataManager :: get_instance()->retrieve_my_publications(
                    $this->get_browser()->get_tool_browser()->get_location(),
                    $this->get_browser()->get_tool_browser()->get_entities(),
                    $this->get_browser()->get_tool_browser()->get_publication_conditions(), $order_property, $offset,
                    $count,
                    $this->get_browser()->get_tool_browser()->get_user_id()
                );
                break;
            case Tool :: PUBLICATION_TYPE_ALL :
                return WeblcmsDataManager :: get_instance()->retrieve_all_publications(
                    $this->get_browser()->get_tool_browser()->get_publication_conditions(), $order_property, $offset,
                    $count
                );
                break;
            default :
                return WeblcmsDataManager :: get_instance()
                    ->retrieve_content_object_publications_with_view_right_granted_in_category_location(
                    $this->get_browser()->get_tool_browser()->get_location(),
                    $this->get_browser()->get_tool_browser()->get_entities(),
                    $this->get_browser()->get_tool_browser()->get_publication_conditions(), $order_property, $offset,
                    $count,
                    $this->get_browser()->get_tool_browser()->get_user_id()
                );
                break;
        }
    }

    /*
    * Inherited
    */

    private $count_cache;

    function get_object_count()
    {
        $type = $this->get_browser()->get_tool_browser()->get_publication_type();

        if (is_null($this->count_cache))
        {
            switch ($type)
            {
                case Tool :: PUBLICATION_TYPE_FROM_ME :
                    $this->count_cache = WeblcmsDataManager :: get_instance()->count_my_publications(
                        $this->get_browser()->get_tool_browser()->get_location(),
                        $this->get_browser()->get_tool_browser()->get_entities(),
                        $this->get_browser()->get_tool_browser()->get_publication_conditions(),
                        $this->get_browser()->get_tool_browser()->get_user_id()
                    );
                    break;
                case Tool :: PUBLICATION_TYPE_ALL :
                    $this->count_cache = WeblcmsDataManager :: get_instance()->count_content_object_publications(
                        $this->get_browser()->get_tool_browser()->get_publication_conditions()
                    );
                    break;
                default :
                    $this->count_cache = WeblcmsDataManager :: get_instance()
                        ->count_content_object_publications_with_view_right_granted_in_category_location(
                        $this->get_browser()->get_tool_browser()->get_location(),
                        $this->get_browser()->get_tool_browser()->get_entities(),
                        $this->get_browser()->get_tool_browser()->get_publication_conditions(),
                        $this->get_browser()->get_tool_browser()->get_user_id()
                    );
                    break;
            }
        }
        return $this->count_cache;
    }

}

?>