<?php
namespace application\weblcms;

use common\extensions\category_manager\CategoryVisibilitySupported;
use common\libraries\Utilities;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use common\libraries\Path;
use common\extensions\category_manager\PlatformCategory;
use common\libraries\Translation;

/**
 * $Id: content_object_publication_category.class.php 216 2009-11-13 14:08:06Z
 * kariboe $
 * 
 * @package application.lib.weblcms.category_manager
 */
/**
 *
 * @author Sven Vanpoucke
 */

class ContentObjectPublicationCategory extends PlatformCategory implements CategoryVisibilitySupported
{
    const CLASS_NAME = __CLASS__;
    
    const PROPERTY_COURSE = 'course_id';
    const PROPERTY_TOOL = 'tool';
    const PROPERTY_ALLOW_CHANGE = 'allow_change';
    
    const PROPERTY_VISIBLE = 'visible';

    function create($create_in_batch = false)
    {
        $wdm = WeblcmsDataManager :: get_instance();
        
        $conditions[] = new EqualityCondition(PlatformCategory :: PROPERTY_PARENT, $this->get_parent());
        $conditions[] = new EqualityCondition(self :: PROPERTY_COURSE, $this->get_course());
        $conditions[] = new EqualityCondition(self :: PROPERTY_TOOL, $this->get_tool());
        $condition = new AndCondition($conditions);
        $sort = $wdm->retrieve_max_sort_value(self :: get_table_name(), PlatformCategory :: PROPERTY_DISPLAY_ORDER, $condition);
        $this->set_display_order($sort + 1);
        
        $succes = parent :: create();
        if (! $succes)
        {
            return false;
        }
        
        if ($this->get_parent())
        {
            $parent = WeblcmsRights :: get_instance()->get_weblcms_location_id_by_identifier_from_courses_subtree(WeblcmsRights :: TYPE_COURSE_CATEGORY, $this->get_parent(), $this->get_course());
        }
        else
        {
            $course_tool = WeblcmsDataManager :: retrieve_course_tool_by_name($this->get_tool());
            $course_tool_id = $course_tool->get_id();
            
            $parent = WeblcmsRights :: get_instance()->get_weblcms_location_id_by_identifier_from_courses_subtree(WeblcmsRights :: TYPE_COURSE_MODULE, $course_tool_id, $this->get_course());
        }
        
        return WeblcmsRights :: get_instance()->create_location_in_courses_subtree(WeblcmsRights :: TYPE_COURSE_CATEGORY, $this->get_id(), $parent, $this->get_course(), $create_in_batch);
    }

    function create_dropbox($course_code)
    {
        $this->set_course($course_code);
        $this->set_tool('document');
        $this->set_name(Translation :: get('Dropbox'));
        $this->set_parent(0);
        $this->set_allow_change(0);
        
        $this->create();
    }

    function update($move = false)
    {
        $succes = parent :: update();
        if (! $succes)
        {
            return false;
        }
        
        if ($move)
        {
            if ($this->get_parent())
            {
                $new_parent_id = WeblcmsRights :: get_instance()->get_weblcms_location_id_by_identifier_from_courses_subtree(WeblcmsRights :: TYPE_COURSE_CATEGORY, $this->get_parent(), $this->get_course());
            }
            else
            {
                $course_module_id = WeblcmsDataManager :: retrieve_course_tool_by_name($this->get_tool())->get_id();
                $new_parent_id = WeblcmsRights :: get_instance()->get_weblcms_location_id_by_identifier_from_courses_subtree(WeblcmsRights :: TYPE_COURSE_MODULE, $course_module_id, $this->get_course());
            }
            
            $location = WeblcmsRights :: get_instance()->get_weblcms_location_by_identifier_from_courses_subtree(WeblcmsRights :: TYPE_COURSE_CATEGORY, $this->get_id(), $this->get_course());
            if ($location)
            {
                return $location->move($new_parent_id);
            }
        }
        
        return true;
    }

    function delete()
    {
        $location = WeblcmsRights :: get_instance()->get_weblcms_location_by_identifier_from_courses_subtree(WeblcmsRights :: TYPE_COURSE_CATEGORY, $this->get_id(), $this->get_course());
        if ($location)
        {
            if (! $location->delete())
            {
                return false;
            }
        }
        
        return parent :: delete();
    }

    /**
     * inherited
     */
    function get_data_manager()
    {
        return WeblcmsDataManager :: get_instance();
    }

    static function get_default_property_names($extended_property_names = array())
    {
        return array(self :: PROPERTY_COURSE, self :: PROPERTY_ID, self :: PROPERTY_NAME, self :: PROPERTY_TOOL, 
                self :: PROPERTY_PARENT, self :: PROPERTY_DISPLAY_ORDER, self :: PROPERTY_ALLOW_CHANGE, 
                self :: PROPERTY_VISIBLE);
    }

    function get_course()
    {
        return $this->get_default_property(self :: PROPERTY_COURSE);
    }

    function set_course($course)
    {
        $this->set_default_property(self :: PROPERTY_COURSE, $course);
    }

    function get_tool()
    {
        return $this->get_default_property(self :: PROPERTY_TOOL);
    }

    function set_tool($tool)
    {
        $this->set_default_property(self :: PROPERTY_TOOL, $tool);
    }

    function get_allow_change()
    {
        return $this->get_default_property(self :: PROPERTY_ALLOW_CHANGE);
    }

    function set_allow_change($allow_change)
    {
        $this->set_default_property(self :: PROPERTY_ALLOW_CHANGE, $allow_change);
    }

    static function get_table_name()
    {
        return Utilities :: get_classname_from_namespace(self :: CLASS_NAME, true);
    }

    /**
     * Implementation of CategoryVisibilitySupported
     */
    /**
     *
     * @return True if the category is visible for everyone.
     */
    public function get_visibility()
    {
        return $this->get_default_property(self :: PROPERTY_VISIBLE);
    }

    public function set_visibility($visibility)
    {
        $this->set_default_property(self :: PROPERTY_VISIBLE, $visibility);
    }

    public function toggle_visibility()
    {
        $this->set_visibility(! $this->get_visibility());
    }
    
    /**
     * Recursively checks the visibility of a category and its parent.
     *
     * This is needed because when a category is invisible, its children are not
     * necessarily
     * marked invisible too.
     */
    function is_recursive_visible()
    {
        if ($this->get_visibility())
        {
            if ($this->get_parent() != 0)
            {
                $parent_category = $this->get_data_manager()->retrieve_content_object_publication_category($this->get_parent());
                return $parent_category->is_recursive_visible();
            }
            else
            {
                return true;
            }
        }
        else
        {
            return false;
        }
    }

}