<?php
namespace application\weblcms;

use user\UserDataManager;
use common\libraries\FormValidator;
use common\libraries\EqualityCondition;
use common\libraries\Translation;
use common\libraries\Import;
use common\libraries\Utilities;
use application\weblcms\course\Course;
use application\weblcms\course\CourseDataManager;
use application\weblcms\course_type\CourseTypeDataManager;

/**
 * $Id: course_import_form.class.php 216 2009-11-13 14:08:06Z kariboe $
 * 
 * @package application.lib.weblcms.course
 */

ini_set("max_execution_time", - 1);
ini_set("memory_limit", - 1);

class CourseImportForm extends FormValidator
{
    const TYPE_IMPORT = 1;
    
    private $failedcsv;
    private $udm;

    function __construct($form_type, $action)
    {
        parent :: __construct('course_import', 'post', $action);
        
        $this->form_type = $form_type;
        $this->failedcsv = array();
        if ($this->form_type == self :: TYPE_IMPORT)
        {
            $this->build_importing_form();
        }
    }

    function build_importing_form()
    {
        $this->addElement('file', 'file', Translation :: get('FileName'));
        // $this->addElement('submit', 'course_import', Translation :: get('Ok',
        // null ,Utilities:: COMMON_LIBRARIES));
        $buttons[] = $this->createElement('style_submit_button', 'submit', Translation :: get('Import', null, Utilities :: COMMON_LIBRARIES), array(
                'class' => 'positive import'));
        // $buttons[] = $this->createElement('style_reset_button', 'reset',
        // Translation :: get('Reset', null ,Utilities:: COMMON_LIBRARIES),
        // array('class' => 'normal empty'));
        
        $this->addGroup($buttons, 'buttons', null, '&nbsp;', false);
    }

    function import_courses()
    {
        $csvcourses = Import :: csv_to_array($_FILES['file']['tmp_name']);
        $failures = 0;
        
        foreach ($csvcourses as $csvcourse)
        {
            if (! $this->validate_data($csvcourse))
            {
                $failures ++;
                $this->failedcsv[] = Translation :: get('Invalid', null, Utilities :: COMMON_LIBRARIES) . ': ' . implode($csvcourse, ';');
            }
        }
        
        if ($failures > 0)
        {
            return false;
        }
        
        $wdm = WeblcmsDataManager :: get_instance();
        $cdm = CourseDataManager :: get_instance();
        
        foreach ($csvcourses as $csvcourse)
        {
            $teacher_info = $this->get_teacher_info($csvcourse['teacher']);
            $cat = $wdm->retrieve_course_categories(new EqualityCondition('name', $csvcourse['category']))->next_result();
            $catid = $cat ? $cat->get_id() : 0;
            $action = strtoupper($csvcourse['action']);
            
            // check course type
            $course_type_id = 0;
            $course_type_name = $csvcourse['course_type'];
            if ($course_type_name)
            {
                $course_type = CourseTypeDataManager :: retrieve_course_type_by_name($course_type_name);
                if ($course_type)
                {
                    $course_type_id = $course_type->get_id();
                }
            }
            
            if ($action == 'A')
            {
                $course = new Course();
                $course->set_course_type_id($course_type_id);
                $course->set_visual_code($csvcourse['code']);
                $course->set_title($csvcourse[Course :: PROPERTY_TITLE]);
                
                // CTODO categories...
                $course->set_category_id($catid);
                
                $course->set_titular_id($teacher_info->get_id());
                $language = $csvcourse[Course :: PROPERTY_LANGUAGE];
                if(!$language)
                {
                    $language = $this->determine_default_course_language($course);
                }
                $course->set_language($language);
                
                if ($course->create())
                {
                    // create settings
                    $setting_values = array();
                    $setting_values[CourseSettingsController :: SETTING_PARAM_COURSE_SETTINGS][CourseSettingsConnector :: CATEGORY] = $catid;
                    $setting_values[CourseSettingsController :: SETTING_PARAM_COURSE_SETTINGS][CourseSettingsConnector :: LANGUAGE] = $language;
                    $setting_values[CourseSettingsController :: SETTING_PARAM_COURSE_SETTINGS][CourseSettingsConnector :: TITULAR] = $course->get_titular_id();

                    $course->create_course_settings_from_values($setting_values);
                    CourseManagementRights :: get_instance()->create_rights_from_values($course, array());
                    
                    if (! $wdm->subscribe_user_to_course($course, '1', '1', $teacher_info->get_id()))
                    {
                        $failures ++;
                        $this->failedcsv[] = Translation :: get('SubscriptionFailed') . ':' . implode($csvcourse, ';');
                    }
                }
                else
                {
                    $failures ++;
                    $this->failedcsv[] = Translation :: get('CreationFailed') . ':' . implode($csvcourse, ';');
                }
                
                $setting_language = $course->get_course_setting(CourseSettingsConnector :: LANGUAGE);
                if($setting_language != $course->get_language())
                {
                    $this->failedcsv[] = Translation :: get('LanguageSettingFailed') . ':' . implode($csvcourse, ';');
                    $course->set_language($setting_language);
                    if(!$course->update())
                    {
                        $this->failedcsv[] = Translation :: get('CreationFailed') . ':' . implode($csvcourse, ';');
                    }
                }
            }
            elseif ($action == 'U')
            {
                $course = $cdm->retrieve_courses(new EqualityCondition(Course :: PROPERTY_VISUAL_CODE, $csvcourse['code']))->next_result();
                
                $course->set_course_type_id($course_type_id);
                $course->set_title($csvcourse[Course :: PROPERTY_TITLE]);
                $language = $csvcourse[Course :: PROPERTY_LANGUAGE];
                if(!$language)
                {
                    $language = $this->determine_default_course_language($course);
                }
                $course->set_language($language);
                $course->set_category_id($catid);
                $course->set_titular_id($teacher_info->get_id());
                
                if ($course->update())
                {
                    $setting_values = array();
                    $setting_values[CourseSettingsController :: SETTING_PARAM_COURSE_SETTINGS][CourseSettingsConnector :: CATEGORY] = $catid;
                    $setting_values[CourseSettingsController :: SETTING_PARAM_COURSE_SETTINGS][CourseSettingsConnector :: LANGUAGE] = $language;
                    $setting_values[CourseSettingsController :: SETTING_PARAM_COURSE_SETTINGS][CourseSettingsConnector :: TITULAR] = $course->get_titular_id();

                    $course->update_course_settings_from_values($setting_values);
                }
                else
                {
                    $failures ++;
                    $this->failedcsv[] = Translation :: get('UpdateFailed') . ':' . implode($csvcourse, ';');
                }
                
                $setting_language = $course->get_course_setting(CourseSettingsConnector :: LANGUAGE);
                if($setting_language != $course->get_language())
                {
                    $this->failedcsv[] = Translation :: get('LanguageSettingFailed') . ':' . implode($csvcourse, ';');
                    $course->set_language($setting_language);
                    if(!$course->update())
                    {
                        $this->failedcsv[] = Translation :: get('CreationFailed') . ':' . implode($csvcourse, ';');
                    }
                }
            }
            elseif ($action == 'D')
            {
                $course = $cdm->retrieve_courses(new EqualityCondition(Course :: PROPERTY_VISUAL_CODE, $csvcourse['code']))->next_result();
                
                if (! $wdm->delete_course($course->get_id()))
                {
                    $failures ++;
                    $this->failedcsv[] = Translation :: get('DeleteFailed') . ':' . implode($csvcourse, ';');
                }
            }
        }
        
        if ($failures > 0)
        {
            return false;
        }
        else
        {
            return true;
        }
    }
    
    // TODO: Temporary solution pending implementation of user object
    function get_teacher_info($user_name)
    {
        $udm = UserDataManager :: get_instance();
        if (! $udm->is_username_available($user_name))
        {
            return $udm->retrieve_user_info($user_name);
        }
        else
        {
            return null;
        }
    }

    function get_failed_csv()
    {
        return implode($this->failedcsv, '<br />');
    }

    function validate_data($csvcourse)
    {
        $failures = 0;
        
        // 1. Action valid ?
        $action = strtoupper($csvcourse['action']);
        if ($action != 'A' && $action != 'D' && $action != 'U')
        {
            $failures ++;
        }
        
        // 2. check if code isn't in use for create and if code exists for
        // update / delete
        if (($action == 'A' && $this->is_course($csvcourse['code'])) || ($action != 'A' && ! $this->is_course($csvcourse['code'])))
        {
            $failures ++;
        }
        
        if ($csvcourse['teacher'])
        {
            $csvcourse[Course :: PROPERTY_TITULAR_ID] = $csvcourse['teacher'];
        }
        
        // 3. check if teacher exists
        $teacher_info = $this->get_teacher_info($csvcourse[Course :: PROPERTY_TITULAR_ID]);
        if (! isset($teacher_info))
        {
            $failures ++;
        }
        
        // 4. check if category exists
        if (! $this->is_course_category($csvcourse['category']))
        {
            $failures ++;
        }
        
        // 5. check if the course_type exists (if the type is provided)
        $course_type = $csvcourse['course_type'];
        if ($course_type)
        {
            if (! $this->is_course_type($course_type))
            {
                $failures ++;
            }
        }
        
        if ($failures > 0)
        {
            return false;
        }
        else
        {
            return true;
        }
    }

    private function is_course_type($type_name)
    {
        return CourseTypeDataManager :: is_course_type_valid($type_name);
    }

    private function is_course_category($category_name)
    {
        $cat = WeblcmsDataManager :: get_instance()->retrieve_course_categories(new EqualityCondition(CourseCategory :: PROPERTY_NAME, $category_name))->next_result();
        if ($cat)
        {
            return true;
        }
        
        return false;
    }

    private function is_course($course_code)
    {
        $course = CourseDataManager :: get_instance()->retrieve_courses(new EqualityCondition(Course :: PROPERTY_VISUAL_CODE, $course_code))->next_result();
        // $course = WeblcmsDataManager :: get_instance()->retrieve_courses(new
        // EqualityCondition(Course :: PROPERTY_VISUAL_CODE,
        // $course_code))->next_result();
        if ($course)
        {
            return true;
        }
        
        return false;
    }
    
    private function determine_default_course_language($course)
    {
        return CourseSettingsController :: get_instance()->get_course_type_setting($course->get_course_type_id(), Course :: PROPERTY_LANGUAGE);
    }
}
?>
