<?php
namespace application\weblcms;

use group\Group;
use group\GroupDataManager;

use HTML_Menu;

use common\libraries\TreeMenuRenderer;
use common\libraries\Utilities;
use common\libraries\EqualityCondition;
use common\libraries\InCondition;

/**
 * $Id: content_object_category_menu.class.php 204 2009-11-13 12:51:30Z tristan
 * $
 * 
 * @package repository.lib
 */

class RightsTreeRenderer extends HTML_Menu
{
    const TREE_NAME = __CLASS__;
    
    private $data_manager;
    
    private $groups;

    /**
     *
     * @param $extra_items array
     *            An array of extra tree items, added to the
     *            root.
     */
    function __construct($groups)
    {
        $this->groups = $groups;
        $menu = $this->get_menu_items();
        parent :: __construct($menu);
    }

    /**
     * Returns the menu items.
     * 
     * @param $extra_items array
     *            An array of extra tree items, added to the
     *            root.
     * @return array An array with all menu items. The structure of this array
     *         is the structure needed by PEAR::HTML_Menu, on which this
     *         class is based.
     */
    private function get_menu_items()
    {
        $menu = array();
        $condition = new InCondition(Group :: PROPERTY_ID, $this->groups);
        $sub_groups = GroupDataManager :: get_instance()->retrieve_groups($condition);
        while ($group = $sub_groups->next_result())
        {
            $sub_menu_item = $this->get_group_array($group);
            $menu[] = $sub_menu_item;
        }
        return $menu;
    }

    private function get_group_array($group)
    {
        $selected_group = array();
        $selected_group['id'] = 'group_' . $group->get_id();
        $selected_group['class'] = 'type type_group';
        $selected_group['title'] = $group->get_name();
        $selected_group['description'] = $group->get_name();
        $selected_group['url'] = '#';
        return $selected_group;
    }

    /**
     * Renders the menu as a tree
     * 
     * @return string The HTML formatted tree
     */
    function render_as_tree()
    {
        $renderer = new TreeMenuRenderer($this->get_tree_name());
        $this->render($renderer, 'sitemap');
        $html = array();
        $html[] = '<div class="active_elements" style="overflow: auto; height: 300px; width: 310px;">';
        $html[] = $renderer->toHTML();
        $html[] = '</div>';
        return implode("\n", $html);
    }

    static function get_tree_name()
    {
        return Utilities :: get_classname_from_namespace(self :: TREE_NAME, true);
    }
}