<?php

namespace application\weblcms;

use application\weblcms\WeblcmsDataManager;

use common\libraries\DataClass;
use common\libraries\Utilities;

/**
 * This class defines a registered course tool on the platform.
 * The relation between a course (type) and a
 * course tool is defined through the course tool setting "active".
 *
 * @package application\weblcms\course;
 *         
 * @author Sven Vanpoucke - Hogeschool Gent
 */
class CourseTool extends DataClass
{
    /**
     * **************************************************************************************************************
     * Table Properties *
     * **************************************************************************************************************
     */
    
    const PROPERTY_SECTION_TYPE = 'section_type';
    const PROPERTY_NAME = 'name';

    /**
     * **************************************************************************************************************
     * Inherited Functionality *
     * **************************************************************************************************************
     */
    
    /**
     * Returns the default properties of this dataclass
     *
     * @return String[] - The property names.
     */
    static function get_default_property_names($extended_property_names = array())
    {
        return parent :: get_default_property_names(array(self :: PROPERTY_SECTION_TYPE, self :: PROPERTY_NAME));
    }

    /**
     * Returns the datamanager for this dataclass
     *
     * @return WeblcmsDataManager
     */
    function get_data_manager()
    {
        return WeblcmsDataManager :: get_instance();
    }

    /**
     * Returns the table name of this dataclass
     *
     * * @return String
     */
    static function get_table_name()
    {
        return Utilities :: get_classname_from_namespace(__CLASS__, true);
    }

    /**
     * **************************************************************************************************************
     * Getters and Setters *
     * **************************************************************************************************************
     */
    
    /**
     * Returns the section_type property of this object
     *
     * @return String
     */
    function get_section_type()
    {
        return $this->get_default_property(self :: PROPERTY_SECTION_TYPE);
    }

    /**
     * Sets the section_type property of this object
     *
     * @param $section_type String           
     */
    function set_section_type($section_type)
    {
        $this->set_default_property(self :: PROPERTY_SECTION_TYPE, $section_type);
    }

    /**
     * Returns the name property of this object
     *
     * @return String
     */
    function get_name()
    {
        return $this->get_default_property(self :: PROPERTY_NAME);
    }

    /**
     * Sets the name property of this object
     *
     * @param $name String           
     */
    function set_name($name)
    {
        $this->set_default_property(self :: PROPERTY_NAME, $name);
    }
}

?>
