<?php
namespace application\weblcms;

use common\libraries\DatetimeUtilities;
use repository\RepositoryDataManager;
use user\UserDataManager;
use common\libraries\Redirect;
use common\libraries\Application;
use common\libraries\OrCondition;
use common\libraries\InCondition;
use common\libraries\Utilities;
use common\libraries\ObjectTableOrder;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use common\libraries\Path;
use common\libraries\Translation;
use common\libraries\PublicationRSS;

//use repository\content_object\announcement\Announcement;
use application\weblcms\course\CourseDataManager;

use group\Mdb2GroupDataManager;
use application\weblcms\CourseSettingsController;
use application\weblcms\course\CourseGroupRelation;
use rights\TemplateEntity;

class WeblcmsPublicationRSS extends PublicationRSS
{

    function __construct()
    {
        Utilities :: set_application(WeblcmsManager :: APPLICATION_NAME);
        parent :: __construct(Translation :: get('WeblcmsPublicationRSSTitle'), htmlspecialchars(Path :: get(WEB_PATH)), Translation :: get('WeblcmsPublicationRSSDescription'), htmlspecialchars(Path :: get(WEB_PATH)));
    }

    function retrieve_items($user)
    {
        return $this->get_publications($user);

        /*
        $pubs = WeblcmsDataManager :: get_instance()->retrieve_content_object_publications($this->get_access_condition($user), new ObjectTableOrder(ContentObjectPublication :: PROPERTY_PUBLICATION_DATE, SORT_DESC), 0, 20); // ,
                                                                                                                                                                                                                               // array('id',
                                                                                                                                                                                                                               // SORT_DESC));
        $publications = array();
        while ($pub = $pubs->next_result())
        {
            if ($this->is_visible_for_user($user, $pub))
            {
                $publications[] = $pub;
            }
        }
        return $publications;
         */
    }

    function add_item($publication, $channel)
    {
        $course = CourseDataManager :: get_instance()->retrieve_course($publication->get_course_id());
        $co = $publication->get_content_object();
        if (! is_object($co))
        {
            $co = RepositoryDataManager :: get_instance()->retrieve_content_object($co);
        }

        $title = $co->get_title();
        $description = '<b>' . Translation :: get('Course') . ': </b>' . $course->get_title() . '<br />';
        $description .= '<b>' . Translation :: get('Tool') . ': </b>' . Translation :: get(Utilities :: underscores_to_camelcase($publication->get_tool())) . '<br />';
        $description .= '<b>' . Translation :: get('Published') . ': </b>' . DatetimeUtilities :: format_locale_date(Translation :: get('DateFormatShort', null, Utilities :: COMMON_LIBRARIES) . ', ' . Translation :: get('TimeNoSecFormat', null, Utilities :: COMMON_LIBRARIES), $publication->get_publication_date()) . '<br />';
        $description .= '<b>' . Translation :: get('Publisher') . ': </b>' . UserDataManager :: get_instance()->retrieve_user($publication->get_publisher_id())->get_fullname() . '<br />';
        $description .= '<br />' . $co->get_description();

        $channel->add_item(htmlspecialchars($title), htmlspecialchars($this->get_url($publication)), htmlspecialchars($description));
    }

    function get_url($pub)
    {
        $params = array();
        $params[Application :: PARAM_ACTION] = WeblcmsManager :: ACTION_VIEW_COURSE;
        $params[WeblcmsManager :: PARAM_COURSE_USER] = $pub->get_course_id();
        $params[ContentObjectPublication :: PROPERTY_TOOL] = $pub->get_tool();
        return str_replace('/application/weblcms/php/lib/rss/','/',Path :: get(WEB_PATH)) . Redirect :: get_link(WeblcmsManager :: APPLICATION_NAME, $params);
    }

    function is_visible_for_user($user, $pub)
    {
        return $user->is_platform_admin() || ($user->get_id() == $pub->get_publisher_id()) || $pub->is_visible_for_target_users();
    }

    /*private function get_access_condition($user)
    {
        $wdm = WeblcmsDataManager :: get_instance();
        
        if ($user->is_platform_admin())
        {
            $user_id = array();
            $course_group_ids = array();
        }
        else
        {
            $user_id = $user->get_id();
            $course_groups = $this->get_user_groups($user_id);
            
            $course_group_ids = array();
            
            foreach ($course_groups as $course_group)
            {
                $course_group_ids[] = $course_group->get_id();
            }
        }
        
        $access = array();
        
        if (! empty($user_id))
        {
            $access[] = new InCondition('user_id', $user_id, $wdm->get_alias('content_object_publication_user'));
        }
        
        if (! empty($course_group_ids))
        {
            $access[] = new InCondition('course_group_id', $course_group_ids, $wdm->get_alias('content_object_publication_course_group'));
        }
        
        if (! empty($user_id) || ! empty($course_groups))
        {
            $access[] = new AndCondition(array(
                    new EqualityCondition('user_id', null, $wdm->get_alias('content_object_publication_user')), 
                    new EqualityCondition('course_group_id', null, $wdm->get_alias('content_object_publication_course_group'))));
        }
        
        if (! empty($access))
        {
            return new OrCondition($access);
        }
    }//*/

    private function get_user_groups($user_id)
    {
        return WeblcmsDataManager :: get_user_course_groups($user_id);
    }
    
    private function get_publications($user)
    {
        //Direct user courses.
        $dm = WeblcmsDataManager :: get_instance();
        $condition = WeblcmsDataManager :: get_user_courses_condition($user);
        $courses = $dm->retrieve_user_courses($condition)->as_array();

        //Courses active through group membership.
        $gdm = new Mdb2GroupDataManager();
        $groups = $gdm->retrieve_all_subscribed_groups_array($user->get_id());
        
        $group_ids = array();
        foreach($groups as $group)
        {
            $group_ids[$group->get_id()] = $group->get_id();
        }
        
        $condition = new InCondition(CourseGroupRelation :: PROPERTY_GROUP_ID, $group_ids, CourseGroupRelation :: get_table_name());
        array_splice($courses, 0, 0, $dm->retrieve_user_courses($condition)->as_array());
               
        $course_settings_controller = CourseSettingsController::get_instance();
        $unique_publications = array();
        foreach($courses as $course)
        {
            if ($course_settings_controller->get_course_setting($course->get_id(), CourseSettingsConnector::VISIBILITY) == 1)
            {
                $condition = WeblcmsDataManager :: get_publications_condition($course, $user);
                /*$condition = WeblcmsDataManager :: get_publications_condition($course, $user, 'announcement', Announcement::get_type_name());
                $course_module_id = WeblcmsDataManager :: retrieve_course_tool_by_name('announcement')->get_id();
                $location = WeblcmsRights :: get_instance()->get_weblcms_location_by_identifier_from_courses_subtree(
                    WeblcmsRights :: TYPE_COURSE_MODULE, $course_module_id, $course->get_id());
                 */
                
                $location = WeblcmsRights :: get_instance()->get_weblcms_location_by_identifier_from_courses_subtree(WeblcmsRights :: TYPE_ROOT, $course->get_id(), $course->get_id());
                                
                $entities = array();
                $entities[CourseGroupEntity :: ENTITY_TYPE] = CourseGroupEntity :: get_instance($course->get_id());
                $entities[CourseUserEntity :: ENTITY_TYPE] = CourseUserEntity :: get_instance();
                $entities[CoursePlatformGroupEntity :: ENTITY_TYPE] = CoursePlatformGroupEntity :: get_instance();
                $entities[TemplateEntity :: ENTITY_TYPE] = TemplateEntity :: get_instance();

                $publications = $dm->retrieve_content_object_publications_with_view_right_granted_in_category_location($location, $entities, $condition, new ObjectTableOrder(ContentObjectPublication :: PROPERTY_DISPLAY_ORDER_INDEX, SORT_DESC));

                if($publications == 0)
                {
                    continue;
                }
                foreach($publications->as_array() as $publication)
                {
                    $unique_publications[$course->get_id() . '.' . $publication->get_id()] = $publication;
                }
            }
        }
        return $unique_publications;
    }
}

?>