<?php
namespace application\weblcms;

use common\libraries\Application;

use application\personal_calendar\PersonalCalendarManager;

use repository\ContentObjectRendition;

use repository\ContentObjectRenditionImplementation;

use repository\RepositoryDataManager;
use common\libraries\Display;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\ObjectNotExistException;
use common\libraries\ParameterNotDefinedException;

/**
 * $Id: attachment_viewer.class.php 216 2009-11-13 14:08:06Z kariboe $
 *
 * @package application.lib.weblcms.tool.component
 */

class ToolComponentAttachmentViewerComponent extends ToolComponent
{
    private $action_bar;

    function run()
    {

        $trail = BreadcrumbTrail :: get_instance();
        $trail->add_help('courses general');

        $failed = false;
        $error_message = '';

        // retrieve the publication
        $publication_id = Request :: get(WeblcmsManager :: PARAM_PUBLICATION);

        if (is_null($publication_id))
        {
            throw new ParameterNotDefinedException(WeblcmsManager :: PARAM_PUBLICATION);
        }
        $publication = WeblcmsDataManager :: get_instance()->retrieve_content_object_publication($publication_id);

        if (is_null($publication))
        {
            throw new ObjectNotExistException(Translation :: get('Publication'), $publication);
        }

        // retrieve the attachment
        $object_id = Request :: get('object_id');

        if (is_null($object_id))
        {
            $failed = true;
            $error_message = Translation :: get('NoObjectSelected');
        }

        // Let the parent decide where the object is attached
        if (method_exists($this->get_parent(), 'is_object_attached_in_context'))
        {
            if (! $this->get_parent()->is_object_attached_in_context($this))
            {
                $failed = true;
                $error_message = Translation :: get('WrongObjectSelected');
            }
        } // Default the attachment is attached to the content object of the
          // publication
        else
            if (! RepositoryDataManager :: is_attached_or_included_to($publication->get_content_object_id(), $object_id))
            {
                $failed = true;
                $error_message = Translation :: get('WrongObjectSelected');
            }

        // Is the view right granted on the publication?
        if (! $this->is_allowed(WeblcmsRights :: VIEW_RIGHT, $publication))
        {
            $failed = true;
            $error_message = Translation :: get('NotAllowed');
        }

        if (! $failed)
        {
            $trail->add(new Breadcrumb($this->get_url(array('object' => $object_id)), Translation :: get('ViewAttachment', null, 'repository')));

            Display :: small_header();

//            echo '<a href="javascript:history.go(-1)">' . Translation :: get('Back', null, Utilities :: COMMON_LIBRARIES) . '</a><br /><br />';

            $object = RepositoryDataManager :: get_instance()->retrieve_content_object($object_id);

            echo ContentObjectRenditionImplementation :: launch($object, ContentObjectRendition :: FORMAT_HTML, ContentObjectRendition :: VIEW_FULL, $this);

            Display :: small_footer();
        }
        else
        {
            Display :: small_header();
            $this->display_error_message($error_message);
            Display :: small_footer();
        }

    }

    function get_additional_parameters()
    {
        $params = array();
        $params[] = WeblcmsManager :: PARAM_PUBLICATION;
        return $params;
    }

}
?>