<?php
namespace application\weblcms;

use common\libraries\Display;
use common\libraries\Categorizable;
use common\libraries\PatternMatchCondition;
use repository\ContentObject;
use common\libraries\ObjectTableFormAction;
use common\libraries\ObjectTableFormActions;
use common\libraries\ActionBarRenderer;
use common\libraries\SubselectCondition;
use repository\RepositoryDataManager;
use common\libraries\ToolbarItem;
use user\User;
use common\libraries\Theme;
use common\libraries\OrCondition;
use common\libraries\InCondition;
use common\libraries\Utilities;
use common\libraries\ObjectTableOrder;
use common\libraries\AndCondition;
use common\libraries\InequalityCondition;
use common\libraries\EqualityCondition;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\ResourceManager;
use common\libraries\Path;
use common\libraries\DynamicVisualTabsRenderer;
use common\libraries\DynamicVisualTab;
use common\libraries\NotCondition;
use common\libraries\Session;
use common\libraries\PlatformSetting;

/**
 * $Id: viewer.class.php 200 2009-11-13 12:30:04Z kariboe $
 *
 * @package repository.lib.complex_display.assessment.component
 */
class ToolComponentBrowserComponent extends ToolComponent
{

    private $action_bar;

    private $introduction_text;

    private $publication_category_tree;

    private $publications;

    private $is_course_admin;

    function run()
    {
        // set if we are browsing as course admin, used for displaying the
        // additional tabs and actions
        $this->is_course_admin = $this->get_course()->is_course_admin($this->get_user());

        if (! $this->is_allowed(WeblcmsRights :: VIEW_RIGHT))
        {
            $this->redirect(Translation :: get("NotAllowed"), true, array(),
                    array(WeblcmsManager :: PARAM_TOOL, Tool :: PARAM_ACTION, WeblcmsManager :: PARAM_CATEGORY));
        }

        $this->introduction_text = $this->get_parent()->get_introduction_text();
        $this->action_bar = $this->get_action_bar();

        $tree_id = Request :: get(WeblcmsManager :: PARAM_CATEGORY);
        $this->publication_category_tree = new PublicationCategoriesTree($this);

        $publication_renderer = ContentObjectPublicationListRenderer :: factory($this->get_parent()->get_browser_type(),
                $this);

        $actions = new ObjectTableFormActions(__NAMESPACE__, Tool :: PARAM_ACTION);
        $actions->add_form_action(
                new ObjectTableFormAction(Tool :: ACTION_DELETE,
                        Translation :: get('RemoveSelected', null, Utilities :: COMMON_LIBRARIES)));
        $actions->add_form_action(
                new ObjectTableFormAction(Tool :: ACTION_TOGGLE_VISIBILITY, Translation :: get('ToggleVisibility'),
                        false));
        if ($this->is_allowed(WeblcmsRights :: EDIT_RIGHT) && $this->get_parent() instanceof Categorizable)
        {
            $actions->add_form_action(
                    new ObjectTableFormAction(Tool :: ACTION_MOVE_TO_CATEGORY,
                            Translation :: get('MoveSelected', null, Utilities :: COMMON_LIBRARIES), false));
        }
        $publication_renderer->set_actions($actions);

        $this->display_header();

        $html = array();

        $course_settings_controller = CourseSettingsController :: get_instance();

        if ($course_settings_controller->get_course_setting($this->get_course_id(),
                CourseSettingsConnector :: ALLOW_INTRODUCTION_TEXT))
        {
            $html[] = $this->get_parent()->display_introduction_text($this->introduction_text);
        }

        $html[] = $this->action_bar->as_html();
        $html[] = '<div id="action_bar_browser" style="width:100%;">';

        if ($this->get_parent() instanceof Categorizable)
        {
            $html[] = '<div class="tree_menu_on_top" style="max-height:150px; overflow: auto;">';
            $html[] = '<div id="tree_menu_hide_container" class="tree_menu_hide_container" style="float: right;overflow: auto; ">';
            $html[] = '<a id="tree_menu_action_hide" class="tree_menu_hide" href="#">' . Translation :: get('ShowAll') . '</a>';
            $html[] = '</div>';
            $html[] = '<div id=tree style="width:90%;overflow: auto;">';
            $html[] = $this->publication_category_tree->render_as_tree();
            $html[] = '</div>';
            $html[] = ResourceManager :: get_instance()->get_resource_html(
                    Path :: get(WEB_APP_PATH) . 'weblcms/resources/javascript/tree_menu.js');
            $html[] = '</div>';

            $cat_id = intval(Request :: get(WeblcmsManager :: PARAM_CATEGORY));

            if (! $cat_id || $cat_id == 0)
            {
                $cat_name = Translation :: get('Root');
            }
            else
            {
                $category = $this->retrieve_category($cat_id);
                if ($category)
                {
                    $cat_name = $category->get_name();
                }
                else
                {
                    $cat_name = Translation :: get('Root');
                }
            }
            $html[] = '<div style="color: #797268; font-weight: bold;">Current
            category: ' . $cat_name . '</div><br />';
        }

        echo implode("\n", $html);

        $html = array();

        $type = $this->get_publication_type();

        $tabs = new DynamicVisualTabsRenderer('tool_browser');

        if ($this->is_course_admin)
        {
            $tabs->add_tab(
                    new DynamicVisualTab(Tool :: PUBLICATION_TYPE_ALL, Translation :: get('AllPublications'),
                            Theme :: get_common_image_path() . 'treemenu/shared_objects.png',
                            $this->get_url(
                                    array(Tool :: PARAM_BROWSE_PUBLICATION_TYPE => Tool :: PUBLICATION_TYPE_ALL)),
                            $type == Tool :: PUBLICATION_TYPE_ALL));
        }
        $tabs->add_tab(
                new DynamicVisualTab(Tool :: PUBLICATION_TYPE_FROM_ME, Translation :: get('PublishedForMe'),
                        Theme :: get_common_image_path() . 'treemenu/shared_objects.png',
                        $this->get_url(
                                array(Tool :: PARAM_BROWSE_PUBLICATION_TYPE => Tool :: PUBLICATION_TYPE_FOR_ME)),
                        $type == Tool :: PUBLICATION_TYPE_FOR_ME));
        $tabs->add_tab(
                new DynamicVisualTab(Tool :: PUBLICATION_TYPE_FROM_ME, Translation :: get('MyPublications'),
                        Theme :: get_common_image_path() . 'treemenu/publication.png',
                        $this->get_url(
                                array(Tool :: PARAM_BROWSE_PUBLICATION_TYPE => Tool :: PUBLICATION_TYPE_FROM_ME)),
                        $type == Tool :: PUBLICATION_TYPE_FROM_ME));
        $html[] = $publication_renderer->as_html();
        $html[] = '<div class="clear"></div>';

        if (method_exists($this->get_parent(), 'show_additional_information'))
        {
            $this->get_parent()->show_additional_information($this);
        }
        $html[] = '</div>';

        $tabs->set_content(implode("\n", $html));

        if ($this->get_publication_count() > 0 && $this->get_parent()->get_tool_registration()->get_section_type() == CourseSection :: TYPE_DISABLED)
        {
            Display :: warning_message(Translation :: get('ToolInvisible'));
        }

        echo $tabs->render();

        $this->display_footer();
    }

    /**
     * Retrieves the publications
     *
     * @return array An array of ContentObjectPublication objects
     */
    function get_publications($offset, $max_objects, ObjectTableOrder $object_table_order)
    {
        if (empty($this->publications))
        {

            if ($this->get_publication_type() == Tool :: PUBLICATION_TYPE_FROM_ME)
            {

                $publications_resultset = WeblcmsDataManager :: get_instance()->retrieve_my_publications(
                        $this->get_location(), $this->get_entities(), $this->get_publication_conditions(),
                        $object_table_order, $offset, $max_objects, $this->get_user_id());
            }
            elseif ($this->get_publication_type() == Tool :: PUBLICATION_TYPE_ALL)
            {
                $publications_resultset = WeblcmsDataManager :: get_instance()->retrieve_all_publications(
                        $this->get_publication_conditions(), $object_table_order, $offset, $max_objects);
            }
            else
            {
                $publications_resultset = WeblcmsDataManager :: get_instance()->retrieve_content_object_publications_with_view_right_granted_in_category_location(
                        $this->get_location(), $this->get_entities(), $this->get_publication_conditions(),
                        $object_table_order, $offset, $max_objects, $this->get_user_id());
            }
            if ($publications_resultset)
            {
                $this->publications = $publications_resultset->as_array();
            }
        }

        if ($this->publications)
        {
            return $this->publications;
        }
    }

    /**
     * Retrieves the number of published content objects
     *
     * @return int
     */
    function get_publication_count()
    {
        if ($this->get_publication_type() == Tool :: PUBLICATION_TYPE_FROM_ME)
        {
            $count = WeblcmsDataManager :: get_instance()->count_my_publications($this->get_location(),
                    $this->get_entities(), $this->get_publication_conditions(), $this->get_user_id());
        }
        elseif ($this->get_publication_type() == Tool :: PUBLICATION_TYPE_ALL)
        {
            $count = WeblcmsDataManager :: get_instance()->count_content_object_publications(
                    $this->get_publication_conditions());
        }
        else
        {
            $count = WeblcmsDataManager :: get_instance()->count_content_object_publications_with_view_right_granted_in_category_location(
                    $this->get_location(), $this->get_entities(), $this->get_publication_conditions(),
                    $this->get_user_id());
        }
        return $count;
    }

    function get_action_bar()
    {
        $action_bar = new ActionBarRenderer(ActionBarRenderer :: TYPE_HORIZONTAL);

        $action_bar->set_search_url($this->get_url());
        if ($this->is_allowed(WeblcmsRights :: ADD_RIGHT))
        {
            $publish_type = PlatformSetting :: get('display_publication_screen', __NAMESPACE__);
            if ($publish_type == Tool :: PUBLISH_TYPE_BOTH)
            {
                $action_bar->add_common_action(
                        new ToolbarItem(Translation :: get('QuickPublish', null, Utilities :: COMMON_LIBRARIES),
                                Theme :: get_common_image_path() . 'action_publish.png',
                                $this->get_url(
                                        array(Tool :: PARAM_ACTION => Tool :: ACTION_PUBLISH,
                                                Tool :: PARAM_PUBLISH_MODE => Tool :: PUBLISH_MODE_QUICK)),
                                ToolbarItem :: DISPLAY_ICON_AND_LABEL));
            }

            $action_bar->add_common_action(
                    new ToolbarItem(Translation :: get('Publish', null, Utilities :: COMMON_LIBRARIES),
                            Theme :: get_common_image_path() . 'action_publish.png',
                            $this->get_url(array(Tool :: PARAM_ACTION => Tool :: ACTION_PUBLISH)),
                            ToolbarItem :: DISPLAY_ICON_AND_LABEL));
        }

        if ($this->is_course_admin)
        {
            $action_bar->add_common_action(
                    new ToolbarItem(Translation :: get('ManageRights', null, Utilities :: COMMON_LIBRARIES),
                            Theme :: get_common_image_path() . 'action_rights.png',
                            $this->get_url(
                                    array(Tool :: PARAM_ACTION => Tool :: ACTION_EDIT_RIGHTS,
                                            WeblcmsManager :: PARAM_CATEGORY => Request :: get(
                                                    WeblcmsManager :: PARAM_CATEGORY))),
                            ToolbarItem :: DISPLAY_ICON_AND_LABEL));
        }

        $action_bar->add_common_action(
                new ToolbarItem(Translation :: get('ShowAll', null, Utilities :: COMMON_LIBRARIES),
                        Theme :: get_common_image_path() . 'action_browser.png',
                        $this->get_url(array(Tool :: PARAM_ACTION => null)), ToolbarItem :: DISPLAY_ICON_AND_LABEL));

        if ($this->is_course_admin && $this->get_parent() instanceof Categorizable)
        {
            $action_bar->add_common_action(
                    new ToolbarItem(Translation :: get('ManageCategories', null, Utilities :: COMMON_LIBRARIES),
                            Theme :: get_common_image_path() . 'action_category.png',
                            $this->get_url(
                                    array(Tool :: PARAM_ACTION => Tool :: ACTION_MANAGE_CATEGORIES)),
                            ToolbarItem :: DISPLAY_ICON_AND_LABEL));
        }

        $course_settings_controller = CourseSettingsController :: get_instance();

        if (! $this->introduction_text && $this->is_course_admin && $course_settings_controller->get_course_setting(
                $this->get_course_id(), CourseSettingsConnector :: ALLOW_INTRODUCTION_TEXT))
        {
            $action_bar->add_common_action(
                    new ToolbarItem(Translation :: get('PublishIntroductionText', null, Utilities :: COMMON_LIBRARIES),
                            Theme :: get_common_image_path() . 'action_introduce.png',
                            $this->get_url(
                                    array(Tool :: PARAM_ACTION => Tool :: ACTION_PUBLISH_INTRODUCTION)),
                            ToolbarItem :: DISPLAY_ICON_AND_LABEL));
        }

        if (method_exists($this->get_parent(), 'get_tool_actions'))
        {
            $action_bar->set_tool_actions($this->get_parent()->get_tool_actions());
        }

        $browser_types = $this->get_parent()->get_available_browser_types();

        if (count($browser_types) > 1)
        {
            foreach ($browser_types as $browser_type)
            {
                $action_bar->add_tool_action(
                        new ToolbarItem(
                                Translation :: get(Utilities :: underscores_to_camelcase($browser_type) . 'View', null,
                                        Utilities :: COMMON_LIBRARIES),
                                Theme :: get_common_image_path() . 'view_' . $browser_type . '.png',
                                $this->get_url(
                                        array(Tool :: PARAM_BROWSER_TYPE => $browser_type)),
                                ToolbarItem :: DISPLAY_ICON_AND_LABEL));
            }
        }

        return $action_bar;
    }

    function get_publication_conditions()
    {
        $conditions = array();

        $type = $this->get_publication_type();
        switch ($type)
        {
            // Begin with the publisher condition when FROM_ME and add the
            // remaining conditions. Skip the publisher
            // condition when ALL.
            case Tool :: PUBLICATION_TYPE_FROM_ME :
                $va_id = Session :: get(Tool :: PARAM_VIEW_AS_ID);
                $course_id = Session :: get(Tool :: PARAM_VIEW_AS_COURSE_ID);
                $user_id = Session :: get_user_id();
                if (isset($va_id) && isset($course_id))
                {
                    if ($course_id == $this->get_course_id())
                    {
                        $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_PUBLISHER_ID, $va_id);
                    }
                    else
                    {
                        $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_PUBLISHER_ID,
                                $user_id);
                    }
                }
                else
                {
                    $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_PUBLISHER_ID, $user_id);
                }
            // DON'T BREAK HERE! => the following conditions for ALL need to be
            // added as well...
            case Tool :: PUBLICATION_TYPE_ALL :

                $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_COURSE_ID,
                        $this->get_course_id());

                if ($this->get_tool_id())
                {
                    $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_TOOL,
                            $this->get_tool_id());
                }

                $category_id = Request :: get(WeblcmsManager :: PARAM_CATEGORY);
                if (! $category_id)
                {
                    $category_id = 0;
                }
                $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_CATEGORY_ID, $category_id);
                break;
            default :

                $time_conditions = array();
                $time_conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_HIDDEN, 0);

                $forever_condition = new AndCondition(
                        array(new EqualityCondition(ContentObjectPublication :: PROPERTY_FROM_DATE, 0),
                                new EqualityCondition(ContentObjectPublication :: PROPERTY_TO_DATE, 0)));
                $between_condition = new AndCondition(
                        array(
                                new InequalityCondition(ContentObjectPublication :: PROPERTY_FROM_DATE,
                                        InequalityCondition :: LESS_THAN_OR_EQUAL, time()),
                                new InequalityCondition(ContentObjectPublication :: PROPERTY_TO_DATE,
                                        InequalityCondition :: GREATER_THAN_OR_EQUAL, time())));

                $time_conditions[] = new OrCondition(array($forever_condition, $between_condition));

                $conditions[] = new AndCondition($time_conditions);
                break;
        }

        if ($this->get_search_condition())
        {
            $conditions[] = $this->get_search_condition();
        }

        $rdm = RepositoryDataManager :: get_instance();
        $conditions[] = new InCondition(ContentObject :: PROPERTY_TYPE, $this->get_allowed_types(),
                $rdm->get_alias(ContentObject :: get_table_name()), true);
        if (method_exists($this->get_parent(), 'get_tool_conditions'))
        {
            foreach ($this->get_parent()->get_tool_conditions() as $tool_condition)
            {
                $conditions[] = $tool_condition;
            }
        }

        if ($conditions)
        {
            return new AndCondition($conditions);
        }
        else
        {
            return null;
        }
    }

    function get_search_condition()
    {
        $query = $this->action_bar->get_query();
        if (isset($query) && $query != '')
        {
            $rdm = RepositoryDataManager :: get_instance();
            $conditions[] = new PatternMatchCondition(ContentObject :: PROPERTY_TITLE, '*' . $query . '*',
                    $rdm->get_alias(ContentObject :: get_table_name()), true);
            $conditions[] = new PatternMatchCondition(ContentObject :: PROPERTY_DESCRIPTION, '*' . $query . '*',
                    $rdm->get_alias(ContentObject :: get_table_name()), true);
            return new OrCondition($conditions);
        }

        return null;
    }

    function count_tool_categories()
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(ContentObjectPublicationCategory :: PROPERTY_TOOL, $this->get_tool_id());
        $conditions[] = new EqualityCondition(ContentObjectPublicationCategory :: PROPERTY_COURSE,
                $this->get_course_id());
        $condition = new AndCondition($conditions);

        return WeblcmsDataManager :: get_instance()->count_content_object_publication_categories($condition);
    }

    private function retrieve_category($category_id)
    {
        $conditions[] = new EqualityCondition(ContentObjectPublicationCategory :: PROPERTY_ID, $category_id);
        $conditions[] = new EqualityCondition(ContentObjectPublicationCategory :: PROPERTY_COURSE,
                $this->get_parent()->get_course_id());
        $conditions[] = new EqualityCondition(ContentObjectPublicationCategory :: PROPERTY_TOOL,
                $this->get_parent()->get_tool_id());
        $condition = new AndCondition($conditions);

        $objects = WeblcmsDataManager :: get_instance()->retrieve_content_object_publication_categories($condition);

        return $objects->next_result();
    }

    public function get_publication_type()
    {
        $type = Request :: get(Tool :: PARAM_BROWSE_PUBLICATION_TYPE);
        if (! $type)
        {
            if ($this->is_course_admin)
            {
                $type = Tool :: PUBLICATION_TYPE_ALL;
            }
            else
            {
                $type = Tool :: PUBLICATION_TYPE_FOR_ME;
            }
        }

        return $type;
    }

    /**
     * Returns the default object table order for the browser. Can be "overridden" by the individual component to force
     * a different order if needed. Because the individual component is not an actual implementation but merely this
     * parent, there is a check if the method exists.
     *
     * @return ObjectTableOrder
     */
    function get_default_order_property()
    {
        if (method_exists($this->get_parent(), 'get_default_order_property'))
        {
            return $this->get_parent()->get_default_order_property();
        }
        return new ObjectTableOrder(ContentObjectPublication :: PROPERTY_DISPLAY_ORDER_INDEX);
    }

    function tool_category_has_new_publications($category_id)
    {
        return WeblcmsDataManager :: tool_category_has_new_publications($this->get_tool_id(), $this->get_user(),
                $this->get_course(), $category_id);
    }
}

?>