<?php
namespace application\weblcms;

use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Request;
use common\libraries\Translation;
use repository\ContentObjectForm;
use common\libraries\Utilities;

/**
 * Shows the publication update form
 *
 * @author Sven Vanpoucke
 *        
 * @package application.lib.weblcms.tool.component
 */

class ToolComponentPublicationUpdaterComponent extends ToolComponent
{

    function run()
    {
        $pid = Request :: get(Tool :: PARAM_PUBLICATION_ID) ? Request :: get(Tool :: PARAM_PUBLICATION_ID) : $_POST[Tool :: PARAM_PUBLICATION_ID];
        
        $datamanager = WeblcmsDataManager :: get_instance();
        $publication = $datamanager->retrieve_content_object_publication($pid);
        
        if ($this->is_allowed(WeblcmsRights :: EDIT_RIGHT, $publication))
        {
            
            $content_object = $publication->get_content_object();
            BreadcrumbTrail :: get_instance()->add(new Breadcrumb($this->get_url(), Translation :: get('ToolPublicationUpdaterComponent', array(
                    'TITLE' => $content_object->get_title()))));
            $course = $this->get_course();
            $is_course_admin = $course->is_course_admin($this->get_user());
            
            $publication_form = new ContentObjectPublicationForm(ContentObjectPublicationForm :: TYPE_UPDATE, array(
                    $publication), $course, $this->get_url(), $is_course_admin);
            
            if ($publication_form->validate() || $content_object->get_type() == 'introduction')
            {
                $succes = $publication_form->handle_form_submit();
                
                $message = htmlentities(Translation :: get(($succes ? 'ObjectUpdated' : 'ObjectNotUpdated'), array(
                        'OBJECT' => Translation :: get('Publication')), Utilities :: COMMON_LIBRARIES));
                
                $show_details = Request :: get('details');
                $tool = Request :: get(WeblcmsManager :: PARAM_TOOL);
                
                $params = array();
                if ($show_details == 1)
                {
                    $params[Tool :: PARAM_PUBLICATION_ID] = $pid;
                    $params[Tool :: PARAM_ACTION] = Tool :: ACTION_VIEW;
                }
                
                // TODO: What does this code do? Is this still valid?
                if ($tool == 'learning_path')
                {
                    $params[Tool :: PARAM_ACTION] = null;
                    $params['display_action'] = 'view';
                    $params[Tool :: PARAM_PUBLICATION_ID] = Request :: get(Tool :: PARAM_PUBLICATION_ID);
                }
                
                if (! isset($show_details) && $tool != 'learning_path')
                {
                    $filter = array(Tool :: PARAM_ACTION, Tool :: PARAM_PUBLICATION_ID);
                }
                
                $this->redirect($message, ! $succes, $params, $filter);
            }
            else
            {
                $this->display_header();
                $publication_form->display();
                $this->display_footer();
            }
        }
        else
        {
            $this->redirect(Translation :: get("NotAllowed"), true, array(), array(Tool :: PARAM_ACTION, 
                    Tool :: PARAM_PUBLICATION_ID));
        }
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add_help('courses general');
    }
}
?>