<?php
namespace application\weblcms;

use common\libraries\Breadcrumb;

use common\libraries\DelegateComponent;

use common\extensions\feedback_manager\FeedbackManager;
use common\libraries\ActionBarRenderer;
use common\libraries\BreadcrumbTrail;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Utilities;

/**
 * $Id: viewer.class.php 200 2009-11-13 12:30:04Z kariboe $
 *
 * @package repository.lib.complex_display.assessment.component
 */
class ToolComponentViewerComponent extends ToolComponent implements DelegateComponent
{
    
    private $action_bar;
    private $html;

    function run()
    {
        // check if the content object has indeed been published for the user
        $publication = WeblcmsDataManager :: get_instance()->retrieve_content_object_publication($this->get_publication_id());
        
        if (! $this->is_allowed(WeblcmsRights :: VIEW_RIGHT, $publication))
        {
            $this->redirect(Translation :: get("NotAllowed", null, Utilities :: COMMON_LIBRARIES), true, array(), array(
                    Tool :: PARAM_ACTION, Tool :: PARAM_PUBLICATION_ID));
        }
        
        $object = $publication->get_content_object();
        BreadcrumbTrail :: get_instance()->add(new Breadcrumb($this->get_url(), Translation :: get('ToolViewerComponent', array(
                'TITLE' => $object->get_title()))));
        
        $trail = BreadcrumbTrail :: get_instance();
        
        $this->action_bar = $this->get_action_bar();
        $renderer = new ContentObjectPublicationDetailsRenderer($this);
        $this->html = $renderer->as_html();
        
        $course_settings_controller = CourseSettingsController :: get_instance();
        $feedback_allowed = $course_settings_controller->get_course_setting($this->get_course_id(), CourseSettingsConnector :: ALLOW_FEEDBACK);
        if ($feedback_allowed)
        {
            $feedback_manager = new FeedbackManager($this, WeblcmsManager :: APPLICATION_NAME, $publication->get_id(), null, null, $this->is_allowed(WeblcmsRights :: DELETE_RIGHT, $publication));
            return $feedback_manager->run();
        }
        else
        {
            $this->display_header();
            $this->display_footer();
        }
    }

    function display_header()
    {
        parent :: display_header();
        echo $this->action_bar->as_html();
        echo '<div id="action_bar_browser">';
        echo $this->html;
    }

    function display_footer()
    {
        echo '</div>';
        parent :: display_footer();
    }

    function get_publication_id()
    {
        return Request :: get(Tool :: PARAM_PUBLICATION_ID);
    }

    function get_publication_count()
    {
        return 1;
    }

    function get_action_bar()
    {
        $action_bar = new ActionBarRenderer(ActionBarRenderer :: TYPE_HORIZONTAL);
        
        if ($this->is_allowed(WeblcmsRights :: EDIT_RIGHT))
        {
            $action_bar->add_common_action($this->get_access_details_toolbar_item($this));
        }
        
        if (method_exists($this->get_parent(), 'get_tool_actions'))
        {
            $action_bar->set_tool_actions($this->get_parent()->get_tool_actions());
        }
        
        return $action_bar;
    }

    function add_actionbar_item($item)
    {
        $this->action_bar->add_common_action($item);
    }

    function set_action_bar($action_bar)
    {
        $this->action_bar = $action_bar;
    }

}

?>
