<?php
namespace application\weblcms;

use common\libraries\ToolbarItem;
use common\libraries\Display;
use common\libraries\Application;
use common\libraries\Theme;
use common\libraries\Session;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Utilities;
use common\libraries\Request;
use common\libraries\DelegateComponent;
use common\libraries\Translation;
use application\weblcms\course\CourseDataManager;
use application\weblcms\tool\user\UserTool;

/**
 * $Id: course_viewer.class.php 218 2009-11-13 14:21:26Z kariboe $
 * 
 * @package application.lib.weblcms.weblcms_manager.component
 */
/**
 * Weblcms component which provides the course page
 */
class WeblcmsManagerCourseViewerComponent extends WeblcmsManager implements DelegateComponent
{
    /**
     * The selected course object
     *
     * @var \application\weblcms\course\Course
     */
    private $course;
    
    /**
     * The selected tool registration
     *
     * @var \application\weblcms\CourseTool
     */
    private $course_tool_registration;

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        if (! $this->access_allowed())
        {
            throw new \Exception(Translation :: get('NotAllowedToView'));
        }
        
        if (is_null($this->get_course()))
        {
            throw new \Exception(Translation :: get('SelectedCourseNotValid'));
        }
        
        $this->load_course_theme();
        $this->load_course_language();
        
        $course = Request :: get(WeblcmsManager :: PARAM_COURSE);
        $tool = Request :: get(WeblcmsManager :: PARAM_TOOL);
        if (! $tool)
        {
            $tool = 'home';
        }
        
        $action = Request :: get(Application :: PARAM_ACTION);
        $category = Request :: get(WeblcmsManager :: PARAM_CATEGORY);
        
        if (! $category)
        {
            $category = 0;
        }
        
        $this->course_tool_registration = WeblcmsDataManager :: retrieve_course_tool_by_name($tool);
        if (is_null($this->course_tool_registration))
        {
            throw new \Exception(Translation :: get('SelectedCourseToolNotValid'));
        }
        
        if ($tool != 'course_group')
        {
            $this->set_parameter('course_group', null);
        }
        
        $breadcrumbtrail = BreadcrumbTrail :: get_instance();
        
        $breadcrumb_title = CourseSettingsConnector :: get_breadcrumb_title_for_course($this->get_course());
        
        $breadcrumbtrail->add(new Breadcrumb($this->get_url(array(WeblcmsManager :: PARAM_CATEGORY => null, 
                WeblcmsManager :: PARAM_TOOL => null)), $breadcrumb_title));
        
        if ($tool != 'home')
        {
            $breadcrumbtrail->add(new Breadcrumb($this->get_url(), Translation :: get('TypeName', null, 'application\weblcms\tool\\' . $tool)));
        }
        
        $wdm = WeblcmsDataManager :: get_instance();
        
        Tool :: factory_and_launch($tool, $this);
        
        $wdm->log_course_module_access($this->get_course_id(), $this->get_user_id(), $tool, $category);
    }

    /**
     * Returns the course
     *
     * @return \application\weblcms\Course
     */
    function get_course()
    {
        if (is_null($this->course))
        {
            $course_id = Request :: get(WeblcmsManager :: PARAM_COURSE);
            
            if (! $course_id)
            {
                throw new \Exception(Translation :: get('NoCourseSelected'));
            }
            
            $this->course = CourseDataManager :: get_instance()->retrieve_course($course_id);
        }
        
        return $this->course;
    }  
    
    /**
     * Fake user id as necessary for "view as" functionality.
     * If no "view as" id is set, use normal user id.
     */
    function get_user_id()
    {
        $va_id = Session :: get(Tool :: PARAM_VIEW_AS_ID);
        $course_id = Session :: get(Tool :: PARAM_VIEW_AS_COURSE_ID);

        if (isset($va_id) && isset($course_id))
        {
            if ($course_id == $this->get_course_id())
            {
                return $va_id;
            }
        }
        return parent :: get_user_id();
    }
    
    /**
     * Fake user as necessary for "view as" functionality.
     */
    function get_user() 
    {
        $va_id = Session :: get(Tool :: PARAM_VIEW_AS_ID);
        $course_id = Session :: get(Tool :: PARAM_VIEW_AS_COURSE_ID);

        if (isset($va_id) && isset($course_id))
        {
            if ($course_id == $this->get_course_id())
            {
                return $this->get_user_info($va_id);
            }
        }
        return parent :: get_user();
    }

    /**
     * Add a header when viewing course as another user. 
     */
    function display_header()
    {
        $va_id = Session :: get(Tool :: PARAM_VIEW_AS_ID);
        $course_id = Session :: get(Tool :: PARAM_VIEW_AS_COURSE_ID);
        
        if (isset($va_id) && isset($course_id))
        {
            if ($course_id == $this->get_course_id())
            {
                // show extra part in header to indicate that we're viewing as
                // another user
                $user = $this->get_user_info($va_id);
                echo '<div id="emulator">' . Translation :: get('ViewingAsUser') . ' ' . $user->get_firstname() . ' ' . $user->get_lastname() . ' <a href="' . $this->get_url(array(
                        WeblcmsManager :: PARAM_TOOL => 'user',  // replace,
                                                                // seriously
                        WeblcmsManager :: PARAM_TOOL_ACTION => UserTool :: ACTION_VIEW_AS)) . '">' . Translation :: get('Back') . '</a></div>';
            }
        }
        parent :: display_header();
    }

    /**
     * Returns the identifier of the course that is being used.
     *
     * @return int
     */
    function get_course_id()
    {
        return $this->get_course()->get_id();
    }

    /**
     * Loads the theme of the course
     */
    function load_course_theme()
    {
        $course_settings_controller = CourseSettingsController :: get_instance();
        $theme_setting = $course_settings_controller->get_course_setting($this->get_course_id(), CourseSettingsConnector :: THEME);
        
        if ($theme_setting)
        {
            Theme :: set_theme($theme_setting);
        }
    }

    /**
     * Loads the language of the course
     */
    function load_course_language()
    {
        $course_settings_controller = CourseSettingsController :: get_instance();
        $language = $course_settings_controller->get_course_setting($this->get_course_id(), CourseSettingsConnector :: LANGUAGE);
        
        Translation :: set_language($language);
    }
    
    private $is_teacher;

    function is_teacher()
    {
        if (is_null($this->is_teacher))
        {
            $user = $this->get_user();
            $course = $this->get_course();
            
            $this->is_teacher = parent :: is_teacher($course, $user);
        }
        
        return $this->is_teacher;
    }

    /**
     * Returns the additional parameters that need to be registered for this
     * component
     *
     * @return String[]
     */
    function get_additional_parameters()
    {
        return array(self :: PARAM_COURSE, self :: PARAM_TOOL);
    }

    /**
     * determine if this user has access to this course
     * platform admin & course admin always have access
     * subscribed users have access when status is 'open', 'open to platform' or
     * 'open to world'
     * other 'real' platform users have access when status is 'open to platform'
     * or 'open to world'
     * anonymous users have access when status is 'open to world'
     * 
     * @return boolean access_allowed
     */
    function access_allowed()
    {
        $allowed = false;
        
        if ($this->is_teacher())
        {
            $allowed = true;
        }
        else
        {
            $allowed = true;
            
            $course_settings_controller = CourseSettingsController :: get_instance();
            $course_access = $course_settings_controller->get_course_setting($this->get_course_id(), CourseSettingsConnector :: COURSE_ACCESS);
            
            if ($access == CourseSettingsConnector :: COURSE_ACCESS_CLOSED)
            {
                $allowed = false;
            }
            else
            {
                $open_course_access_type = $course_settings_controller->get_course_setting($this->get_course_id(), CourseSettingsConnector :: OPEN_COURSE_ACCESS_TYPE);
                
                $is_subscribed = $this->is_subscribed($this->get_course(), $this->get_user());
                
                if ($is_subscribed || $open_course_access_type == CourseSettingsConnector :: OPEN_COURSE_ACCESS_WORLD)
                {
                    $allowed = true;
                }
                else 
                    if ($open_course_access_type == CourseSettingsConnector :: OPEN_COURSE_ACCESS_PLATFORM && ! $this->get_user()->is_anonymous_user())
                    {
                        $allowed = true;
                    }
                    else
                    {
                        $allowed = false;
                    }
            }
        }
        
        return $allowed;
    }

    /**
     * Returns the CourseTool registration of the selected tool
     *
     * @return CourseTool
     */
    function get_tool_registration()
    {
        return $this->course_tool_registration;
    }
    
    /**
     * Indicates whether the current tool may be accessed for the current course.
     * @return bool
     */
    function is_tool_accessible()
    {
        return CourseSettingsController::get_instance()->get_course_setting($this->get_course_id(),
                CourseSetting::COURSE_SETTING_TOOL_ACTIVE, $this->get_tool_registration()->get_id());
    }
}
?>