<?php
namespace application\weblcms;

use common\libraries\CommonDataManager;
use admin\AdminDataManager;

use core\lynx\PackageList;

use application\weblcms\tool\user\SubscribeGroupBrowserTable;
use application\weblcms\tool\user\SubscribedUserBrowserTable;

use application\weblcms\course\CourseManager;
use application\weblcms\course\CourseUserRelation;

use common\libraries\ObjectTable;
use common\libraries\DynamicAction;
use common\libraries\Filesystem;
use common\libraries\Redirect;
use common\libraries\Display;
use common\libraries\Application;
use common\libraries\Theme;
use common\libraries\Session;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Utilities;
use common\libraries\EqualityCondition;
use common\libraries\Request;
use common\libraries\WebApplication;
use common\libraries\Translation;

use user\UserDataManager;

use HTML_Table;
use application\weblcms\course\Course;

/**
 * ============================================================================== This is an application that creates a
 * fully fledged web-based learning content management system. The Web-LCMS is based on so-called "tools", which each
 * represent a segment in the application.
 *
 * @author Tim De Pauw ==============================================================================
 */

class WeblcmsManager extends WebApplication
{
    const APPLICATION_NAME = 'weblcms';

    const PARAM_REQUEST_TYPE = 'request_type';
    const PARAM_REQUEST_VIEW = 'request_view';
    const PARAM_REQUEST = 'request';
    const PARAM_REMOVE_SELECTED_REQUESTS = 'removed selected requests';
    const PARAM_COURSE = 'course';
    const PARAM_CATEGORY = 'publication_category';
    const PARAM_COURSE_CATEGORY_ID = 'category';
    const PARAM_COURSE_USER = 'course';
    const PARAM_COURSE_GROUP = 'course_group';
    const PARAM_COURSE_TYPE_USER_CATEGORY_ID = 'user_category';
    const PARAM_COURSE_TYPE = 'course_type';
    const PARAM_USERS = 'users';
    const PARAM_GROUP = 'group';
    const PARAM_TYPE = 'type';
    const PARAM_ACTIVE = 'active';
    const PARAM_TOOL = 'tool';
    const PARAM_COMPONENT_ACTION = 'action';
    const PARAM_DIRECTION = 'direction';
    const PARAM_REMOVE_SELECTED = 'remove_selected';
    const PARAM_REMOVE_SELECTED_COURSE_TYPES = 'remove selected coursetypes';
    const PARAM_ACTIVATE_SELECTED_COURSE_TYPES = 'activate selected coursetypes';
    const PARAM_DEACTIVATE_SELECTED_COURSE_TYPES = 'deactivate selected coursetypes';
    const PARAM_CHANGE_COURSE_TYPE_SELECTED_COURSES = 'Change Coursetype selected courses';
    const PARAM_UNSUBSCRIBE_SELECTED = 'unsubscribe_selected';
    const PARAM_SUBSCRIBE_SELECTED = 'subscribe_selected';
    const PARAM_SUBSCRIBE_SELECTED_AS_STUDENT = 'subscribe_selected_as_student';
    const PARAM_SUBSCRIBE_SELECTED_AS_ADMIN = 'subscribe_selected_as_admin';
    const PARAM_SUBSCRIBE_SELECTED_GROUP = 'subscribe_selected_group_admin';
    const PARAM_TOOL_ACTION = 'tool_action';
    const PARAM_STATUS = 'user_status';
    const PARAM_EXTRA = 'extra';
    const PARAM_PUBLICATION = 'publication';
    const PARAM_ALLOW_SELECTED_REQUESTS = 'allow_selected_requests';
    const PARAM_REFUSE_SELECTED_REQUESTS = 'refuse_selected_requests';

    const ACTION_SUBSCRIBE = 'subscribe';
    const ACTION_CHANGE_COURSE_TYPE_FROM_COURSE = 'course_change_course_type';
    const ACTION_SUBSCRIBE_GROUP = 'group_subscribe';
    const ACTION_UNSUBSCRIBE_GROUP = 'group_unsubscribe';
    const ACTION_SUBSCRIBE_GROUP_USERS = 'group_users_subscribe';
    const ACTION_VIEW_WEBLCMS_HOME = 'home';
    const ACTION_VIEW_COURSE = 'course_viewer';
    const ACTION_IMPORT_COURSES = 'course_importer';
    const ACTION_IMPORT_COURSE_USERS = 'course_user_importer';
    const ACTION_DELETE_COURSE = 'course_deleter';
    const ACTION_DELETE_COURSES_BY_COURSE_TYPE = 'course_type_courses_deleter';
    const ACTION_MANAGER_SORT = 'sorter';
    const ACTION_MANAGER_SUBSCRIBE = 'subscribe';
    const ACTION_MANAGER_UNSUBSCRIBE = 'unsubscribe';
    const ACTION_COURSE_CATEGORY_MANAGER = 'course_category_manager';
    const ACTION_ADMIN_COURSE_BROWSER = 'admin_course_browser';
    const ACTION_SELECT_COURSE_TYPE = 'course_type_selector';
    const ACTION_DELETE_COURSE_TYPE = 'course_type_deleter';
    const ACTION_VIEW_COURSE_TYPE = 'course_type_viewer';
    const ACTION_CHANGE_ACTIVATION = 'active_changer';
    const ACTION_CHANGE_ACTIVE = 'activity_changer';
    const ACTION_ADMIN_COURSE_TYPE_CREATOR = 'admin_course_type_creator';
    const ACTION_ADMIN_COURSE_TYPE_BROWSER = 'admin_course_type_browser';
    const ACTION_COURSE_EDITOR_REQUEST = 'course_request_editor';
    const ACTION_COURSE_SUBSCRIBE_CREATE_REQUEST = 'course_subscribe_request_creator';
    const ACTION_ADMIN_REQUEST_BROWSER = 'admin_request_browser';
    const ACTION_COURSE_REQUEST_DELETER = 'course_request_deleter';
    const ACTION_COURSE_ALLOWING_REQUEST = 'course_request_allow';
    const ACTION_COURSE_REFUSE_REQUEST = 'course_request_refuse';
    const ACTION_VIEW_REQUEST = 'course_request_viewer';
    const ACTION_PUBLISH_INTRODUCTION = 'introduction_publisher';
    const ACTION_DELETE_INTRODUCTION = 'introduction_deleter';
    const ACTION_EDIT_INTRODUCTION = 'introduction_editor';
    const ACTION_REPORTING = 'reporting';
    const ACTION_COURSE_CODE = 'course_code_subscriber';
    const ACTION_COURSE_CREATE_REQUEST_CREATOR = 'course_create_request_creator';

    const ACTION_COURSE_TYPE_MANAGER = 'course_type_manager';
    const ACTION_ADMIN_COURSE_MANAGER = 'admin_course_manager';
    const ACTION_COURSE_MANAGER = 'course_manager';

    const ACTION_RENDER_BLOCK = 'block';

    const DEFAULT_ACTION = self :: ACTION_VIEW_WEBLCMS_HOME;

    /**
     * The sections that this application offers.
     */
    private $sections;

    /**
     * The course_group object of the course_group currently active in this application
     */
    private $course_group;

    private $request;

    /**
     * The new publications for each tool are cached here
     *
     * @var Array[tool] = new publications count
     */
    private static $new_publications;

    /**
     * Constructor. Optionally takes a default tool; otherwise, it is taken from the query string.
     *
     * @param $tool Tool The default tool, or null if none.
     */
    function __construct($user)
    {
        parent :: __construct($user);
    }

    /**
     * Renders the weblcms block and returns it.
     */
    function render_block($block)
    {
        $weblcms_block = WeblcmsBlock :: factory($this, $block);
        return $weblcms_block->run();
    }

    /**
     * Gets the identifier of the current tool
     *
     * @return string The identifier of current tool
     */
    function get_tool_id()
    {
        return $this->get_parameter(self :: PARAM_TOOL);
    }

    /**
     * Retrieves the change active url
     *
     * @return the change active component url
     */
    function get_change_active_url($type, $course_type_id)
    {
        $parameters = array();
        $parameters[self :: PARAM_ACTION] = self :: ACTION_CHANGE_ACTIVE;
        $parameters[self :: PARAM_TYPE] = $type;
        $parameters[self :: PARAM_COURSE_TYPE] = $course_type_id;

        return $this->get_url($parameters);
    }

    /**
     * Gets the user object for a given user
     *
     * @param $user_id int
     * @return User
     */
    function get_user_info($user_id)
    {
        return UserDataManager :: get_instance()->retrieve_user($user_id);
    }

    function set_request($request)
    {
        $this->request = $request;
    }

    /**
     * Returns the course_group that is being used.
     *
     * @return string The course_group.
     */
    function get_course_group()
    {
        return $this->course_group;
    }

    function get_course_type_deleting_all_courses_url($course_type)
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_DELETE_COURSES_BY_COURSE_TYPE,
                self :: PARAM_COURSE_TYPE => $course_type->get_id()));
    }

    function get_request()
    {
        return $this->request;
    }

    function get_course_changing_course_type_url($course)
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_CHANGE_COURSE_TYPE_FROM_COURSE,
                self :: PARAM_COURSE => $course->get_id()));
    }

    function get_course_type_deleting_url($course_type)
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_DELETE_COURSE_TYPE,
                self :: PARAM_COURSE_TYPE => $course_type->get_id()));
    }

    function get_course_type_editing_url($course_type)
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_ADMIN_COURSE_TYPE_CREATOR,
                self :: PARAM_COURSE_TYPE => $course_type->get_id(),
                self :: PARAM_TOOL => 'course_type_settings',
                'previous' => 'admin'));
    }

    function get_course_request_deleting_url($request, $request_type, $request_view)
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_COURSE_REQUEST_DELETER,
                self :: PARAM_REQUEST => $request->get_id(),
                self :: PARAM_REQUEST_TYPE => $request_type,
                self :: PARAM_REQUEST_VIEW => $request_view));
    }

    function get_course_request_allowing_url($request, $request_type, $request_view)
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_COURSE_ALLOWING_REQUEST,
                self :: PARAM_REQUEST => $request->get_id(),
                self :: PARAM_REQUEST_TYPE => $request_type,
                self :: PARAM_REQUEST_VIEW => $request_view));
    }

    function get_course_request_viewing_url($request, $request_type, $request_view)
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_VIEW_REQUEST,
                self :: PARAM_REQUEST => $request->get_id(),
                self :: PARAM_REQUEST_TYPE => $request_type));
    }

    function get_course_request_refuse_url($request, $request_type, $request_view)
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_COURSE_REFUSE_REQUEST,
                self :: PARAM_REQUEST => $request->get_id(),
                self :: PARAM_REQUEST_TYPE => $request_type,
                self :: PARAM_REQUEST_VIEW => $request_view));
    }

    function get_course_type_maintenance_url($course_type)
    {
        // return $this->get_url(array(self :: PARAM_ACTION => self ::
        // ACTION_VIEW_COURSE, self :: PARAM_COURSE => $course->get_id(), self
        // :: PARAM_TOOL => 'maintenance'));
        return null;
    }

    function get_course_type_viewing_url($course_type)
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_VIEW_COURSE_TYPE,
                self :: PARAM_COURSE_TYPE => $course_type->get_id()));
    }

    function get_home_url()
    {
        return $this->get_url(array(self :: PARAM_ACTION => self :: ACTION_VIEW_WEBLCMS_HOME));
    }

    /**
     * Sets the course_group
     *
     * @param $course_group CourseGroup
     */
    function set_course_group($course_group)
    {
        $this->course_group = $course_group;
    }

    /**
     * Gets a list of all course_groups of the current active course in which the current user is subscribed.
     */
    function get_course_groups()
    {
        $wdm = WeblcmsDataManager :: get_instance();
        $course_groups = $wdm->retrieve_course_groups_from_user($this->get_user_id(), $this->get_course_id())->as_array();
        return $course_groups;
    }

    /**
     * Makes a category tree ready for displaying by adding a prefix to the category title based on the level of that
     * category in the tree structure.
     *
     * @param $tree array The category tree
     * @param $categories array In this array the new category titles (with prefix) will be stored. The keys in this
     * array are the category ids, the values are the new titles
     * @param $level int The current level in the tree structure
     */
    private static function translate_category_tree($tree, $categories, $level = 0)
    {
        foreach ($tree as $node)
        {
            $obj = $node['obj'];
            $prefix = ($level ? str_repeat('&nbsp;&nbsp;&nbsp;', $level) . '&mdash; ' : '');
            $categories[$obj->get_id()] = $prefix . $obj->get_title();
            $subtree = $node['sub'];
            if (is_array($subtree) && count($subtree))
            {
                self :: translate_category_tree($subtree, $categories, $level + 1);
            }
        }
    }

    /**
     * Gets a category
     *
     * @param $id int The id of the requested category
     * @return LearningPublicationCategory The requested category
     */
    function get_category($id)
    {
        return WeblcmsDataManager :: get_instance()->retrieve_content_object_publication_category($id);
    }

    /**
     * Returns the names of the sections known to this application.
     *
     * @return array The tools.
     */
    function get_registered_sections()
    {
        if (is_null($this->sections))
        {
            $this->load_sections();
        }
        return $this->sections;
    }

    /**
     * Loads the sections installed on the system.
     */
    function load_sections()
    {
        // if (! is_null($this->get_course_id()))
        {
            $wdm = WeblcmsDataManager :: get_instance();
            $condition = new EqualityCondition(CourseSection :: PROPERTY_COURSE_ID, Request :: get(self :: PARAM_COURSE));
            $sections = $wdm->retrieve_course_sections($condition);

            while ($section = $sections->next_result())
            {
                // $type = isset($section->type) ? $section->type : '';
                $this->sections[] = $section;
            }
        }
    }

    /**
     * Determines whether or not the given name is a valid tool name.
     *
     * @param $name string The name to evaluate.
     * @return True if the name is a valid tool name, false otherwise.
     */
    static function is_tool_name($name)
    {
        return (preg_match('/^[a-z][a-z_]+$/', $name) > 0);
    }

    /*
     * Inherited
     */
    function retrieve_max_sort_value($table, $column, $condition = null)
    {
        return WeblcmsDataManager :: get_instance()->retrieve_max_sort_value($table, $column, $condition);
    }

    /*
     * Inherited
     */
    static function content_object_is_published($object_id)
    {
        return WeblcmsDataManager :: get_instance()->content_object_is_published($object_id);
    }

    /*
     * Inherited
     */
    static function any_content_object_is_published($object_ids)
    {
        return WeblcmsDataManager :: get_instance()->any_content_object_is_published($object_ids);
    }

    /*
     * Inherited
     */
    static function get_content_object_publication_attributes($object_id, $type = null, $offset = null, $count = null, $order_property = null)
    {
        return WeblcmsDataManager :: get_instance()->get_content_object_publication_attributes(null, $object_id, $type, $offset, $count, $order_property);
    }

    /*
     * Inherited
     */
    static function get_content_object_publication_attribute($publication_id)
    {
        return WeblcmsDataManager :: get_instance()->get_content_object_publication_attribute($publication_id);
    }

    /*
     * Inherited
     */
    static function delete_content_object_publications($object_id)
    {
        return WeblcmsDataManager :: get_instance()->delete_content_object_publications($object_id);
    }

    static function delete_content_object_publication($publication_id)
    {
        $publication = WeblcmsDataManager :: get_instance()->retrieve_content_object_publication($publication_id);
        if (! $publication)
        {
            return false;
        }
        return $publication->delete();
    }

    /*
     * Inherited
     */
    static function update_content_object_publication_id($publication_attr)
    {
        return WeblcmsDataManager :: get_instance()->update_content_object_publication_id($publication_attr);
    }

    /**
     * Inherited
     */
    static function count_publication_attributes($user = null, $object_id = null, $condition = null)
    {
        return WeblcmsDataManager :: get_instance()->count_publication_attributes($user, $object_id, $condition);
    }

    /**
     * Inherited
     */
    static function get_content_object_publication_locations($content_object, $user = null)
    {
        $locations = array();
        $type = $content_object->get_type();

        $conditions = WeblcmsDataManager :: get_user_courses_condition($user);
        $courses = WeblcmsDataManager :: get_instance()->retrieve_user_courses($conditions);

        $possible_courses = array();

        while ($course = $courses->next_result())
        {
            if ($course->is_course_admin($user))
            {
                $possible_courses[] = $course;
            }
        }

        $course_settings_controller = CourseSettingsController :: get_instance();
        $course_management_rights = CourseManagementRights :: get_instance();

        $tools = WeblcmsDataManager :: get_instance()->retrieve_course_tools();
        $tool_directory = __DIR__ . '/../../../tool/';

        $tool_names = array();

        while ($tool = $tools->next_result())
        {
            $tool_name = $tool->get_name();

            $path = $tool_directory . $tool_name . '/php/lib/' . $tool_name . '_tool.class.php';

            if (! file_exists($path))
            {
                continue;
            }

            $class = Tool :: get_tool_type_namespace($tool_name) . '\\' . Utilities :: underscores_to_camelcase($tool_name) . 'Tool';
            $obj = new $class(new self());

            $types[$tool->get_id()] = $obj->get_allowed_types();

            $tool_names[$tool->get_id()] = $tool->get_name();
        }

        foreach ($types as $tool_id => $allowed_types)
        {
            if (in_array($type, $allowed_types))
            {
                $user = Session :: get_user_id();

                foreach ($possible_courses as $course)
                {
                    if ($course_settings_controller->get_course_setting($course->get_id(), CourseSetting :: COURSE_SETTING_TOOL_ACTIVE, $tool_id) && $course_management_rights->is_allowed(CourseManagementRights :: PUBLISH_FROM_REPOSITORY_RIGHT, $course->get_id()))
                    {
                        $tool_name = $tool_names[$tool_id];

                        $locations[$course->get_id() . '-' . $tool_name] = 'Course: ' . $course->get_title() . ' (' . $course->get_visual_code() . ')' . ' - Tool: ' . $tool_name;
                    }
                }
            }
        }
        return $locations;
    }

    static function publish_content_object($content_object, $location, $attributes)
    {
        $location_split = split('-', $location);
        $course = $location_split[0];
        $tool = $location_split[1]; // echo $location;
        $dm = WeblcmsDataManager :: get_instance();
        $do = $dm->get_next_content_object_publication_display_order_index($course, $tool, 0);

        $pub = new ContentObjectPublication();
        $pub->set_content_object_id($content_object->get_id());
        $pub->set_course_id($course);
        $pub->set_tool($tool);
        $pub->set_publisher_id(Session :: get_user_id());
        $pub->set_display_order_index($do);
        $pub->set_publication_date(time());
        $pub->set_modified_date(time());

        $pub->set_hidden($attributes[ContentObjectPublication :: PROPERTY_HIDDEN]);
        if (is_null($pub->is_hidden()))
            $pub->set_hidden(0);

        if ($attributes['forever'] == 0)
        {
            $pub->set_from_date(Utilities :: time_from_datepicker($attributes['from_date']));
            $pub->set_to_date(Utilities :: time_from_datepicker($attributes['to_date']));
        }

        $pub->create();

        $course = \application\weblcms\course\CourseDataManager :: get_instance()->retrieve_course($course);
        return Translation :: get('PublicationCreated') . ': <b>' . Translation :: get('Course') . '</b>: ' . $course->get_title() . ' - <b>' . Translation :: get('Tool') . '</b>: ' . $tool;
    }

    static function add_publication_attributes_elements($form)
    {
        $form->addElement('category', Translation :: get('PublicationDetails'));
        $form->addElement('checkbox', self :: APPLICATION_NAME . '_opt_' . ContentObjectPublication :: PROPERTY_HIDDEN, Translation :: get('Hidden'));
        $form->add_forever_or_timewindow('PublicationPeriod', self :: APPLICATION_NAME . '_opt_');
        $form->addElement('category');
        $form->addElement('html', '<br />');

        $defaults[self :: APPLICATION_NAME . '_opt_forever'] = 1;
        $form->setDefaults($defaults);
    }

    /**
     * Count the number of courses
     *
     * @param $condition Condition
     * @return int
     */
    function count_courses($condition = null)
    {
        return WeblcmsDataManager :: get_instance()->count_courses($condition);
    }

    function count_course_types($condition = null)
    {
        return WeblcmsDataManager :: get_instance()->count_course_types($condition);
    }

    function count_requests($condition = null)
    {
        return WeblcmsDataManager :: get_instance()->count_requests($condition);
    }

    function count_course_create_requests($condition = null)
    {
        return WeblcmsDataManager :: get_instance()->count_course_create_requests($condition);
    }

    function count_requests_by_course($condition = null)
    {
        return WeblcmsDataManager :: get_instance()->count_requests_by_course($condition);
    }

    function subscribe_user_to_allowed_courses($user_id)
    {
        return WeblcmsDataManager :: get_instance()->subscribe_user_to_allowed_courses($user_id);
    }

    /**
     * Count the number of course categories
     *
     * @param $condition Condition
     * @return int
     */
    function count_course_categories($condition = null)
    {
        return WeblcmsDataManager :: get_instance()->count_course_categories($condition);
    }

    /**
     * Count the number of courses th user is subscribed to
     *
     * @param $condition Condition
     * @return int
     */
    function count_user_courses($condition = null)
    {
        return WeblcmsDataManager :: get_instance()->count_user_courses($condition);
    }

    /**
     * Count the number of course user categories
     *
     * @param $condition Condition
     * @return int
     */
    function count_course_user_categories($condition = null)
    {
        return WeblcmsDataManager :: get_instance()->count_course_user_categories($condition);
    }

    /**
     * Retrieves the course categories that match the criteria from persistent storage.
     *
     * @param $parent string The parent of the course category.
     * @return DatabaseCourseCategoryResultSet The resultset of course category.
     */
    function retrieve_course_categories($conditions = null, $offset = null, $count = null, $order_by = null)
    {
        return WeblcmsDataManager :: get_instance()->retrieve_course_categories($conditions, $offset, $count, $order_by);
    }

    /**
     * Retrieves the personal course categories for a given user.
     *
     * @return DatabaseUserCourseCategoryResultSet The resultset of course categories.
     */
    function retrieve_course_user_categories($conditions = null, $offset = null, $count = null, $order_property = null)
    {
        return WeblcmsDataManager :: get_instance()->retrieve_course_user_categories($conditions, $offset, $count, $order_property);
    }

    /**
     * Retrieves a personal course category for the user.
     *
     * @return CourseUserCategory The course user category.
     */
    function retrieve_course_user_category($condition = null)
    {
        return WeblcmsDataManager :: get_instance()->retrieve_course_user_category($condition);
    }

    function retrieve_course_type_user_category($condition = null)
    {
        return WeblcmsDataManager :: get_instance()->retrieve_course_type_user_category($condition);
    }

    /**
     * Retrieves a personal course category for the user according to
     *
     * @param $user_id int
     * @param $sort int
     * @param $direction string
     * @return CourseUserCategory The course user category.
     */
    function retrieve_course_type_user_category_at_sort($user_id, $course_type_id, $sort, $direction)
    {
        return WeblcmsDataManager :: get_instance()->retrieve_course_type_user_category_at_sort($user_id, $course_type_id, $sort, $direction);
    }

    /**
     * Retrieves a single course from persistent storage.
     *
     * @param $course_code string The alphanumerical identifier of the course.
     * @return Course The course.
     */
    function retrieve_course($course_code)
    {
        return WeblcmsDataManager :: get_instance()->retrieve_course($course_code);
    }

    function retrieve_requests_by_course($id)
    {
        return WeblcmsDataManager :: get_instance()->retrieve_requests_by_course($id);
    }

    function retrieve_course_type($course_type_id)
    {
        return WeblcmsDataManager :: get_instance()->retrieve_course_type($course_type_id);
    }

    function retrieve_course_type_user_categories($condition = null, $offset = null, $count = null, $order_property = null)
    {
        return WeblcmsDataManager :: get_instance()->retrieve_course_type_user_categories($condition, $offset, $count, $order_property);
    }

    function retrieve_course_types($condition = null, $offset = null, $count = null, $order_property = null)
    {
        return WeblcmsDataManager :: get_instance()->retrieve_course_types($condition, $offset, $count, $order_property);
    }

    function retrieve_requests($condition = null, $offset = null, $count = null, $order_property = null)
    {
        return WeblcmsDataManager :: get_instance()->retrieve_requests($condition, $offset, $count, $order_property);
    }

    function retrieve_course_create_requests($condition = null, $offset = null, $count = null, $order_property = null)
    {
        return WeblcmsDataManager :: get_instance()->retrieve_course_create_requests($condition, $offset, $count, $order_property);
    }

    function retrieve_active_course_types()
    {
        return WeblcmsDataManager :: get_instance()->retrieve_active_course_types();
    }

    function count_active_course_types()
    {
        return WeblcmsDataManager :: get_instance()->count_active_course_type();
    }

    /**
     * Retrieves a single course category from persistent storage.
     *
     * @param $category_code string The alphanumerical identifier of the course category.
     * @return CourseCategory The course category.
     */
    function retrieve_course_category($course_category)
    {
        return WeblcmsDataManager :: get_instance()->retrieve_course_category($course_category);
    }

    /**
     * Retrieves a single course user relation from persistent storage.
     *
     * @param $course_code string
     * @param $user_id int
     * @return CourseCategory The course category.
     */
    function retrieve_course_user_relation($course_code, $user_id)
    {
        return WeblcmsDataManager :: get_instance()->retrieve_course_user_relation($course_code, $user_id);
    }

    /**
     * Retrieves a set of course user relations
     *
     * @param $user_id int
     * @param $course_user_category string
     */
    function retrieve_course_user_relations($condition = null, $offset = null, $count = null, $order_property = null)
    {
        return WeblcmsDataManager :: get_instance()->retrieve_course_user_relations($condition, $offset, $count, $order_property);
    }

    /**
     * Retrieve a series of courses
     *
     * @param $user User
     * @param $category string
     * @param $condition Condition
     * @param $order_by array
     * @param $offset int
     * @param $max_objects int
     * @return CourseResultSet
     */
    function retrieve_courses($condition = null, $offset = null, $count = null, $order_property = null)
    {
        return WeblcmsDataManager :: get_instance()->retrieve_courses($condition, $offset, $count, $order_property);
    }

    /**
     * Retrieve a series of courses for a specific user + the relation
     *
     * @param $condition Condition
     * @param $order_by array
     * @param $offset int
     * @param $max_objects int
     * @return CourseResultSet
     */
    function retrieve_user_courses($condition = null, $offset = null, $count = null, $order_property = null)
    {
        return WeblcmsDataManager :: get_instance()->retrieve_user_courses($condition, $offset, $count, $order_property);
    }

    /**
     * Gets the date of the last visit of current user to the current location
     *
     * @param $tool string If $tool equals null, current active tool will be taken into account. If no tool is given or
     * no tool is active the date of last visit to the course homepage will be returned.
     * @param $category_id int The category in the given tool of which the last visit date is requested. If $category_id
     * equals null, the current active category will be used.
     * @return int
     */
    function get_last_visit_date($tool = null, $category_id = null)
    {
        if (is_null($tool))
        {
            $tool = $this->get_parameter(self :: PARAM_TOOL);
        }
        if (is_null($category_id))
        {
            $category_id = $this->get_parameter(self :: PARAM_CATEGORY);
            if (is_null($category_id))
            {
                $category_id = 0;
            }
        }
        $wdm = WeblcmsDataManager :: get_instance();
        $date = $wdm->get_last_visit_date($this->get_course_id(), $this->get_user_id(), $tool, $category_id);
        return $date;
    }

    /**
     * Determines if a tool has new publications since the last time the current user visited the tool.
     *
     * @param $tool string
     * @param $course Course
     */
    function tool_has_new_publications($tool, Course $course = null)
    {
        if ($course == null)
        {
            $course = $this->get_course();
        }

        return WeblcmsDataManager :: tool_has_new_publications($tool, $this->get_user(), $course);
    }

    /**
     * Returns the url to the course's page
     *
     * @param $course Course
     * @return String
     */
    function get_course_viewing_url($course)
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_VIEW_COURSE,
                self :: PARAM_COURSE => $course->get_id()));
    }

    function retrieve_request($id)
    {
        return WeblcmsDataManager :: get_instance()->retrieve_request($id);
    }

    function retrieve_course_create_request($id)
    {
        return WeblcmsDataManager :: get_instance()->retrieve_course_create_request($id);
    }

    /**
     * Returns the link to the course's page
     *
     * @param $course Course
     * @return String
     */
    function get_course_viewing_link($course, $encode = false)
    {
        return $this->get_link(array(
                self :: PARAM_ACTION => self :: ACTION_VIEW_COURSE,
                self :: PARAM_COURSE => $course->get_id()), $encode);
    }

    /**
     * Returns the editing url for the course
     *
     * @param $course Course
     * @return String
     */
    function get_course_editing_url($course)
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_CREATE_COURSE,
                self :: PARAM_COURSE => $course->get_id(),
                self :: PARAM_TOOL => 'course_settings',
                'previous' => 'admin'));
    }

    /**
     * Returns the deleting url for the course
     *
     * @param $course Course
     * @return String
     */
    function get_course_deleting_url($course)
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_DELETE_COURSE,
                self :: PARAM_COURSE => $course->get_id()));
    }

    /**
     * Returns the maintenance url for the course
     *
     * @param $course Course
     * @return String
     */
    function get_course_maintenance_url($course)
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_VIEW_COURSE,
                self :: PARAM_COURSE => $course->get_id(),
                self :: PARAM_TOOL => 'maintenance'));
    }

    /**
     * Returns the subscription url for the course
     *
     * @param $course Course
     * @return String
     */
    function get_course_subscription_url($course)
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_MANAGER_SUBSCRIBE,
                self :: PARAM_COURSE => $course->get_id()));
    }

    function get_course_request_form_url($course)
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_COURSE_SUBSCRIBE_CREATE_REQUEST,
                self :: PARAM_COURSE => $course->get_id()));

    }

    function get_course_code_url($course)
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_COURSE_CODE,
                self :: PARAM_COURSE => $course->get_id()));
    }

    /**
     * Returns the unsubscription url for the course
     *
     * @param $course Course
     * @return String
     */
    function get_course_unsubscription_url($course)
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_MANAGER_UNSUBSCRIBE,
                self :: PARAM_COURSE => $course->get_id()));
    }

    /**
     * Returns the editing url for the course user category
     *
     * @param $course_user_category CourseUsercategory
     * @return String
     */
    function get_course_user_category_edit_url(CourseTypeUserCategory $course_type_user_category)
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_MANAGER_SORT,
                self :: PARAM_COMPONENT_ACTION => 'edit',
                self :: PARAM_COURSE_TYPE_USER_CATEGORY_ID => $course_type_user_category->get_id()));
    }

    /**
     * Returns the creating url for a course user category
     *
     * @return String
     */
    function get_course_user_category_add_url()
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_MANAGER_SORT,
                self :: PARAM_COMPONENT_ACTION => 'add'));
    }

    /**
     * Returns the moving url for the course user category
     *
     * @param $course_user_category CourseUserCategory
     * @param $direction string
     * @return String
     */
    function get_course_user_category_move_url(CourseTypeUserCategory $course_type_user_category, $direction)
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_MANAGER_SORT,
                self :: PARAM_COMPONENT_ACTION => 'movecat',
                self :: PARAM_DIRECTION => $direction,
                self :: PARAM_COURSE_TYPE_USER_CATEGORY_ID => $course_type_user_category->get_id()));
    }

    /**
     * Returns the deleting url for the course user category
     *
     * @param $course_user_category CourseUserCategory
     * @return String
     */
    function get_course_user_category_delete_url(CourseTypeUserCategory $course_type_user_category)
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_MANAGER_SORT,
                self :: PARAM_COMPONENT_ACTION => 'delete',
                self :: PARAM_COURSE_TYPE_USER_CATEGORY_ID => $course_type_user_category->get_id()));
    }

    /**
     * Returns the editing url for the course category
     *
     * @param $course_category CourseCategory
     * @return String
     */
    function get_course_category_edit_url($course_category)
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_COURSE_CATEGORY_MANAGER,
                self :: PARAM_COMPONENT_ACTION => 'edit',
                self :: PARAM_COURSE_CATEGORY => $course_category->get_code()));
    }

    /**
     * Returns the creating url for a course category
     *
     * @return String
     */
    function get_course_category_add_url()
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_COURSE_CATEGORY_MANAGER,
                self :: PARAM_COMPONENT_ACTION => 'add'));
    }

    /**
     * Returns the deleting url for the course category
     *
     * @param $course_category CourseCategory
     * @return String
     */
    function get_course_category_delete_url($coursecategory)
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_COURSE_CATEGORY_MANAGER,
                self :: PARAM_COMPONENT_ACTION => 'delete',
                self :: PARAM_COURSE_CATEGORY_ID => $coursecategory->get_code()));
    }

    /**
     * Returns the editing url for the course user relation
     *
     * @param $course Course
     * @return String
     */
    function get_course_user_edit_url(CourseTypeUserCategory $course_type_user_category = null, Course $course = null)
    {
        if ($course_type_user_category)
        {
            $course_type_user_category_id = $course_type_user_category->get_id();
        }

        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_MANAGER_SORT,
                self :: PARAM_COMPONENT_ACTION => 'assign',
                self :: PARAM_COURSE => $course->get_id(),
                self :: PARAM_COURSE_TYPE_USER_CATEGORY_ID => $course_type_user_category_id));
    }

    /**
     * Returns the moving url for the course user relation
     *
     * @param $course Course
     * @param $direction string
     * @return String
     */
    function get_course_user_move_url(CourseTypeUserCategory $course_type_user_category, Course $course, $direction)
    {
        return $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_MANAGER_SORT,
                self :: PARAM_COMPONENT_ACTION => 'move',
                self :: PARAM_DIRECTION => $direction,
                self :: PARAM_COURSE => $course->get_id(),
                self :: PARAM_COURSE_TYPE_USER_CATEGORY_ID => $course_type_user_category->get_id()));
    }

    /**
     * Checks whether subscription to the course is allowed for the current user
     *
     * @param $course Course
     * @return boolean
     */
    function course_subscription_allowed($course)
    {
        return WeblcmsDataManager :: course_subscription_allowed($course, $this->get_user());
    }

    /**
     * Checks whether unsubscription from the course is allowed for the current user
     *
     * @param $course Course
     * @return boolean
     */
    function course_unsubscription_allowed($course)
    {
        return WeblcmsDataManager :: course_unsubscription_allowed($course, $this->get_user());
    }

    /**
     * Checks whether the user is subscribed to the given course
     *
     * @param $course Course
     * @param $user User
     * @return boolean
     */
    function is_subscribed($course, $user)
    {
        $wdm = WeblcmsDataManager :: get_instance();
        return $wdm->is_subscribed($course, $user);
    }

    function is_teacher($course, $user)
    {
        if ($user != null && $course != null)
        {
            $relation = $this->retrieve_course_user_relation($course->get_id(), $user->get_id());

            if (($relation && $relation->get_status() == 1) || $user->is_platform_admin())
            {
                return true;
            }
            else
            {
                return WeblcmsDataManager :: is_teacher_through_platform_groups($course, $user);
            }

        }

        return false;
    }

    /**
     * Subscribe a user to a course.
     *
     * @param $course Course
     * @param $status int
     * @param $tutor_id int
     * @param $user_id int
     * @return boolean
     */
    function subscribe_user_to_course($course, $status, $tutor_id, $user_id)
    {
        $wdm = WeblcmsDataManager :: get_instance();
        return $wdm->subscribe_user_to_course($course, $status, $tutor_id, $user_id);
    }

    /**
     * Unsubscribe a user from a course.
     *
     * @param $course Course
     * @param $user_id int
     * @return boolean
     */
    function unsubscribe_user_from_course($course, $user_id)
    {
        // first delete the user from course groups
        $wdm = WeblcmsDataManager :: get_instance();

        $success = true;
        $course_groups = $wdm->retrieve_course_groups_from_user($user_id, $course->get_id());
        while ($course_group = $course_groups->next_result())
        {
            $success &= $wdm->unsubscribe_users_from_course_groups($user_id, $course_group);
        }

        // unsubscribe the user from the course
        return ($success && $wdm->unsubscribe_user_from_course($course, $user_id));
    }

    /**
     * Subscribe a group to a course.
     *
     * @param $course Course
     * @param $group_id int
     * @return boolean
     */
    function subscribe_group_to_course($course, $group_id, $status)
    {
        $wdm = WeblcmsDataManager :: get_instance();
        return $wdm->subscribe_group_to_course($course, $group_id, $status);
    }

    /**
     * Unsubscribe a group from a course.
     *
     * @param $course Course
     * @param $user_id int
     * @return boolean
     */
    function unsubscribe_group_from_course($course, $group_id)
    {
        $wdm = WeblcmsDataManager :: get_instance();
        return $wdm->unsubscribe_group_from_course($course, $group_id);
    }

    /**
     * Returns a list of actions available to the admin.
     *
     * @param $user User The current user.
     * @return Array $info Contains all possible actions.
     */
    public static function get_application_platform_admin_links()
    {
        $links = array();
        $links[] = new DynamicAction(Translation :: get('CourseTypeList'), Translation :: get('CourseTypeListDescription'), Theme :: get_image_path() . 'admin/list.png', Redirect :: get_link(self :: APPLICATION_NAME, array(
                Application :: PARAM_ACTION => WeblcmsManager :: ACTION_COURSE_TYPE_MANAGER)));

        $links[] = new DynamicAction(Translation :: get('CourseList'), Translation :: get('ListDescription'), Theme :: get_image_path() . 'admin/list.png', Redirect :: get_link(self :: APPLICATION_NAME, array(
                Application :: PARAM_ACTION => WeblcmsManager :: ACTION_ADMIN_COURSE_MANAGER)));

        $links[] = new DynamicAction(Translation :: get('CreateCourse'), Translation :: get('CreateDescription'), Theme :: get_image_path() . 'admin/add.png', Redirect :: get_link(self :: APPLICATION_NAME, array(
                Application :: PARAM_ACTION => WeblcmsManager :: ACTION_ADMIN_COURSE_MANAGER,
                CourseManager :: PARAM_ACTION => CourseManager :: ACTION_CREATE)));

        $links[] = new DynamicAction(Translation :: get('Import'), Translation :: get('ImportDescription'), Theme :: get_image_path() . 'admin/import.png', Redirect :: get_link(self :: APPLICATION_NAME, array(
                Application :: PARAM_ACTION => WeblcmsManager :: ACTION_IMPORT_COURSES)));

        $links[] = new DynamicAction(Translation :: get('RequestList'), Translation :: get('RequestDescription'), Theme :: get_image_path() . 'admin/list.png', Redirect :: get_link(self :: APPLICATION_NAME, array(
                Application :: PARAM_ACTION => WeblcmsManager :: ACTION_ADMIN_REQUEST_BROWSER)));

        $links[] = new DynamicAction(Translation :: get('CourseCategoryManagement'), Translation :: get('CourseCategoryManagementDescription'), Theme :: get_image_path() . 'admin/category.png', Redirect :: get_link(self :: APPLICATION_NAME, array(
                Application :: PARAM_ACTION => WeblcmsManager :: ACTION_COURSE_CATEGORY_MANAGER)));

        $links[] = new DynamicAction(Translation :: get('UserImport'), Translation :: get('UserImportDescription'), Theme :: get_image_path() . 'admin/import.png', Redirect :: get_link(self :: APPLICATION_NAME, array(
                Application :: PARAM_ACTION => WeblcmsManager :: ACTION_IMPORT_COURSE_USERS)));

        $info = parent :: get_application_platform_admin_links(self :: APPLICATION_NAME);

        $info['links'] = $links;

        $info['search'] = Redirect :: get_link(self :: APPLICATION_NAME, array(
                Application :: PARAM_ACTION => WeblcmsManager :: ACTION_ADMIN_COURSE_MANAGER));

        return $info;
    }

    /**
     * Gets the available links to display in the platform admin @retun array of links and actions
     */
    public static function get_application_platform_import_links()
    {
        $links = array();
        $links[] = array(
                'name' => Translation :: get('ImportCourses'),
                'description' => Translation :: get('ImportCoursesDescription'),
                'url' => Redirect :: get_link(self :: APPLICATION_NAME, array(Application :: PARAM_ACTION => WeblcmsManager :: ACTION_IMPORT_COURSES)));
        $links[] = array(
                'name' => Translation :: get('ImportCourseUsers'),
                'description' => Translation :: get('ImportCourseUsersDescription'),
                'url' => Redirect :: get_link(self :: APPLICATION_NAME, array(
                        Application :: PARAM_ACTION => WeblcmsManager :: ACTION_IMPORT_COURSE_USERS)));

        return $links;
    }

    function get_reporting_url($params)
    {
        $array = array(
                Application :: PARAM_APPLICATION => self :: APPLICATION_NAME,
                self :: PARAM_TOOL => null,
                self :: PARAM_ACTION => self :: ACTION_REPORTING);
        $array = array_merge($array, $params);
        return $this->get_url($array);
    }

    /**
     * Helper function for the Application class, pending access to class constants via variables in PHP 5.3 e.g. $name
     * = $class :: APPLICATION_NAME DO NOT USE IN THIS APPLICATION'S CONTEXT Instead use: - self :: APPLICATION_NAME in
     * the context of this class - YourApplicationManager :: APPLICATION_NAME in all other application classes
     */
    function get_application_name()
    {
        return self :: APPLICATION_NAME;
    }

    /**
     * Returns html of additional user information for the user view
     *
     * @param $user User
     */
    function get_additional_user_information($user)
    {
        $html = array();

        $table = new HTML_Table(array('class' => 'data_table'));

        $table->setHeaderContents(0, 0, Translation :: get('Courses'));
        $table->setCellAttributes(0, 0, array('colspan' => 2, 'style' => 'text-align: center;'));

        $table->setHeaderContents(1, 0, Translation :: get('CourseCode'));
        $table->setHeaderContents(1, 1, Translation :: get('CourseName'));

        $courses = $this->retrieve_user_courses(new EqualityCondition(CourseUserRelation :: PROPERTY_USER_ID, $user->get_id(), CourseUserRelation :: get_table_name()));

        if ($courses->size() == 0)
        {
            $table->setCellContents(2, 0, Translation :: get('NoCourses'));
            $table->setCellAttributes(2, 0, array('colspan' => 2, 'style' => 'text-align: center;'));
        }

        $i = 2;

        while ($course = $courses->next_result())
        {
            $url = '<a href="' . $this->get_course_viewing_link($course) . '">';
            $table->setCellContents($i, 0, $url . $course->get_visual_code() . '</a>');
            $table->setCellAttributes($i, 0, array('style' => 'width: 150px;'));
            $table->setCellContents($i, 1, $url . $course->get_title() . '</a>');
            $i ++;
        }

        $table->altRowAttributes(1, array('class' => 'row_odd'), array('class' => 'row_even'), true);

        $html[] = $table->toHtml();

        return implode("\n", $html);
    }

    /**
     * Helper function for the Application class, pending access to class constants via variables in PHP 5.3 e.g. $name
     * = $class :: DEFAULT_ACTION DO NOT USE IN THIS APPLICATION'S CONTEXT Instead use: - self :: DEFAULT_ACTION in the
     * context of this class - YourApplicationManager :: DEFAULT_ACTION in all other application classes
     */
    function get_default_action()
    {
        return self :: DEFAULT_ACTION;
    }

    static function get_installable_application_packages($include_installed = false)
    {
        $package_list = new PackageList(self :: context(), Translation :: get('TypeName', null, __NAMESPACE__), Theme :: get_image_path() . 'logo/16.png');

        if (! CommonDataManager :: get_registration(\application\weblcms\course\CourseManager :: context()) || $include_installed)
        {
            $package_list->add_package(\application\weblcms\course\CourseManager :: context());
        }

        if (! CommonDataManager :: get_registration(\application\weblcms\course_type\CourseTypeManager :: context()) || $include_installed)
        {
            $package_list->add_package(\application\weblcms\course_type\CourseTypeManager :: context());
        }

        $tool_list = new PackageList(self :: context() . '\tool', Translation :: get('Tools', null, __NAMESPACE__));

        foreach (Tool :: get_packages_from_filesystem() as $tool_type)
        {
            if (! CommonDataManager :: get_registration($tool_type) || $include_installed)
            {
                $tool_list->add_package($tool_type);
            }
        }

        $package_list->add_child($tool_list);

        return $package_list;
    }

    /**
     * Indicates whether the current tool may be accessed for the current course.
     * @return bool
     */
    function get_course_id()
    {
        return Request::get(self::PARAM_COURSE);
    }
}
?>
