<?php
namespace application\weblcms;

use common\libraries\WebApplicationInstaller;
use rights\RightsUtil;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\Filesystem;

/**
 *
 * @package application.lib.weblcms.install
 */

/**
 * This installer can be used to create the storage structure for the weblcms application.
 */
class WeblcmsInstaller extends WebApplicationInstaller
{

    /**
     * Constructor
     */
    function __construct($values)
    {
        parent :: __construct($values, WeblcmsDataManager :: get_instance());
    }

    /**
     * **************************************************************************************************************
     * Inherited Functionality *
     * **************************************************************************************************************
     */

    /**
     * Runs the install-script.
     */
    function install_extra()
    {
        if (! parent :: install_extra())
        {
            return false;
        }

        if (! $this->create_courses_subtree())
        {
            return false;
        }
        else
        {
            $this->add_message(self :: TYPE_NORMAL,
                    Translation :: get('ObjectCreated', array('OBJECT' => Translation :: get('CoursesTree')),
                            Utilities :: COMMON_LIBRARIES));
        }
        if (! $this->create_default_categories_in_weblcms())
        {
            return false;
        }

        if (! CourseSettingsController :: install_course_settings($this))
        {
            return false;
        }

        return true;
    }

    /**
     * Returns the list with extra installable packages that are connected to this package Example: tool package in
     * weblcms optional application
     *
     * @return String[]
     */
    function get_additional_installers()
    {
        $installers = array();

        $tools_folder = dirname(__FILE__) . '/../../../tool/';
        $tools = Filesystem :: get_directory_content($tools_folder, Filesystem :: LIST_DIRECTORIES, false);

        foreach ($tools as $tool)
        {
            $tool = basename($tool);
            $installers[] = ToolInstaller :: factory($tool, $this->get_form_values());
        }

        $installers[] = new \application\weblcms\course_type\Installer($this->get_form_values());
        $installers[] = new \application\weblcms\course\Installer($this->get_form_values());

        return $installers;
    }

    /**
     * **************************************************************************************************************
     * Helper Functionality *
     * **************************************************************************************************************
     */

    /**
     * Installs the root location of the courses subtree and sets the default rights for everyone on root location so
     * the rights are no issue when using no course type
     *
     * @return boolean
     */
    private function create_courses_subtree()
    {
        $rights_utilities = CourseManagementRights :: get_instance();

        $location = $rights_utilities->create_subtree_root_location(0, WeblcmsRights :: TREE_TYPE_COURSE);

        if (! $location)
        {
            return false;
        }

        $specific_rights = $rights_utilities->get_specific_course_management_rights();

        foreach ($specific_rights as $right_id)
        {

            if (! $rights_utilities->invert_location_entity_right($right_id, 0, 0, $location))
            {
                return false;
            }
        }

        return true;
    }

    /**
     * Installs example course categories
     *
     * @return boolean
     */
    private function create_default_categories_in_weblcms()
    {
        // Creating Language Skills
        $cat = new CourseCategory();
        $cat->set_name('Language skills');
        $cat->set_parent('0');
        $cat->set_display_order(1);

        if (! $cat->create())
        {
            return false;
        }

        // creating PC Skills
        $cat = new CourseCategory();
        $cat->set_name('PC skills');
        $cat->set_parent('0');
        $cat->set_display_order(1);
        if (! $cat->create())
        {
            return false;
        }

        // creating Projects
        $cat = new CourseCategory();
        $cat->set_name('Projects');
        $cat->set_parent('0');
        $cat->set_display_order(1);
        if (! $cat->create())
        {
            return false;
        }

        return true;
    }
}
?>
