<?php
namespace application\weblcms;

use application\weblcms\tool\assessment\AssessmentTool;
use common\libraries\Application;
use common\libraries\AndCondition;
use common\libraries\DatetimeUtilities;
use common\libraries\EqualityCondition;
use common\libraries\Path;
use common\libraries\Theme;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\Redirect;
use reporting\Reporting;
use reporting\ReportingData;
use reporting\ReportingFormatter;
use reporting\ReportingManager;
use repository\content_object\assessment\Assessment;

/**
 *
 * @package application.weblcms.php.reporting.blocks
 *         
 *          Reporting block with all attempts of an assessment from one user
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 */
class WeblcmsAssessmentAttemptsUserReportingBlock extends WeblcmsToolReportingBlock
{

    public function count_data()
    {
        $reporting_data = new ReportingData();
        $reporting_data->set_rows(array(Translation :: get('Date'), Translation :: get('Score'), 
                Translation :: get('Time'), Translation :: get('Status'), Translation :: get('AttemptDetails')));
        
        $pub_id = $this->get_pid();
        $user_id = $this->get_user_id();
        
        $tracker = new WeblcmsAssessmentAttemptsTracker();
        $conditions = array();
        $conditions[] = new EqualityCondition(WeblcmsAssessmentAttemptsTracker :: PROPERTY_ASSESSMENT_ID, $pub_id);
        $conditions[] = new EqualityCondition(WeblcmsAssessmentAttemptsTracker :: PROPERTY_USER_ID, $user_id);
        $condition = new AndCondition($conditions);
        $attempts = $tracker->retrieve_tracker_items($condition);
        $img = '<img src="' . Theme :: get_common_image_path() . 'action_details.png" title="' . Translation :: get('Details') . '" />';
        
        foreach ($attempts as $key => $attempt)
        {
            $date = DatetimeUtilities :: format_locale_date(Translation :: get('DateFormatShort', null, Utilities :: COMMON_LIBRARIES) . ', ' . Translation :: get('TimeNoSecFormat', null, Utilities :: COMMON_LIBRARIES), $attempt->get_date());
            $time = Utilities :: format_seconds_to_hours($attempt->get_total_time());
            
            $params = array();
            $params[Application :: PARAM_APPLICATION] = WeblcmsManager :: APPLICATION_NAME;
            $params[Application :: PARAM_ACTION] = WeblcmsManager :: ACTION_VIEW_COURSE;
            $params[WeblcmsManager :: PARAM_COURSE] = $this->get_course_id();
            $params[WeblcmsManager :: PARAM_TOOL] = Assessment :: get_type_name();
            $params[WeblcmsManager :: PARAM_TOOL_ACTION] = AssessmentTool :: ACTION_VIEW_RESULTS;
            $params[AssessmentTool :: PARAM_USER_ASSESSMENT] = $attempt->get_id();
            $params[AssessmentTool :: PARAM_ASSESSMENT] = $pub_id;
            $link = '<a href="' . Redirect :: get_url($params) . '">' . $img . '</a>';
            
            $score = $this->get_score_bar($attempt->get_total_score());
            
            $reporting_data->add_category($key);
            $reporting_data->add_data_category_row($key, Translation :: get('Date'), $date);
            $reporting_data->add_data_category_row($key, Translation :: get('Status'), $attempt->get_status());
            if ($attempt->get_status() != 'not attempted')
            {
                $reporting_data->add_data_category_row($key, Translation :: get('Score'), $score);
                $reporting_data->add_data_category_row($key, Translation :: get('Time'), $time);
                $reporting_data->add_data_category_row($key, Translation :: get('AttemptDetails'), $link);
            }
        }
        $reporting_data->hide_categories();
        return $reporting_data;
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        return $modes;
    }

}
?>