<?php
namespace application\weblcms;

use application\weblcms\tool\assessment\AssessmentTool;
use common\libraries\Application;
use common\libraries\Request;
use common\libraries\DatetimeUtilities;
use common\libraries\Utilities;
use common\libraries\Redirect;
use common\libraries\Translation;
use common\libraries\Path;
use common\libraries\PatternMatchCondition;
use reporting\ReportingFormatter;
use reporting\ReportingData;
use repository\content_object\assessment\Assessment;
use user\VisitTracker;

/**
 *
 * @package application.weblcms.php.reporting.blocks
 *         
 *          Reporting block displaying information about the assessment and
 *          access details
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 */
class WeblcmsAssessmentInformationReportingBlock extends WeblcmsToolReportingBlock
{

    public function count_data()
    {
        $reporting_data = new ReportingData();
        $reporting_data->set_categories(array(Translation :: get('Title'), Translation :: get('Description'), 
                Translation :: get('Published'), Translation :: get('LastModified'), Translation :: get('LastAccess'), 
                Translation :: get('TotalTimeSpent'), Translation :: get('Clicks')));
        
        $publication_id = $this->get_pid();
        $course_id = $this->get_course_id();
        
        $params = array();
        $params[Application :: PARAM_APPLICATION] = WeblcmsManager :: APPLICATION_NAME;
        $params[WeblcmsManager :: PARAM_COURSE] = $course_id;
        $params[WeblcmsManager :: PARAM_TOOL] = Assessment :: get_type_name();
        $params[Application :: PARAM_ACTION] = WeblcmsManager :: ACTION_VIEW_COURSE;
        $params[Tool::PARAM_ACTION] = AssessmentTool::ACTION_VIEW_RESULTS;
        $params[AssessmentTool::PARAM_ASSESSMENT] = $publication_id;
        $url_title = Redirect :: get_url($params);
        
        $weblcms_manager = WeblcmsDataManager :: get_instance();
        $publication = $weblcms_manager->retrieve_content_object_publication($publication_id);
        $assessment = $publication->get_content_object();
        
        $created = DatetimeUtilities :: format_locale_date(Translation :: get('DateFormatShort', null, Utilities :: COMMON_LIBRARIES) . ', ' . Translation :: get('TimeNoSecFormat', null, Utilities :: COMMON_LIBRARIES), $assessment->get_creation_date());
        $modified = DatetimeUtilities :: format_locale_date(Translation :: get('DateFormatShort', null, Utilities :: COMMON_LIBRARIES) . ', ' . Translation :: get('TimeNoSecFormat', null, Utilities :: COMMON_LIBRARIES), $assessment->get_modification_date());
        
        $tracker = new VisitTracker();
        $condition = new PatternMatchCondition(VisitTracker :: PROPERTY_LOCATION, '*&course=' . $course_id . '*&tool=' . Assessment :: get_type_name() . '*&publication=' . $publication_id . '*');
        $trackerdata = $tracker->retrieve_tracker_items($condition);
        
        $lastconnection = null;
        foreach ($trackerdata as $key => $value)
        {
            if (is_null($lastconnection) || $value->get_leave_date() > $lastconnection)
            {
                $lastconnection = $value->get_leave_date();
            }
        }
        
        if (count($trackerdata) > 0)
        {
            $last_date = DatetimeUtilities :: format_locale_date(null, $lastconnection);
        }
        else
        {
            $last_date = Translation :: get('NeverAccessed');
        }
        
        $reporting_data->set_rows(array(Translation :: get('Details')));
        $reporting_data->add_data_category_row(Translation :: get('Title'), Translation :: get('Details'), '<a href="' . $url_title . '">' . $assessment->get_title() . '</a>');
        $reporting_data->add_data_category_row(Translation :: get('Description'), Translation :: get('Details'), $assessment->get_description());
        $reporting_data->add_data_category_row(Translation :: get('Published'), Translation :: get('Details'), $created);
        $reporting_data->add_data_category_row(Translation :: get('LastModified'), Translation :: get('Details'), $modified);
        $reporting_data->add_data_category_row(Translation :: get('LastAccess'), Translation :: get('Details'), $last_date);
        $reporting_data->add_data_category_row(Translation :: get('TotalTimeSpent'), Translation :: get('Details'), $this->get_total_time($trackerdata));
        $reporting_data->add_data_category_row(Translation :: get('Clicks'), Translation :: get('Details'), count($trackerdata));
        
        return $reporting_data;
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        return $modes;
    }
}
?>