<?php
namespace application\weblcms;

use application\weblcms\tool\reporting\ReportingTool;
use common\libraries\EqualityCondition;
use common\libraries\Path;
use common\libraries\Translation;
use common\libraries\Utilities;
use reporting\ReportingManager;
use reporting\Reporting;
use reporting\ReportingData;
use reporting\ReportingFormatter;
use common\libraries\Request;
use repository\RepositoryDataManager;
use user\UserDataManager;
use common\libraries\DatetimeUtilities;
use common\libraries\PlatformSetting;

/**
 *
 * @package application.weblcms.php.reporting.blocks
 *         
 *          Reporting block with an overview of the scores of an assessment
 *          question per user
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 */
class WeblcmsAssessmentQuestionAttemptsReportingBlock extends WeblcmsToolReportingBlock
{

    public function count_data()
    {
        $user_data_manager = UserDataManager :: get_instance();
        $reporting_data = new ReportingData();
        $reporting_data->set_rows(array(Translation :: get('Date'), Translation :: get('User'), 
                Translation :: get('Score')));
        
        $pub_id = $this->get_pid();
        $course_id = $this->get_course_id();
        $question_id = Request :: get(ReportingTool :: PARAM_QUESTION);
        $question = RepositoryDataManager :: get_instance()->retrieve_complex_content_object_item($question_id);
        $weight = $question->get_weight();
        
        $assessment_tracker = new WeblcmsAssessmentAttemptsTracker();
        $condition = new EqualityCondition(WeblcmsAssessmentAttemptsTracker :: PROPERTY_ASSESSMENT_ID, $pub_id);
        $assessment_attempts_from_tracker = $assessment_tracker->retrieve_tracker_items($condition);
        $user_attempts = array();
        foreach ($assessment_attempts_from_tracker as $attempt)
        {
            $assessment_attempts[$attempt->get_id()] = $attempt;
        }
        
        $question_tracker = new WeblcmsQuestionAttemptsTracker();
        $condition = new EqualityCondition(WeblcmsQuestionAttemptsTracker :: PROPERTY_QUESTION_CID, $question_id);
        $question_trackers = $question_tracker->retrieve_tracker_items($condition);
        $question_scores = array();
        foreach ($question_trackers as $key => $attempt)
        {
            $assessment_attempt = $assessment_attempts[$attempt->get_assessment_attempt_id()];
            $date = DatetimeUtilities :: format_locale_date(Translation :: get('DateFormatShort', null, Utilities :: COMMON_LIBRARIES) . ', ' . Translation :: get('TimeNoSecFormat', null, Utilities :: COMMON_LIBRARIES), $assessment_attempt->get_date());
            $user_id = $assessment_attempt->get_user_id();
            $user = $user_data_manager->retrieve_user($user_id);
            
            $score = $attempt->get_score();
            if ($score / $question->get_weight() >= PlatformSetting :: get('passing_percentage') / 100)
            {
                $score = '<span style="color: green">' . $score . ' / ' . $question->get_weight() . '</span>';
            }
            else
            {
                $score = '<span style="color: red">' . $score . ' / ' . $question->get_weight() . '</span>';
            }
            
            $reporting_data->add_category($key);
            $reporting_data->add_data_category_row($key, Translation :: get('Date'), $date);
            $reporting_data->add_data_category_row($key, Translation :: get('User'), $user->get_fullname());
            $reporting_data->add_data_category_row($key, Translation :: get('Score'), $score);
        }
        
        $reporting_data->hide_categories();
        return $reporting_data;
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        return $modes;
    }

}
?>