<?php
namespace application\weblcms;

use common\libraries\EqualityCondition;
use common\libraries\Path;
use common\libraries\Translation;
use common\libraries\Request;
use reporting\ReportingData;
use reporting\ReportingFormatter;
use application\weblcms\tool\reporting\ReportingTool;
use common\libraries\AndCondition;
use common\libraries\InCondition;
use common\libraries\DatetimeUtilities;
use common\libraries\Utilities;
use repository\RepositoryDataManager;
use common\libraries\PlatformSetting;

/**
 *
 * @package application.weblcms.php.reporting.blocks
 *         
 *          Reporting block with the assessment question attempts of one user
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 */
class WeblcmsAssessmentQuestionAttemptsUserReportingBlock extends WeblcmsToolReportingBlock
{

    public function count_data()
    {
        $reporting_data = new ReportingData();
        $reporting_data->set_rows(array(Translation :: get('Date'), Translation :: get('Score')));
        
        $pub_id = $this->get_pid();
        $user_id = $this->get_user_id();
        $question_id = Request :: get(ReportingTool :: PARAM_QUESTION);
        
        $question = RepositoryDataManager :: get_instance()->retrieve_complex_content_object_item($question_id);
        $weight = $question->get_weight();
        
        $assessment_tracker = new WeblcmsAssessmentAttemptsTracker();
        $conditions = array();
        $conditions[] = new EqualityCondition(WeblcmsAssessmentAttemptsTracker :: PROPERTY_ASSESSMENT_ID, $pub_id);
        $conditions[] = new EqualityCondition(WeblcmsAssessmentAttemptsTracker :: PROPERTY_USER_ID, $user_id);
        $condition = new AndCondition($conditions);
        $assessment_attempts_trackers = $assessment_tracker->retrieve_tracker_items($condition);
        $attempt_ids = array();
        $assessment_attempts = array();
        foreach ($assessment_attempts_trackers as $attempt_tracker)
        {
            $attempt_ids[] = $attempt_tracker->get_id();
            $assessment_attempts[$attempt_tracker->get_id()] = $attempt_tracker;
        }
        
        $question_tracker = new WeblcmsQuestionAttemptsTracker();
        $conditions = array();
        $conditions[] = new EqualityCondition(WeblcmsQuestionAttemptsTracker :: PROPERTY_QUESTION_CID, $question_id);
        $conditions[] = new InCondition(WeblcmsQuestionAttemptsTracker :: PROPERTY_ASSESSMENT_ATTEMPT_ID, $attempt_ids);
        $condition = new AndCondition($conditions);
        $question_attempts = $question_tracker->retrieve_tracker_items($condition);
        
        foreach ($question_attempts as $key => $attempt)
        {
            $date = $assessment_attempts[$attempt->get_assessment_attempt_id()]->get_date();
            $date = DatetimeUtilities :: format_locale_date(Translation :: get('DateFormatShort', null, Utilities :: COMMON_LIBRARIES) . ', ' . Translation :: get('TimeNoSecFormat', null, Utilities :: COMMON_LIBRARIES), $date);
            
            $score = $attempt->get_score();
            if ($score / $weight >= PlatformSetting :: get('passing_percentage') / 100)
            {
                $score = '<span style="color: green">' . $score . ' / ' . $weight . '</span>';
            }
            else
            {
                $score = '<span style="color: red">' . $score . ' / ' . $weight . '</span>';
            }
            
            $reporting_data->add_category($key);
            $reporting_data->add_data_category_row($key, Translation :: get('Date'), $date);
            $reporting_data->add_data_category_row($key, Translation :: get('Score'), $score);
        }
        
        $reporting_data->hide_categories();
        return $reporting_data;
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        return $modes;
    }

}
?>