<?php
namespace application\weblcms;

use application\weblcms\tool\reporting\ReportingTool;
use common\libraries\EqualityCondition;
use common\libraries\Path;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\Theme;
use common\libraries\Request;
use reporting\ReportingManager;
use reporting\Reporting;
use reporting\ReportingData;
use reporting\ReportingFormatter;
use repository\RepositoryDataManager;

/**
 *
 * @package application.weblcms.php.reporting.blocks
 *         
 *          Reporting block with an overview of the scores of an assessment
 *          question per user
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 */
class WeblcmsAssessmentQuestionUsersReportingBlock extends WeblcmsToolReportingBlock
{

    public function count_data()
    {
        $reporting_data = new ReportingData();
        $reporting_data->set_rows(array(Translation :: get('Name'), Translation :: get('NumberOfAttempts'), 
                Translation :: get('AverageScore'), Translation :: get('MinScoreAchieved'), 
                Translation :: get('MaxScoreAchieved'), Translation :: get('Attempts')));
        
        $pub_id = $this->get_pid();
        $course_id = $this->get_course_id();
        $question_id = Request :: get(ReportingTool :: PARAM_QUESTION);
        $question = RepositoryDataManager :: get_instance()->retrieve_complex_content_object_item($question_id);
        $weight = $question->get_weight();
        $img = '<img src="' . Theme :: get_common_image_path() . 'action_reporting.png" title="' . Translation :: get('Details') . '" />';
        
        $wdm = WeblcmsDataManager :: get_instance();
        $users_resultset = $wdm->retrieve_publication_target_users($pub_id, $course_id);
        
        $assessment_tracker = new WeblcmsAssessmentAttemptsTracker();
        $condition = new EqualityCondition(WeblcmsAssessmentAttemptsTracker :: PROPERTY_ASSESSMENT_ID, $pub_id);
        $assessment_attempts = $assessment_tracker->retrieve_tracker_items($condition);
        $user_attempts = array();
        foreach ($assessment_attempts as $attempt)
        {
            $user_attempts[$attempt->get_user_id()][] = $attempt->get_id();
        }
        
        $question_tracker = new WeblcmsQuestionAttemptsTracker();
        $condition = new EqualityCondition(WeblcmsQuestionAttemptsTracker :: PROPERTY_QUESTION_CID, $question_id);
        $question_trackers = $question_tracker->retrieve_tracker_items($condition);
        $question_scores = array();
        foreach ($question_trackers as $attempt)
        {
            $question_scores[$attempt->get_assessment_attempt_id()] = $attempt->get_score();
        }
        
        $count = 0;
        while ($user = $users_resultset->next_result())
        {
            $min = $max = $score = $score_count = null;
            foreach ($user_attempts[$user->get_id()] as $question_attempt_id)
            {
                if (! is_null($question_scores[$question_attempt_id]))
                {
                    $score += $question_scores[$question_attempt_id];
                    $score_count ++;
                    if (is_null($min) || $question_scores[$question_attempt_id] < $min)
                    {
                        $min = $question_scores[$question_attempt_id];
                    }
                    if (is_null($max) || $question_scores[$question_attempt_id] > $max)
                    {
                        $max = $question_scores[$question_attempt_id];
                    }
                }
            }
            
            if (! is_null($score))
            {
                $score = $this->get_score_bar($score / $score_count / $weight * 100);
            }
            if (! is_null($min))
            {
                $min = $min . ' / ' . $weight;
            }
            if (! is_null($max))
            {
                $max = $max . ' / ' . $weight;
            }
            
            $params = $this->get_parent()->get_parameters();
            $params[ReportingManager :: PARAM_TEMPLATE_ID] = Reporting :: get_name_registration(Utilities :: camelcase_to_underscores('AssessmentQuestionAttemptsUserReportingTemplate'), WeblcmsManager :: APPLICATION_NAME)->get_id();
            $params[WeblcmsManager :: PARAM_USERS] = $user->get_id();
            $link = '<a href="' . $this->get_parent()->get_url($params) . '">' . $img . '</a>';
            
            $reporting_data->add_category($count);
            $reporting_data->add_data_category_row($count, Translation :: get('Name'), $user->get_fullname());
            $reporting_data->add_data_category_row($count, Translation :: get('NumberOfAttempts'), $score_count);
            $reporting_data->add_data_category_row($count, Translation :: get('AverageScore'), $score);
            $reporting_data->add_data_category_row($count, Translation :: get('MinScoreAchieved'), $min);
            $reporting_data->add_data_category_row($count, Translation :: get('MaxScoreAchieved'), $max);
            $reporting_data->add_data_category_row($count, Translation :: get('Attempts'), $link);
            
            $count ++;
        }
        
        $reporting_data->hide_categories();
        return $reporting_data;
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        return $modes;
    }

}
?>