<?php
namespace application\weblcms;

use application\weblcms\tool\reporting\ReportingTool;
use common\libraries\EqualityCondition;
use common\libraries\Path;
use common\libraries\Theme;
use common\libraries\Translation;
use common\libraries\Utilities;
use reporting\ReportingManager;
use reporting\Reporting;
use reporting\ReportingData;
use reporting\ReportingFormatter;
use repository\RepositoryDataManager;
use repository\ComplexContentObjectItem;
use repository\ContentObject;

/**
 *
 * @package application.weblcms.php.reporting.blocks
 *         
 *          Reporting block with an overview of the scores of each question in
 *          the assessment
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 */
class WeblcmsAssessmentQuestionsReportingBlock extends WeblcmsToolReportingBlock
{

    public function count_data()
    {
        $reporting_data = new ReportingData();
        $reporting_data->set_rows(array(Translation :: get('Title'), Translation :: get('Type'), 
                Translation :: get('NumberOfAttempts'), Translation :: get('AverageScore'), 
                Translation :: get('MinScoreAchieved'), Translation :: get('MaxScoreAchieved'), 
                Translation :: get('QuestionDetails')));
        
        $pid = $this->get_pid();
        $publication = WeblcmsDataManager :: get_instance()->retrieve_content_object_publication($pid);
        $condition = new EqualityCondition(ComplexContentObjectItem :: PROPERTY_PARENT, $publication->get_content_object_id());
        $questions = RepositoryDataManager :: get_instance()->retrieve_complex_content_object_items($condition);
        $tracker = new WeblcmsQuestionAttemptsTracker();
        $img = '<img src="' . Theme :: get_common_image_path() . 'action_reporting.png" title="' . Translation :: get('Details') . '" />';
        
        $count = 0;
        while ($question = $questions->next_result())
        {
            $count ++;
            $reporting_data->add_category($count);
            $weight = $question->get_weight();
            $condition = new EqualityCondition(WeblcmsQuestionAttemptsTracker :: PROPERTY_QUESTION_CID, $question->get_id());
            $attempts = $tracker->retrieve_tracker_items($condition);
            
            $score = $min = $max = null;
            foreach ($attempts as $attempt)
            {
                if (is_null($min) || $min > $attempt->get_score())
                {
                    $min = $attempt->get_score();
                }
                if (is_null($max) || $max < $attempt->get_score())
                {
                    $max = $attempt->get_score();
                }
                $score += $attempt->get_score();
            }
            if (count($attempts) > 0)
            {
                $score = $this->get_score_bar($score / count($attempts) / $weight * 100);
                
                $params = $this->get_parent()->get_parameters();
                $params[ReportingManager :: PARAM_TEMPLATE_ID] = Reporting :: get_name_registration(Utilities :: camelcase_to_underscores('AssessmentQuestionUsersReportingTemplate'), WeblcmsManager :: APPLICATION_NAME)->get_id();
                $params[ReportingTool :: PARAM_QUESTION] = $question->get_id();
                $link = '<a href="' . $this->get_parent()->get_url($params) . '">' . $img . '</a>';
                $reporting_data->add_data_category_row($count, Translation :: get('QuestionDetails'), $link);
            }
            if (! is_null($min))
            {
                $min = $min . ' / ' . $weight;
            }
            if (! is_null($max))
            {
                $max = $max . ' / ' . $weight;
            }
            
            $object = $question->get_ref_object();
            $type = Translation :: get('TypeName', array(), ContentObject :: get_content_object_type_namespace($object->get_type_name()));
            
            $reporting_data->add_data_category_row($count, Translation :: get('Title'), $object->get_title());
            $reporting_data->add_data_category_row($count, Translation :: get('Type'), $type);
            $reporting_data->add_data_category_row($count, Translation :: get('NumberOfAttempts'), count($attempts));
            $reporting_data->add_data_category_row($count, Translation :: get('AverageScore'), $score);
            $reporting_data->add_data_category_row($count, Translation :: get('MinScoreAchieved'), $min);
            $reporting_data->add_data_category_row($count, Translation :: get('MaxScoreAchieved'), $max);
        }
        
        $reporting_data->hide_categories();
        return $reporting_data;
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        return $modes;
    }

}
?>