<?php
namespace application\weblcms;

use common\libraries\Path;
use common\libraries\Application;
use common\libraries\Redirect;
use common\libraries\DatetimeUtilities;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\EqualityCondition;
use common\libraries\AndCondition;
use common\libraries\Theme;
use reporting\ReportingManager;
use reporting\Reporting;
use reporting\ReportingData;
use reporting\ReportingFormatter;
use repository\content_object\assessment\Assessment;

/**
 *
 * @package application.weblcms.php.reporting.blocks
 *         
 *          Reporting block displaying all assessments within a course and their
 *          attempt stats
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 */
class WeblcmsAssessmentReportingBlock extends WeblcmsCourseReportingBlock
{

    public function count_data()
    {
        $reporting_data = new ReportingData();
        $reporting_data->set_rows(array(Translation :: get('Title'), Translation :: get('NumberOfAttempts'), 
                Translation :: get('LastAttempt'), Translation :: get('AverageScore'), 
                Translation :: get('AssessmentDetails')));
        
        $course_id = $this->get_course_id();
        $tool = Assessment :: get_type_name();
        $wdm = WeblcmsDataManager :: get_instance();
        $tracker = new WeblcmsAssessmentAttemptsTracker();
        $img = '<img src="' . Theme :: get_common_image_path() . 'action_reporting.png" title="' . Translation :: get('Details') . '" />';
        $count = 1;
        
        $conditions = array();
        $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_COURSE_ID, $course_id);
        $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_TOOL, $tool);
        $condition = new AndCondition($conditions);
        $pub_resultset = $wdm->retrieve_content_object_publications($condition);
        
        while ($pub = $pub_resultset->next_result())
        {
            $condition = new EqualityCondition(WeblcmsAssessmentAttemptsTracker :: PROPERTY_ASSESSMENT_ID, $pub->get_id());
            $attempts = $tracker->retrieve_tracker_items($condition);
            
            $score = null;
            $score_count = 0;
            $last_attempt = null;
            foreach ($attempts as $key => $attempt)
            {
                if ($attempt->get_date() > $last_attempt)
                {
                    $last_attempt = $attempt->get_date();
                }
                if ($attempt->get_status() != 'not attempted')
                {
                    $score += $attempt->get_total_score();
                    $score_count ++;
                }
            }
            if (! is_null($last_attempt))
            {
                $last_attempt = $last_date = DatetimeUtilities :: format_locale_date(Translation :: get('DateFormatShort', null, Utilities :: COMMON_LIBRARIES) . ', ' . Translation :: get('TimeNoSecFormat', null, Utilities :: COMMON_LIBRARIES), $last_attempt);
            }
            if (! is_null($score))
            {
                $score = $this->get_score_bar($score / $score_count);
            }
            
            $params = $this->get_parent()->get_parameters();
            $params[ReportingManager :: PARAM_TEMPLATE_ID] = Reporting :: get_name_registration(Utilities :: camelcase_to_underscores('AssessmentAttemptsReportingTemplate'), WeblcmsManager :: APPLICATION_NAME)->get_id();
            $params[WeblcmsManager :: PARAM_PUBLICATION] = $pub->get_id();
            $link = '<a href="' . $this->get_parent()->get_url($params) . '">' . $img . '</a>';
            
            $params = array();
            $params[Application :: PARAM_ACTION] = WeblcmsManager :: ACTION_VIEW_COURSE;
            $params[Application :: PARAM_APPLICATION] = WeblcmsManager :: APPLICATION_NAME;
            $params[WeblcmsManager :: PARAM_COURSE] = $course_id;
            $params[WeblcmsManager :: PARAM_TOOL] = $tool;
            $params[WeblcmsManager :: PARAM_PUBLICATION] = $pub->get_id();
            $params[WeblcmsManager :: PARAM_TOOL_ACTION] = Tool :: ACTION_VIEW;
            $url_title = Redirect :: get_url($params);
            
            $reporting_data->add_category($count);
            $reporting_data->add_data_category_row($count, Translation :: get('Title'), '<a href="' . $url_title . '">' . $pub->get_content_object()->get_title() . '</a>');
            $reporting_data->add_data_category_row($count, Translation :: get('NumberOfAttempts'), count($attempts));
            $reporting_data->add_data_category_row($count, Translation :: get('LastAttempt'), $last_attempt);
            $reporting_data->add_data_category_row($count, Translation :: get('AverageScore'), $score);
            $reporting_data->add_data_category_row($count, Translation :: get('AssessmentDetails'), $link);
            
            $count ++;
        }
        $reporting_data->hide_categories();
        
        return $reporting_data;
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        return $modes;
    }

}
?>