<?php
namespace application\weblcms;

use application\weblcms\course\Course;
use application\weblcms\course\CourseDataManager;
use common\libraries\Application;
use common\libraries\Request;
use common\libraries\DatetimeUtilities;
use common\libraries\Utilities;
use common\libraries\Redirect;
use common\libraries\Translation;
use common\libraries\Path;
use common\libraries\PatternMatchCondition;
use reporting\ReportingFormatter;
use reporting\ReportingData;
use repository\content_object\assessment\Assessment;
use user\VisitTracker;
use common\libraries\EqualityCondition;
use user\UserDataManager;
use common\libraries\AndCondition;
use common\libraries\PlatformSetting;

/**
 *
 * @package application.weblcms.php.reporting.blocks
 *         
 *          Reporting block displaying information about the assessment and the
 *          user
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 */
class WeblcmsAssessmentUserInformationReportingBlock extends WeblcmsToolReportingBlock
{

    public function count_data()
    {
        $reporting_data = new ReportingData();
        $reporting_data->set_categories(array(Translation :: get('Title'), Translation :: get('Course'), 
                Translation :: get('User'), Translation :: get('AverageScore')));
        
        $publication_id = $this->get_pid();
        $course_id = $this->get_course_id();
        $user_id = Request :: get('users');
        
        $weblcms_data_manager = CourseDataManager :: get_instance();
        $user_data_manager = UserDataManager :: get_instance();
        $user = $user_data_manager->retrieve_user($user_id);
        $publication = $weblcms_data_manager->retrieve_content_object_publication($publication_id);
        $condition = new EqualityCondition(Course :: PROPERTY_ID, $course_id);
        $courses_resultset = $weblcms_data_manager->retrieve_courses($condition);
        $course = $courses_resultset->next_result();
        $assessment = $publication->get_content_object();
        $conditions = array();
        $conditions[] = new EqualityCondition(WeblcmsAssessmentAttemptsTracker :: PROPERTY_STATUS, 'completed');
        $conditions[] = new EqualityCondition(WeblcmsAssessmentAttemptsTracker :: PROPERTY_ASSESSMENT_ID, $publication_id);
        $conditions[] = new EqualityCondition(WeblcmsAssessmentAttemptsTracker :: PROPERTY_USER_ID, $user_id);
        $condition = new AndCondition($conditions);
        $attempts_tracker = new WeblcmsAssessmentAttemptsTracker();
        $scores = $attempts_tracker->retrieve_tracker_items($condition);
        
        if (count($scores) != 0)
        {
            $total_score = 0;
            foreach ($scores as $score)
            {
                $total_score += $score->get_total_score();
            }
            $avg_score = $total_score / count($scores);
        }
        
        if ($avg_score < PlatformSetting :: get('passing_percentage'))
        {
            $avg_score = '<span style="color: red;">' . number_format($avg_score, 2) . '%</span>';
        }
        else
        {
            $avg_score = '<span style="color: green;">' . number_format($avg_score, 2) . '%</span>';
        }
        
        $params = array();
        $params[Application :: PARAM_ACTION] = WeblcmsManager :: ACTION_VIEW_COURSE;
        $params[Application :: PARAM_APPLICATION] = WeblcmsManager :: APPLICATION_NAME;
        $params[WeblcmsManager :: PARAM_COURSE] = $course_id;
        $params[WeblcmsManager :: PARAM_TOOL] = Assessment :: get_type_name();
        $params[WeblcmsManager :: PARAM_PUBLICATION] = $publication_id;
        $params[WeblcmsManager :: PARAM_TOOL_ACTION] = Tool :: ACTION_VIEW;
        $url_title = Redirect :: get_url($params);
        
        $reporting_data->set_rows(array(Translation :: get('Details')));
        $reporting_data->add_data_category_row(Translation :: get('Title'), Translation :: get('Details'), '<a href="' . $url_title . '">' . $assessment->get_title() . '</a>');
        $reporting_data->add_data_category_row(Translation :: get('Course'), Translation :: get('Details'), $course->get_title());
        $reporting_data->add_data_category_row(Translation :: get('User'), Translation :: get('Details'), $user->get_fullname());
        $reporting_data->add_data_category_row(Translation :: get('AverageScore'), Translation :: get('Details'), $avg_score);
        return $reporting_data;
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        return $modes;
    }
}
?>