<?php
namespace application\weblcms;

use reporting\Reporting;
use reporting\ReportingData;
use reporting\ReportingFormatter;
use reporting\ReportingManager;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use common\libraries\InCondition;
use common\libraries\Redirect;
use common\libraries\Utilities;
use common\libraries\Path;
use common\libraries\Translation;
use common\libraries\DatetimeUtilities;
use common\libraries\Request;
use common\libraries\Theme;
use user\UserDataManager;
use user\User;

/**
 *
 * @package application.weblcms.php.reporting.blocks
 *         
 *          Reporting block with an overiew of all users the assessment is
 *          published for
 *          and their attempt stats
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 */
class WeblcmsAssessmentUsersReportingBlock extends WeblcmsToolReportingBlock
{

    public function count_data()
    {
        $reporting_data = new ReportingData();
        $reporting_data->set_rows(array(Translation :: get('Name'), Translation :: get('NumberOfAttempts'), 
                Translation :: get('FirstAttempt'), Translation :: get('LastAttempt'), Translation :: get('TotalTime'), 
                Translation :: get('AverageScore'), Translation :: get('UserDetails')));
        
        $pub_id = $this->get_pid();
        $course_id = $this->get_course_id();
        
        $weblcms_data_manager = WeblcmsDataManager :: get_instance();
        $users_resultset = $weblcms_data_manager->retrieve_publication_target_users($pub_id, $course_id);
        
        $tracker = new WeblcmsAssessmentAttemptsTracker();
        $condition = new EqualityCondition(WeblcmsAssessmentAttemptsTracker :: PROPERTY_ASSESSMENT_ID, $pub_id);
        $attempts = $tracker->retrieve_tracker_items($condition);
        $img = '<img src="' . Theme :: get_common_image_path() . 'action_reporting.png" title="' . Translation :: get('Details') . '" />';
        $count = 1;
        
        $user_attempts = array();
        $score_count = 0;
        foreach ($attempts as $key => $attempt)
        {
            $user_attempts[$attempt->get_user_id()]['count'] ++;
            $user_attempts[$attempt->get_user_id()]['time'] += $attempt->get_total_time();
            
            if ($attempt->get_status() != 'not attempted')
            {
                $user_attempts[$attempt->get_user_id()]['total_score'] += $attempt->get_total_score();
                $user_attempts[$attempt->get_user_id()]['score_count'] ++;
            }
            
            if ($user_attempts[$attempt->get_user_id()]['first'] == null || $user_attempts[$attempt->get_user_id()]['first'] > $attempt->get_date())
            {
                $user_attempts[$attempt->get_user_id()]['first'] = $attempt->get_date();
            }
            
            if ($user_attempts[$attempt->get_user_id()]['last'] == null || $attempt->get_date() > $user_attempts[$attempt->get_user_id()]['last'])
            {
                $user_attempts[$attempt->get_user_id()]['last'] = $attempt->get_date();
            }
        }
        
        while ($user = $users_resultset->next_result())
        {
            $reporting_data->add_category($count);
            
            $score = $first = $last = $time = null;
            if ($user_attempts[$user->get_id()]['count'] > 0)
            {
                $score = $this->get_score_bar($user_attempts[$user->get_id()]['total_score'] / $user_attempts[$user->get_id()]['score_count']);
                
                $first = DatetimeUtilities :: format_locale_date(Translation :: get('DateFormatShort', null, Utilities :: COMMON_LIBRARIES) . ', ' . Translation :: get('TimeNoSecFormat', null, Utilities :: COMMON_LIBRARIES), $user_attempts[$user->get_id()]['first']);
                $last = DatetimeUtilities :: format_locale_date(Translation :: get('DateFormatShort', null, Utilities :: COMMON_LIBRARIES) . ', ' . Translation :: get('TimeNoSecFormat', null, Utilities :: COMMON_LIBRARIES), $user_attempts[$user->get_id()]['last']);
                $time = Utilities :: format_seconds_to_hours($user_attempts[$user->get_id()]['time']);
                
                $params = $this->get_parent()->get_parameters();
                $params[ReportingManager :: PARAM_TEMPLATE_ID] = Reporting :: get_name_registration(Utilities :: camelcase_to_underscores('AssessmentAttemptsUserReportingTemplate'), WeblcmsManager :: APPLICATION_NAME)->get_id();
                $params[WeblcmsManager :: PARAM_USERS] = $user->get_id();
                $link = '<a href="' . $this->get_parent()->get_url($params) . '">' . $img . '</a>';
                $reporting_data->add_data_category_row($count, Translation :: get('UserDetails'), $link);
                $reporting_data->add_data_category_row($count, Translation :: get('NumberOfAttempts'), $user_attempts[$user->get_id()]['count']);
            }
            else
            {
                $reporting_data->add_data_category_row($count, Translation :: get('NumberOfAttempts'), 0);
            }
            
            $reporting_data->add_data_category_row($count, Translation :: get('Name'), $user->get_fullname());
            $reporting_data->add_data_category_row($count, Translation :: get('FirstAttempt'), $first);
            $reporting_data->add_data_category_row($count, Translation :: get('LastAttempt'), $last);
            $reporting_data->add_data_category_row($count, Translation :: get('TotalTime'), $time);
            $reporting_data->add_data_category_row($count, Translation :: get('AverageScore'), $score);
            
            $count ++;
        }
        $reporting_data->hide_categories();
        
        return $reporting_data;
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        return $modes;
    }

}
?>