<?php

namespace application\weblcms;

use common\libraries\EqualityCondition;

/**
 * Reporting block with scores for the course groups.
 *
 * @author Bert De Clercq (Hogeschool Gent)
 */
class WeblcmsAssignmentCourseGroupScoresReportingBlock extends WeblcmsAssignmentGroupScoresReportingBlock
{

    /**
     * Returns the submitter type for this reporting block.
     * 
     * @return int The submitter type
     */
    public function get_current_submitter_type()
    {
        return WeblcmsAssignmentSubmissionsTracker :: SUBMITTER_TYPE_COURSE_GROUP;
    }

    /**
     * Returns the groups for this reporting block.
     * 
     * @return array The groups
     */
    public function get_groups()
    {
        $condition = new EqualityCondition(CourseGroup :: PROPERTY_PARENT_ID, $this->course_id);
        return WeblcmsDataManager :: get_instance()->retrieve_course_groups($condition)->as_array();
    }

    /**
     * Returns true if the group with the given group id belongs to the given
     * target entities and false otherwise.
     * 
     * @param $target_entities array
     *            The target entities
     * @param $group_id int
     *            The group id
     * @return boolean True if the given group id belongs to the given target
     *         entities
     */
    public function is_target_entity_group($target_entities, $group_id)
    {
        foreach ($target_entities[CourseGroupEntity :: ENTITY_TYPE] as $course_group_id)
        {
            if ($group_id == $course_group_id)
            {
                return true;
            }
        }
        
        return false;
    }

}

?>
