<?php
namespace application\weblcms;

use common\libraries\ObjectTableOrder;

/**
 *
 * @package application.weblcms.php.reporting.blocks
 *         
 *          Reporting block with an overview of all course groups the assignment
 *          is published for
 *          and their submission stats
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 * @author Anthony Hurst (Hogeschool Gent)
 */
class WeblcmsAssignmentCourseGroupsReportingBlock extends WeblcmsAssignmentSubmittersReportingBlock
{

    /**
     * #Override (Implementation)
     * Obtains the course groups registered to see the assignment, sorted
     * alphabetically by name.
     * 
     * @return array() The course groups registered to see the assignment,
     *         sorted alphabetically by name.
     */
    public function get_submitters()
    {
        $order_by = array();
        $order_by[] = new ObjectTableOrder(CourseGroup :: PROPERTY_NAME);
        return WeblcmsDataManager :: get_instance()->retrieve_publication_target_course_groups($this->get_pid(), $this->get_course_id(), null, null, $order_by)->as_array();
    }

    /**
     * #Override (Implementation)
     * Gets the users, course groups and platform groups the assignment was
     * published for
     * plus the number of their submissions and feedbacks
     */
    public function get_submitters_data()
    {
        $manager = WeblcmsDataManager :: get_instance();
        
        // Course groups
        $submissions_resultset = $manager->retrieve_submissions_by_submitter_type($this->get_pid(), WeblcmsAssignmentSubmissionsTracker :: SUBMITTER_TYPE_COURSE_GROUP, WeblcmsAssignmentSubmissionsTracker :: CLASS_NAME);
        $this->get_array_from_resultset($submissions_resultset, $this->submissions);
        $feedbacks_resultset = $manager->count_submitter_feedbacks($this->get_pid(), WeblcmsAssignmentSubmissionsTracker :: SUBMITTER_TYPE_COURSE_GROUP, WeblcmsAssignmentSubmissionsTracker :: CLASS_NAME);
        $this->get_array_from_resultset($feedbacks_resultset, $this->feedbacks);
    }

    /**
     * Obtains trhe name of the submitter.
     * 
     * @param $submitter type
     *            The submitter whose name is to be obtained.
     * @return string The name of the submitter.
     */
    public function get_submitter_name($submitter)
    {
        return $submitter->get_name();
    }
}
?>
