<?php

namespace application\weblcms;

use application\weblcms\course\CourseGroupRelation;
use common\libraries\EqualityCondition;
use group\GroupDataManager;

/**
 * Reporting block with score for the platform groups.
 *
 * @author Bert De Clercq (Hogeschool Gent)
 */
class WeblcmsAssignmentPlatformGroupScoresReportingBlock extends WeblcmsAssignmentGroupScoresReportingBlock
{

    /**
     * Returns the submitter type for this reporting block.
     * 
     * @return int The submitter type
     */
    public function get_current_submitter_type()
    {
        return WeblcmsAssignmentSubmissionsTracker :: SUBMITTER_TYPE_PLATFORM_GROUP;
    }

    /**
     * Returns the groups for this reporting block.
     * 
     * @return array The groups
     */
    public function get_groups()
    {
        $condition = new EqualityCondition(CourseGroupRelation :: PROPERTY_COURSE_ID, $this->course_id);
        $course_groups_rels_resultset = WeblcmsDataManager :: get_instance()->retrieve_course_group_relations($condition);
        
        $group_ids = array();
        while ($group_rel = $course_groups_rels_resultset->next_result())
        {
            $group_ids[] = $group_rel->get_group_id();
        }
        
        $group_data_manager = GroupDataManager :: get_instance();
        return $group_data_manager->retrieve_groups_and_subgroups($group_ids)->as_array();
    }

    /**
     * Returns true if the group with the given group id belongs to the given
     * target entities and false otherwise.
     * 
     * @param $target_entities array
     *            The target entities
     * @param $group_id int
     *            The group id
     * @return boolean True if the given group id belongs to the given target
     *         entities
     */
    public function is_target_entity_group($target_entities, $group_id)
    {
        $groups_resultset = GroupDataManager :: get_instance()->retrieve_groups_and_subgroups($target_entities[CoursePlatformGroupEntity :: ENTITY_TYPE]);
        
        while ($group = $groups_resultset->next_result())
        {
            if ($group_id == $group->get_id())
            {
                return true;
            }
        }
        
        return false;
    }

}

?>
