<?php
namespace application\weblcms;

use reporting\Reporting;
use user\VisitTracker;
use reporting\ReportingData;
use reporting\ReportingFormatter;
use common\libraries\PatternMatchCondition;
use reporting\ReportingManager;
use common\libraries\Redirect;
use common\libraries\Application;
use common\libraries\Theme;
use common\libraries\OrCondition;
use common\libraries\Utilities;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use common\libraries\Path;
use common\libraries\Translation;
use application\weblcms\tool\reporting\ReportingTool;
use common\libraries\DatetimeUtilities;
use common\libraries\Request;
use application\weblcms\tool\assignment\AssignmentTool;
use repository\RepositoryDataManager;
use repository\ContentObjectRenderer;
use repository\RepositoryManager;
use common\libraries\Session;
use user\UserDataManager;
use user\UserManager;
use application\weblcms\tool\user\UserTool;
use repository\content_object\assignment\Assignment;

/**
 *
 * @package application.weblcms.php.reporting.blocks
 *         
 *          Reporting block with an overview of all submissions of an assignment
 *          from a user/group
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 * @author Anthony Hurst (Hogeschool Gent)
 */
class WeblcmsAssignmentSubmitterSubmissionsReportingBlock extends WeblcmsAssignmentReportingManager
{
    private static $COLUMN_DATE_SUBMITTED;
    private static $COLUMN_INDIVIDUAL_SUBMITTER;
    private static $COLUMN_IP_ADDRESS;
    private static $COLUMN_NUMBER_OF_FEEDBACKS;
    private static $COLUMN_SCORE;
    private static $COLUMN_TITLE;

    /**
     * Instatiates the column headers.
     * 
     * @param $parent type
     *            Pass-through variable. Please refer to parent class(es) for
     *            more details.
     *            &param type $vertical Pass-through variable. Please refer to
     *            parent class(es) for more details.
     */
    public function __construct($parent, $vertical)
    {
        self :: $COLUMN_TITLE = Translation :: get('Title');
        self :: $COLUMN_INDIVIDUAL_SUBMITTER = Translation :: get('SubmittedBy');
        self :: $COLUMN_DATE_SUBMITTED = Translation :: get('DateSubmitted');
        self :: $COLUMN_SCORE = Translation :: get('Score');
        self :: $COLUMN_NUMBER_OF_FEEDBACKS = Translation :: get('NumberOfFeedbacks');
        self :: $COLUMN_IP_ADDRESS = Translation :: get('IpAddress');
        parent :: __construct($parent, $vertical);
    }

    public function count_data()
    {
        $reporting_data = new ReportingData();
        $reporting_data_headers = array(self :: $COLUMN_TITLE, self :: $COLUMN_DATE_SUBMITTED, self :: $COLUMN_SCORE, 
                self :: $COLUMN_NUMBER_OF_FEEDBACKS, self :: $COLUMN_IP_ADDRESS);
        if ($this->get_submitter_type() != WeblcmsAssignmentSubmissionsTracker :: SUBMITTER_TYPE_USER)
        {
            array_splice($reporting_data_headers, 1, 0, array(self :: $COLUMN_INDIVIDUAL_SUBMITTER));
        }
        $reporting_data->set_rows($reporting_data_headers);
        
        $assignment = WeblcmsDataManager :: get_instance()->retrieve_content_object_publication($this->get_publication_id())->get_content_object();
        
        $conditions = array();
        $conditions[] = new EqualityCondition(WeblcmsAssignmentSubmissionsTracker :: PROPERTY_SUBMITTER_ID, $this->get_target_id());
        $conditions[] = new EqualityCondition(WeblcmsAssignmentSubmissionsTracker :: PROPERTY_SUBMITTER_TYPE, $this->get_submitter_type());
        $conditions[] = new EqualityCondition(WeblcmsAssignmentSubmissionsTracker :: PROPERTY_PUBLICATION_ID, $this->get_publication_id());
        $condition = new AndCondition($conditions);
        $submission_trackers = WeblcmsAssignmentSubmissionsTracker :: get_data(WeblcmsAssignmentSubmissionsTracker :: CLASS_NAME, WeblcmsManager :: APPLICATION_NAME, $condition)->as_array();
        
        foreach ($submission_trackers as $key => $submission_tracker)
        {
            $score = null;
            
            $date_submitted = $this->format_date_html($submission_tracker->get_date_submitted(), $assignment->get_end_time());
            
            $condition = new EqualityCondition(WeblcmsSubmissionScoreTracker :: PROPERTY_SUBMISSION_ID, $submission_tracker->get_id());
            $score_trackers = WeblcmsSubmissionScoreTracker :: get_data(WeblcmsSubmissionScoreTracker :: CLASS_NAME, WeblcmsManager :: APPLICATION_NAME, $condition)->as_array();
            
            if ($score_trackers[0])
            {
                $score = $this->format_score_html($score_trackers[0]->get_score());
            }
            
            $condition = new EqualityCondition(WeblcmsSubmissionFeedbackTracker :: PROPERTY_SUBMISSION_ID, $submission_tracker->get_id());
            $number_feedbacks = WeblcmsSubmissionFeedbackTracker :: count_data(WeblcmsSubmissionFeedbackTracker :: CLASS_NAME, WeblcmsManager :: APPLICATION_NAME, $condition);
            
            if ($this->get_submitter_type() != WeblcmsAssignmentSubmissionsTracker :: SUBMITTER_TYPE_USER)
            {
                // Link to the User
                $individual_submitter = $this->generate_user_name_link($submission_tracker->get_user_id());
            }
            // Link to submission details.
            $title = $this->generate_submission_title_link($submission_tracker);
            
            $reporting_data->add_category($key);
            $reporting_data->add_data_category_row($key, self :: $COLUMN_TITLE, $title);
            $reporting_data->add_data_category_row($key, self :: $COLUMN_DATE_SUBMITTED, $date_submitted);
            $reporting_data->add_data_category_row($key, self :: $COLUMN_SCORE, $score);
            $reporting_data->add_data_category_row($key, self :: $COLUMN_NUMBER_OF_FEEDBACKS, $number_feedbacks);
            $reporting_data->add_data_category_row($key, self :: $COLUMN_IP_ADDRESS, $submission_tracker->get_ip_address());
            
            if ($this->get_submitter_type() != WeblcmsAssignmentSubmissionsTracker :: SUBMITTER_TYPE_USER)
            {
                $reporting_data->add_data_category_row($key, self :: $COLUMN_INDIVIDUAL_SUBMITTER, $individual_submitter);
            }
        }
        $reporting_data->hide_categories();
        return $reporting_data;
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        return $modes;
    }
}
?>
