<?php
namespace application\weblcms;

use common\libraries\ObjectTableOrder;
use user\User;

/**
 *
 * @package application.weblcms.php.reporting.blocks
 *         
 *          Reporting block with an overiew of all users the assigment is
 *          published for
 *          and their submission stats
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 * @author Anthony Hurst (Hogeschool Gent)
 */
class WeblcmsAssignmentUsersReportingBlock extends WeblcmsAssignmentSubmittersReportingBlock
{

    public function get_submitters()
    {
        $order_by = array();
        $order_by[] = new ObjectTableOrder(User :: PROPERTY_LASTNAME);
        $order_by[] = new ObjectTableOrder(User :: PROPERTY_FIRSTNAME);
        return WeblcmsDataManager :: get_instance()->retrieve_publication_target_users($this->get_pid(), $this->get_course_id(), null, null, $order_by)->as_array();
    }

    /**
     * Gets the users, course groups and platform groups the assignment was
     * published for
     * plus the number of their submissions and feedbacks
     */
    public function get_submitters_data()
    {
        $manager = WeblcmsDataManager :: get_instance();
        
        // Users
        $submissions_resultset = $manager->retrieve_submissions_by_submitter_type($this->get_pid(), WeblcmsAssignmentSubmissionsTracker :: SUBMITTER_TYPE_USER, WeblcmsAssignmentSubmissionsTracker :: CLASS_NAME);
        $this->get_array_from_resultset($submissions_resultset, $this->submissions);
        $feedbacks_resultset = $manager->count_submitter_feedbacks($this->get_pid(), WeblcmsAssignmentSubmissionsTracker :: SUBMITTER_TYPE_USER, WeblcmsAssignmentSubmissionsTracker :: CLASS_NAME);
        $this->get_array_from_resultset($feedbacks_resultset, $this->feedbacks);
    }

    /**
     * Obtains the name of the submitter.
     * 
     * @param $submitter type
     *            The submitter whose name is to be obtained.
     * @return string The name of the submitter.
     */
    public function get_submitter_name($submitter)
    {
        return $submitter->get_fullname();
    }
}
?>
