<?php
namespace application\weblcms;

use application\weblcms\tool\learning_path\LearningPathTool;
use common\libraries\Path;
use common\libraries\Translation;
use common\libraries\EqualityCondition;
use common\libraries\AndCondition;
use common\libraries\Application;
use common\libraries\Redirect;
use common\libraries\Theme;
use common\libraries\Utilities;
use reporting\ReportingManager;
use reporting\Reporting;
use reporting\ReportingData;
use reporting\ReportingFormatter;
use repository\content_object\learning_path\LearningPath;

/**
 *
 * @package application.weblcms.php.reporting.blocks
 *         
 *          Reporting block with an overiew of the learning paths the user has
 *          attempted
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 */
class WeblcmsCourseUserLearningPathInformationReportingBlock extends WeblcmsToolReportingBlock
{

    public function count_data()
    {
        $reporting_data = new ReportingData();
        $reporting_data->set_rows(array(Translation :: get('Title'), Translation :: get('Progress'), 
                Translation :: get('LearningPathDetails')));
        $course_id = $this->get_course_id();
        $user_id = $this->get_user_id();
        $tracker = new WeblcmsLpAttemptTracker();
        $conditions[] = new EqualityCondition(WeblcmsLpAttemptTracker :: PROPERTY_COURSE_ID, $course_id);
        $conditions[] = new EqualityCondition(WeblcmsLpAttemptTracker :: PROPERTY_USER_ID, $user_id);
        $condition = new AndCondition($conditions);
        $trackerdata = $tracker->retrieve_tracker_items($condition);
        
        foreach ($trackerdata as $tracker)
        {
            $learning_paths[$tracker->get_lp_id()] = $tracker;
        }
        
        $params = array();
        $params[Application :: PARAM_ACTION] = WeblcmsManager :: ACTION_VIEW_COURSE;
        $params[Application :: PARAM_APPLICATION] = WeblcmsManager :: APPLICATION_NAME;
        $params[WeblcmsManager :: PARAM_COURSE] = $course_id;
        $params[WeblcmsManager :: PARAM_TOOL] = LearningPath :: get_type_name();
        $params[WeblcmsManager :: PARAM_TOOL_ACTION] = Tool :: ACTION_VIEW;
        
        $params_detail = $this->get_parent()->get_parameters();
        $params_detail[ReportingManager :: PARAM_TEMPLATE_ID] = Reporting :: get_name_registration(Utilities :: camelcase_to_underscores('LearningPathAttemptProgressReportingTemplate'), WeblcmsManager :: APPLICATION_NAME)->get_id();
        $img = '<img src="' . Theme :: get_common_image_path() . 'action_reporting.png" title="' . Translation :: get('Details') . '" />';
        
        $weblcms_data_manager = WeblcmsDataManager :: get_instance();
        $conditions = array();
        $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_TOOL, LearningPath :: get_type_name());
        $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_COURSE_ID, $course_id);
        $condition = new AndCondition($conditions);
        $publications_resultset = $weblcms_data_manager->retrieve_content_object_publications($condition);
        /*
         * $publications_arr = $publications_resultset->as_array();
         * dump($publications_arr);
         */
        $key = 0;
        while ($publication = $publications_resultset->next_result())
        {
            $progress = $url = $link = null;
            if (! $weblcms_data_manager->is_publication_target_user($user_id, $publication->get_id()))
            {
                continue;
            }
            ++ $key;
            
            if ($learning_paths[$publication->get_id()])
            {
                $params_detail[WeblcmsManager :: PARAM_PUBLICATION] = $publication->get_id();
                $params_detail[LearningPathTool :: PARAM_ATTEMPT_ID] = $learning_paths[$publication->get_id()];
                $link = '<a href="' . $this->get_parent()->get_url($params_detail) . '">' . $img . '</a>';
                $progress = $this->get_progress_bar($learning_paths[$publication->get_id()]->get_progress());
            }
            
            $params[WeblcmsManager :: PARAM_PUBLICATION] = $publication->get_id();
            $learning_path = $weblcms_data_manager->retrieve_content_object_publication($publication->get_id())->get_content_object();
            $url = '<a href="' . Redirect :: get_url($params) . '">' . $learning_path->get_title() . '</a>';
            
            $reporting_data->add_category($key);
            $reporting_data->add_data_category_row($key, Translation :: get('Title'), $url);
            $reporting_data->add_data_category_row($key, Translation :: get('Progress'), $progress);
            $reporting_data->add_data_category_row($key, Translation :: get('LearningPathDetails'), $link);
        }
        
        $reporting_data->hide_categories();
        return $reporting_data;
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        return $modes;
    }

}
?>
