<?php
namespace application\weblcms;

use user\VisitTracker;
use reporting\Reporting;
use reporting\ReportingData;
use reporting\ReportingFormatter;
use common\libraries\PatternMatchCondition;
use common\libraries\Utilities;
use common\libraries\Path;
use common\libraries\Translation;
use common\libraries\ObjectTableOrder;
use common\libraries\DatetimeUtilities;

class WeblcmsLastAccessToToolsPlatformReportingBlock extends WeblcmsCourseReportingBlock
{

    public function count_data()
    {
        $reporting_data = new ReportingData();
        $reporting_data->set_rows(array(Translation :: get('LastAccess'), Translation :: get('Clicks')));

        $wdm = WeblcmsDataManager :: get_instance();
        $tracker = new VisitTracker();

        $tools = $wdm->get_all_course_modules();
        foreach ($tools as $name)
        {
            $last_access = null;
            $tool = Translation :: get(Utilities :: underscores_to_camelcase($name));
            $condition = new PatternMatchCondition(VisitTracker :: PROPERTY_LOCATION, '*&tool=' . $name . '*');
            $count = $tracker->count_tracker_items($condition);
            $order_by = new ObjectTableOrder(VisitTracker :: PROPERTY_ID, SORT_DESC);
            $last_visit = $tracker->retrieve_tracker_items_result_set($condition, 0, 1, $order_by);
            if ($last_visit->size() > 0)
            {
                $last_access = $last_visit->next_result()->get_leave_date();
                $last_access = DatetimeUtilities :: format_locale_date(Translation :: get('DateFormatShort', null, Utilities :: COMMON_LIBRARIES) . ', ' . Translation :: get('TimeNoSecFormat', null, Utilities :: COMMON_LIBRARIES), $last_access);
            }

            $reporting_data->add_category($tool);
            $reporting_data->add_data_category_row($tool, Translation :: get('Clicks'), $count);
            $reporting_data->add_data_category_row($tool, Translation :: get('LastAccess'), $last_access);
        }

        return $reporting_data;
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        return $modes;
    }
}
?>