<?php
namespace application\weblcms;

use application\weblcms\tool\reporting\ReportingTool;
use common\libraries\Redirect;
use common\libraries\Application;
use common\libraries\Theme;
use common\libraries\OrCondition;
use common\libraries\Utilities;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use common\libraries\PatternMatchCondition;
use common\libraries\Path;
use common\libraries\Toolbar;
use common\libraries\ToolbarItem;
use common\libraries\Translation;
use common\libraries\DatetimeUtilities;
use reporting\Reporting;
use reporting\ReportingData;
use reporting\ReportingFormatter;
use reporting\ReportingManager;
use repository\content_object\assignment\Assignment;
use repository\content_object\assessment\Assessment;
use repository\content_object\learning_path\LearningPath;
use user\VisitTracker;

/**
 *
 * @package application.weblcms.php.reporting.blocks
 *         
 *          Reporting block with an overiew of the tools and their access
 *          details
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 */
class WeblcmsLastAccessToToolsReportingBlock extends WeblcmsToolReportingBlock
{

    public function count_data()
    {
        $reporting_data = new ReportingData();
        $reporting_data->set_rows(array(Translation :: get('Tool'), Translation :: get('LastAccess'), 
                Translation :: get('Clicks'), Translation :: get('TotalPublications'), Translation :: get('Actions')));
        
        $wdm = WeblcmsDataManager :: get_instance();
        $tracker = new VisitTracker();
        $course_id = $this->get_course_id();

        $course_tools = $wdm->retrieve_course_tools();
        $csc = CourseSettingsController :: get_instance();
        
        $tools = array();
        while($tool = $course_tools->next_result())
        {
            $active = $csc->get_course_setting($this->get_course_id(), CourseSetting :: COURSE_SETTING_TOOL_ACTIVE, $tool->get_id());
            if($active)
            {
                $tools[] = $tool;
            }
        }
        
        foreach ($tools as $key => $value)
        {
            $name = $value->get_name();
            $tool = Translation :: get('TypeName', null, Tool :: get_tool_type_namespace($name));
            $params = array();
            $params[Application :: PARAM_ACTION] = WeblcmsManager :: ACTION_VIEW_COURSE;
            $params[Application :: PARAM_APPLICATION] = WeblcmsManager :: APPLICATION_NAME;
            $params[WeblcmsManager :: PARAM_COURSE] = $this->get_course_id();
            $params[WeblcmsManager :: PARAM_TOOL] = $name;
            
            $link = ' <a href="' . Redirect :: get_url($params) . '">' . $tool . '</a>';
            $date = $wdm->get_last_visit_date_per_course($course_id, $name);
            if ($date)
            {
                $date = DatetimeUtilities :: format_locale_date(Translation :: get('DateFormatShort', null, Utilities :: COMMON_LIBRARIES) . ', ' . Translation :: get('TimeNoSecFormat', null, Utilities :: COMMON_LIBRARIES), $date);
            }
            else
            {
                $date = Translation :: get('NeverAccessed');
            }
            
            $conditions = array();
            $conditions[] = new PatternMatchCondition(VisitTracker :: PROPERTY_LOCATION, '*&course=' . $course_id . '*&tool=' . $name . '*');
            if (isset($user_id))
                $conditions[] = new EqualityCondition(VisitTracker :: PROPERTY_USER_ID, $user_id);
            $condition = new AndCondition($conditions);
            $count = $tracker->count_tracker_items($condition);
            
            $conditions = array();
            $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_COURSE_ID, $course_id);
            $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_TOOL, $name);
            $condition = new AndCondition($conditions);
            $publications = $wdm->count_content_object_publications($condition);
            
            $reporting_data->add_category($key);
            $reporting_data->add_data_category_row($key, Translation :: get('Tool'), $link);
            $reporting_data->add_data_category_row($key, Translation :: get('LastAccess'), $date);
            $reporting_data->add_data_category_row($key, Translation :: get('Clicks'), $count);
            $reporting_data->add_data_category_row($key, Translation :: get('TotalPublications'), $publications);
            
            if ($publications > 0)
            {
                $params = $this->get_parent()->get_parameters();
                $params[ReportingManager :: PARAM_TEMPLATE_ID] = Reporting :: get_name_registration(Utilities :: camelcase_to_underscores('ToolPublicationsDetailReportingTemplate'), WeblcmsManager :: APPLICATION_NAME)->get_id();
                $params[WeblcmsManager :: PARAM_USERS] = $user_id;
                $params[ReportingTool :: PARAM_REPORTING_TOOL] = $name;
                $url = $this->get_parent()->get_url($params);
                $link_pub = '<a href="' . $url . '">' . Translation :: get('ViewPublications') . '</a>';
                
                $toolbar = new Toolbar();
                $toolbar->add_item(new ToolbarItem(Translation :: get('ViewPublications'), Theme :: get_common_image_path() . 'action_reporting.png', $url, ToolbarItem :: DISPLAY_ICON));
                
                switch ($name)
                {
                    case Assignment :: get_type_name() :
                        $params = $this->get_parent()->get_parameters();
                        $params[ReportingManager :: PARAM_TEMPLATE_ID] = Reporting :: get_name_registration(Utilities :: camelcase_to_underscores('AssignmentScoresReportingTemplate'), WeblcmsManager :: APPLICATION_NAME)->get_id();
                        $params[WeblcmsManager :: PARAM_COURSE] = $course_id;
                        $url_detail = $this->get_parent()->get_url($params);
                        $toolbar->add_item(new ToolbarItem(Translation :: get('ViewScores'), Theme :: get_common_image_path() . 'action_view_results.png', $url_detail, ToolbarItem :: DISPLAY_ICON));
                        break;
                    case Assessment :: get_type_name() :
                        $params = $this->get_parent()->get_parameters();
                        $params[ReportingManager :: PARAM_TEMPLATE_ID] = Reporting :: get_name_registration(Utilities :: camelcase_to_underscores('AssessmentScoresReportingTemplate'), WeblcmsManager :: APPLICATION_NAME)->get_id();
                        $params[WeblcmsManager :: PARAM_COURSE] = $course_id;
                        $url_detail = $this->get_parent()->get_url($params);
                        $toolbar->add_item(new ToolbarItem(Translation :: get('ViewScores'), Theme :: get_common_image_path() . 'action_view_results.png', $url_detail, ToolbarItem :: DISPLAY_ICON));
                        break;
                    case LearningPath :: get_type_name() :
                        $params = $this->get_parent()->get_parameters();
                        $params[ReportingManager :: PARAM_TEMPLATE_ID] = Reporting :: get_name_registration(Utilities :: camelcase_to_underscores('LearningPathProgressReportingTemplate'), WeblcmsManager :: APPLICATION_NAME)->get_id();
                        $params[WeblcmsManager :: PARAM_COURSE] = $course_id;
                        $url_detail = $this->get_parent()->get_url($params);
                        $toolbar->add_item(new ToolbarItem(Translation :: get('ViewProgressUsers'), Theme :: get_common_image_path() . 'action_view_results.png', $url_detail, ToolbarItem :: DISPLAY_ICON));
                        break;
                }
                
                $reporting_data->add_data_category_row($key, Translation :: get('Actions'), $toolbar->as_html());
            }
        }
        
        $reporting_data->hide_categories();
        return $reporting_data;
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        return $modes;
    }
}
?>
