<?php
namespace application\weblcms;

use application\weblcms\tool\reporting\ReportingTool;
use common\libraries\PatternMatchCondition;
use common\libraries\DatetimeUtilities;
use common\libraries\Redirect;
use common\libraries\Application;
use common\libraries\Theme;
use common\libraries\OrCondition;
use common\libraries\Utilities;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use common\libraries\Path;
use common\libraries\Translation;
use reporting\ReportingManager;
use reporting\Reporting;
use reporting\ReportingData;
use reporting\ReportingFormatter;
use user\VisitTracker;

class WeblcmsLastAccessToToolsUserReportingBlock extends WeblcmsToolReportingBlock
{

    public function count_data()
    {
        $reporting_data = new ReportingData();
        $reporting_data->set_rows(array(Translation :: get('Tool'), Translation :: get('LastAccess'), 
                Translation :: get('Clicks'), Translation :: get('Publications')));
        
        $wdm = WeblcmsDataManager :: get_instance();
        $tracker = new VisitTracker();
        $course_id = $this->get_course_id();
        $user_id = $this->get_user_id();
        
        $course_tools = $wdm->retrieve_course_tools();
        $csc = CourseSettingsController :: get_instance();
        
        $tools = array();
        while($tool = $course_tools->next_result())
        {
            $active = $csc->get_course_setting($this->get_course_id(), CourseSetting :: COURSE_SETTING_TOOL_ACTIVE, $tool->get_id());
            if($active)
            {
                $tools[] = $tool;
            }
        }
        
        $img = '<img src="' . Theme :: get_common_image_path() . 'action_reporting.png" title="' . Translation :: get('ViewPublications') . '" />';
        
        foreach ($tools as $key => $value)
        {
            $name = $value->get_name();
            $tool = Translation :: get('TypeName', null, Tool :: get_tool_type_namespace($name));
            $params = array();
            $params[Application :: PARAM_ACTION] = WeblcmsManager :: ACTION_VIEW_COURSE;
            $params[Application :: PARAM_APPLICATION] = WeblcmsManager :: APPLICATION_NAME;
            $params[WeblcmsManager :: PARAM_COURSE] = $this->get_course_id();
            $params[WeblcmsManager :: PARAM_TOOL] = $name;
            
            $link = ' <a href="' . Redirect :: get_url($params) . '">' . $tool . '</a>';
            $date = $wdm->get_last_visit_date_per_course($course_id, $name, $user_id);
            if ($date)
            {
                $date = DatetimeUtilities :: format_locale_date(Translation :: get('DateFormatShort', null, Utilities :: COMMON_LIBRARIES) . ', ' . Translation :: get('TimeNoSecFormat', null, Utilities :: COMMON_LIBRARIES), $date);
            }
            else
            {
                $date = Translation :: get('NeverAccessed');
            }
            
            $conditions = array();
            $conditions[] = new PatternMatchCondition(VisitTracker :: PROPERTY_LOCATION, '*&course=' . $course_id . '*&tool=' . $name . '*');
            if (isset($user_id))
            {
                $conditions[] = new EqualityCondition(VisitTracker :: PROPERTY_USER_ID, $user_id);
            }
            $condition = new AndCondition($conditions);
            $count = $tracker->count_tracker_items($condition);
            
            $conditions = array();
            $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_COURSE_ID, $course_id);
            $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_TOOL, $name);
            $condition = new AndCondition($conditions);
            $publications = $wdm->count_content_object_publications($condition);
            
            $reporting_data->add_category($key);
            $reporting_data->add_data_category_row($key, Translation :: get('Tool'), $link);
            $reporting_data->add_data_category_row($key, Translation :: get('LastAccess'), $date);
            $reporting_data->add_data_category_row($key, Translation :: get('Clicks'), $count);
            
            if ($publications > 0)
            {
                $params = $this->get_parent()->get_parameters();
                $params[ReportingManager :: PARAM_TEMPLATE_ID] = Reporting :: get_name_registration(Utilities :: camelcase_to_underscores('ToolPublicationsDetailReportingTemplate'), WeblcmsManager :: APPLICATION_NAME)->get_id();
                $params[WeblcmsManager :: PARAM_USERS] = $user_id;
                $params[ReportingTool :: PARAM_REPORTING_TOOL] = $name;
                $link_pub = '<a href="' . $this->get_parent()->get_url($params) . '">' . $img . '</a>';
                
                $reporting_data->add_data_category_row($key, Translation :: get('Publications'), $link_pub);
            }
        }
        $reporting_data->hide_categories();
        return $reporting_data;
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        return $modes;
    }
}
?>
