<?php
namespace application\weblcms;

use application\weblcms\tool\learning_path\LearningPathTool;
use application\weblcms\tool\learning_path\LearningPathToolStatisticsViewerComponent;
use reporting\Reporting;
use reporting\ReportingData;
use reporting\ReportingFormatter;
use reporting\ReportingManager;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use common\libraries\Redirect;
use common\libraries\Theme;
use common\libraries\Path;
use common\libraries\Translation;
use common\libraries\Text;
use common\libraries\Utilities;
use user\UserDataManager;

class WeblcmsLearningPathAttemptsReportingBlock extends WeblcmsToolReportingBlock
{

    public function count_data()
    {
        $reporting_data = new ReportingData();
        $reporting_data->set_rows(array(Translation :: get('Name'), Translation :: get('Progress'), 
                Translation :: get('Details')));
        
        $pid = $this->get_pid();
        $course_id = $this->get_course_id();
        $tool = $this->get_tool();
        
        $weblcms_data_manager = WeblcmsDataManager :: get_instance();
        $users_resultset = $weblcms_data_manager->retrieve_publication_target_users($pid, $course_id);
        
        $conditions[] = new EqualityCondition(WeblcmsLpAttemptTracker :: PROPERTY_COURSE_ID, $course_id);
        $conditions[] = new EqualityCondition(WeblcmsLpAttemptTracker :: PROPERTY_LP_ID, $pid);
        $condition = new AndCondition($conditions);
        
        $dummy = new WeblcmsLpAttemptTracker();
        $trackers = $dummy->retrieve_tracker_items($condition);
        $user_progress = array();
        foreach ($trackers as $tracker)
        {
            $user_progress[$tracker->get_user_id()] = $tracker;
        }
        
        $count = 1;
        $params = $this->get_parent()->get_parameters();
        $params[ReportingManager :: PARAM_TEMPLATE_ID] = Reporting :: get_name_registration(Utilities :: camelcase_to_underscores('LearningPathAttemptProgressReportingTemplate'), WeblcmsManager :: APPLICATION_NAME)->get_id();
        $img = '<img src="' . Theme :: get_common_image_path() . 'action_reporting.png" title="' . Translation :: get('Details') . '" />';
        
        while ($user = $users_resultset->next_result())
        {
            $reporting_data->add_category($count);
            $reporting_data->add_data_category_row($count, Translation :: get('Name'), $user->get_fullname());
            
            $tracker = $user_progress[$user->get_id()];
            if ($tracker)
            {
                $params[LearningPathTool :: PARAM_ATTEMPT_ID] = $tracker->get_id();
                $params[WeblcmsManager :: PARAM_USERS] = $user->get_id();
                $params[LearningPathToolStatisticsViewerComponent :: PARAM_STAT] = null;
                $url = Redirect :: get_url($params);
                
                $params[LearningPathToolStatisticsViewerComponent :: PARAM_STAT] = LearningPathToolStatisticsViewerComponent :: ACTION_DELETE_LP_ATTEMPT;
                $delete_url = Redirect :: get_url($params);
                
                if ($tool == 'reporting')
                {
                    $action = '<a href="' . $url . '">' . $img . '</a>';
                }
                else
                {
                    $action = Text :: create_link($url, Theme :: get_common_image('action_reporting')) . ' ' . Text :: create_link($delete_url, Theme :: get_common_image('action_delete'));
                }
                
                $progress = $this->get_progress_bar($tracker->get_progress());
                
                $reporting_data->add_data_category_row($count, Translation :: get('Progress'), $progress);
                $reporting_data->add_data_category_row($count, Translation :: get('Details'), $action);
            }
            $count ++;
        }
        
        $reporting_data->hide_categories();
        return $reporting_data;
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        return $modes;
    }

}
?>