<?php
namespace application\weblcms;

use reporting\Reporting;
use user\VisitTracker;
use reporting\ReportingData;
use reporting\ReportingFormatter;
use common\libraries\PatternMatchCondition;
use reporting\ReportingManager;
use common\libraries\Redirect;
use common\libraries\Application;
use common\libraries\Theme;
use common\libraries\OrCondition;
use common\libraries\Utilities;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use common\libraries\Path;
use common\libraries\Translation;
use application\weblcms\tool\reporting\ReportingTool;
use common\libraries\DatetimeUtilities;
use common\libraries\Request;
use repository\RepositoryDataManager;
use repository\ContentObjectRenderer;
use repository\RepositoryManager;
use common\libraries\Session;
use user\UserDataManager;
use user\UserManager;
use application\weblcms\tool\user\UserTool;
use common\libraries\ObjectTableOrder;
use common\libraries\InCondition;
use repository\content_object\learning_path\LearningPath;

/**
 *
 * @package application.weblcms.php.reporting.blocks
 *         
 *          Reporting block with an overview of progress of each learning path
 *          per user
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 */
class WeblcmsLearningPathProgressUsersReportingBlock extends WeblcmsToolReportingBlock
{

    public function count_data()
    {
        $reporting_data = new ReportingData();
        $course_id = $this->get_course_id();
        $weblcms_data_manager = WeblcmsDataManager :: get_instance();
        $users = $weblcms_data_manager->retrieve_all_course_users($course_id)->as_array();
        
        $conditions = array();
        $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_COURSE_ID, $course_id);
        $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_TOOL, LearningPath :: get_type_name());
        $condition = new AndCondition($conditions);
        
        $order_by = new ObjectTableOrder(ContentObjectPublication :: PROPERTY_MODIFIED_DATE, SORT_DESC);
        
        $publication_resultset = $weblcms_data_manager->retrieve_content_object_publications($condition, $order_by);
        
        $publications = array();
        $headings = array();
        $headings[] = Translation :: get('Name');
        while ($publication = $publication_resultset->next_result())
        {
            $publications[] = $publication;
            if ($publication_resultset->size() > 5)
            {
                $headings[] = substr($publication->get_content_object()->get_title(), 0, 14);
            }
            else
            {
                $headings[] = $publication->get_content_object()->get_title();
            }
        }
        
        $reporting_data->set_rows($headings);
        
        foreach ($users as $key => $user)
        {
            $reporting_data->add_category($key);
            $reporting_data->add_data_category_row($key, Translation :: get('Name'), $user->get_fullname());
            
            foreach ($publications as $publication)
            {
                if ($publication_resultset->size() > 5)
                {
                    $title = substr($publication->get_content_object()->get_title(), 0, 14);
                }
                else
                {
                    $title = $publication->get_content_object()->get_title();
                }
                $tracker = new WeblcmsLpAttemptTracker();
                $conditions = array();
                $conditions[] = new EqualityCondition(WeblcmsLpAttemptTracker :: PROPERTY_LP_ID, $publication->get_id());
                $conditions[] = new EqualityCondition(WeblcmsLpAttemptTracker :: PROPERTY_USER_ID, $user->get_id());
                $condition = new AndCondition($conditions);
                $attempt_trackers = $tracker->retrieve_tracker_items($condition);
                
                if (count($attempt_trackers) < 1)
                {
                    if ($weblcms_data_manager->is_publication_target_user($user->get_id(), $publication->get_id(), $course_id))
                    {
                        $reporting_data->add_data_category_row($key, $title, null);
                        continue;
                    }
                    
                    $reporting_data->add_data_category_row($key, $title, 'X');
                    continue;
                }
                
                $progress = $attempt_trackers[0]->get_progress();
                
                switch ($progress)
                {
                    case 0 :
                        $progress = '<span style="color:red">' . $progress . '%</span>';
                        break;
                    case 100 :
                        $progress = '<span style="color:green">' . $progress . '%</span>';
                        break;
                    default :
                        $progress = '<span style="color:orange">' . $progress . '%</span>';
                        break;
                }
                
                $reporting_data->add_data_category_row($key, $title, $progress);
            }
        
        }
        $reporting_data->hide_categories();
        return $reporting_data;
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        return $modes;
    }

}
?>
