<?php
namespace application\weblcms;

use application\weblcms\course\CourseDataManager;
use user\VisitTracker;
use reporting\ReportingData;
use reporting\ReportingChartFormatter;
use reporting\ReportingFormatter;
use common\libraries\PatternMatchCondition;
use common\libraries\DatetimeUtilities;
use common\libraries\EqualityCondition;
use common\libraries\Path;
use common\libraries\Translation;

class WeblcmsMostActiveInactiveLastDetailReportingBlock extends WeblcmsCourseReportingBlock
{

    public function count_data()
    {
        $reporting_data = new ReportingData();
        $reporting_data->set_rows(array(Translation :: get('LastVisit'), Translation :: get('LastPublication')));

        $wdm = CourseDataManager :: get_instance();
        $tracker = new VisitTracker();
        $courses = $wdm->retrieve_courses();
        while ($course = $courses->next_result())
        {

            $lastaccess = Translation :: get('NeverAccessed');
            $lastpublication = Translation :: get('NothingPublished');

            $condition = new PatternMatchCondition(VisitTracker :: PROPERTY_LOCATION, '*&course=' . $course->get_id() . '*');
            $trackerdata = $tracker->retrieve_tracker_items($condition);
            foreach ($trackerdata as $key => $value)
            {
                $lastaccess = DatetimeUtilities :: format_locale_date(null, $value->get_leave_date());
            }

            $condition = new EqualityCondition(ContentObjectPublication :: PROPERTY_COURSE_ID, $course->get_id());
            $publications = $wdm->retrieve_content_object_publications($condition);

            while ($publication = $publications->next_result())
            {
                $lastpublication = DatetimeUtilities :: format_locale_date(null, $publication->get_modified_date());

                // $lastpublication = date('Y-m-d G:i:s', $lastpublication);
            }

            $reporting_data->add_category($course->get_title());
            // $reporting_data->add_data_category_row($course->get_title(),
            // Translation :: get('Course'), '<a
            // href="index.php?go=courseviewer&course=' . $course->get_id() .
            // '&application=weblcms&" />' . $course->get_title() . '</a>');
            $reporting_data->add_data_category_row($course->get_title(), Translation :: get('LastVisit'), $lastaccess);
            $reporting_data->add_data_category_row($course->get_title(), Translation :: get('LastPublication'), $lastpublication);
        }
        return $reporting_data;
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    function get_application()
    {
        return WeblcmsManager :: APPLICATION_NAME;
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        // $modes[ReportingFormatter::DISPLAY_TEXT] = Translation ::
        // get('Text');
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        // $modes[ReportingChartFormatter::DISPLAY_PIE] = Translation ::
        // get('Chart:Pie');
        return $modes;
    }
}
?>