<?php
namespace application\weblcms;

use application\weblcms\course\CourseDataManager;
use user\VisitTracker;
use reporting\ReportingData;
use reporting\ReportingFormatter;
use common\libraries\PatternMatchCondition;
use common\libraries\Path;
use common\libraries\Translation;
use common\libraries\ObjectTableOrder;

class WeblcmsMostActiveInactiveLastVisitReportingBlock extends WeblcmsCourseReportingBlock
{

    public function count_data()
    {
        $reporting_data = new ReportingData();
        $wdm = CourseDataManager :: get_instance();
        $tracker = new VisitTracker();
        $courses = $wdm->retrieve_courses();

        $arr[Translation :: get('Past24hr')] = 0;
        $arr[Translation :: get('PastWeek')] = 0;
        $arr[Translation :: get('PastMonth')] = 0;
        $arr[Translation :: get('PastYear')] = 0;
        $arr[Translation :: get('NeverAccessed')] = 0;
        $arr[Translation :: get('MoreThenOneYear')] = 0;

        while ($course = $courses->next_result())
        {
            $lastaccess = 0;
            $condition = new PatternMatchCondition(VisitTracker :: PROPERTY_LOCATION, '*&course=' . $course->get_id() . '*');
            $order_by = new ObjectTableOrder(VisitTracker :: PROPERTY_ID, SORT_DESC);
            $trackerdata = $tracker->retrieve_tracker_items_result_set($condition, 0, 1, $order_by);

            if ($trackerdata->size() > 0)
            {
                $lastaccess = $trackerdata->next_result()->get_leave_date();
            }

            if ($lastaccess == 0)
            {
                $arr[Translation :: get('NeverAccessed')] ++;
            }
            else
                if ($lastaccess > time() - 86400)
                {
                    $arr[Translation :: get('Past24hr')] ++;
                }
                else
                    if ($lastaccess > time() - 604800)
                    {
                        $arr[Translation :: get('PastWeek')] ++;
                    }
                    else
                        if ($lastaccess > time() - 18144000)
                        {
                            $arr[Translation :: get('PastMonth')] ++;
                        }
                        else
                            if ($lastaccess > time() - 31536000)
                            {
                                $arr[Translation :: get('PastYear')] ++;
                            }
                            else
                            {
                                $arr[Translation :: get('MoreThenOneYear')] ++;
                            }
        }

        $reporting_data->set_categories(array(Translation :: get('Past24hr'), Translation :: get('PastWeek'),
                Translation :: get('PastMonth'), Translation :: get('PastYear'), Translation :: get('MoreThenOneYear'),
                Translation :: get('NeverAccessed')));
        $reporting_data->set_rows(array(Translation :: get('TimesAccessed')));

        $reporting_data->add_data_category_row(Translation :: get('Past24hr'), Translation :: get('TimesAccessed'), $arr[Translation :: get('Past24hr')]);
        $reporting_data->add_data_category_row(Translation :: get('PastWeek'), Translation :: get('TimesAccessed'), $arr[Translation :: get('PastWeek')]);
        $reporting_data->add_data_category_row(Translation :: get('PastMonth'), Translation :: get('TimesAccessed'), $arr[Translation :: get('PastMonth')]);
        $reporting_data->add_data_category_row(Translation :: get('PastYear'), Translation :: get('TimesAccessed'), $arr[Translation :: get('PastYear')]);
        $reporting_data->add_data_category_row(Translation :: get('MoreThenOneYear'), Translation :: get('TimesAccessed'), $arr[Translation :: get('MoreThenOneYear')]);
        $reporting_data->add_data_category_row(Translation :: get('NeverAccessed'), Translation :: get('TimesAccessed'), $arr[Translation :: get('NeverAccessed')]);

        return $reporting_data;
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    function get_application()
    {
        return WeblcmsManager :: APPLICATION_NAME;
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        // $modes[ReportingFormatter::DISPLAY_TEXT] = Translation ::
        // get('Text');
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        return $modes;
    }
}
?>