<?php
namespace application\weblcms;

use application\weblcms\tool\reporting\ReportingTool;
use common\libraries\PatternMatchCondition;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use common\libraries\NotCondition;
use common\libraries\Path;
use common\libraries\Translation;
use common\libraries\Request;
use common\libraries\Redirect;
use common\libraries\Session;
use reporting\ReportingData;
use reporting\ReportingFormatter;
use user\UserDataManager;
use user\VisitTracker;

class WeblcmsPublicationAccessReportingBlock extends WeblcmsToolReportingBlock
{

    public function count_data()
    {
        $reporting_data = new ReportingData();
        $reporting_data->set_rows(array(Translation :: get('User', null, 'user'), Translation :: get('LastAccess'),
                Translation :: get('TotalTime')));
        $course_id = $this->get_course_id();
        $user_id = $this->get_user_id();
        $tool = Request :: get(ReportingTool :: PARAM_REPORTING_TOOL);
        if (is_null($tool))
        {
            $tool = $this->get_tool();
        }
        $pid = $this->get_pid();

        $udm = UserDataManager :: get_instance();

        if (isset($user_id))
        {
            $conditions[] = new PatternMatchCondition(VisitTracker :: PROPERTY_LOCATION, '*&' . WeblcmsManager :: PARAM_TOOL . '=' . $tool . '*' . Tool :: PARAM_PUBLICATION_ID . '=' . $pid . '*');
            $conditions[] = new EqualityCondition(VisitTracker :: PROPERTY_USER_ID, $user_id);
            $condition = new AndCondition($conditions);
            $user = $udm->retrieve_user($user_id);
        }
        else
        {
            $conditions[] = new PatternMatchCondition(VisitTracker :: PROPERTY_LOCATION, '*&' . WeblcmsManager :: PARAM_TOOL . '=' . $tool . '*' . Tool :: PARAM_PUBLICATION_ID . '=' . $pid . '*');
            if (Request :: post('sel'))
            {
                $conditions[] = new NotCondition(new EqualityCondition(VisitTracker :: PROPERTY_USER_ID, Session :: get_user_id()));
            }
            $condition = new AndCondition($conditions);
        }

        $arr = self :: visit_tracker_to_array($condition, $user);

        $i = 1;
        foreach ($arr[Translation :: get('User', null, 'user')] as $category)
        {
            $reporting_data->add_category($i);
            $i ++;
        }

        foreach ($arr as $row_name => $row_data)
        {
            foreach ($row_data as $category_id => $category_value)
            {
                $reporting_data->add_data_category_row($category_id + 1, $row_name, $category_value);
            }
        }

        $reporting_data->hide_categories();
        return $reporting_data;
    }

    public function display_header()
    {
        $html[] = parent :: display_header();

        $user_id = $this->get_user_id();
        if (! isset($user_id))
        {
            $html[] = '<script type="text/javascript" src="' . Path :: get_application_web_path() . 'weblcms/resources/javascript/reporting_filter.js"></script>';
            $html[] = '<div class="reporting_header_filter"><form id="select_form" method="post" action ="' . Redirect :: current_url() . '">';
            if (Request :: post('sel'))
            {
                $html[] = '<input type="checkbox" id="sel" name="sel" value="exclude" checked="checked"/>';
            }
            else
            {
                $html[] = '<input type="checkbox" id="sel" name="sel" value="exclude"/>';
            }
            $html[] = Translation :: get('HideOwnDetails') . '</form></div>';
        }
        return implode("\n", $html);
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    function get_application()
    {
        return WeblcmsManager :: APPLICATION_NAME;
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        return $modes;
    }

}
?>
