<?php
namespace application\weblcms;

use user\VisitTracker;
use reporting\ReportingData;
use reporting\ReportingFormatter;
use common\libraries\PatternMatchCondition;
use common\libraries\DatetimeUtilities;
use repository\RepositoryDataManager;
use common\libraries\Utilities;
use common\libraries\EqualityCondition;
use common\libraries\Request;
use common\libraries\Path;
use common\libraries\Translation;
use common\libraries\Application;
use common\libraries\Redirect;
use application\weblcms\tool\reporting\ReportingTool;
use common\libraries\AndCondition;

class WeblcmsPublicationDetailReportingBlock extends WeblcmsToolReportingBlock
{

    public function count_data()
    {
        $reporting_data = new ReportingData();

        $course_id = $this->get_course_id();
        $user_id = $this->get_user_id();
        $tool = Request :: get(ReportingTool :: PARAM_REPORTING_TOOL);
        $pid = Request :: get(Tool :: PARAM_PUBLICATION_ID);

        $tracker = new VisitTracker();
        $wdm = WeblcmsDataManager :: get_instance();
        $lop = $wdm->retrieve_content_object_publication($pid);

        if (empty($lop))
        {
            $lop = RepositoryDataManager :: get_instance()->retrieve_content_object($pid);
            $title = $lop->get_title();
            $id = $lop->get_id();
            $descr = $lop->get_description();
        }
        else
        {
            $title = $lop->get_content_object()->get_title();
            $id = $pid;
            $descr = $lop->get_content_object()->get_description();
        }

        $condition = new PatternMatchCondition(VisitTracker :: PROPERTY_LOCATION, '*&' . WeblcmsManager :: PARAM_TOOL . '=' . $tool . '*' . Tool :: PARAM_PUBLICATION_ID . '=' . $pid . '*');
        $trackerdata = $tracker->retrieve_tracker_items($condition);

        foreach ($trackerdata as $key => $value)
        {
            if ($value->get_leave_date() > $lastaccess)
                $lastaccess = $value->get_leave_date();
        }

        $params = array();
        $params[Application :: PARAM_ACTION] = WeblcmsManager :: ACTION_VIEW_COURSE;
        $params[Application :: PARAM_APPLICATION] = WeblcmsManager :: APPLICATION_NAME;
        $params[WeblcmsManager :: PARAM_COURSE] = $course_id;
        $params[WeblcmsManager :: PARAM_TOOL] = $tool;
        $params[WeblcmsManager :: PARAM_PUBLICATION] = $id;
        $params[WeblcmsManager :: PARAM_TOOL_ACTION] = Tool :: ACTION_VIEW;
        $url = Redirect :: get_url($params);

        $reporting_data->set_categories(array(Translation :: get('Title'), Translation :: get('Description'),
                Translation :: get('LastAccess'), Translation :: get('TotalTimesAccessed')));
        $reporting_data->set_rows(array(Translation :: get('count')));

        $reporting_data->add_data_category_row(Translation :: get('Title'), Translation :: get('count'), '<a href="' . $url . '">' . $title . '</a>');
        $reporting_data->add_data_category_row(Translation :: get('Description'), Translation :: get('count'), Utilities :: truncate_string($descr, 50));
        $reporting_data->add_data_category_row(Translation :: get('LastAccess'), Translation :: get('count'), DatetimeUtilities :: format_locale_date(null, $lastaccess));
        $reporting_data->add_data_category_row(Translation :: get('TotalTimesAccessed'), Translation :: get('count'), count($trackerdata));

        return $reporting_data;
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    function get_application()
    {
        return WeblcmsManager :: APPLICATION_NAME;
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        // $modes[ReportingFormatter::DISPLAY_TEXT] = Translation ::
        // get('Text');
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        return $modes;
    }
}
?>
