<?php
namespace application\weblcms;

use user\VisitTracker;
use reporting\ReportingData;
use reporting\ReportingFormatter;
use common\libraries\PatternMatchCondition;
use user\UserDataManager;
use common\libraries\ObjectTableOrder;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use common\libraries\Path;
use common\libraries\Translation;
use common\libraries\DatetimeUtilities;
use common\libraries\Utilities;
use common\libraries\Request;
use application\weblcms\tool\reporting\ReportingTool;

class WeblcmsPublicationUserAccessReportingBlock extends WeblcmsToolReportingBlock
{

    public function count_data()
    {
        $reporting_data = new ReportingData();
        $tracker = new VisitTracker();

        $course_id = $this->get_course_id();
        $user_id = $this->get_user_id();
        $pid = $this->get_pid();

        $tool = Request :: get(ReportingTool :: PARAM_REPORTING_TOOL);

        $udm = UserDataManager :: get_instance();
        $user = $udm->retrieve_user($user_id);

        $conditions = array();
        $conditions[] = new EqualityCondition(VisitTracker :: PROPERTY_USER_ID, $user_id);
        $conditions[] = new PatternMatchCondition(VisitTracker :: PROPERTY_LOCATION, '*&' . WeblcmsManager :: PARAM_TOOL . '=' . $tool . '*' . Tool :: PARAM_PUBLICATION_ID . '=' . $pid . '*');
        $condition = new AndCondition($conditions);

        $order_by = new ObjectTableOrder(VisitTracker :: PROPERTY_ENTER_DATE, SORT_DESC);
        if ($params['order_by'])
        {
            $order_by = $params['order_by'];
        }

        $trackerdata = $tracker->retrieve_tracker_items_result_set($condition, null, null, $order_by);

        $reporting_data->set_categories(array(Translation :: get('User', null, 'user'),
                Translation :: get('LastAccess'), Translation :: get('TotalTime'), Translation :: get('Clicks')));
        $reporting_data->set_rows(array(Translation :: get('count')));

        // $arr[Translation :: get('User')] =
        // $udm->retrieve_user($user_id)->get_fullname();
        while ($value = $trackerdata->next_result())
        {
            $time = $value->get_leave_date() - $value->get_enter_date();
            if ($value->get_enter_date() > $arr['LastAccess'])
            {
                $arr['LastAccess'] = $value->get_enter_date();
            }
            $arr['TotalTime'] += $time;
            $arr['Clicks'] ++;
        }

        $lastaccess = DatetimeUtilities :: format_locale_date(Translation :: get('DateFormatShort', null, Utilities :: COMMON_LIBRARIES) . ', ' . Translation :: get('TimeNoSecFormat', null, Utilities :: COMMON_LIBRARIES), $arr['LastAccess']);
        $totaltime = mktime(0, 0, $arr['TotalTime'], 0, 0);
        $totaltime = date('G:i:s', $totaltime);
        $reporting_data->add_data_category_row(Translation :: get('User', null, 'user'), Translation :: get('count'), $user->get_fullname());
        $reporting_data->add_data_category_row(Translation :: get('LastAccess'), Translation :: get('count'), $lastaccess);
        $reporting_data->add_data_category_row(Translation :: get('TotalTime'), Translation :: get('count'), $totaltime);
        $reporting_data->add_data_category_row(Translation :: get('Clicks'), Translation :: get('count'), $arr['Clicks']);
        return $reporting_data;
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    function get_application()
    {
        return WeblcmsManager :: APPLICATION_NAME;
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        // $modes[ReportingFormatter::DISPLAY_TEXT] = Translation ::
        // get('Text');
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        return $modes;
    }
}
?>