<?php
namespace application\weblcms;

use application\weblcms\tool\reporting\ReportingTool;
use application\weblcms\ContentObjectPublicationUser;
use common\libraries\PatternMatchCondition;
use common\libraries\Redirect;
use common\libraries\Application;
use common\libraries\OrCondition;
use common\libraries\InCondition;
use common\libraries\Utilities;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use common\libraries\Path;
use common\libraries\Translation;
use common\libraries\Theme;
use common\libraries\Request;
use common\libraries\DatetimeUtilities;
use reporting\Reporting;
use reporting\ReportingManager;
use reporting\ReportingData;
use reporting\ReportingFormatter;
use user\VisitTracker;

class WeblcmsToolPublicationsReportingBlock extends WeblcmsToolReportingBlock
{

    public function count_data()
    {
        $reporting_data = new ReportingData();
        $course_id = $this->get_course_id();
        $user_id = $this->get_user_id();
        $tool = Request :: get(ReportingTool :: PARAM_REPORTING_TOOL);
        $tracker = new VisitTracker();
        $wdm = WeblcmsDataManager :: get_instance();

        if (is_null($user_id))
        {
            $reporting_data->set_rows(array(Translation :: get('Title'), Translation :: get('Description'),
                    Translation :: get('LastAccess'), Translation :: get('Clicks'), Translation :: get('TotalTime'),
                    Translation :: get('AccessDetails')));
        }
        else
        {
            $reporting_data->set_rows(array(Translation :: get('Title'), Translation :: get('Description'),
                    Translation :: get('LastAccess'), Translation :: get('Clicks'), Translation :: get('TotalTime')));
        }

        $conditions = array();
        $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_COURSE_ID, $course_id);
        $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_TOOL, $tool);
        $condition = new AndCondition($conditions);
        $lops = $wdm->retrieve_content_object_publications($condition, $params['order_by']);
        $img = '<img src="' . Theme :: get_common_image_path() . 'action_reporting.png" title="' . Translation :: get('Details') . '" />';
        $i = 1;

        while ($lop = $lops->next_result())
        {
            $lastaccess = null;
            $total_time = 0;

            $conditions = array();
            $conditions[] = new PatternMatchCondition(VisitTracker :: PROPERTY_LOCATION, '*&' . WeblcmsManager :: PARAM_TOOL . '=' . $tool . '*' . Tool :: PARAM_PUBLICATION_ID . '=' . $lop->get_id() . '*');
            if (! is_null($user_id))
            {
                $conditions[] = new EqualityCondition(VisitTracker :: PROPERTY_USER_ID, $user_id);
            }
            $condition = new AndCondition($conditions);
            $trackerdata = $tracker->retrieve_tracker_items($condition);

            foreach ($trackerdata as $key => $value)
            {
                $time = $value->get_leave_date() - $value->get_enter_date();
                $total_time += $time;
                if ($value->get_leave_date() > $lastaccess)
                {
                    $lastaccess = $value->get_leave_date();
                }
            }
            if ($lastaccess)
            {
                $lastaccess = DatetimeUtilities :: format_locale_date(Translation :: get('DateFormatShort', null, Utilities :: COMMON_LIBRARIES) . ', ' . Translation :: get('TimeNoSecFormat', null, Utilities :: COMMON_LIBRARIES), $lastaccess);
            }
            $total_time = Utilities :: format_seconds_to_hours($total_time);

            $params = array();
            $params[Application :: PARAM_ACTION] = WeblcmsManager :: ACTION_VIEW_COURSE;
            $params[Application :: PARAM_APPLICATION] = WeblcmsManager :: APPLICATION_NAME;
            $params[WeblcmsManager :: PARAM_COURSE] = $course_id;
            $params[WeblcmsManager :: PARAM_TOOL] = $tool;
            $params[WeblcmsManager :: PARAM_PUBLICATION] = $lop->get_id();
            $params[WeblcmsManager :: PARAM_TOOL_ACTION] = Tool :: ACTION_VIEW;
            $url = Redirect :: get_url($params);

            $des = $lop->get_content_object()->get_description();
            $this->get_parent()->set_parameter($lop->get_id());
            $this->set_params($course_id, $user_id, $tool, $this->get_pid());

            $reporting_data->add_category($i);
            $reporting_data->add_data_category_row($i, Translation :: get('Title'), '<a href="' . $url . '">' . $lop->get_content_object()->get_title() . '</a>');
            $reporting_data->add_data_category_row($i, Translation :: get('Description'), Utilities :: truncate_string($des, 50));
            $reporting_data->add_data_category_row($i, Translation :: get('LastAccess'), $lastaccess);
            $reporting_data->add_data_category_row($i, Translation :: get('Clicks'), count($trackerdata));
            $reporting_data->add_data_category_row($i, Translation :: get('TotalTime'), $total_time);

            if (is_null($user_id))
            {
                $params = $this->get_parent()->get_parameters();
                $params[ReportingManager :: PARAM_TEMPLATE_ID] = Reporting :: get_name_registration(Utilities :: camelcase_to_underscores('PublicationDetailReportingTemplate'), WeblcmsManager :: APPLICATION_NAME)->get_id();
                $params[WeblcmsManager :: PARAM_COURSE] = $course_id;
                $params[WeblcmsManager :: PARAM_USERS] = $user_id;
                $params[WeblcmsManager :: PARAM_PUBLICATION] = $lop->get_id();
                $link = '<a href="' . $this->get_parent()->get_url($params) . '">' . $img . '</a>';

                $reporting_data->add_data_category_row($i, Translation :: get('AccessDetails'), $link);
            }

            $i ++;
        }

        $reporting_data->hide_categories();
        return $reporting_data;
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        return $modes;
    }
}
?>
