<?php
namespace application\weblcms;

use reporting\ReportingData;
use reporting\ReportingFormatter;
use user\UserDataManager;
use common\libraries\Path;
use common\libraries\Translation;
use user\VisitTracker;
use common\libraries\PatternMatchCondition;
use common\libraries\EqualityCondition;
use common\libraries\AndCondition;
use common\libraries\DatetimeUtilities;

class WeblcmsUserInformationReportingBlock extends WeblcmsToolReportingBlock
{

    public function count_data()
    {
        $reporting_data = new ReportingData();
        
        $course_id = $this->get_course_id();
        $user_id = $this->get_user_id();
        $udm = UserDataManager :: get_instance();
        $user = $udm->retrieve_user($user_id);
        
        $tracker = new VisitTracker();
        $conditions[] = new PatternMatchCondition(VisitTracker :: PROPERTY_LOCATION, '*&course=' . $course_id . '*');
        $conditions[] = new EqualityCondition(VisitTracker :: PROPERTY_USER_ID, $user_id);
        $condition = new AndCondition($conditions);
        $visits = $tracker->retrieve_tracker_items($condition);
        
        $firstconnection = $lastconnection = null;
        foreach ($visits as $key => $value)
        {
            if (is_null($firstconnection) || $firstconnection > $value->get_enter_date())
            {
                $firstconnection = $value->get_enter_date();
            }
            
            if (is_null($lastconnection) || $value->get_enter_date() > $lastconnection)
            {
                $lastconnection = $value->get_enter_date();
            }
        }
        
        if (count($visits) > 0)
        {
            $first_date = DatetimeUtilities :: format_locale_date(null, $firstconnection);
            $last_date = DatetimeUtilities :: format_locale_date(null, $lastconnection);
        }
        else
        {
            $first_date = Translation :: get('NeverAccessed');
            $last_date = Translation :: get('NeverAccessed');
        }
        
        $reporting_data->set_categories(array(Translation :: get('Name'), Translation :: get('Email'), 
                Translation :: get('FirstAccessToCourse'), Translation :: get('LastAccessToCourse')));
        $reporting_data->set_rows(array(Translation :: get('Details')));
        
        $reporting_data->add_data_category_row(Translation :: get('Name'), Translation :: get('Details'), $user->get_fullname());
        $reporting_data->add_data_category_row(Translation :: get('Email'), Translation :: get('Details'), '<a href="mailto:' . $user->get_email() . '" >' . $user->get_email() . '</a>');
        $reporting_data->add_data_category_row(Translation :: get('FirstAccessToCourse'), Translation :: get('Details'), $first_date);
        $reporting_data->add_data_category_row(Translation :: get('LastAccessToCourse'), Translation :: get('Details'), $last_date);
        
        return $reporting_data;
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        return $modes;
    }
}
?>