<?php
namespace application\weblcms;

use common\libraries\PatternMatchCondition;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use common\libraries\Path;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\DatetimeUtilities;
use common\libraries\Theme;
use reporting\Reporting;
use reporting\ReportingManager;
use reporting\ReportingData;
use reporting\ReportingFormatter;
use repository\RepositoryDataManager;
use user\UserDataManager;
use user\VisitTracker;

class WeblcmsUsersTrackingReportingBlock extends WeblcmsCourseReportingBlock
{

    public function count_data()
    {
        $reporting_data = new ReportingData();
        $reporting_data->set_rows(array(Translation :: get('Name'), Translation :: get('UserName'),
                Translation :: get('TimeOnCourse'), Translation :: get('LastAccess'), Translation :: get('Clicks'),
                Translation :: get('TotalPublications'), Translation :: get('UserDetail')));

        $course_id = $this->get_course_id();
        $wdm = WeblcmsDataManager :: get_instance();
        $img = '<img src="' . Theme :: get_common_image_path() . 'action_reporting.png" title="' . Translation :: get('Details') . '" />';

        $count = 1;
        $users_resultset = $wdm->retrieve_all_course_users($course_id);
        $tracker = new VisitTracker();
        while ($user = $users_resultset->next_result())
        {
            $conditions = array();
            $conditions[] = new PatternMatchCondition(VisitTracker :: PROPERTY_LOCATION, '*&course=' . $course_id . '*');
            $conditions[] = new EqualityCondition(VisitTracker :: PROPERTY_USER_ID, $user->get_id());
            $condition = new AndCondition($conditions);
            $trackerdata = $tracker->retrieve_tracker_items($condition);

            $lastconnection = $last_date = null;
            foreach ($trackerdata as $key => $value)
            {
                if ($value->get_leave_date() > $lastconnection)
                {
                    $lastconnection = $value->get_leave_date();
                }
            }

            if ($lastconnection != null)
            {
                $last_date = DatetimeUtilities :: format_locale_date(Translation :: get('DateFormatShort', null, Utilities :: COMMON_LIBRARIES) . ', ' . Translation :: get('TimeNoSecFormat', null, Utilities :: COMMON_LIBRARIES), $lastconnection);
            }

            $params = $this->get_parent()->get_parameters();
            $params[ReportingManager :: PARAM_TEMPLATE_ID] = Reporting :: get_name_registration(Utilities :: camelcase_to_underscores('CourseStudentTrackerDetailReportingTemplate'), WeblcmsManager :: APPLICATION_NAME)->get_id();
            $params[WeblcmsManager :: PARAM_USERS] = $user->get_id();
            $link = '<a href="' . $this->get_parent()->get_url($params) . '">' . $img . '</a>';

            $reporting_data->add_category($count);

            $reporting_data->add_data_category_row($count, Translation :: get('Name'), $user->get_fullname());
            $reporting_data->add_data_category_row($count, Translation :: get('UserName'), $user->get_username());
            $reporting_data->add_data_category_row($count, Translation :: get('TimeOnCourse'), self :: get_total_time($trackerdata));
            $reporting_data->add_data_category_row($count, Translation :: get('LastAccess'), $last_date);
            $reporting_data->add_data_category_row($count, Translation :: get('Clicks'), count($trackerdata));

            $publication_conditions = array();
            $publication_conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_PUBLISHER_ID, $user->get_id());
            $publication_conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_COURSE_ID, $course_id);
            $publication_condition = new AndCondition($publication_conditions);

            $reporting_data->add_data_category_row($count, Translation :: get('TotalPublications'), $wdm->count_content_object_publications($publication_condition));
            $reporting_data->add_data_category_row($count, Translation :: get('UserDetail'), $link);

            $count ++;
        }
        $reporting_data->hide_categories();

        return $reporting_data;
    }

    public function retrieve_data()
    {
        return $this->count_data();
    }

    public function get_available_displaymodes()
    {
        $modes = array();
        $modes[ReportingFormatter :: DISPLAY_TABLE] = Translation :: get('Table');
        return $modes;
    }
}
?>
