<?php

namespace application\weblcms;

use common\libraries\Request;
use reporting\ReportingTemplate;
use common\libraries\Breadcrumb;
use Exception;
use repository\RepositoryDataManager;
use common\libraries\EqualityCondition;
use repository\ComplexContentObjectItem;

/**
 *
 * @package application.weblcms.php.reporting.templates
 *         
 *          Reporting template with information about the assessment, the
 *          attempts per user
 *          and questions score stats
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 */
class AssessmentAttemptsReportingTemplate extends ReportingTemplate
{

    function __construct($parent)
    {
        parent :: __construct($parent);
        
        $this->publication_id = Request :: get(WeblcmsManager :: PARAM_PUBLICATION);
        if ($this->publication_id)
        {
            $this->set_parameter(WeblcmsManager :: PARAM_PUBLICATION, $this->publication_id);
        }
        
        $sel = (Request :: post('sel')) ? Request :: post('sel') : Request :: get('sel');
        if ($sel)
        {
            $this->set_parameter('sel', $sel);
        }
        
        // Retrieve the questions of the assessment
        $weblcms_data_manager = WeblcmsDataManager :: get_instance();
        $publication = WeblcmsDataManager :: get_instance()->retrieve_content_object_publication($this->publication_id);
        $condition = new EqualityCondition(ComplexContentObjectItem :: PROPERTY_PARENT, $publication->get_content_object_id());
        $questions_resultset = RepositoryDataManager :: get_instance()->retrieve_complex_content_object_items($condition);
        $tracker = new WeblcmsQuestionAttemptsTracker();
        
        while ($question = $questions_resultset->next_result())
        {
            $this->th_titles[] = $question->get_ref_object()->get_title();
        }
        
        $this->add_reporting_block($this->get_assessment_information());
        $this->add_reporting_block($this->get_assessment_users());
        $this->add_reporting_block($this->get_assessment_questions());
        $this->add_reporting_block($this->get_assessment_questions_users());
        
        $assessment = $weblcms_data_manager->retrieve_content_object_publication($this->publication_id)->get_content_object();
        $custom_breadcrumbs = array();
        $custom_breadcrumbs[] = new Breadcrumb($this->get_url(), $assessment->get_title());
        $this->set_custom_breadcrumb_trail($custom_breadcrumbs);
    }

    function display_context()
    {
    
    }

    function get_application()
    {
        return WeblcmsManager :: APPLICATION_NAME;
    }

    function get_assessment_information()
    {
        $assessment_block = new WeblcmsAssessmentInformationReportingBlock($this);
        return $assessment_block;
    }

    function get_assessment_users()
    {
        $assessment_block = new WeblcmsAssessmentUsersReportingBlock($this);
        $assessment_block->set_sorting(3, SORT_DESC);
        return $assessment_block;
    }

    function get_assessment_questions()
    {
        $assessment_block = new WeblcmsAssessmentQuestionsReportingBlock($this);
        $assessment_block->set_sorting(3, SORT_DESC);
        return $assessment_block;
    }

    function get_assessment_questions_users()
    {
        $assessment_block = new WeblcmsAssessmentQuestionsUsersReportingBlock($this, true);
        $assessment_block->set_sorting(0);
        return $assessment_block;
    }

}

?>