<?php

namespace application\weblcms;

use common\libraries\Request;
use reporting\ReportingTemplate;
use common\libraries\Breadcrumb;
use user\UserDataManager;
use reporting\ReportingManager;
use reporting\Reporting;
use common\libraries\Utilities;
use Exception;

/**
 *
 * @package application.weblcms.php.reporting.templates
 *         
 *          Reporting template with an overview of the assessment attempts of
 *          one user
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 */
class AssessmentAttemptsUserReportingTemplate extends ReportingTemplate
{

    function __construct($parent)
    {
        parent :: __construct($parent);
        $this->initialize_parameters();
        $this->add_reporting_block($this->get_user_assessment_information());
        $this->add_reporting_block($this->get_user_assessment_attempts());
        
        $weblcms_data_manager = WeblcmsDataManager :: get_instance();
        $assessment = $weblcms_data_manager->retrieve_content_object_publication($this->publication_id)->get_content_object();
        $user_data_manager = UserDataManager :: get_instance();
        $user = $user_data_manager->retrieve_user($this->user_id);
        $params = array();
        $params[ReportingManager :: PARAM_TEMPLATE_ID] = Reporting :: get_name_registration(Utilities :: camelcase_to_underscores('AssessmentAttemptsReportingTemplate'), WeblcmsManager :: APPLICATION_NAME)->get_id();
        $params[WeblcmsManager :: PARAM_USERS] = null;
        $custom_breadcrumbs = array();
        $custom_breadcrumbs[] = new Breadcrumb($this->get_url($params), $assessment->get_title());
        $custom_breadcrumbs[] = new Breadcrumb($this->get_url(), $user->get_fullname());
        $this->set_custom_breadcrumb_trail($custom_breadcrumbs);
    }

    function initialize_parameters()
    {
        $this->publication_id = Request :: get(WeblcmsManager :: PARAM_PUBLICATION);
        $this->user_id = request :: get(WeblcmsManager :: PARAM_USERS);
        
        if ($this->publication_id)
        {
            $this->set_parameter(WeblcmsManager :: PARAM_PUBLICATION, $this->publication_id);
        }
        
        if ($this->user_id)
        {
            $this->set_parameter(WeblcmsManager :: PARAM_USERS, $this->user_id);
        }
        
        $course_id = Request :: get(WeblcmsManager :: PARAM_COURSE);
        if ($course_id)
        {
            $this->set_parameter(WeblcmsManager :: PARAM_COURSE, $course_id);
        }
    }

    function display_context()
    {
    
    }

    function get_application()
    {
        return WeblcmsManager :: APPLICATION_NAME;
    }

    function get_user_assessment_attempts()
    {
        $assessment_block = new WeblcmsAssessmentAttemptsUserReportingBlock($this);
        $assessment_block->set_sorting(0, SORT_DESC);
        return $assessment_block;
    }

    function get_user_assessment_information()
    {
        $assessment_block = new WeblcmsAssessmentUserInformationReportingBlock($this);
        return $assessment_block;
    }
}

?>