<?php

namespace application\weblcms;

use application\weblcms\tool\reporting\ReportingTool;
use common\libraries\Breadcrumb;
use common\libraries\Request;
use reporting\ReportingTemplate;
use user\UserDataManager;
use reporting\ReportingManager;
use reporting\Reporting;
use common\libraries\Utilities;
use repository\RepositoryDataManager;

/**
 *
 * @package application.weblcms.php.reporting.templates
 *         
 *          Reporting template with the assessment question attempts of one user
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 */
class AssessmentQuestionAttemptsUserReportingTemplate extends ReportingTemplate
{

    function __construct($parent)
    {
        parent :: __construct($parent);
        
        $this->question_id = Request :: get(ReportingTool :: PARAM_QUESTION);
        $this->publication_id = Request :: get(WeblcmsManager :: PARAM_PUBLICATION);
        $this->user_id = Request :: get(WeblcmsManager :: PARAM_USERS);
        $this->add_reporting_block($this->get_question_attempts_user());
        
        $custom_breadcrumbs = array();
        
        $weblcms_data_manager = WeblcmsDataManager :: get_instance();
        $assessment = $weblcms_data_manager->retrieve_content_object_publication($this->publication_id)->get_content_object();
        $params = array();
        $params[ReportingManager :: PARAM_TEMPLATE_ID] = Reporting :: get_name_registration(Utilities :: camelcase_to_underscores('AssessmentAttemptsReportingTemplate'), WeblcmsManager :: APPLICATION_NAME)->get_id();
        $params[WeblcmsManager :: PARAM_USERS] = null;
        $params[ReportingTool :: PARAM_QUESTION] = null;
        $custom_breadcrumbs[] = new Breadcrumb($this->get_url($params), $assessment->get_title());
        
        $params = array();
        $params[ReportingManager :: PARAM_TEMPLATE_ID] = Reporting :: get_name_registration(Utilities :: camelcase_to_underscores('AssessmentQuestionUsersReportingTemplate'), WeblcmsManager :: APPLICATION_NAME)->get_id();
        $params[WeblcmsManager :: PARAM_USERS] = null;
        $question = RepositoryDataManager :: get_instance()->retrieve_complex_content_object_item($this->question_id);
        $custom_breadcrumbs[] = new Breadcrumb($this->get_url($params), $question->get_ref_object()->get_title());
        
        $user_data_manager = UserDataManager :: get_instance();
        $user = $user_data_manager->retrieve_user($this->user_id);
        $custom_breadcrumbs[] = new Breadcrumb($this->get_url(), $user->get_fullname());
        
        $this->set_custom_breadcrumb_trail($custom_breadcrumbs);
    }

    function display_context()
    {
    
    }

    function get_application()
    {
        return WeblcmsManager :: APPLICATION_NAME;
    }

    function get_question_attempts_user()
    {
        if ($this->question_id)
        {
            $this->set_parameter(ReportingTool :: PARAM_QUESTION, $this->question_id);
        }
        
        if ($this->publication_id)
        {
            $this->set_parameter(WeblcmsManager :: PARAM_PUBLICATION, $this->publication_id);
        }
        
        if ($this->user_id)
        {
            $this->set_parameter(WeblcmsManager :: PARAM_USERS, $this->user_id);
        }
        
        $question_attempts_user_block = new WeblcmsAssessmentQuestionAttemptsUserReportingBlock($this);
        $question_attempts_user_block->set_sorting(0, SORT_DESC);
        return $question_attempts_user_block;
    }

}

?>