<?php

namespace application\weblcms;

use application\weblcms\tool\reporting\ReportingTool;
use common\libraries\Breadcrumb;
use common\libraries\Request;
use reporting\ReportingTemplate;
use user\UserDataManager;
use reporting\ReportingManager;
use reporting\Reporting;
use common\libraries\Utilities;
use repository\RepositoryDataManager;

/**
 *
 * @package application.weblcms.php.reporting.templates
 *         
 *          Reporting template with an overview of the scores of an assessment
 *          question per user
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 */
class AssessmentQuestionUsersReportingTemplate extends ReportingTemplate
{

    function __construct($parent)
    {
        parent :: __construct($parent);
        $this->initialize_parameters();
        $this->add_reporting_block($this->get_question_users());
        $this->add_reporting_block($this->get_question_attempts());
        
        $weblcms_data_manager = WeblcmsDataManager :: get_instance();
        $assessment = $weblcms_data_manager->retrieve_content_object_publication($this->publication_id)->get_content_object();
        $question = RepositoryDataManager :: get_instance()->retrieve_complex_content_object_item($this->question_id);
        $params = array();
        $params[ReportingManager :: PARAM_TEMPLATE_ID] = Reporting :: get_name_registration(Utilities :: camelcase_to_underscores('AssessmentAttemptsReportingTemplate'), WeblcmsManager :: APPLICATION_NAME)->get_id();
        $params[WeblcmsManager :: PARAM_PUBLICATION] = $this->publication_id;
        $custom_breadcrumbs = array();
        $custom_breadcrumbs[] = new Breadcrumb($this->get_url($params), $assessment->get_title());
        $custom_breadcrumbs[] = new Breadcrumb($this->get_url(), $question->get_ref_object()->get_title());
        $this->set_custom_breadcrumb_trail($custom_breadcrumbs);
    }

    private function initialize_parameters()
    {
        $this->question_id = Request :: get(ReportingTool :: PARAM_QUESTION);
        if ($this->question_id)
        {
            $this->set_parameter(ReportingTool :: PARAM_QUESTION, $this->question_id);
        }
        
        $this->publication_id = Request :: get(WeblcmsManager :: PARAM_PUBLICATION);
        if ($this->publication_id)
        {
            $this->set_parameter(WeblcmsManager :: PARAM_PUBLICATION, $this->publication_id);
        }
        
        $this->user_id = Request :: get(WeblcmsManager :: PARAM_USERS);
        if ($this->user_id)
        {
            $this->set_parameter(WeblcmsManager :: PARAM_USERS, $this->user_id);
        }
    }

    function display_context()
    {
    
    }

    function get_application()
    {
        return WeblcmsManager :: APPLICATION_NAME;
    }

    function get_question_users()
    {
        $question_block = new WeblcmsAssessmentQuestionUsersReportingBlock($this);
        $question_block->set_sorting(0);
        return $question_block;
    }

    function get_question_attempts()
    {
        $question_block = new WeblcmsAssessmentQuestionAttemptsReportingBlock($this);
        $question_block->set_sorting(0, SORT_DESC);
        return $question_block;
    }
}

?>