<?php

namespace application\weblcms;

use common\libraries\Request;
use reporting\ReportingTemplate;
use common\libraries\Breadcrumb;
use common\libraries\Translation;
use user\UserDataManager;
use group\GroupDataManager;
use reporting\Reporting;
use common\libraries\Utilities;
use reporting\ReportingManager;
use common\libraries\EqualityCondition;
use common\libraries\AndCondition;
use Exception;
use repository\content_object\assessment\Assessment;
use common\libraries\ObjectTableOrder;
use common\libraries\Path;
use common\libraries\Redirect;

/**
 *
 * @package application.weblcms.php.reporting.templates
 *         
 *          Reporting template with an overview of scores of each assessment per
 *          user
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 */
class AssessmentScoresReportingTemplate extends ReportingTemplate
{

    function __construct($parent)
    {
        parent :: __construct($parent);
        
        $this->init_parameters();
        
        $custom_breadcrumbs = array();
        $custom_breadcrumbs[] = new Breadcrumb($this->get_url(), Translation :: get('AssessmentScores'));
        $this->set_custom_breadcrumb_trail($custom_breadcrumbs);
        
        // Calculate number of assessments
        $weblcms_data_manager = WeblcmsDataManager :: get_instance();
        $conditions = array();
        $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_COURSE_ID, $this->course_id);
        $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_TOOL, Assessment :: get_type_name());
        $condition = new AndCondition($conditions);
        
        $order_by = new ObjectTableOrder(ContentObjectPublication :: PROPERTY_MODIFIED_DATE, SORT_DESC);
        
        $publications = $weblcms_data_manager->retrieve_content_object_publications($condition, $order_by);
        
        $this->size = $publications->size();
        
        foreach ($publications->as_array() as $publication)
        {
            $this->th_titles[] = $publication->get_content_object()->get_title();
        }
        
        $this->add_reporting_block($this->get_assessment_user_scores());
        $this->add_reporting_block($this->get_assessment_overview());
    }

    function display_context()
    {
        // publicatie, content_object, application ...
    }

    private function init_parameters()
    {
        $this->course_id = Request :: get(WeblcmsManager :: PARAM_COURSE);
        if ($this->course_id)
        {
            $this->set_parameter(WeblcmsManager :: PARAM_COURSE, $this->course_id);
        }
        $sel = (Request :: post('sel')) ? Request :: post('sel') : Request :: get('sel');
        if ($sel)
        {
            $this->set_parameter('sel', $sel);
        }
    }

    function get_application()
    {
        return WeblcmsManager :: APPLICATION_NAME;
    }

    function get_assessment_user_scores()
    {
        $assessment_scores_block = new WeblcmsAssessmentUserScoresReportingBlock($this, true);
        $assessment_scores_block->set_sorting(0);
        $legend[] = 'X : ' . Translation :: get('NotPublishedForUser') . '<br />';
        $legend[] = '- : ' . Translation :: get('NoAttemptsByUser') . '<br />';
        $assessment_scores_block->set_legend($legend);
        return $assessment_scores_block;
    }

    function get_assessment_overview()
    {
        $assessment_overview_block = new WeblcmsAssessmentOverviewReportingBlock($this);
        $assessment_overview_block->set_sorting(1);
        return $assessment_overview_block;
    }

    public function display_header()
    {
        $html[] = parent :: display_header();
        $score_type = (Request :: post('sel')) ? Request :: post('sel') : Request :: get('sel');
        $types = array(1 => 'Average', 2 => 'Minimum', 3 => 'Maximum', 4 => 'First', 5 => 'Last');
        $html[] = '<script type="text/javascript" src="' . Path :: get_application_web_path() . 'weblcms/resources/javascript/reporting_filter.js"></script>';
        $html[] = '<form id="select_form" method="post" action ="' . Redirect :: current_url() . '">';
        $html[] = Translation :: get('ScoreToDisplay') . ': ' . '<select id="sel" name="sel">';
        
        foreach ($types as $key => $value)
        {
            if ($key == $score_type)
            {
                $html[] = '<option value="' . $key . '" selected="selected">' . Translation :: get($value) . '</option>';
            }
            else
            {
                $html[] = '<option value="' . $key . '">' . Translation :: get($value) . '</option>';
            }
        }
        
        $html[] = '</select><input type="hidden" name="p" value="Zoeken" /></form><br />';
        return implode("\n", $html);
    }
}

?>