<?php

namespace application\weblcms;

use common\libraries\Request;
use reporting\ReportingTemplate;
use common\libraries\Breadcrumb;
use Exception;

/**
 *
 * @package application.weblcms.php.reporting.templates
 *         
 *          Reporting template with information about the assignment
 *          and the users, course groups and platform groups the assignment is
 *          published for
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 * @author Anthony Hurst (Hogeschool Gent)
 */
class CourseAssignmentSubmittersReportingTemplate extends ReportingTemplate
{

    function __construct($parent)
    {
        parent :: __construct($parent);
        
        $this->publication_id = Request :: get(WeblcmsManager :: PARAM_PUBLICATION);
        $weblcms_data_manager = WeblcmsDataManager :: get_instance();
        $assignment = $weblcms_data_manager->retrieve_content_object_publication($this->publication_id)->get_content_object();
        $this->init_parameters();
        $this->add_reporting_block($this->get_assignment_information());
        
        if (! $assignment->get_allow_group_submissions())
        {
            $this->add_reporting_block($this->get_assignment_users());
        }
        else
        {
            $this->add_reporting_block($this->get_assignment_course_groups());
            $this->add_reporting_block($this->get_assignment_groups());
        }
        
        $custom_breadcrumbs = array();
        $custom_breadcrumbs[] = new Breadcrumb($this->get_url(), $assignment->get_title());
        $this->set_custom_breadcrumb_trail($custom_breadcrumbs);
    }

    function display_context()
    {
    
    }

    private function init_parameters()
    {
        if ($this->publication_id)
        {
            $this->set_parameter(WeblcmsManager :: PARAM_PUBLICATION, $this->publication_id);
        }
    }

    function get_application()
    {
        return WeblcmsManager :: APPLICATION_NAME;
    }

    function get_assignment_information()
    {
        $assignment_block = new WeblcmsAssignmentInformationReportingBlock($this);
        return $assignment_block;
    }

    function get_assignment_users()
    {
        $assignment_submissions_block = new WeblcmsAssignmentUsersReportingBlock($this);
        $assignment_submissions_block->set_sorting(2, SORT_DESC);
        return $assignment_submissions_block;
    }

    function get_assignment_course_groups()
    {
        $assignment_submissions_block = new WeblcmsAssignmentCourseGroupsReportingBlock($this);
        $assignment_submissions_block->set_sorting(2, SORT_DESC);
        return $assignment_submissions_block;
    }

    function get_assignment_groups()
    {
        $assignment_submissions_block = new WeblcmsAssignmentPlatformGroupsReportingBlock($this);
        $assignment_submissions_block->set_sorting(2, SORT_DESC);
        return $assignment_submissions_block;
    }
}

?>