<?php
namespace application\weblcms;

use application\weblcms\tool\learning_path\LearningPathTool;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Request;
use common\libraries\Utilities;
use reporting\Reporting;
use reporting\ReportingManager;
use reporting\ReportingTemplate;
use repository\content_object\learning_path;
use repository\content_object\learning_path\LearningPathComplexDisplay;
use user\UserDataManager;

/**
 * $Id: learning_path_attempt_progress_reporting_template.class.php 216
 * 2009-11-13 14:08:06Z kariboe $
 *
 * @package application.lib.weblcms.reporting.templates
 */

/**
 * This template shows an overview of the progress in a learning path of a user.
 * If this template is viewed from the reporting tool, it adds an extra block with some information about the learning path.
 * 
 * @author Michael Kyndt
 * @author Bert De Clercq (Hogeschool Gent)
 */
class LearningPathAttemptProgressReportingTemplate extends ReportingTemplate
{

    function __construct($parent)
    {
        parent :: __construct($parent);
        $this->initialize_parameters();
        
        if ($this->tool == 'reporting')
        {
            $weblcms_data_manager = WeblcmsDataManager :: get_instance();
            $lp = $weblcms_data_manager->retrieve_content_object_publication($this->publication_id)->get_content_object();
        
            $params = array();
            $params[ReportingManager :: PARAM_TEMPLATE_ID] = Reporting :: get_name_registration(
                    Utilities :: camelcase_to_underscores('LearningPathAttemptsReportingTemplate'),
                    WeblcmsManager :: APPLICATION_NAME)->get_id();
            $params[WeblcmsManager :: PARAM_USERS] = null;
            $params[LearningPathTool :: PARAM_ATTEMPT_ID] = null;
            
            $custom_breadcrumbs = array();
            $custom_breadcrumbs[] = new Breadcrumb($this->get_url($params), $lp->get_title());
            
            if ($this->user_id)
            {
                $user_data_manager = UserDataManager :: get_instance();
                $user = $user_data_manager->retrieve_user($this->user_id);

                $custom_breadcrumbs[] = new Breadcrumb($this->get_url(), $user->get_fullname());
            }
            
            $this->set_custom_breadcrumb_trail($custom_breadcrumbs);
            
            $this->add_reporting_block($this->get_learning_path_progress_information());
        }
        
        $this->add_reporting_block($this->get_learning_path_progress());
    }

    function display_context()
    {
    
    }

    function get_application()
    {
        return WeblcmsManager :: APPLICATION_NAME;
    }

    private function initialize_parameters()
    {
        $this->publication_id = Request :: get(WeblcmsManager :: PARAM_PUBLICATION);
        $this->user_id = Request :: get(WeblcmsManager :: PARAM_USERS);
        $this->tool = Request :: get(WeblcmsManager :: PARAM_TOOL);
        $course_id = Request :: get(WeblcmsManager :: PARAM_COURSE);
        if ($course_id)
        {
            $this->set_parameter(WeblcmsManager :: PARAM_COURSE, $course_id);
        }
        
        $this->set_parameter(WeblcmsManager :: PARAM_TOOL, $this->tool);
        $this->set_parameter(WeblcmsManager :: PARAM_USERS, $this->user_id);
        $this->set_parameter(Tool :: PARAM_PUBLICATION_ID, $this->publication_id);
        
        $attempt_id = Request :: get(LearningPathTool :: PARAM_ATTEMPT_ID);
        if ($attempt_id)
        {
            $this->set_parameter(LearningPathTool :: PARAM_ATTEMPT_ID, $attempt_id);
        }
        else
        {
            $this->set_parameter(LearningPathComplexDisplay :: PARAM_SHOW_PROGRESS, 'true');
        }
    }

    function get_learning_path_progress()
    {
        $course_weblcms_block = new WeblcmsLearningPathAttemptProgressReportingBlock($this);
        return $course_weblcms_block;
    }

    function get_learning_path_progress_information()
    {
        $course_weblcms_block = new WeblcmsLearningPathAttemptProgressInformationReportingBlock($this);
        return $course_weblcms_block;
    }
}
?>