<?php

namespace application\weblcms;

use common\libraries\Request;
use reporting\ReportingTemplate;
use common\libraries\Breadcrumb;
use common\libraries\Translation;
use user\UserDataManager;
use group\GroupDataManager;
use reporting\Reporting;
use common\libraries\Utilities;
use reporting\ReportingManager;
use common\libraries\EqualityCondition;
use common\libraries\AndCondition;
use common\libraries\ObjectTableOrder;
use repository\content_object\learning_path\LearningPath;

/**
 *
 * @package application.weblcms.php.reporting.templates
 *         
 *          Reporting template with an overview of the progress of each learning
 *          path per user
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 */
class LearningPathProgressReportingTemplate extends ReportingTemplate
{

    function __construct($parent)
    {
        parent :: __construct($parent);
        
        $this->course_id = Request :: get(WeblcmsManager :: PARAM_COURSE);
        $this->set_parameter(WeblcmsManager :: PARAM_COURSE, $this->course_id);
        
        $custom_breadcrumbs = array();
        $custom_breadcrumbs[] = new Breadcrumb($this->get_url(), Translation :: get('LearningPathProgress'));
        $this->set_custom_breadcrumb_trail($custom_breadcrumbs);
        
        // learning path titles for tooltips
        $weblcms_data_manager = WeblcmsDataManager :: get_instance();
        $conditions = array();
        $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_COURSE_ID, $this->course_id);
        $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_TOOL, LearningPath :: get_type_name());
        $condition = new AndCondition($conditions);
        $order_by = new ObjectTableOrder(ContentObjectPublication :: PROPERTY_MODIFIED_DATE, SORT_DESC);
        $publications = $weblcms_data_manager->retrieve_content_object_publications($condition, $order_by);
        
        while ($publication = $publications->next_result())
        {
            $this->th_titles[] = $publication->get_content_object()->get_title();
        }
        
        $this->add_reporting_block($this->get_learning_path_progress_users());
    }

    function display_context()
    {
    
    }

    function get_application()
    {
        return WeblcmsManager :: APPLICATION_NAME;
    }

    function get_learning_path_progress_users()
    {
        $lp_block = new WeblcmsLearningPathProgressUsersReportingBlock($this, true);
        $lp_block->set_sorting(0);
        
        $legend[] = 'X : ' . Translation :: get('NotPublishedForUser') . '<br />';
        $legend[] = '- : ' . Translation :: get('NotAttemptedByUser') . '<br />';
        $lp_block->set_legend($legend);
        
        return $lp_block;
    }

}

?>