<?php
namespace application\weblcms;

use user\VisitTracker;
use common\libraries\DatetimeUtilities;
use user\UserDataManager;
use common\libraries\ObjectTableOrder;
use common\libraries\Path;
use common\libraries\Translation;
use common\libraries\PlatformSetting;

abstract class WeblcmsCourseReportingBlock extends WeblcmsReportingBlock
{
    const SCORE_TYPE_AVG = 1;
    const SCORE_TYPE_MIN = 2;
    const SCORE_TYPE_MAX = 3;
    const SCORE_TYPE_FIRST = 4;
    const SCORE_TYPE_LAST = 5;

    function get_course_id()
    {
        return $this->get_parent()->get_parameter(WeblcmsManager :: PARAM_COURSE);
    }

    static function get_total_time($trackerdata)
    {
        foreach ($trackerdata as $key => $value)
        {
            $time += $value->get_leave_date() - $value->get_enter_date();
        }

        $time = mktime(0, 0, $time, 0, 0, 0);
        $time = date('G:i:s', $time);
        return $time;
    }

    public static function visit_tracker_to_array($condition, $user, $order_by)
    {
        $tracker = new VisitTracker();
        $udm = UserDataManager :: get_instance();

        if (! $order_by)
        {
            $order_by = new ObjectTableOrder(VisitTracker :: PROPERTY_ENTER_DATE, SORT_DESC);
        }
        $trackerdata = $tracker->retrieve_tracker_items_result_set($condition, null, null, $order_by);

        while ($visittracker = $trackerdata->next_result())
        {
            if (! $user)
            {
                $user = $udm->retrieve_user($visittracker->get_user_id());
                $arr[Translation :: get('User', null, 'user')][] = $user->get_fullname();
                $user = null;
            }
            else
            {
                $arr[Translation :: get('User', null, 'user')][] = $user->get_fullname();
            }

            $arr[Translation :: get('LastAccess')][] = DatetimeUtilities :: format_locale_date(null, $visittracker->get_enter_date());
            $time = $visittracker->get_leave_date() - $visittracker->get_enter_date();
            $time = mktime(0, 0, $time, 0, 0, 0);
            $time = date('G:i:s', $time);
            $arr[Translation :: get('TotalTime')][] = $time;
        }

        return $arr;
    }

    function get_score_bar($score)
    {
        if ($score < PlatformSetting :: get('passing_percentage'))
        {
            $color = 'lightcoral';
        }
        else
        {
            $color = 'lightgreen';
        }

        $html[] = '<div style="position: relative; border: 1px solid black; height: 14px; width:100px;">';
        $html[] = '<div style="background-color: ' . $color . '; height: 14px; width:' . round($score) . 'px; text-align: center;">';
        $html[] = '</div>';
        $html[] = '<div style="width: 100px; text-align: center; position: absolute; top: 0px;">' . round($score) . '%</div></div>';

        return implode("\n", $html);
    }

    function get_progress_bar($progress)
    {
        if ($progress == 100)
        {
            $color = 'lightgreen';
        }
        else
        {
            $color = 'lightblue';
        }

        $html[] = '<div style="position: relative; border: 1px solid black; height: 14px; width:100px;">';
        $html[] = '<div style="background-color: ' . $color . '; height: 14px; width:' . round($progress) . 'px; text-align: center;">';
        $html[] = '</div>';
        $html[] = '<div style="width: 100px; text-align: center; position: absolute; top: 0px;">' . round($progress) . '%</div></div>';

        return implode("\n", $html);
    }
}
?>