<?php
namespace application\weblcms;

use common\libraries\Utilities;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use tracking\SimpleTracker;
use repository\RepositoryDataManager;

/**
 *
 * @package application.lib.weblcms.trackers
 */

class WeblcmsAssignmentSubmissionsTracker extends SimpleTracker
{
    const CLASS_NAME = __CLASS__;
    
    const PROPERTY_PUBLICATION_ID = 'publication_id';
    const PROPERTY_CONTENT_OBJECT_ID = 'content_object_id';
    const PROPERTY_SUBMITTER_ID = 'submitter_id';
    const PROPERTY_DATE_SUBMITTED = 'date_submitted';
    const PROPERTY_SUBMITTER_TYPE = 'submitter_type';
    const PROPERTY_USER_ID = 'user_id';
    const PROPERTY_IP_ADDRESS = 'ip_address';
    const SUBMITTER_TYPE_USER = 0;
    const SUBMITTER_TYPE_COURSE_GROUP = 1;
    const SUBMITTER_TYPE_PLATFORM_GROUP = 2;

    /**
     * Inherited
     * 
     * @see MainTracker :: track()
     */
    function validate_parameters(array $parameters = array())
    {
        $this->set_publication_id($parameters[self :: PROPERTY_PUBLICATION_ID]);
        $this->set_content_object_id($parameters[self :: PROPERTY_CONTENT_OBJECT_ID]);
        $this->set_submitter_id($parameters[self :: PROPERTY_SUBMITTER_ID]);
        $this->set_date_submitted($parameters[self :: PROPERTY_DATE_SUBMITTED]);
        $this->set_submitter_type($parameters[self :: PROPERTY_SUBMITTER_TYPE]);
        $this->set_user_id($parameters[self :: PROPERTY_USER_ID]);
        $this->set_ip_address($parameters[self :: PROPERTY_IP_ADDRESS]);
    }

    /**
     * Inherited
     */
    static function get_default_property_names()
    {
        return parent :: get_default_property_names(array(self :: PROPERTY_PUBLICATION_ID, 
                self :: PROPERTY_CONTENT_OBJECT_ID, self :: PROPERTY_SUBMITTER_ID, self :: PROPERTY_DATE_SUBMITTED, 
                self :: PROPERTY_SUBMITTER_TYPE, self :: PROPERTY_USER_ID, self :: PROPERTY_IP_ADDRESS));
    }

    function get_publication_id()
    {
        return $this->get_default_property(self :: PROPERTY_PUBLICATION_ID);
    }

    function set_publication_id($publication_id)
    {
        $this->set_default_property(self :: PROPERTY_PUBLICATION_ID, $publication_id);
    }

    function get_content_object_id()
    {
        return $this->get_default_property(self :: PROPERTY_CONTENT_OBJECT_ID);
    }

    function set_content_object_id($content_object_id)
    {
        $this->set_default_property(self :: PROPERTY_CONTENT_OBJECT_ID, $content_object_id);
    }

    function get_submitter_id()
    {
        return $this->get_default_property(self :: PROPERTY_SUBMITTER_ID);
    }

    function set_submitter_id($submitter_id)
    {
        $this->set_default_property(self :: PROPERTY_SUBMITTER_ID, $submitter_id);
    }

    function get_date_submitted()
    {
        return $this->get_default_property(self :: PROPERTY_DATE_SUBMITTED);
    }

    function set_date_submitted($date_submitted)
    {
        $this->set_default_property(self :: PROPERTY_DATE_SUBMITTED, $date_submitted);
    }

    function get_submitter_type()
    {
        return $this->get_default_property(self :: PROPERTY_SUBMITTER_TYPE);
    }

    function set_submitter_type($submitter_type)
    {
        $this->set_default_property(self :: PROPERTY_SUBMITTER_TYPE, $submitter_type);
    }

    function get_user_id()
    {
        return $this->get_default_property(self :: PROPERTY_USER_ID);
    }

    function set_user_id($user_id)
    {
        $this->set_default_property(self :: PROPERTY_USER_ID, $user_id);
    }

    function get_ip_address()
    {
        return $this->get_default_property(self :: PROPERTY_IP_ADDRESS);
    }

    function set_ip_address($ip_address)
    {
        $this->set_default_property(self :: PROPERTY_IP_ADDRESS, $ip_address);
    }

    static function get_table_name()
    {
        return Utilities :: get_classname_from_namespace(self :: CLASS_NAME, true);
    }

    function get_content_object()
    {
        $repository_data_manager = RepositoryDataManager :: get_instance();
        return $repository_data_manager->retrieve_content_object($this->get_content_object_id());
    }
}
?>