<?php

namespace application\weblcms;

use common\libraries\Translation;
use common\libraries\CreateObjectWebserviceHandler;
use common\libraries\EqualityCondition;
use group\Group;
use group\GroupDataManager;

use application\weblcms\course\CourseDataManager;
use application\weblcms\course\CourseGroupRelation;
use application\weblcms\course\Course;

class CourseGroupRelationCreateWebserviceHandler extends CreateObjectWebserviceHandler
{

    function get_object()
    {
        return new CourseGroupRelation();
    }

    function get_object_translation()
    {
        return Translation :: get('CourseGroupRelation');
    }

    function manipulate_data($object, $extra_properties = null)
    {
        if ($extra_properties['course_code'])
        {
            $condition = new EqualityCondition(Course :: PROPERTY_VISUAL_CODE, $extra_properties['course_code']);
            $course = CourseDataManager :: get_instance()->retrieve_courses($condition)->next_result();
            if (! $course)
            {
                return false;
            }
            $object->set_course_id($course->get_id());
        }
        if ($extra_properties['group_code'])
        {
            $condition = new EqualityCondition(Group :: PROPERTY_CODE, $extra_properties['group_code']);
            $group = GroupDataManager :: get_instance()->retrieve_groups($condition)->next_result();
            if (! $group)
            {
                return false;
            }
            $object->set_group_id($group->get_id());
        }
        if (! $object->get_course_id() || ! $object->get_group_id())
        {
            return false;
        }
        return $object;
    }

    function default_properties_required()
    {
        return false;
    }

    function is_allowed_to_create_object($object)
    {
        if ($this->get_user()->is_platform_admin())
        {
            return true;
        }
        return WeblcmsDataManager :: get_instance()->is_course_admin($object->get_course_id(), $this->get_user_id());
    }

}

?>
