<?php
namespace application\weblcms\tool\assessment;

class Autoloader
{

    /**
     * The array mapping class names to paths
     *
     * @var multitype:string
     */
     private static $map = array(
         'Autoloader' => '/autoloader.class.php',
         'AssessmentTool' => '/lib/assessment_tool.class.php',
         'SurveyInvitation' => '/lib/survey_invitation.class.php',
         'AssessmentToolBrowserComponent' => '/lib/component/browser.class.php',
         'AssessmentToolCategoryManagerComponent' => '/lib/component/category_manager.class.php',
         'AssessmentToolCategoryMoverComponent' => '/lib/component/category_mover.class.php',
         'AssessmentToolComplexBuilderComponent' => '/lib/component/complex_builder.class.php',
         'AssessmentToolComplexDisplayComponent' => '/lib/component/complex_display.class.php',
         'AssessmentToolContentObjectUpdaterComponent' => '/lib/component/content_object_updater.class.php',
         'AssessmentToolDeleterComponent' => '/lib/component/deleter.class.php',
         'AssessmentToolDocumentSaverComponent' => '/lib/component/document_saver.class.php',
         'AssessmentToolHidePublicationComponent' => '/lib/component/hide_publication.class.php',
         'AssessmentToolIntroductionPublisherComponent' => '/lib/component/introduction_publisher.class.php',
         'AssessmentToolMoverComponent' => '/lib/component/mover.class.php',
         'AssessmentToolPublicationUpdaterComponent' => '/lib/component/publication_updater.class.php',
         'AssessmentToolPublisherComponent' => '/lib/component/publisher.class.php',
         'AssessmentToolQtiExporterComponent' => '/lib/component/qti_exporter.class.php',
         'AssessmentToolQtiImporterComponent' => '/lib/component/qti_importer.class.php',
         'AssessmentToolRawExportResultsComponent' => '/lib/component/raw_export_results.class.php',
         'AssessmentToolReportingViewerComponent' => '/lib/component/reporting_viewer.class.php',
         'AssessmentToolResultsDeleterComponent' => '/lib/component/results_deleter.class.php',
         'AssessmentToolResultsExportComponent' => '/lib/component/results_export.class.php',
         'AssessmentToolResultsViewerComponent' => '/lib/component/results_viewer.class.php',
         'AssessmentToolRightsEditorComponent' => '/lib/component/rights_editor.class.php',
         'AssessmentToolShareContentObjectsComponent' => '/lib/component/share_content_objects.class.php',
         'AssessmentToolShowPublicationComponent' => '/lib/component/show_publication.class.php',
         'AssessmentToolToggleVisibilityComponent' => '/lib/component/toggle_visibility.class.php',
         'AssessmentToolUpdaterComponent' => '/lib/component/updater.class.php',
         'AssessmentToolViewerComponent' => '/lib/component/viewer.class.php',
         'AssessmentCellRenderer' => '/lib/component/assessment_browser/assessment_cell_renderer.class.php',
         'AssessmentColumnModel' => '/lib/component/assessment_browser/assessment_column_model.class.php',
         'ResultsExport' => '/lib/component/assessment_results_export_form/export.class.php',
         'AssessmentResultsExportForm' => '/lib/component/assessment_results_export_form/results_export_form.class.php',
         'ResultsCsvExport' => '/lib/component/assessment_results_export_form/results_exporters/export_csv.class.php',
         'ResultsPdfExport' => '/lib/component/assessment_results_export_form/results_exporters/export_pdf.class.php',
         'ResultsXmlExport' => '/lib/component/assessment_results_export_form/results_exporters/export_xml.class.php',
         'AssessmentResultsTableDetail' => '/lib/component/assessment_results_table_admin/assessment_results_table_detail.class.php',
         'AssessmentResultsTableDetailCellRenderer' => '/lib/component/assessment_results_table_admin/assessment_results_table_detail_cell_renderer.class.php',
         'AssessmentResultsTableDetailColumnModel' => '/lib/component/assessment_results_table_admin/assessment_results_table_detail_column_model.class.php',
         'AssessmentResultsTableDetailDataProvider' => '/lib/component/assessment_results_table_admin/assessment_results_table_detail_data_provider.class.php',
         'AssessmentResultsTableOverviewAdmin' => '/lib/component/assessment_results_table_admin/assessment_results_table_overview.class.php',
         'AssessmentResultsTableOverviewAdminCellRenderer' => '/lib/component/assessment_results_table_admin/assessment_results_table_overview_cell_renderer.class.php',
         'AssessmentResultsTableOverviewAdminColumnModel' => '/lib/component/assessment_results_table_admin/assessment_results_table_overview_column_model.class.php',
         'AssessmentResultsTableOverviewAdminDataProvider' => '/lib/component/assessment_results_table_admin/assessment_results_table_overview_data_provider.class.php',
         'AssessmentResultsTableOverviewStudent' => '/lib/component/assessment_results_table_student/assessment_results_table_overview.class.php',
         'AssessmentResultsTableOverviewStudentCellRenderer' => '/lib/component/assessment_results_table_student/assessment_results_table_overview_cell_renderer.class.php',
         'AssessmentResultsTableOverviewStudentColumnModel' => '/lib/component/assessment_results_table_student/assessment_results_table_overview_column_model.class.php',
         'AssessmentResultsTableOverviewStudentDataProvider' => '/lib/component/assessment_results_table_student/assessment_results_table_overview_data_provider.class.php',
         'SurveyPublicationForm' => '/lib/component/assessment_survey_publisher/survey_publication_form.class.php',
         'SurveyPublicationViewer' => '/lib/component/assessment_survey_publisher/survey_publication_viewer.class.php',
         'SurveyPublisher' => '/lib/component/assessment_survey_publisher/survey_publisher.class.php',
         'SurveyPublisherComponent' => '/lib/component/assessment_survey_publisher/survey_publisher_component.class.php',
         'SurveyUserTable' => '/lib/component/assessment_survey_publisher/survey_user_table/survey_user_table.class.php',
         'SurveyUserTableCellRenderer' => '/lib/component/assessment_survey_publisher/survey_user_table/survey_user_table_cell_renderer.class.php',
         'SurveyUserTableColumnModel' => '/lib/component/assessment_survey_publisher/survey_user_table/survey_user_table_column_model.class.php',
         'SurveyUserTableDataProvider' => '/lib/component/assessment_survey_publisher/survey_user_table/survey_user_table_data_provider.class.php',
         'Activator' => '/package/activate/activator.class.php',
         'Deactivator' => '/package/deactivate/deactivator.class.php',
         'Installer' => '/package/install/installer.class.php'
    );

    /**
     * Try to load the class
     *
     * @param $classname string
     * @return boolean
     */
    static function load($classname)
    {
        if (isset(self :: $map[$classname]))
        {
            require_once __DIR__ . self :: $map[$classname];
            return true;
        }

        return false;
    }

    /**
     * Synchronize the autoloader
     *
     * @param $update boolean
     * @return multitype:string
     */
    static function synch($update)
    {
        return \common\libraries\AutoloaderUtilities :: synch(__DIR__, __DIR__, $update);
    }

}
?>