<?php
namespace application\weblcms\tool\assessment;

use application\weblcms\WeblcmsDataManager;
use application\weblcms\WeblcmsRights;
use application\weblcms\Tool;
use common\libraries\DatetimeUtilities;
use common\libraries\Toolbar;
use common\libraries\ToolbarItem;
use user\UserDataManager;
use common\libraries\Theme;
use common\libraries\Path;
use common\libraries\Translation;
use repository\DefaultContentObjectTableCellRenderer;
use application\weblcms\WeblcmsAssessmentAttemptsTracker;
use repository\content_object\hotpotatoes\Hotpotatoes;
use repository\content_object\assessment\Assessment;

/**
 * $Id: assessment_results_table_detail_cell_renderer.class.php 216 2009-11-13
 * 14:08:06Z kariboe $
 * 
 * @package
 *          application.lib.weblcms.tool.assessment.component.assessment_results_table_admin
 */

/**
 * This class is a cell renderer for a publication candidate table
 */
class AssessmentResultsTableDetailCellRenderer extends DefaultContentObjectTableCellRenderer
{
    private $table_actions;
    private $browser;
    private $table;

    /**
     * Constructor.
     * 
     * @param $publish_url_format string
     *            URL for publishing the selected
     *            learning object.
     * @param $edit_and_publish_url_format string
     *            URL for editing and publishing
     *            the selected learning object.
     */
    function __construct($browser, $table)
    {
        $this->table_actions = array();
        $this->browser = $browser;
        $this->table = $table;
    }
    
    /*
     * Inherited
     */
    function render_cell($column, $user_assessment)
    {
        
        if ($column === AssessmentResultsTableDetailColumnModel :: get_action_column())
        {
            return $this->get_actions($user_assessment);
        }
        else
        {
            switch ($column->get_name())
            {
                case Translation :: get(WeblcmsAssessmentAttemptsTracker :: PROPERTY_USER_ID) :
                    $user_id = $user_assessment->get_user_id();
                    if ($user_id > 0)
                        return UserDataManager :: get_instance()->retrieve_user($user_id)->get_fullname();
                    else
                        return 'Anonymous';
                case Translation :: get(WeblcmsAssessmentAttemptsTracker :: PROPERTY_TOTAL_SCORE) :
                    $total = $user_assessment->get_total_score();
                    // $pub = WeblcmsDataManager ::
                    // get_instance()->retrieve_content_object_publication($user_assessment->get_assessment_id());
                    // $assessment = $pub->get_content_object();
                    // $max = $assessment->get_maximum_score();
                    // $pct = round(($total / $max) * 100, 2);
                    // return $total.'/'.$max.' ('.$pct.'%)';
                    return $total . '%';
                case $this->table->get_start_date_column() :
                    return DatetimeUtilities :: format_locale_date(null, $user_assessment->get_date());
                case $this->table->get_end_date_column():
                    return DatetimeUtilities::format_locale_date(null, $user_assessment->get_date() + $user_assessment->get_total_time());
                default :
                    return '';
            }
        }
    }

    function get_actions($user_assessment)
    {
        $pub = WeblcmsDataManager :: get_instance()->retrieve_content_object_publication($user_assessment->get_assessment_id());
        $assessment = $pub->get_content_object();
        
        $toolbar = new Toolbar();
        
        if ($assessment->get_type() != Hotpotatoes :: TYPE_HOTPOTATOES)
        {
            $toolbar->add_item(new ToolbarItem(Translation :: get('ViewResults'), Theme :: get_common_image_path() . 'action_view_results.png', $this->browser->get_url(array(
                    Tool :: PARAM_ACTION => AssessmentTool :: ACTION_VIEW_RESULTS, 
                    AssessmentTool :: PARAM_USER_ASSESSMENT => $user_assessment->get_id())), ToolbarItem :: DISPLAY_ICON));
            
            // $toolbar->add_item(new ToolbarItem(Translation ::
        // get('ExportResults'), Theme :: get_common_image_path() .
        // 'action_export.png', $this->browser->get_url(array(Tool ::
        // PARAM_ACTION => AssessmentTool :: ACTION_EXPORT_RESULTS,
        // AssessmentTool :: PARAM_USER_ASSESSMENT =>
        // $user_assessment->get_id())), ToolbarItem :: DISPLAY_ICON));
        }
        else
        {
            $toolbar->add_item(new ToolbarItem(Translation :: get('ViewResultsNA'), Theme :: get_common_image_path() . 'action_view_results_na.png', null, ToolbarItem :: DISPLAY_ICON));
            
            // $toolbar->add_item(new ToolbarItem(Translation ::
        // get('ExportResultsNA'), Theme :: get_common_image_path() .
        // 'action_export_na.png', null, ToolbarItem :: DISPLAY_ICON));
        }
        
        if ($this->browser->is_allowed(WeblcmsRights :: DELETE_RIGHT))
        {
            $toolbar->add_item(new ToolbarItem(Translation :: get('DeleteResult'), Theme :: get_common_image_path() . 'action_delete.png', $this->browser->get_url(array(
                    Tool :: PARAM_ACTION => AssessmentTool :: ACTION_DELETE_RESULTS, 
                    AssessmentTool :: PARAM_USER_ASSESSMENT => $user_assessment->get_id())), ToolbarItem :: DISPLAY_ICON, true));
        }
        return $toolbar->as_html();
    }

    /**
     * Gets the links to publish or edit and publish a learning object.
     * 
     * @param $content_object ContentObject
     *            The learning object for which the
     *            links should be returned.
     * @return string A HTML-representation of the links.
     */
    private function get_publish_links($content_object)
    {
        $toolbar = new Toolbar();
        // $toolbar_data = array();
        $table_actions = $this->table_actions;
        
        foreach ($table_actions as $table_action)
        {
            // $table_action['href'] = sprintf($table_action['href'],
            // $content_object->get_id());
            $toolbar->add_item(new ToolbarItem(null, null, sprintf($table_action['href'], $content_object->get_id())));
            
            // $toolbar_data[] = $table_action;
        }
        
        return $toolbar->as_html();
    }
}
?>