<?php
namespace application\weblcms\tool\assessment;

use application\weblcms\ContentObjectPublicationCategoryTree;
use application\weblcms\tool\reporting\ReportingTool;
use application\weblcms\Tool;
use application\weblcms\WeblcmsAssessmentAttemptsTracker;
use application\weblcms\WeblcmsDataManager;
use application\weblcms\WeblcmsQuestionAttemptsTracker;
use application\weblcms\WeblcmsRights;
use application\weblcms\WeblcmsManager;
use common\libraries\ActionBarRenderer;
use common\libraries\AndCondition;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Display;
use common\libraries\EqualityCondition;
use common\libraries\Path;
use common\libraries\Request;
use common\libraries\Theme;
use common\libraries\ToolbarItem;
use common\libraries\Translation;
use common\libraries\Utilities;
use reporting\Reporting;
use reporting\ReportingManager;
use repository\ComplexDisplay;

/**
 * $Id: assessment_results_viewer.class.php 216 2009-11-13 14:08:06Z kariboe $
 * 
 * @package application.lib.weblcms.tool.assessment.component
 */
class AssessmentToolResultsViewerComponent extends AssessmentTool
{
    private $object;

    function run()
    {
        if (Request :: get(AssessmentTool :: PARAM_USER_ASSESSMENT))
        {
            $this->view_single_result();
        }
        elseif (Request :: get(AssessmentTool :: PARAM_ASSESSMENT))
        {
            $this->view_assessment_results();
        }
        else
        {
            $this->view_all_results();
        }
    
    }

    function view_all_results()
    {
        $crumbs[] = new Breadcrumb($this->get_url(array(
                AssessmentTool :: PARAM_ACTION => AssessmentTool :: ACTION_VIEW_RESULTS)), Translation :: get('ViewResults'));
        
        $visible = $this->display_header();
        if (! $visible)
        {
            return;
        }
        
        $tree_id = WeblcmsManager :: PARAM_CATEGORY;
        $params = array(AssessmentTool :: PARAM_ACTION => AssessmentTool :: ACTION_VIEW_RESULTS);
        $tree = new ContentObjectPublicationCategoryTree($this, $tree_id, $params);
        $this->set_parameter($tree_id, Request :: get($tree_id));
        echo '<div style="width:18%; float: left; overflow: auto;">';
        echo $tree->as_html();
        echo '</div>';
        echo '<div style="width:80%; padding-left: 1%; float:right; ">';
        
        if ($this->is_allowed(WeblcmsRights :: EDIT_RIGHT))
        {
            $table = new AssessmentResultsTableOverviewAdmin($this, $this->get_user());
        }
        else
        {
            $table = new AssessmentResultsTableOverviewStudent($this, $this->get_user());
        }
        
        echo $table->as_html();
        echo '</div>';
        $this->display_footer();
    }

    function view_assessment_results()
    {
        $pid = Request :: get(AssessmentTool :: PARAM_ASSESSMENT);
        
        $publication = WeblcmsDataManager :: get_instance()->retrieve_content_object_publication($pid);
        $assessment = $publication->get_content_object();
        
        $this->add_assessment_title_breadcrumb($assessment);
        
        if (! $this->is_allowed(WeblcmsRights :: VIEW_RIGHT, $publication))
        {
            $this->redirect(Translation :: get("NotAllowed", null, Utilities :: COMMON_LIBRARIES), true, array(), array(
                    Tool :: PARAM_ACTION, AssessmentTool :: PARAM_ASSESSMENT));
        }
        
        $visible = $this->display_header();
        if (! $visible)
        {
            return;
        }
        
        echo '<div class="content_object" style="background-image: url(' . Theme :: get_common_image_path() . 'content_object/assessment.png);">';
        echo '<div class="title">';
        echo $assessment->get_title();
        echo '</div>';
        echo $assessment->get_description();
        echo '<div class="title">';
        echo Translation :: get('Statistics');
        echo '</div>';
        $track = new WeblcmsAssessmentAttemptsTracker();
        
        if (! $this->is_allowed(WeblcmsRights :: EDIT_RIGHT))
        {
            $usr = $this->get_user_id();
        }
        
        $avg = $track->get_average_score($publication, $usr);
        if (! isset($avg))
        {
            $avg_line = 'No results';
        }
        else
        {
            $avg_line = $avg . '%';
        }
        echo Translation :: get('AverageScore') . ': ' . $avg_line;
        echo '<br/>' . Translation :: get('TimesTaken') . ': ' . $track->get_times_taken($publication, $usr);
        echo '</div>';
        $table = new AssessmentResultsTableDetail($this, $this->get_user(), Request :: get(AssessmentTool :: PARAM_ASSESSMENT));
        echo $table->as_html();
        
        $this->display_footer();
    }
    
    private $user_assessment;

    function view_single_result()
    {
        $uaid = Request :: get(AssessmentTool :: PARAM_USER_ASSESSMENT);
        
        $track = new WeblcmsAssessmentAttemptsTracker();
        $condition = new EqualityCondition(WeblcmsAssessmentAttemptsTracker :: PROPERTY_ID, $uaid);
        $user_assessments = $track->retrieve_tracker_items($condition);
        $this->user_assessment = $user_assessments[0];
        
        $publication = WeblcmsDataManager :: get_instance()->retrieve_content_object_publication($this->user_assessment->get_assessment_id());
        if (! $this->is_allowed(WeblcmsRights :: VIEW_RIGHT, $publication) || (! $this->is_allowed(WeblcmsRights :: EDIT_RIGHT) && $this->get_user_id() != $this->user_assessment->get_user_id()))
        {
            $this->redirect(Translation :: get("NotAllowed", null, Utilities :: COMMON_LIBRARIES), true, array(), array(
                    Tool :: PARAM_ACTION, AssessmentTool :: PARAM_ASSESSMENT, AssessmentTool :: PARAM_USER_ASSESSMENT));
        }
        $assessment = $publication->get_content_object();
        
        $this->add_assessment_title_breadcrumb($assessment);
        
        $_GET['display_action'] = AssessmentTool :: ACTION_VIEW_RESULTS;
        
        $this->set_parameter('uaid', $uaid);
        
        $this->object = $assessment;
        ComplexDisplay :: launch($assessment->get_type(), $this);
    }

    function retrieve_assessment_results()
    {
        $condition = new EqualityCondition(WeblcmsQuestionAttemptsTracker :: PROPERTY_ASSESSMENT_ATTEMPT_ID, $this->user_assessment->get_id());
        
        $dummy = new WeblcmsQuestionAttemptsTracker();
        $trackers = $dummy->retrieve_tracker_items($condition);
        
        $results = array();
        
        foreach ($trackers as $tracker)
        {
            $results[$tracker->get_question_cid()] = array('answer' => $tracker->get_answer(), 
                    'feedback' => $tracker->get_feedback(), 'score' => $tracker->get_score());
        }
        
        return $results;
    }

    function change_answer_data($question_cid, $score, $feedback)
    {
        $conditions[] = new EqualityCondition(WeblcmsQuestionAttemptsTracker :: PROPERTY_ASSESSMENT_ATTEMPT_ID, $this->user_assessment->get_id());
        $conditions[] = new EqualityCondition(WeblcmsQuestionAttemptsTracker :: PROPERTY_QUESTION_CID, $question_cid);
        $condition = new AndCondition($conditions);
        
        $dummy = new WeblcmsQuestionAttemptsTracker();
        $trackers = $dummy->retrieve_tracker_items($condition);
        $tracker = $trackers[0];
        $tracker->set_score($score);
        $tracker->set_feedback($feedback);
        $tracker->update();
    }

    function change_total_score($total_score)
    {
        $this->user_assessment->set_total_score($total_score);
        $this->user_assessment->update();
    }

    function can_change_answer_data()
    {
        return $this->is_allowed(WeblcmsRights :: EDIT_RIGHT);
    }

    function display_header($breadcrumbs = array())
    {
        // $trail = BreadcrumbTrail :: get_instance();
        // foreach ($breadcrumbs as $breadcrumb)
        // {
        // $trail->add($breadcrumb);
        // }
        parent :: display_header();
        
        $this->action_bar = $this->get_toolbar();
        if ($this->action_bar)
        {
            echo $this->action_bar->as_html();
        }
        
        return true;
    }

    function get_toolbar()
    {
        if (Request :: get(AssessmentTool :: PARAM_USER_ASSESSMENT))
        {
        }
        elseif (Request :: get(AssessmentTool :: PARAM_ASSESSMENT) && $this->is_allowed(WeblcmsRights :: EDIT_RIGHT))
        {
            $action_bar = new ActionBarRenderer(ActionBarRenderer :: TYPE_HORIZONTAL);
            
            $aid = Request :: get(AssessmentTool :: PARAM_ASSESSMENT);
            $action_bar->add_common_action(new ToolbarItem(Translation :: get('DownloadDocuments'), Theme :: get_common_image_path() . 'action_download.png', $this->get_url(array(
                    Tool :: PARAM_ACTION => AssessmentTool :: ACTION_SAVE_DOCUMENTS, 
                    AssessmentTool :: PARAM_ASSESSMENT => $aid)), ToolbarItem :: DISPLAY_ICON_AND_LABEL));
            $action_bar->add_common_action(new ToolbarItem(Translation :: get('DeleteAllResults'), Theme :: get_common_image_path() . 'action_delete.png', $this->get_url(array(
                    Tool :: PARAM_ACTION => AssessmentTool :: ACTION_DELETE_RESULTS, 
                    AssessmentTool :: PARAM_ASSESSMENT => $aid)), ToolbarItem :: DISPLAY_ICON_AND_LABEL, true));
            $action_bar->add_common_action(new ToolbarItem(Translation :: get('RawExportResults'), Theme :: get_common_image_path() . 'action_export.png', $this->get_url(array(
                    Tool :: PARAM_ACTION => AssessmentTool :: ACTION_RAW_EXPORT_RESULTS, 
                    AssessmentTool :: PARAM_ASSESSMENT => Request :: get(AssessmentTool :: PARAM_ASSESSMENT))), ToolbarItem :: DISPLAY_ICON_AND_LABEL));
            $action_bar->add_tool_action(new ToolbarItem(Translation :: get('AdditionalReporting'), Theme :: get_common_image_path() . 'action_statistics.png', $this->get_url(array(
                    WeblcmsManager :: PARAM_TOOL => WeblcmsManager :: ACTION_REPORTING, 
                    WeblcmsManager :: PARAM_TOOL_ACTION => ReportingTool :: ACTION_VIEW, 
                    ReportingManager :: PARAM_TEMPLATE_ID => Reporting :: get_name_registration(Utilities :: camelcase_to_underscores('AssessmentAttemptsReportingTemplate'), WeblcmsManager :: APPLICATION_NAME)->get_id(), 
                    WeblcmsManager :: PARAM_PUBLICATION => Request :: get(AssessmentTool :: PARAM_ASSESSMENT))), ToolbarItem :: DISPLAY_ICON_AND_LABEL));
        }
        elseif ($this->is_allowed(WeblcmsRights :: EDIT_RIGHT))
        {
            $action_bar = new ActionBarRenderer(ActionBarRenderer :: TYPE_HORIZONTAL);
            $action_bar->add_tool_action(new ToolbarItem(Translation :: get('AdditionalReporting'), Theme :: get_common_image_path() . 'action_statistics.png', $this->get_url(array(
                    WeblcmsManager :: PARAM_TOOL => WeblcmsManager :: ACTION_REPORTING, 
                    WeblcmsManager :: PARAM_TOOL_ACTION => ReportingTool :: ACTION_VIEW)), ToolbarItem :: DISPLAY_ICON_AND_LABEL));
        }
        return $action_bar;
    }

    function get_root_content_object()
    {
        return $this->object;
    }

    function get_assessment_parameters()
    {
        return array();
    }

    function get_additional_parameters()
    {
        return array(AssessmentTool :: PARAM_ASSESSMENT);
    }

    /**
     * Modifies the last breadcrumb with the view result text.
     * 
     * @return BreadcrumbTrail The modified breadcrumb trail
     */
    protected function modify_view_result_breadcrumb()
    {
        $breadcrumb_trail = BreadcrumbTrail :: get_instance();
        $breadcrumbs = $breadcrumb_trail->get_breadcrumbs();
        
        $breadcrumbs[$breadcrumb_trail->size() - 1] = new Breadcrumb($this->get_url(array(
                AssessmentTool :: PARAM_ACTION => AssessmentTool :: ACTION_VIEW_RESULTS), array(
                AssessmentTool :: PARAM_ASSESSMENT)), Translation :: get('ViewResults'));
        
        $breadcrumb_trail->set_breadcrumbtrail($breadcrumbs);
        
        return $breadcrumb_trail;
    }

    /**
     * Add a breadcrumb with the title of the assessment
     * 
     * @param $assessment Assessment           
     */
    protected function add_assessment_title_breadcrumb($assessment)
    {
        $breadcrumb_trail = $this->modify_view_result_breadcrumb();
        
        $breadcrumb_trail->add(new Breadcrumb($this->get_url(array(
                AssessmentTool :: PARAM_ACTION => AssessmentTool :: ACTION_VIEW_RESULTS)), $assessment->get_title()));
    }
}
?>
