<?php
namespace application\weblcms\tool\assignment;

use application\weblcms\ContentObjectPublicationListRenderer;
use application\weblcms\Tool;
use application\weblcms\WeblcmsAssignmentSubmissionsTracker;
use common\libraries\Categorizable;
use common\libraries\Theme;
use common\libraries\ToolbarItem;
use common\libraries\Translation;
use repository\content_object\assignment\Assignment;

/**
 *
 * @package application.weblcms.tool.assignment.php
 *         
 *          This tool allows a user to publish assignments in his or her course
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 * @author Bert De Clercq (Hogeschool Gent)
 * @author Anthony Hurst (Hogeschool Gent)
 */
class AssignmentTool extends Tool implements Categorizable
{
    
    // Browse actions
    const ACTION_BROWSE_SUBMISSIONS = 'submissions_browser';
    const ACTION_BROWSE_SUBMITTERS = 'submitters_browser';
    const ACTION_STUDENT_BROWSE_SUBMISSIONS = 'student_submissions_browser';
    // Submission actions
    const ACTION_DELETE_SUBMISSION = 'submission_deleter';
    const ACTION_DOWNLOAD_SUBMISSIONS = 'submissions_downloader';
    const ACTION_SUBMIT_SUBMISSION = 'submission_submit';
    const ACTION_VIEW_SUBMISSION = 'submission_viewer';
    // Feedback actions
    const ACTION_DELETE_FEEDBACK = 'feedback_deleter';
    const ACTION_EDIT_FEEDBACK = 'feedback_updater';
    const ACTION_GIVE_FEEDBACK = 'submission_feedback';
    // Parameters
    const PARAM_ATTACHMENT_TYPE = 'attachment_type';
    const PARAM_FEEDBACK_ID = 'feedback_id';
    const PARAM_SUBMISSION = 'submission';
    const PARAM_SUBMITTER_TYPE = 'submitter_type';
    const PARAM_TARGET_ID = 'target_id';
    const PARAM_TYPE = 'type';
    // Properties
    const PROPERTY_DATE_SUBMITTED = 'DateSubmitted';
    const PROPERTY_DESCRIPTION = 'Description';
    const PROPERTY_FIRST_SUBMISSION = 'FirstSubmissionDate';
    const PROPERTY_GROUP_MEMBERS = 'GroupMembers';
    const PROPERTY_LAST_SUBMISSION = 'LastSubmissionDate';
    const PROPERTY_NAME = 'Name';
    const PROPERTY_NUMBER_OF_SUBMISSIONS = 'NumberOfSubmissions';
    const PROPERTY_NUMBER_OF_FEEDBACKS = 'NumberOfFeedbacks';
    const PROPERTY_SCORE = 'Score';
    const PROPERTY_TITLE = 'Title';

    function get_available_browser_types()
    {
        $browser_types = array();
        $browser_types[] = ContentObjectPublicationListRenderer :: TYPE_TABLE;
        $browser_types[] = ContentObjectPublicationListRenderer :: TYPE_LIST;
        $browser_types[] = ContentObjectPublicationListRenderer :: TYPE_CALENDAR;
        return $browser_types;
    }

    static function get_allowed_types()
    {
        return array(Assignment :: get_type_name());
    }

    function get_application_component_path()
    {
        return dirname(__FILE__) . '/component/';
    }

    /**
     * Helper function for the SubManager class,
     * pending access to class constants via variables in PHP 5.3
     * e.g.
     * $name = $class :: DEFAULT_ACTION
     *
     * DO NOT USE IN THIS SUBMANAGER'S CONTEXT
     * Instead use:
     * - self :: DEFAULT_ACTION in the context of this class
     * - YourSubManager :: DEFAULT_ACTION in all other application classes
     */
    static function get_default_action()
    {
        return self :: DEFAULT_ACTION;
    }

    /**
     * Helper function for the SubManager class,
     * pending access to class constants via variables in PHP 5.3
     * e.g.
     * $name = $class :: PARAM_ACTION
     *
     * DO NOT USE IN THIS SUBMANAGER'S CONTEXT
     * Instead use:
     * - self :: PARAM_ACTION in the context of this class
     * - YourSubManager :: PARAM_ACTION in all other application classes
     */
    static function get_action_parameter()
    {
        return self :: PARAM_ACTION;
    }

    /**
     * Adds extra actions to the toolbar in different components
     * 
     * @param $toolbar Toolbar           
     * @param $publication Publication           
     * @return Toolbar
     */
    function add_content_object_publication_actions($toolbar, $publication)
    {
        $toolbar->add_item(new ToolbarItem(Translation :: get('BrowseSubmitters'), Theme :: get_common_image_path() . 'action_browser.png', $this->get_url(array(
                Tool :: PARAM_ACTION => AssignmentTool :: ACTION_BROWSE_SUBMITTERS, 
                Tool :: PARAM_PUBLICATION_ID => $publication->get_id())), ToolbarItem :: DISPLAY_ICON));
        $toolbar->add_item(new ToolbarItem(Translation :: get('SubmissionSubmit'), Theme :: get_common_image_path() . 'action_add.png', $this->get_url(array(
                Tool :: PARAM_ACTION => AssignmentTool :: ACTION_SUBMIT_SUBMISSION, 
                Tool :: PARAM_PUBLICATION_ID => $publication->get_id(), self :: PARAM_TARGET_ID => $this->get_user_id(), 
                self :: PARAM_SUBMITTER_TYPE => WeblcmsAssignmentSubmissionsTracker :: SUBMITTER_TYPE_USER)), ToolbarItem :: DISPLAY_ICON));
        return $toolbar;
    }

}

?>