<?php
namespace application\weblcms\tool\assignment;

use application\weblcms\ObjectPublicationTableCellRenderer;
use application\weblcms\ObjectPublicationTableColumnModel;
use application\weblcms\Tool;
use application\weblcms\WeblcmsAssignmentSubmissionsTracker;
use application\weblcms\WeblcmsManager;
use application\weblcms\WeblcmsRights;
use common\libraries\DatetimeUtilities;
use common\libraries\EqualityCondition;
use common\libraries\Theme;
use common\libraries\ToolbarItem;
use common\libraries\Translation;
use common\libraries\Utilities;
use repository\ContentObject;
use repository\content_object\assignment\Assignment;

/**
 * $Id: assessment_cell_renderer.class.php 216 2009-11-13 14:08:06Z kariboe $
 * 
 * @package application.lib.weblcms.tool.assessment.component.assessment_browser
 */

/**
 * This class is a cell renderer for a publication candidate table
 * 
 * @author Anthony Hurst (Hogeschool Gent)
 */
class AssignmentCellRenderer extends ObjectPublicationTableCellRenderer
{
    private $browser;
    /*
     * Inherited
     */
    /*function __construct($tool_browser, $browser)
    {
        parent::__construct($tool_browser);
        $this->browser = $browser;
    }*/
    
    function set_browser($browser)
    {
        $this->browser = $browser;
    }

    /**
     * Defines the contents of a cell in relation to the given column and the
     * given publication.
     * 
     * @param $column type
     *            The column for which information is wanted.
     * @param $publication type
     *            The publication for which information is wanted.
     * @return string The content of the cell related to both the $column and
     *         the $publication.
     */
    function render_cell($column, $publication)
    {
        if ($column === ObjectPublicationTableColumnModel :: get_action_column())
        {
            return $this->get_actions($publication)->as_html();
        }
        
        switch ($column->get_name())
        {
            case ContentObject :: PROPERTY_TITLE :
                return $this->generate_title_link($publication);
            case Assignment :: PROPERTY_END_TIME :
                $time = $publication->get_content_object()->get_end_time();
                $date_format = Translation :: get('DateTimeFormatLong', null, Utilities :: COMMON_LIBRARIES);
                $time = DatetimeUtilities :: format_locale_date($date_format, $time);
                if ($publication->is_hidden())
                {
                    return '<span style="color: gray">' . $time . '</span>';
                }
                return $time;
            case AssignmentTool :: PROPERTY_NUMBER_OF_SUBMISSIONS :
                $tracker = new WeblcmsAssignmentSubmissionsTracker();
                $condition = new EqualityCondition(WeblcmsAssignmentSubmissionsTracker :: PROPERTY_PUBLICATION_ID, $publication->get_id());
                return $tracker->count_tracker_items($condition);
            case Assignment :: PROPERTY_ALLOW_GROUP_SUBMISSIONS :
                if ($publication->get_content_object()->get_allow_group_submissions())
                {
                    return '<img src="' . Theme :: get_image_path() . 'type/group.png" alt="' . Translation :: get('GroupAssignment') . '" title="' . Translation :: get('GroupAssignment') . '"/>';
                }
                return '<img src="' . Theme :: get_image_path() . 'type/individual.png" alt="' . Translation :: get('IndividualAssignment') . '" title="' . Translation :: get('IndividualAssignment') . '"/>';
        }
        return parent :: render_cell($column, $publication);
    }

    /**
     * Generated the HTML for the title column, including link, depending on the
     * status of the current browsing user.
     * 
     * @param $publication type
     *            The publication for which the title link is to be generated.
     * @return string The HTML for the link in the title column.
     */
    private function generate_title_link($publication)
    {
        if ($this->browser->is_allowed(WeblcmsRights :: EDIT_RIGHT))
        {
            return $this->generate_teacher_title_link($publication);
        }
        return $this->generate_student_title_link($publication);
    }

    /**
     * Generates the link applicable for the current browsing user being a
     * teacher or admin.
     * 
     * @param $publication type
     *            The publication for which the link is being generated.
     * @return string The HTML anchor elemnt that represents the link.
     */
    private function generate_teacher_title_link($publication)
    {
        $url = $this->table_renderer->get_url(array(Tool :: PARAM_PUBLICATION_ID => $publication->get_id(), 
                Tool :: PARAM_ACTION => AssignmentTool :: ACTION_BROWSE_SUBMITTERS));
        return '<a href="' . $url . '">' . Utilities :: truncate_string($publication->get_content_object()->get_title(), 50) . '</a>';
    }

    /**
     * Generates the link applicable for the current browsing user being a
     * student.
     * 
     * @param $publication type
     *            The publication for which the link is being generated.
     * @return string The HTML anchor element that represents the link.
     */
    private function generate_student_title_link($publication)
    {
        $url = $this->table_renderer->get_url(array(
                Tool :: PARAM_ACTION => AssignmentTool :: ACTION_STUDENT_BROWSE_SUBMISSIONS, 
                Tool :: PARAM_PUBLICATION_ID => $publication->get_id()));
        return '<a href="' . $url . '">' . Utilities :: truncate_string($publication->get_content_object()->get_title(), 50) . '</a>';
    }
}
?>
