<?php

namespace application\weblcms\tool\assignment;

use application\weblcms\ToolComponent;
use application\weblcms\WeblcmsAssignmentSubmissionsTracker;
use application\weblcms\WeblcmsSubmissionFeedbackTracker;
use application\weblcms\WeblcmsSubmissionScoreTracker;
use application\weblcms\WeblcmsSubmissionNoteTracker;
use application\weblcms\WeblcmsDataManager;
use application\weblcms\WeblcmsRights;
use application\weblcms\WeblcmsManager;
use application\weblcms\Tool;
use common\libraries\Request;
use common\libraries\EqualityCondition;
use common\libraries\Translation;

/**
 *
 * @package application.weblcms.tool.assignment.php.component
 *         
 *          Deleter for assignments.
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 */
class AssignmentToolDeleterComponent extends AssignmentTool
{

    function run()
    {
        if (Request :: get(Tool :: PARAM_PUBLICATION_ID))
            $publication_ids = Request :: get(Tool :: PARAM_PUBLICATION_ID);
        else
            $publication_ids = $_POST[Tool :: PARAM_PUBLICATION_ID];
        
        if (! is_array($publication_ids))
        {
            $publication_ids = array($publication_ids);
        }
        
        $datamanager = WeblcmsDataManager :: get_instance();
        $failures = 0;
        
        foreach ($publication_ids as $index => $pid)
        {
            $publication = $datamanager->retrieve_content_object_publication($pid);
            if ($this->is_allowed(WeblcmsRights :: DELETE_RIGHT, $publication))
            {
                $publication->delete();
                $condition = new EqualityCondition(WeblcmsAssignmentSubmissionsTracker :: PROPERTY_PUBLICATION_ID, $pid);
                $submissions = WeblcmsAssignmentSubmissionsTracker :: get_data(WeblcmsAssignmentSubmissionsTracker :: CLASS_NAME, WeblcmsManager :: APPLICATION_NAME, $condition);
                while ($submission = $submissions->next_result())
                {
                    $id = $submission->get_id();
                    $subm_condition = new EqualityCondition(WeblcmsSubmissionFeedbackTracker :: PROPERTY_SUBMISSION_ID, $submission->get_id());
                    WeblcmsSubmissionFeedbackTracker :: remove_data(WeblcmsSubmissionFeedbackTracker :: CLASS_NAME, WeblcmsManager :: APPLICATION_NAME, $subm_condition);
                    WeblcmsSubmissionScoreTracker :: remove_data(WeblcmsSubmissionScoreTracker :: CLASS_NAME, WeblcmsManager :: APPLICATION_NAME, $subm_condition);
                    WeblcmsSubmissionNoteTracker :: remove_data(WeblcmsSubmissionNoteTracker :: CLASS_NAME, WeblcmsManager :: APPLICATION_NAME, $subm_condition);
                    $submission->delete();
                }
            }
            else
            {
                $failures ++;
            }
        }
        if ($failures == 0)
        {
            if (count($publication_ids) > 1)
            {
                $message = htmlentities(Translation :: get('ContentObjectPublicationsDeleted'));
            }
            else
            {
                $message = htmlentities(Translation :: get('ContentObjectPublicationDeleted'));
            }
        }
        else
        {
            $message = htmlentities(Translation :: get('ContentObjectPublicationsNotDeleted'));
        }
        
        $this->redirect($message, '', array(Tool :: PARAM_PUBLICATION_ID => null, 'tool_action' => null));
    }

}

?>