<?php

namespace application\weblcms\tool\assignment;

use application\weblcms\WeblcmsRights;
use common\libraries\Display;
use common\libraries\EqualityCondition;
use common\libraries\Translation;
use common\libraries\Request;
use application\weblcms\Tool;
use application\weblcms\WeblcmsSubmissionFeedbackTracker;
use application\weblcms\WeblcmsDataManager;

/**
 *
 * @package application.weblcms.tool.assignment.php.component
 *         
 *          Deleter for submission feedback.
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 */
class AssignmentToolFeedbackDeleterComponent extends AssignmentTool
{

    function run()
    {
        $weblcms_manager = WeblcmsDataManager :: get_instance();
        $pub = $weblcms_manager->retrieve_content_object_publication(Request :: get(Tool :: PARAM_PUBLICATION_ID));
        if (! $this->is_allowed(WeblcmsRights :: DELETE_RIGHT, $pub))
        {
            Display :: not_allowed();
            return;
        }
        
        $ids = Request :: get(AssignmentTool :: PARAM_FEEDBACK_ID);
        if (! is_array($ids))
        {
            $feedback_ids[] = $ids;
        }
        else
        {
            $feedback_ids = $ids;
        }
        $tracker = new WeblcmsSubmissionFeedbackTracker();
        
        foreach ($feedback_ids as $fid)
        {
            $condition = new EqualityCondition(WeblcmsSubmissionFeedbackTracker :: PROPERTY_ID, $fid);
            $feedbacks = $tracker->retrieve_tracker_items($condition);
            foreach ($feedbacks as $feedback)
            {
                $submission_id = $feedback->get_submission_id();
                $feedback->delete();
            }
        }
        
        $publication_id = Request :: get(AssignmentTool :: PARAM_PUBLICATION_ID);
        $target_id = Request :: get(AssignmentTool :: PARAM_TARGET_ID);
        $submitter_type = Request :: get(AssignmentTool :: PARAM_SUBMITTER_TYPE);
        
        $params = array(Tool :: PARAM_ACTION => AssignmentTool :: ACTION_VIEW_SUBMISSION, 
                Tool :: PARAM_PUBLICATION_ID => $publication_id, AssignmentTool :: PARAM_TARGET_ID => $target_id, 
                AssignmentTool :: PARAM_SUBMITTER_TYPE => $submitter_type, 
                AssignmentTool :: PARAM_SUBMISSION => $submission_id);
        
        $this->redirect(Translation :: get('FeedbackDeleted'), false, $params);
    }

}

?>
