<?php
namespace application\weblcms\tool\assignment;

use application\weblcms\tool\assignment\AssignmentTool;
use application\weblcms\CourseGroup;
use application\weblcms\WeblcmsAssignmentSubmissionsTracker;
use application\weblcms\WeblcmsDataManager;
use common\libraries\ObjectTableColumn;
use common\libraries\ObjectTableColumnModel;
use common\libraries\StaticTableColumn;
use common\libraries\Translation;
use group\Group;
use group\GroupDataManager;
use tracking\TrackingDataManager;
use user\User;
use user\UserDataManager;

/**
 * @package application.weblcms.tool.assignment.php.component.submission_browser
 *
 * Table column model for the submitters browser table
 *
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 * @author Anthony Hurst (Hogeschool Gent)
 */
class SubmissionBrowserTableColumnModel extends ObjectTableColumnModel
{
    /**
     * The tables modification column
     */
    private static $action_column;
    
    private $submitter_type;

    /**
     * Constructor
     */
    function __construct($submitter_type)
    {
        $this->submitter_type = $submitter_type;
		//$this, not self, as subclasses need to call their own get_columns() function.
        parent :: __construct($this->get_columns(), 0, SORT_ASC); //sort on name column.
        //parent :: __construct($this->get_columns(), 2, SORT_DESC); //sort on last submission date latest first.
    }

    /**
     * Defines the columns visible in the table.
     * @return array The column definitions.
     */
    function get_columns()
    {
        $gdm = GroupDataManager::get_instance();
        $udm = UserDataManager::get_instance();
        $wdm = WeblcmsDataManager::get_instance();
        
        $columns = array();
        if($this->submitter_type)
        {
            switch($this->submitter_type)
            {
                case WeblcmsAssignmentSubmissionsTracker::SUBMITTER_TYPE_COURSE_GROUP:
                    $columns[] = new ObjectTableColumn(CourseGroup :: PROPERTY_NAME, true, $wdm->get_alias(CourseGroup::get_table_name()));
                    break;
                case WeblcmsAssignmentSubmissionsTracker::SUBMITTER_TYPE_PLATFORM_GROUP:
                    $columns[] = new ObjectTableColumn(Group::PROPERTY_NAME, true, $gdm->get_alias(Group::get_table_name()));
                    break;
            }
        }
        else
        {
            $columns[] = new ObjectTableColumn(User :: PROPERTY_LASTNAME, true, $udm->get_alias(User::get_table_name()));
        }
        $columns[] = new ObjectTableColumn(AssignmentTool :: PROPERTY_FIRST_SUBMISSION, true, '');
        $columns[] = new ObjectTableColumn(AssignmentTool :: PROPERTY_LAST_SUBMISSION, true, '');
        $columns[] = new ObjectTableColumn(AssignmentTool :: PROPERTY_NUMBER_OF_SUBMISSIONS, true, '');
        $columns[] = new ObjectTableColumn(AssignmentTool :: PROPERTY_NUMBER_OF_FEEDBACKS, false);
        $columns[] = self :: get_action_column();
        return $columns;
    }

    /**
     * Gets the column which contains the action buttons.
     * @return ContentObjectTableColumn The action column.
     */
    static function get_action_column()
    {
        if (!isset(self :: $action_column))
        {
            self :: $action_column = new StaticTableColumn(Translation :: get('Actions'));
        }
        return self :: $action_column;
    }

}

?>