<?php
namespace application\weblcms\tool\assignment;

use common\libraries\ObjectTableDataProvider;
use application\weblcms\CourseGroup;
use application\weblcms\WeblcmsDataManager;
use common\libraries\ObjectTableOrder;

/**
 * @package application.weblcms.tool.assignment.php.component.submission_browser
 *
 * Data provider for a course group submissions browser table.
 *
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 */
class SubmissionCourseGroupsBrowserTableDataProvider extends ObjectTableDataProvider
{

    private $browser;
    private $condition;

    /**
     * Constructor
     * @param WeblcmsManagerComponent $browser
     */
    function __construct($browser, $condition = null)
    {
        parent :: __construct($browser);
        $this->browser = $browser;
        $this->condition = $condition;
    }

    /**
     * Retrieves the entities needed for the table from the database.
     * @param int $offset The start position of the entities to be retrieved.
     * @param int $count The number of entities to be retrieved from the database.
     * @param ObjectTableOrder $order_properties The order in which the entities are to be sorted.
     * @return  mdb2ResultSet A result set of the entities retrieved from the database.
     */
    function get_objects($offset, $count, $order_properties = null)
    {
        if(is_null($order_properties))
        {
            $order_properties = array();
        }
        elseif(!is_array($order_properties))
        {
            $order_properties = array($order_properties);
        }
        $order_properties[] = new ObjectTableOrder(CourseGroup :: PROPERTY_NAME, SORT_ASC, WeblcmsDataManager::get_instance()->get_alias(CourseGroup::get_table_name()));
        $course_groups = WeblcmsDataManager :: get_instance()->retrieve_assignment_publication_target_course_groups($this->browser->get_publication_id(),
            $this->browser->get_course_id(), $offset, $count, $order_properties, $this->condition);
        //dump($course_groups);
        return $course_groups;
    }

    /**
     * Gets the number of course groups in the table
     * @return int The total number of entities in the database that comply with the current conditions.
     */
    function get_object_count()
    {
        return $this->get_objects()->size();
    }

}

?>