<?php

namespace application\weblcms\tool\assignment;

use application\weblcms\WeblcmsAssignmentSubmissionsTracker;
use application\weblcms\WeblcmsManager;
use application\weblcms\WeblcmsRights;
use common\libraries\ObjectTable;
use common\libraries\ObjectTableFormAction;
use common\libraries\ObjectTableFormActions;
use common\libraries\Translation;

/**
 *
 * @package application.weblcms.tool.assignment.php.component.submission_browser
 *         
 *          Table to browse a list of group submissions.
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 * @author Anthony Hurst (Hogeschool Gent)
 * @author Bert De Clercq (Hogeschool Gent)
 */
class SubmissionGroupsBrowserTable extends ObjectTable
{
    
    const DEFAULT_NAME = 'submission_groups_browser_table';

    /**
     * Constructor
     * 
     * @param $browser WeblcmsManagerComponent           
     * @param $submitter_type int           
     */
    function __construct($browser, $submitter_type, $condition)
    {
        $model = new SubmissionGroupsBrowserTableColumnModel($submitter_type);
        if ($submitter_type == WeblcmsAssignmentSubmissionsTracker :: SUBMITTER_TYPE_COURSE_GROUP)
        {
            $data_provider = new SubmissionCourseGroupsBrowserTableDataProvider($browser, $condition);
        }
        else
        {
            $data_provider = new SubmissionGroupsBrowserTableDataProvider($browser, $condition);
        }
        $cell_renderer = new SubmissionGroupsBrowserTableCellRenderer($browser, $submitter_type);
        parent :: __construct($data_provider, SubmissionGroupsBrowserTable :: DEFAULT_NAME, $model, $cell_renderer);
        
        $actions = new ObjectTableFormActions(__NAMESPACE__, AssignmentTool :: PARAM_ACTION);
        if ($browser->is_allowed(WeblcmsRights :: EDIT_RIGHT))
        {
            $actions->add_form_action(new ObjectTableFormAction(AssignmentTool :: ACTION_DOWNLOAD_SUBMISSIONS, Translation :: get('DownloadSubmissionsSelected'), false));
            $this->set_form_actions($actions);
        }
    }

}

?>