<?php
namespace application\weblcms\tool\assignment;

use application\weblcms\CourseGroup;
use application\weblcms\Tool;
use common\libraries\DataClass;
use common\libraries\InCondition;
use common\libraries\ObjectTableOrder;
use common\libraries\Toolbar;
use common\libraries\ToolbarItem;
use common\libraries\Theme;
use common\libraries\Path;
use common\libraries\Translation;
use group\Group;
use repository\DefaultContentObjectTableCellRenderer;
use user\User;
use user\DataManager;
use common\libraries\Request;
use common\libraries\DatetimeUtilities;
use common\libraries\Utilities;
use application\weblcms\WeblcmsAssignmentSubmissionsTracker;
use group\GroupDataManager;
use application\weblcms\WeblcmsRights;
use application\weblcms\WeblcmsDataManager;
use common\libraries\DataClassRetrievesParameters;

/**
 * @package application.weblcms.tool.assignment.php.component.submission_browser
 *
 * This class is a cell renderer for a group submissions browser table
 *
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 * @author Anthony Hurst (Hogeschool Gent)
 * @author Bert De Clercq (Hogeschool Gent)
 */
class SubmissionGroupsBrowserTableCellRenderer extends DefaultContentObjectTableCellRenderer
{

    private $submitter_type;
    private $table_actions;
    private $browser;

    /**
     * Constructor.
     * @param WeblcmsManagerComponent $browser
     * @param int $submitter_type
     */
    function __construct($browser, $submitter_type)
    {
        $this->table_actions = array();
        $this->browser = $browser;
        $this->submitter_type = $submitter_type;
    }

    /**
	 * Defines the contents of a cell in relation to the given column and the given group.
	 * @param type $column The column for which information is wanted.
	 * @param mixed $group The group for which information is wanted.
	 * @return string The content of the cell related to both the $column and the $publication.
     */
    function render_cell($column, $group)
    {
        $name_property = null;
        switch($this->submitter_type)
        {
            case WeblcmsAssignmentSubmissionsTracker::SUBMITTER_TYPE_COURSE_GROUP:
                $name_property = CourseGroup::PROPERTY_NAME;
                break;
            case WeblcmsAssignmentSubmissionsTracker::SUBMITTER_TYPE_PLATFORM_GROUP:
                $name_property = Group::PROPERTY_NAME;
                break;
        }
        
        //$tracker = $this->browser->get_submissions_tracker($this->submitter_type, $group->get_submitter_id());
        if ($column === SubmissionBrowserTableColumnModel :: get_action_column())
        {
            return $this->get_actions($group);
        }
        else
        {
            switch ($column->get_name())
            {
                case $name_property :
                    // Check if submissions of the group should be visible
                    $weblcms_manager = WeblcmsDataManager :: get_instance();
                    if ($this->browser->get_assignment()->get_visibility_submissions() == 1
                        || $this->browser->is_allowed(WeblcmsRights::EDIT_RIGHT)
                        || ($this->submitter_type == WeblcmsAssignmentSubmissionsTracker::SUBMITTER_TYPE_PLATFORM_GROUP
                            && GroupDataManager::get_instance()->is_group_member($group->get_submitter_id(), $this->browser->get_user_id()))
                        || ($this->submitter_type == WeblcmsAssignmentSubmissionsTracker::SUBMITTER_TYPE_COURSE_GROUP
                            && $weblcms_manager->is_course_group_member($group, $this->browser->get_user()) ))
                    {
                        $url = $this->browser->get_url(array(
                            Tool :: PARAM_PUBLICATION_ID => $this->browser->get_publication_id(),
                            AssignmentTool :: PARAM_TARGET_ID => $group->get_submitter_id(),
                            AssignmentTool :: PARAM_SUBMITTER_TYPE => $this->submitter_type,
                            Tool :: PARAM_ACTION => AssignmentTool :: ACTION_BROWSE_SUBMISSIONS));
                        return '<a href=\'' . $url . '\'>' . $group->get_optional_property($name_property) . '</a>';
                    }
                    return $group->get_name();

                case AssignmentTool :: PROPERTY_FIRST_SUBMISSION :
                    if(is_null($group->get_optional_property(AssignmentTool::PROPERTY_FIRST_SUBMISSION)))
                    {
                        return '-';
                    }
                    return $this->format_date($group->get_optional_property(AssignmentTool::PROPERTY_FIRST_SUBMISSION));

                case AssignmentTool :: PROPERTY_LAST_SUBMISSION :
                    if(is_null($group->get_optional_property(AssignmentTool::PROPERTY_LAST_SUBMISSION)))
                    {
                        return '-';
                    }
                    return $this->format_date($group->get_optional_property(AssignmentTool::PROPERTY_LAST_SUBMISSION));

                case AssignmentTool :: PROPERTY_GROUP_MEMBERS :
                    return $this->get_group_members($group);

                case AssignmentTool :: PROPERTY_NUMBER_OF_SUBMISSIONS :
                    return $group->get_optional_property(AssignmentTool::PROPERTY_NUMBER_OF_SUBMISSIONS);

                case AssignmentTool :: PROPERTY_NUMBER_OF_FEEDBACKS :
                    $feedbacks = $this->browser->get_submitter_feedbacks($this->submitter_type, $group->get_submitter_id());
                    if ($feedbacks == null)
                    {
                        return '0';
                    }
                    return $feedbacks->get_optional_property(SubmissionsManager::PARAM_COUNT);

                default :
                    return '-';
            }
        }
    }

    /**
     * Retrieves the members of the broup and displays them in a list.
     * @param mixed $group the group whose members are to be displayed.
     */
    private function get_group_members($group)
    {
        $retrieve_limit = 21;
        $order_properties = array();
        $order_properties[] = new ObjectTableOrder(User :: PROPERTY_LASTNAME);
        $order_properties[] = new ObjectTableOrder(User :: PROPERTY_FIRSTNAME);
        $users = array();;

        switch ($this->submitter_type)
        {
            case WeblcmsAssignmentSubmissionsTracker::SUBMITTER_TYPE_PLATFORM_GROUP:
                $user_ids = GroupDataManager :: get_instance()->retrieve_group($group->get_submitter_id())->get_users(true, true);
                $condition = new InCondition(User :: PROPERTY_ID, $user_ids);
				$users = DataManager :: retrieves(User :: CLASS_NAME, new DataClassRetrievesParameters($condition, $retrieve_limit, null, $order_properties))->as_array();
				break;
			case WeblcmsAssignmentSubmissionsTracker::SUBMITTER_TYPE_COURSE_GROUP:
                $course_group = $this->browser->get_submitter(WeblcmsAssignmentSubmissionsTracker::SUBMITTER_TYPE_COURSE_GROUP, $group->get_submitter_id());
				$users = WeblcmsDataManager :: get_instance()->retrieve_course_group_users($course_group, null, null, $retrieve_limit, $order_properties)->as_array();
				break;
		}
		
        if(count($users) == 0)
        {
            return null;
        }
        
        $display_limit_breached = false;
        if(count($users) == $retrieve_limit)
        {
            $display_limit_breached = true;
            array_pop($users);
        }
        
		$html = array();
        $html[] = '<select style="width:180px">';
        foreach($users as $user)
        {
            $html[] = '<option>' . $user->get_fullname() . '</option>';
        }
        if($display_limit_breached)
        {
            $html[] = '<option>...</option>';
        }
        $html[] = '</select>';
        return implode("\n", $html);
    }

    /**
     * Creates a toolbar with the appropriate actions
     * @param Group $group course group or platform group
     * @return string The HTML code that represents the actions.
     */
    function get_actions($group)
    {
        $toolbar = new Toolbar();

        if($this->submitter_type == WeblcmsAssignmentSubmissionsTracker :: SUBMITTER_TYPE_COURSE_GROUP)
        {
            $is_member = WeblcmsDataManager :: get_instance()->is_course_group_member($group, $this->browser->get_user());
        }
        else
        {
            $is_member = $this->is_group_member($this->browser->get_submitter(WeblcmsAssignmentSubmissionsTracker::SUBMITTER_TYPE_PLATFORM_GROUP, $group->get_submitter_id()));
        }
        if($is_member || $this->browser->get_assignment()->get_visibility_submissions() == 1 || $this->browser->is_allowed(WeblcmsRights :: EDIT_RIGHT))
        {
            $toolbar->add_item($this->get_view_submissions_action($group->get_submitter_id()));
        }
        if($this->browser->is_allowed(WeblcmsRights :: EDIT_RIGHT) 
            && $group->get_optional_property(AssignmentTool::PROPERTY_NUMBER_OF_SUBMISSIONS) > 0)
        {
            $toolbar->add_item($this->get_download_all_submissions_action($group->get_submitter_id()));
        }
        if($is_member)
        {
            $toolbar->add_item($this->get_submission_submit_action($group->get_submitter_id()));
        }
        return $toolbar->as_html();
    }

    /**
     * Recursively iterates over a platform group and its subgroups to identify whether the current user is a member of the platform group at any level.
     * @param Group $group the platform group.
     * @return boolean whether the user is a member of the platform group 
     */
    private function is_group_member($group)
    {
        if(GroupDataManager :: get_instance()->is_group_member($group->get_id(), $this->browser->get_user_id()))
        {
            return true;
        }
        if($group->has_children())
        {
            foreach($group->get_subgroups() as $subgroup)
            {
                if($this->is_group_member($subgroup))
                {
                    return true;
                }
            }
        }
        return false;
    }

    /**
     * Defines the action parameters for the view submissions action.
     * @param int $group_id The id of the group for which the action is being created.
     * @return \common\libraries\ToolbarItem The action item.
     */
    private function get_view_submissions_action($group_id)
    {
        return new ToolbarItem(Translation :: get('ViewSubmissions'), 
            Theme :: get_common_image_path() . 'action_browser.png', $this->browser->get_url(array(
            Tool :: PARAM_ACTION => AssignmentTool :: ACTION_BROWSE_SUBMISSIONS,
            AssignmentTool :: PARAM_TARGET_ID => $group_id,
            AssignmentTool::PARAM_SUBMITTER_TYPE => $this->submitter_type)), ToolbarItem :: DISPLAY_ICON);
    }

    /**
     * Defines the action parameters for the download all submissions action.
     * @param int $group_id The id of the group for which the action is being created.
     * @return \common\libraries\ToolbarItem The action item.
     */
    private function get_download_all_submissions_action($group_id)
    {
        return new ToolbarItem(Translation :: get('DownloadAllSubmissions'),
            Theme :: get_common_image_path() . 'action_download.png', $this->browser->get_url(array(
                Tool :: PARAM_ACTION => AssignmentTool :: ACTION_DOWNLOAD_SUBMISSIONS,
                AssignmentTool :: PARAM_TARGET_ID => $group_id,
                AssignmentTool::PARAM_SUBMITTER_TYPE => $this->submitter_type)),
            ToolbarItem :: DISPLAY_ICON);
    }

    private function get_submission_submit_action($group_id)
    {
        return new ToolbarItem(Translation :: get('SubmissionSubmit'),
            Theme :: get_common_image_path() . 'action_add.png', $this->browser->get_url(array(
            Tool :: PARAM_ACTION => AssignmentTool :: ACTION_SUBMIT_SUBMISSION,
            Tool :: PARAM_PUBLICATION_ID => $this->get_publication_id(), AssignmentTool::PARAM_TARGET_ID => $group_id,
            WeblcmsAssignmentSubmissionsTracker :: PROPERTY_SUBMITTER_TYPE => $this->submitter_type)),
            ToolbarItem :: DISPLAY_ICON);
    }
    
    private function get_publication_id()
    {
        return Request::get(Tool::PARAM_PUBLICATION_ID);
    }

    /**
     * Formats a date.
     * @param type $date the date to be formatted.
     * @return the formatted representation of the date.
     */
    private function format_date($date)
    {
        $formatted_date = DatetimeUtilities :: format_locale_date(Translation :: get('DateTimeFormatLong', null,
            Utilities :: COMMON_LIBRARIES), $date);
        if($date > $this->browser->get_assignment()->get_end_time())
        {
            return '<span style="color:red">' . $formatted_date . '</span>';
        }
        return $formatted_date;
    }

    /**
     * #Override
     * Modifies the assignment of the user id to match the modified join call to the database. To avoid caching conflicts, the user id is stored in the variable $submitter_id.
     * @param type $object The user whose id is to be retrieved.
     */
    public function render_id_cell($object)
    {
        return $object->get_submitter_id();
    }
}

?>