<?php

namespace application\weblcms\tool\assignment;

use application\weblcms\WeblcmsSubmissionNoteTracker;
use common\libraries\FormValidator;
use common\libraries\Request;
use common\libraries\Theme;
use common\libraries\Translation;
use common\libraries\Utilities;
use tracking\Event;

/**
 * This form allows a user to edit and save notes with a submission.
 *
 * @author Bert De Clercq (Hogeschool Gent)
 */
class SubmissionDetailNotesSection extends FormValidator
{
    
    /**
     * Caching variable for the note tracker.
     * 
     * @var WeblcmsSubmissionNoteTracker The note tracker
     */
    private $note_tracker;

    /**
     * Fills the form with all the data.
     * 
     * @param $note_tracker WeblcmsSubmissionNoteTracker           
     * @param $url string
     *            The url of the main page
     */
    function __construct($note_tracker, $url = '')
    {
        parent :: __construct('submission_notes', 'post', $url);
        $this->note_tracker = $note_tracker;
        
        $html_editor_options = array();
        $html_editor_options['collapse_toolbar'] = true;
        $html_editor_options['show_tags'] = false;
        $html_editor_options['toolbar'] = 'RepositoryQuestion';
        
        $this->add_html_editor(WeblcmsSubmissionNoteTracker :: PROPERTY_NOTE, Translation :: get('NoteLong'), false, $html_editor_options);
        
        $save_button = $this->createElement('style_submit_button', 'submit', Translation :: get('Save', null, Utilities :: COMMON_LIBRARIES), array(
                'class' => 'positive publish'));
        $this->addElement($save_button);
        
        $this->set_initial_note();
    }

    /**
     * If a note already exists, set this note on the form.
     */
    private function set_initial_note()
    {
        if ($this->note_tracker)
        {
            $defaults = array();
            $defaults[WeblcmsSubmissionNoteTracker :: PROPERTY_NOTE] = $this->note_tracker->get_note();
            parent :: setDefaults($defaults);
        }
    }

    /**
     * Updates or creates the note tracker.
     */
    function set_note()
    {
        if ($this->note_tracker)
        {
            $this->update_tracker();
        }
        else
        {
            $this->create_tracker();
        }
    }

    /**
     * Creates a note tracker.
     * 
     * @return boolean
     */
    function create_tracker()
    {
        $values = $this->exportValues();
        $note = $values[WeblcmsSubmissionNoteTracker :: PROPERTY_NOTE];
        
        if ($note == "" || $note == "<br />")
        {
            return false;
        }
        
        $arguments = array(
                WeblcmsSubmissionNoteTracker :: PROPERTY_SUBMISSION_ID => Request :: get(AssignmentTool :: PARAM_SUBMISSION), 
                WeblcmsSubmissionNoteTracker :: PROPERTY_CREATED => time(), 
                WeblcmsSubmissionNoteTracker :: PROPERTY_MODIFIED => time(), 
                WeblcmsSubmissionNoteTracker :: PROPERTY_USER_ID => Request :: get(AssignmentTool :: PARAM_TARGET_ID), 
                WeblcmsSubmissionNoteTracker :: PROPERTY_NOTE => $note);
        Event :: trigger('note_submission', 'weblcms', $arguments);
        
        return true;
    }

    /**
     * Updates the score tracker if the note is modified.
     * 
     * @return boolean
     */
    function update_tracker()
    {
        $values = $this->exportValues();
        $note = $values[WeblcmsSubmissionNoteTracker :: PROPERTY_NOTE];
        
        if ($note == "" || $note == "<br />")
        {
            return $this->note_tracker->delete();
        }
        
        $this->note_tracker->set_note($note);
        $this->note_tracker->set_modified(time());
        
        return $this->note_tracker->update();
    }

}

?>
