<?php
namespace application\weblcms\tool\assignment;

use application\weblcms\WeblcmsAssignmentSubmissionsTracker;
use application\weblcms\WeblcmsManager;
use common\libraries\ObjectTableDataProvider;
use common\libraries\ObjectTableOrder;

/**
 * Description of submitter_group_submissions_browser_table_data_provider
 *
 * @author Anthony Hurst (Hogeschool Gent)
 */
class SubmitterGroupSubmissionsBrowserTableDataProvider extends ObjectTableDataProvider
{
    private $browser;
    private $search_condition;
    private $table_conditions;

    function __construct($browser, $search_condition, $table_conditions)
    {
        parent :: __construct($browser);
        $this->browser = $browser;
        $this->search_condition = $search_condition;
        $this->table_conditions = $table_conditions;
    }

    public function get_object_count()
    {
        return $this->get_objects()->size();
    }

    /**
     * Retrieves Submissions from the database.
     * WARNING: This function circumvents the tracking model.
     * REASON: The table construction model is based on result sets retrieved
     * straight from the database whereas the
     * tracking model is based on arrays.
     * 
     * @param $offset int
     *            the start point in the list
     * @param $count int
     *            the number of objects to be retrieved from the database.
     * @param $order_property ObjectTableOrder
     *            the way the contents of the table should be ordered.
     */
    public function get_objects($offset = null, $count = null, $order_property = null)
    {
        if (is_null($order_property))
        {
            $order_property = new ObjectTableOrder(WeblcmsAssignmentSubmissionsTracker :: PROPERTY_DATE_SUBMITTED);
        }
        // From here on, the tracking model is circumvented.
        return WeblcmsAssignmentSubmissionsTracker :: get_data(WeblcmsAssignmentSubmissionsTracker :: CLASS_NAME, WeblcmsManager :: APPLICATION_NAME, $this->table_conditions, $offset, $count, $order_property);
    }
}

?>
