<?php

namespace application\weblcms\tool\assignment;

use application\weblcms\course\CourseGroupRelation;
use application\weblcms\CourseGroupEntity;
use application\weblcms\CoursePlatformGroupEntity;
use application\weblcms\Tool;
use application\weblcms\WeblcmsAssignmentSubmissionsTracker;
use application\weblcms\WeblcmsDataManager;
use application\weblcms\WeblcmsManager;
use application\weblcms\WeblcmsRights;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use common\libraries\FormValidator;
use common\libraries\ObjectTableOrder;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Utilities;
use group\GroupDataManager;
use repository\content_object\assignment\Assignment;
use repository\ContentObjectCopier;
use repository\RepositoryCategory;
use repository\RepositoryDataManager;
use tracking\Event;
use user\UserDataManager;

/**
 *
 * @package application.weblcms.tool.assignment.php.component
 *         
 *          Custom form for the submissions feedback
 *         
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 * @author Bert De Clercq (Hogeschool Gent)
 */
class SubmissionSubmitForm extends FormValidator
{

    function __construct($choices, $url = '')
    {
        parent :: __construct('assignment', 'post', $url);
        
        $publication_id = Request :: get(Tool :: PARAM_PUBLICATION_ID);
        
        // Retrieving assignment
        $publication = WeblcmsDataManager :: get_instance()->retrieve_content_object_publication($publication_id);
        $assignment = $publication->get_content_object();
        
        $this->addElement('category', Translation :: get('Properties', null, Utilities :: COMMON_LIBRARIES));
        // Submit as
        if ($assignment->get_allow_group_submissions())
        {
            $this->addElement('select', WeblcmsAssignmentSubmissionsTracker :: PROPERTY_SUBMITTER_ID, Translation :: get('SubmitAs'), $choices);
        }
        $this->addElement('category');
        
        $buttons = array();
        $buttons[] = $this->createElement('style_submit_button', 'submit', Translation :: get('Submit', null, Utilities :: COMMON_LIBRARIES), array(
                'class' => 'positive publish'));
        $buttons[] = $this->createElement('style_reset_button', 'reset', Translation :: get('Reset', null, Utilities :: COMMON_LIBRARIES), array(
                'class' => 'normal empty'));
        $this->addGroup($buttons, 'buttons', null, '&nbsp;', false);
        
        $this->setDefaults();
    }

    function setDefaults($defaults = array())
    {
        $submitter_type = Request :: get(WeblcmsAssignmentSubmissionsTracker :: PROPERTY_SUBMITTER_TYPE);
        
        if ($submitter_type == WeblcmsAssignmentSubmissionsTracker :: SUBMITTER_TYPE_COURSE_GROUP || $submitter_type == WeblcmsAssignmentSubmissionsTracker :: SUBMITTER_TYPE_PLATFORM_GROUP)
        {
            $defaults[WeblcmsAssignmentSubmissionsTracker :: PROPERTY_SUBMITTER_ID] = $submitter_type . Request :: get(AssignmentTool :: PARAM_TARGET_ID);
        }
        
        parent :: setDefaults($defaults);
    }

}

?>
