<?php

namespace application\weblcms\tool\course_copier;

use common\libraries\DelegateComponent;

use common\libraries\Display;
use common\libraries\BreadcrumbTrail;
use common\libraries\InCondition;
use common\libraries\EqualityCondition;
use common\libraries\Translation;
use common\libraries\AndCondition;
use common\libraries\Utilities;
use common\libraries\ObjectTableOrder;

use application\weblcms\ContentObjectPublicationCategory;
use application\weblcms\ContentObjectPublication;

use application\weblcms\CourseSection;

use application\weblcms\WeblcmsManager;
use application\weblcms\WeblcmsDataManager;
use application\weblcms\course\CourseDataManager;
use application\weblcms\course\CourseUserRelation;
use rights\RightsLocation;
/*
 * This tool is for copying information from othe current course to another
 * 
 * @author Mattias De Pauw - Hogeschool Gent
 */
class CourseCopierToolBrowserComponent extends CourseCopierTool implements DelegateComponent
{
     public $course_copier_form;
     private $category_parent_ids_mapping;
    
    /**
     *Check wether there can be anything coppied to a course and if there is even another course 
     *where the user can copy to. Build the form check validate and copy the selected information  
     */
    function run()
    {       
        $trail = BreadcrumbTrail :: get_instance();
        $trail->add_help('course copier');
        
        $dm = WeblcmsDataManager :: get_instance();
        
        if (! $this->get_course()->is_course_admin($this->get_parent()->get_user()))
        {
            $this->display_header();
            Display :: error_message(Translation :: get('NotAllowed', null, Utilities :: COMMON_LIBRARIES));
            $this->display_footer();
            exit();
        }
        
        $sections_founded = false;
        $condition = new EqualityCondition(CourseSection :: PROPERTY_COURSE_ID, $this->get_course_id());
        $course_sections = $dm->retrieve_course_sections($condition);

        $common_sections = array(CourseSection :: TYPE_TOOL, CourseSection :: TYPE_DISABLED, CourseSection :: TYPE_LINK,
            CourseSection :: TYPE_ADMIN);
        
        while ($course_section = $course_sections->next_result())
        {
            if (! in_array($course_section->get_type(), $common_sections))
            {
                $sections_founded = true;
            }
        }
        $condition = new EqualityCondition(ContentObjectPublication :: PROPERTY_COURSE_ID, $this->get_course_id());
        if ($dm->count_content_object_publications($condition) == 0 && !$sections_founded)
        {
            $this->display_header();
            Display :: warning_message(Translation :: get('NoPublications'));
            $this->display_footer();
            exit();   
        } 
        
        $condition = new EqualityCondition(CourseUserRelation :: PROPERTY_STATUS, 1);
        if ($dm->count_course_user_relations($condition) <= 1)
        {
            $this->display_header();
            Display :: warning_message(Translation :: get('NoCoursesToCopy'));
            $this->display_footer();
            exit(); 
        }
        
        $this->course_copier_form = new CourseCopierForm($this);
        $this->course_copier_form->buildForm();
        
        if($this->course_copier_form->validate())
        {
            $values = $this->course_copier_form->exportValues(); 
        
             if(isset($values['publications'])||isset($values["course_sections"])
                    ||$values['content_object_categories'] == 1)
             {
                // Before copying always first copy the categories !!!!!!
                 
                 $succes_categories = true;
                  if ($values['content_object_categories'] == 1)
                  {
                    $courses = $values['course'];  
                    $succes_categories =  $this->copy_categories(0,$courses);
                  }
                 
                 $succes_publications = $this->copy_publications($values);
                 $succes_sections = $this->copy_sections($values);
              
                if ($succes_publications  && $succes_categories)
                    {
                        $this->redirect(Translation :: get('CopySucceeded'), false, array(
                            WeblcmsManager :: PARAM_ACTION => WeblcmsManager :: ACTION_VIEW_WEBLCMS_HOME));
                    }
                    else
                    {
                        throw new \Exception(Translation :: get('CopyNotSucceeded')); 
                    }
             }
             else
             {
                $this->display_header();
                Display :: error_message(Translation :: get('SelectAItem'));
                $this->course_copier_form->display();
                $this->display_footer();  
             }
        }
        else
        {
            $this->display_header();
            $this->course_copier_form->display();
            $this->display_footer();
        }     
    }
    
    /**
     *Copy the selected sections 
     */
    function copy_sections($values)
    {
        $succes = true;
        $this->parent_ids_mapping = array();
       
        $courses = $values['course'];

        $dm = WeblcmsDataManager :: get_instance();

        $course_section_ids = array_keys($values['course_sections']);
        $condition = new InCondition(CourseSection :: PROPERTY_ID, $course_section_ids);
        $course_sections = $dm->retrieve_course_sections($condition);
        while ($course_section = $course_sections->next_result())
        {
            foreach ($courses as $course_code)
            {
                $course_section->set_id(null);
                $course_section->set_course_id($course_code);
                $succes = $course_section->create();
            }
        }
        return $succes;
    }
    
    /**
     *Copy the selected publications in the right category
     */
    function copy_publications($values)
    {
        $succes = true;
        $courses = $values['course'];
        $dm = WeblcmsDataManager :: get_instance();
        
        $publication_ids = array_keys($values['publications']);
        foreach ($publication_ids as $id)
        {
            $publication = $dm->retrieve_content_object_publication($id);
            $courses = $values['course'];
            $parent = $publication->get_category_id();

            foreach ($courses as $course_code)
            {
                $publication->set_id(null);
                $publication->set_course_id($course_code);

                if ($parent != 0)
                {
                    $publication->set_category_id($this->category_parent_ids_mapping[$course_code][$parent]);
                }
               
                $succes = $publication->create();
                if($succes instanceof RightsLocation)
                {
                   $succes = true;
                }        
            }
        }  
        return $succes;
    }
    
    /**
     * copy the categories to the other course
     * 
     * @param int $parent_id
     * @param type $courses 
     */
    function copy_categories($parent_id, $courses)
    {
        
        $succes = true;
        $dm = WeblcmsDataManager :: get_instance();
        
        $conditions[] = new EqualityCondition(ContentObjectPublicationCategory :: PROPERTY_COURSE, $this->get_course_id());
        $conditions[] = new EqualityCondition(ContentObjectPublicationCategory :: PROPERTY_PARENT, $parent_id);
        $condition = new AndCondition($conditions);
        $order_by = new ObjectTableOrder(ContentObjectPublicationCategory :: PROPERTY_DISPLAY_ORDER);
        $categories = $dm->retrieve_content_object_publication_categories($condition, null, null, $order_by);
        
        while ($category = $categories->next_result())
        {
            if (! $category->get_allow_change())
            {
                continue; //Because the course groups are not copied this won't copy their corresponding folders
            }
            
            $old_id = $category->get_id();

            foreach ($courses as $course_code)
            {
                $category->set_id(null);
                $category->set_course($course_code);

                if ($parent_id != 0)
                {
                    $category->set_parent($this->category_parent_ids_mapping[$course_code][$parent_id]);
                }

                $succes = $category->create();
                
                $this->category_parent_ids_mapping[$course_code][$old_id] = $category->get_id();
            }
            
            //copy the children
           $succes = $this->copy_categories($old_id, $courses);        }
        
        return $succes;
    }
}

?>