<?php
namespace application\weblcms\tool\course_deleter;

use common\libraries\DelegateComponent;

use common\libraries\Display;
use common\libraries\BreadcrumbTrail;
use common\libraries\Translation;
use common\libraries\Utilities;

use application\weblcms\WeblcmsManager;
use application\weblcms\WeblcmsDataManager;
use application\weblcms\course\CourseDataManager;

/**
 * this component is used to delete a course
 * 
 * @author Mattias De Pauw - Hogeschool Gent
 */

class CourseDeleterToolCourseDeleterComponent extends CourseDeleterTool implements DelegateComponent
{
    public $delete_page;
    
    /**
     * this function checks whether the user have the rights to delete the form,
     * build the delete form and checks if the form is valid
     * 
     */
    function run()
    {
        $trail = BreadcrumbTrail :: get_instance();
        $trail->add_help('course delete');
        
        if (! $this->get_course()->is_course_admin($this->get_parent()->get_user()))
        {
            $this->display_header();
            Display :: error_message(Translation :: get('NotAllowed', null, Utilities :: COMMON_LIBRARIES));
            $this->display_footer();
            exit();
        }
        
        $this->delete_page = new CourseDeleterForm($this);
        $this->delete_page->buildForm();
        
        if($this->delete_page->validate())    
        {
           $this->delete_course();
           
        }
        else
        {       
            $this->display_header();
            Display :: error_message(Translation :: get('DeleteReDoMessage'));
            $this->delete_page->display();
            $this->display_footer();        
        }
    }
    
    /**
     * Deletes the course and redirect 
     */
    function delete_course()
    {
        $course_data_manager = CourseDataManager :: get_instance();
        $course = $course_data_manager->retrieve_course($this->get_course_id());
        
        if (!$course->delete())
        {
            throw new \Exception(Translation :: get('CourseDeleteFailed'));
    
        }
        else
        {
            $this->redirect(Translation :: get('CourseDeleted'), false, array(
                WeblcmsManager :: PARAM_ACTION => WeblcmsManager :: ACTION_VIEW_WEBLCMS_HOME));
        }  
    } 
}
?>