<?php

namespace application\weblcms\tool\course_group;

use application\weblcms\CourseGroup;
use application\weblcms\CourseGroupGroupRelation;
use application\weblcms\WeblcmsRights;
use common\libraries\Translation;

/**
 * $Id: default_course_group_table_column_model.class.php 216 2009-11-13
 * 14:08:06Z kariboe $
 *
 * @package
 *          application.lib.weblcms.tool.course_group.component.course_group_table
 */

class DefaultCourseGroupTableColumnModel extends CourseGroupTableColumnModel
{
    
    /**
     * The tables modification column
     */
    private static $modification_column;
    /**
     * The tables number of members column
     */
    private static $number_of_members_column;
    private $course_group_tool;
    private static $max_number_of_members_column;

    /**
     * Constructor
     */
    function __construct($course_group_tool)
    {
        $this->course_group_tool = $course_group_tool;
        parent :: __construct($this->get_default_columns(), 1);
    }

    /**
     * Gets the default columns for this model
     *
     * @return UserTableColumn[]
     */
    private function get_default_columns()
    {
        $columns = array();
        $columns[] = new CourseGroupTableColumn(CourseGroup :: PROPERTY_NAME, true);
        $columns[] = new CourseGroupTableColumn(CourseGroup :: PROPERTY_DESCRIPTION, true);
        
        if ($this->course_group_tool->is_allowed(WeblcmsRights :: EDIT_RIGHT))
        {
            $column = new CourseGroupTableColumn(CourseGroup :: PROPERTY_GROUP_ID, true);
            $column->set_title(CourseGroupGroupRelation :: PROPERTY_NAME);
            $columns[] = $column;
            // $columns[] = new CourseGroupTableColumn(CourseGroup ::
            // PROPERTY_SELF_UNREG, true);
            // $columns[] = new CourseGroupTableColumn(CourseGroup ::
            // PROPERTY_SELF_REG, true);
            // $columns[] = new CourseGroupTableColumn(CourseGroup ::
            // PROPERTY_RANDOM_REG, true);
        }
        $columns[] = self :: get_number_of_members_column();
        // $columns[] = self :: get_max_number_of_members_column();
        
        $column = new CourseGroupTableColumn(CourseGroup :: PROPERTY_MAX_NUMBER_OF_MEMBERS, true);
        $column->set_title(Translation :: get('MaximumMembers'));
        $columns[] = $column;
        
        $columns[] = self :: get_modification_column();
        return $columns;
    }

    /**
     * Gets the modification column
     *
     * @return CourseGroupTableColumn
     */
    static function get_modification_column()
    {
        if (! isset(self :: $modification_column))
        {
            self :: $modification_column = new CourseGroupTableColumn('');
        }
        return self :: $modification_column;
    }

    /**
     * Gets the number of members column
     *
     * @return CourseGroupTableColumn
     */
    static function get_number_of_members_column()
    {
        if (! isset(self :: $number_of_members_column))
        {
            self :: $number_of_members_column = new CourseGroupTableColumn(Translation :: get('NumberOfMembers'), false);
        }
        return self :: $number_of_members_column;
    }

    /**
     * Gets the max number of members column
     *
     * @return CourseGroupTableColumn
     */
    static function get_max_number_of_members_column()
    {
        if (! isset(self :: $max_number_of_members_column))
        {
            self :: $max_number_of_members_column = new CourseGroupTableColumn(Translation :: get('MaximumMembers'), false);
        }
        return self :: $max_number_of_members_column;
    }

}

?>
