<?php
namespace application\weblcms\tool\course_group;

use common\libraries\DelegateComponent;

use application\weblcms\CourseGroupSubscriptionsForm;
use application\weblcms\WeblcmsDataManager;
use application\weblcms\WeblcmsRights;
use application\weblcms\Tool;
use common\libraries\Display;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\NotAllowedException;

/**
 * $Id: course_group_manage_subscriptions.class.php 216 2009-11-13 14:08:06Z
 * kariboe $
 * 
 * @package application.lib.weblcms.tool.course_group.component
 */

class CourseGroupToolManageSubscriptionsComponent extends CourseGroupTool implements DelegateComponent
{
    private $action_bar;

    function run()
    {
        if (! $this->is_allowed(WeblcmsRights :: EDIT_RIGHT))
        {
            throw new NotAllowedException();
        }
        
        $course_group_id = Request :: get(CourseGroupTool :: PARAM_COURSE_GROUP);
        $wdm = WeblcmsDataManager :: get_instance();
        $course_group = $wdm->retrieve_course_group($course_group_id);
        BreadcrumbTrail :: get_instance()->add(new Breadcrumb($this->get_url(), Translation :: get('ManageSubscriptionComponent', array(
                'GROUPNAME' => $course_group->get_name()))));
        $trail = BreadcrumbTrail :: get_instance();
        
        $form = new CourseGroupSubscriptionsForm($course_group, $this->get_url(array(
                CourseGroupTool :: PARAM_ACTION => CourseGroupTool :: ACTION_MANAGE_SUBSCRIPTIONS, 
                CourseGroupTool :: PARAM_COURSE_GROUP => $course_group->get_id())), $this);
        if ($form->validate())
        {
            $succes = $form->update_course_group_subscriptions();
            
            if ($succes)
                $message = Translation :: get('CourseGroupSubscriptionsUpdated', array(
                        'OBJECT' => Translation :: get('CourseGroup')), Utilities :: COMMON_LIBRARIES) . '<br />' . implode('<br />', $course_group->get_errors());
                // $message = 'CourseGroupSubscriptionsUpdated';
            else
                // $message = 'MaximumAmountOfMembersReached';
                
                $message = Translation :: get('ObjectNotUpdated', array('OBJECT' => Translation :: get('CourseGroup')), Utilities :: COMMON_LIBRARIES) . '<br />' . implode('<br />', $course_group->get_errors());
            $this->redirect(Translation :: get($message), ! $succes, array(
                    CourseGroupTool :: PARAM_ACTION => CourseGroupTool :: ACTION_UNSUBSCRIBE, 
                    CourseGroupTool :: PARAM_COURSE_GROUP => $course_group->get_id()));
        }
        else
        {
            $this->display_header();
            echo '<h3>' . Translation :: get('CourseGroup') . ': ' . $course_group->get_name() . '</h3>';
            $form->display();
            $this->display_footer();
        }
    
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add_help('weblcms_course_group_manage_subscription');
    }

    function get_additional_parameters()
    {
        return array(CourseGroupTool :: PARAM_COURSE_GROUP);
    }

}
?>