<?php
namespace application\weblcms\tool\course_group;

use user\DefaultUserTableCellRenderer;
use application\weblcms\WeblcmsRights;
use application\weblcms\WeblcmsManager;
use application\weblcms\WeblcmsDataManager;
use application\weblcms\Tool;
use common\libraries\Toolbar;
use common\libraries\ToolbarItem;
use user\User;
use group\Group;
use group\GroupDataManager;
use common\libraries\PlatformSetting;
use common\libraries\Theme;
use common\libraries\Request;
use common\libraries\Path;
use common\libraries\Translation;
use application\weblcms\course\CourseUserRelation;
use common\libraries\WebApplication;
use application\weblcms\CourseGroup;
use application\weblcms\tool\user\UserTool;

class CourseGroupsUsersBrowserTableCellRenderer extends DefaultUserTableCellRenderer
{

    // **************************************************************************
    // VARIABLES
    // **************************************************************************

    /**
     * Cache to store the status of unknown groups after retrieval.
     */
    private $unknown_status_cache;

    // **************************************************************************
    // CONSTRUCTOR
    // **************************************************************************

    /**
     * Constructor
     *
     * @param $object_table NewObjectTable
     */
    function __construct($object_table)
    {
        parent :: __construct($object_table);
        $this->unknown_status_cache = array();
    }

    // **************************************************************************
    // GENERAL FUNCTIONS
    // **************************************************************************
    // Inherited

    /**
     * Renders a given cell.
     *
     * @param type $column
     * @param type $user_with_subscription_status User from the advanced join query in weblcms database class that
     *            includes his subscription status.
     * @return type
     */
    function render_cell($column, $user_with_subscription_status_and_type)
    {
        switch ($column->get_name())
        {

            case CourseGroup :: PROPERTY_ID :
                $course_id = $this->get_component()->get_course_id();

                $data_set = WeblcmsDataManager :: get_instance()->retrieve_course_groups_from_user(
                        $user_with_subscription_status_and_type->get_id(), $course_id);

                $course_groups_subscribed = array();
                while ($course_group = $data_set->next_result())
                {
                    $course_groups_subscribed[] = $course_group->get_name();
                }

                $course_groups_string;
                foreach ($course_groups_subscribed as $item)
                {
                    if ($course_groups_string)
                    {
                        $course_groups_string = $course_groups_string . ', ' . $item;
                    }
                    else
                        $course_groups_string = $item;
                }
                return $course_groups_string;
        }

        return parent :: render_cell($column, $user_with_subscription_status_and_type);
    }

    public function get_object_actions($object)
    {
        // construct the toolbar
        $toolbar = new Toolbar(Toolbar :: TYPE_HORIZONTAL);

        $parameters = array();
        $parameters[Tool :: PARAM_ACTION] = UserTool :: ACTION_USER_DETAILS;
        $parameters[UserTool :: PARAM_TAB] = Request :: get(UserTool :: PARAM_TAB);
        $parameters[WeblcmsManager :: PARAM_USERS] = $object->get_id();
        $details_url = $this->get_component()->get_url($parameters);

        // always show details
        $toolbar->add_item(
                new ToolbarItem(Translation :: get('Details'), Theme :: get_common_image_path() . 'action_details.png',
                        $details_url, ToolbarItem :: DISPLAY_ICON));

        // display the actions to change the individual status and unsubscribe if:
        // (1) the user is platform or course admin
        // AND
        // (2) the row is not the current user
        // AND
        // (3) the row is not a group-only subscription
        if (($this->get_component()->get_user()->is_platform_admin() || $this->get_component()->get_course()->is_course_admin(
                $this->get_component()->get_user())) && $object->get_id() != $this->get_component()->get_user()->get_id() && $object->get_optional_property(
                CourseGroupsUsersBrowserTableColumnModel :: SUBSCRIPTION_TYPE) % 2)
        {
            $parameters = array();
            $parameters[Tool :: PARAM_ACTION] = UserTool :: ACTION_UNSUBSCRIBE;
            $parameters[UserTool :: PARAM_TAB] = Request :: get(UserTool :: PARAM_TAB);
            $parameters[WeblcmsManager :: PARAM_USERS] = $object->get_id();
            $unsubscribe_url = $this->get_component()->get_url($parameters);

            $toolbar->add_item(
                    new ToolbarItem(Translation :: get('DirectUnsubscribe'),
                            Theme :: get_common_image_path() . 'action_unsubscribe.png', $unsubscribe_url,
                            ToolbarItem :: DISPLAY_ICON));

//             switch ($object->get_optional_property(CourseGroupsUsersBrowserTableColumnModel :: SUBSCRIPTION_STATUS))
//             {
//                 case CourseUserRelation :: STATUS_TEACHER :
//                     $status_change_url = $this->get_component()->get_status_changer_url($object->get_id(),
//                             CourseUserRelation :: STATUS_STUDENT);
//                     $toolbar->add_item(
//                             new ToolbarItem(Translation :: get('MakeStudent'),
//                                     Theme :: get_image_path(
//                                             WebApplication :: determine_namespace(WeblcmsManager :: APPLICATION_NAME)) . 'action_subscribe_student.png',
//                                     $status_change_url, ToolbarItem :: DISPLAY_ICON));
//                     break;
//                 case CourseUserRelation :: STATUS_STUDENT :
//                     $status_change_url = $this->get_component()->get_status_changer_url($object->get_id(),
//                             CourseUserRelation :: STATUS_TEACHER);
//                     $toolbar->add_item(
//                             new ToolbarItem(Translation :: get('MakeTeacher'),
//                                     Theme :: get_image_path(
//                                             WebApplication :: determine_namespace(WeblcmsManager :: APPLICATION_NAME)) . 'action_subscribe_teacher.png',
//                                     $status_change_url, ToolbarItem :: DISPLAY_ICON));
//                     break;
//             }
        }
        else
        {
            $toolbar->add_item(
                    new ToolbarItem(Translation :: get('UnsubscribeNotAvailableForGroups'),
                            Theme :: get_common_image_path() . 'action_unsubscribe_na.png', null,
                            ToolbarItem :: DISPLAY_ICON));
        }

        // if we have editing rights, display the reporting action
        if ($this->get_component()->is_allowed(WeblcmsRights :: EDIT_RIGHT))
        {
            $params = array();
            $params[WeblcmsManager :: PARAM_USERS] = $object->get_id();
            $params[Tool :: PARAM_ACTION] = UserTool :: ACTION_REPORTING;
            $parameters[UserTool :: PARAM_TAB] = Request :: get(UserTool :: PARAM_TAB);
            $reporting_url = $this->get_component()->get_url($params);

            $toolbar->add_item(
                    new ToolbarItem(Translation :: get('Report'),
                            Theme :: get_common_image_path() . 'action_reporting.png', $reporting_url,
                            ToolbarItem :: DISPLAY_ICON));
        }

        // return
        // return $toolbar->as_html();
    }
}

?>