<?php
namespace application\weblcms\tool\course_group;

use common\libraries\DelegateComponent;
use application\weblcms\CourseGroup;
use application\weblcms\WeblcmsRights;
use application\weblcms\Tool;
use common\libraries\Display;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Utilities;
use repository\content_object\introduction\Introduction;
use application\weblcms\ContentObjectPublication;
use application\weblcms\WeblcmsDataManager;
use application\weblcms\WeblcmsManager;
use common\libraries\PatternMatchCondition;
use repository\ContentObject;
use common\libraries\ActionBarRenderer;
use common\libraries\SubselectCondition;
use repository\RepositoryDataManager;
use common\libraries\ToolbarItem;
use user\User;
use user\UserDataManager;
use common\libraries\Theme;
use common\libraries\OrCondition;
use common\libraries\InCondition;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use common\libraries\DynamicVisualTab;
use common\libraries\DynamicVisualTabsRenderer;
use common\libraries\InequalityCondition;
use application\weblcms\CourseSettingsController;
use common\libraries\NewObjectTableSupport;

class CourseGroupToolSubscriptionsOverviewerComponent extends CourseGroupTool implements NewObjectTableSupport
{
    const TAB_USERS = 1;
    const TAB_COURSE_GROUPS = 2;
    const PLATFORM_GROUP_ROOT_ID = 0;

    private $action_bar;

    private $introduction_text;

    private $current_tab;

    /**
     * Temporary variable for condition building
     *
     * @var int
     */
    private $table_course_group_id;

    function run()
    {
        if (! $this->is_allowed(WeblcmsRights :: EDIT_RIGHT))
        {
            Display :: not_allowed();
            return;
        }

        $this->current_tab = self :: TAB_COURSE_GROUPS;
        if (Request :: get(self :: PARAM_TAB))
        {
            $this->current_tab = Request :: get(self :: PARAM_TAB);
        }

        $this->display_header();

        $course_settings_controller = CourseSettingsController :: get_instance();

        if ($course_settings_controller->get_course_setting($this->get_course_id(),
                \application\weblcms\CourseSettingsConnector :: ALLOW_INTRODUCTION_TEXT))
        {
            echo $this->display_introduction_text($this->get_introduction_text());
        }

        $this->action_bar = $this->get_action_bar();
        echo $this->action_bar->as_html();

        echo $this->get_tabs();

        $this->display_footer();
    }

    // **************************************************************************
    // TABS FUNCTIONS
    // **************************************************************************
    /**
     * Creates the tab structure.
     *
     * @return String HTML of the tab(s)
     */
    private function get_tabs()
    {
        $tabs = new DynamicVisualTabsRenderer('weblcms_course_user_browser');

        // all tab
        $link = $this->get_url(array(self :: PARAM_TAB => self :: TAB_USERS));
        $tab_name = Translation :: get('User');
        $tabs->add_tab(
                new DynamicVisualTab(self :: TAB_USERS, $tab_name, Theme :: get_common_image_path() . 'place_users.png',
                        $link, $this->current_tab == self :: TAB_USERS));

        // users tab
        $link = $this->get_url(array(self :: PARAM_TAB => self :: TAB_COURSE_GROUPS));
        $tab_name = Translation :: get('CourseGroup');
        $tabs->add_tab(
                new DynamicVisualTab(self :: TAB_COURSE_GROUPS, $tab_name,
                        Theme :: get_common_image_path() . 'place_user.png', $link,
                        $this->current_tab == self :: TAB_COURSE_GROUPS));

        $tabs->set_content($this->get_tabs_content());

        return $tabs->render();
    }

    /**
     * Creates the content of the selected tab.
     *
     * @return String HTML of the content
     */
    private function get_tabs_content()
    {
        switch ($this->current_tab)
        {
            case self :: TAB_USERS :
                return $this->get_users_tab();
                break;
            case self :: TAB_COURSE_GROUPS :
                return $this->get_course_groups_tab();
                break;
        }
    }

    private function get_users_tab()
    {
        $parameters = $this->get_parameters();
        $table = new UsersCourseGroupsBrowserTable($this);
        return $table->as_html();
    }

    private function get_course_groups_tab()
    {
        $parameters = $this->get_parameters();
        $course_groups = WeblcmsDataManager :: get_instance()->retrieve_course_groups($this->get_condition(), null,
                null, null, CourseGroup :: CLASS_NAME);
        $html_tables = '';
        while ($course_group = $course_groups->next_result())
        {
            $this->table_course_group_id = $course_group->get_id();

            $table = new CourseGroupsUsersBrowserTable($this);
            $html_tables = $html_tables . '<h4>' . $course_group->get_name() . '</h4>' . $table->as_html();
        }
        return $html_tables;
    }

    function get_table_course_group_id()
    {
        return $this->table_course_group_id;
    }

    function get_object_table_condition($table_name)
    {
        if ($table_name == 'application\weblcms\tool\course_group\CourseGroupsUsersBrowserTable')
        {
            return new EqualityCondition(CourseGroup :: PROPERTY_ID, $this->table_course_group_id,
                    CourseGroup :: get_table_name());
        }
        else
        {
            return $this->get_condition();
        }
    }

    function get_group()
    {
        $group = Request :: get(WeblcmsManager :: PARAM_GROUP);
        if (! $group)
        {
            return self :: PLATFORM_GROUP_ROOT_ID;
        }
        return $group;
    }

    function get_action_bar()
    {
        $action_bar = new ActionBarRenderer(ActionBarRenderer :: TYPE_HORIZONTAL);
        $parameters = array();

        $action_bar->set_search_url($this->get_url($parameters));

        $param_export_subscriptions_overview[Tool :: PARAM_ACTION] = CourseGroupTool :: ACTION_EXPORT_SUBSCRIPTIONS_OVERVIEW;
        $param_export_subscriptions_overview[CourseGroupTool :: PARAM_TAB] = $this->current_tab;

        $show_all_url = $this->get_url();

        if ($this->is_allowed(WeblcmsRights :: VIEW_RIGHT))
        {
            $action_bar->add_common_action(
                    new ToolbarItem(Translation :: get('Export', null, Utilities :: COMMON_LIBRARIES),
                            Theme :: get_common_image_path() . 'action_backup.png',
                            $this->get_url($param_export_subscriptions_overview), ToolbarItem :: DISPLAY_ICON_AND_LABEL));
        }

        return $action_bar;
    }

    function get_condition()
    {
        $conditions = array();
        $search_condition = $this->get_search_condition();
        if ($search_condition)
        {
            $conditions[] = $search_condition;
        }

        if ($this->current_tab == self :: TAB_COURSE_GROUPS)
        {
            $conditions[] = new EqualityCondition(CourseGroup :: PROPERTY_COURSE_CODE, $this->get_course_id());
            $conditions[] = new InequalityCondition(CourseGroup :: PROPERTY_PARENT_ID,
                    InequalityCondition :: GREATER_THAN, 0);
        }
        if ($conditions)
        {
            return new AndCondition($conditions);
        }
        return null;
    }

    function get_search_condition()
    {
        $query = $this->action_bar->get_query();
        if (isset($query) && $query != '')
        {
            $conditions = array();
            switch ($this->current_tab)
            {
                case self :: TAB_USERS :
                    $conditions[] = new PatternMatchCondition(User :: PROPERTY_OFFICIAL_CODE, '*' . $query . '*',
                            UserDataManager :: get_instance()->get_alias(User :: get_table_name()), true);
                    $conditions[] = new PatternMatchCondition(User :: PROPERTY_LASTNAME, '*' . $query . '*',
                            UserDataManager :: get_instance()->get_alias(User :: get_table_name()), true);
                    $conditions[] = new PatternMatchCondition(User :: PROPERTY_FIRSTNAME, '*' . $query . '*',
                            UserDataManager :: get_instance()->get_alias(User :: get_table_name()), true);
                    $conditions[] = new PatternMatchCondition(User :: PROPERTY_USERNAME, '*' . $query . '*',
                            UserDataManager :: get_instance()->get_alias(User :: get_table_name()), true);
                    $conditions[] = new PatternMatchCondition(User :: PROPERTY_EMAIL, '*' . $query . '*',
                            UserDataManager :: get_instance()->get_alias(User :: get_table_name()), true);
                    break;
                case self :: TAB_COURSE_GROUPS :
                    $conditions[] = new PatternMatchCondition(CourseGroup :: PROPERTY_NAME, '*' . $query . '*',
                            WeblcmsDataManager :: get_instance()->get_alias(CourseGroup :: get_table_name()), true);
                    $conditions[] = new PatternMatchCondition(CourseGroup :: PROPERTY_DESCRIPTION, '*' . $query . '*',
                            WeblcmsDataManager :: get_instance()->get_alias(CourseGroup :: get_table_name()), true);
                    break;
            }
            return new OrCondition($conditions);
        }
        return null;
    }

    function get_additional_parameters()
    {
        return array(self :: PARAM_TAB, WeblcmsManager :: PARAM_GROUP);
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add_help('weblcms_course_groups_overview');
    }
}

?>
