<?php
namespace application\weblcms\tool\course_sections;

use application\weblcms\WeblcmsDataManager;
use common\libraries\Display;
use common\libraries\BreadcrumbTrail;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Utilities;
use application\weblcms\CourseSection;

/**
 * $Id: course_sections_deleter.class.php 216 2009-11-13 14:08:06Z kariboe $
 *
 * @package application.lib.weblcms.tool.course_sections.component
 */
class CourseSectionsToolDeleterComponent extends CourseSectionsTool
{

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        $user = $this->get_user();

        if (!$this->get_course()->is_course_admin($this->get_parent()->get_user()))
        {
            $trail = BreadcrumbTrail :: get_instance();
            $trail->add_help('courses sections');
            $this->display_header();
            Display :: error_message(Translation :: get('NotAllowed', null, Utilities :: COMMON_LIBRARIES));
            $this->display_footer();
            exit();
        }

        $ids = Request :: get(CourseSectionsTool :: PARAM_COURSE_SECTION_ID);
        $failures = 0;

        if (! empty($ids))
        {
            if (! is_array($ids))
            {
                $ids = array($ids);
            }

            foreach ($ids as $id)
            {
                $wdm = WeblcmsDataManager :: get_instance();
                $condition = new EqualityCondition(CourseSection :: PROPERTY_ID, $id);
                $course_section = $wdm->retrieve_course_sections($condition)->next_result();

                if (! $course_section->delete())
                {
                    $failures ++;
                }

                $tools = $wdm->get_course_modules(Request :: get('course'));

                $conditions[] = new EqualityCondition(CourseSection :: PROPERTY_TYPE, CourseSection :: TYPE_TOOL);
                $conditions[] = new EqualityCondition(CourseSection :: PROPERTY_COURSE_ID, Request :: get('course'));

                $main_section = $wdm->retrieve_course_sections(new AndCondition($conditions))->next_result();

                foreach ($tools as $tool)
                {
                    if ($tool->section == $id)
                    {
                        $wdm->change_module_course_section($tool->id, $main_section->get_id());
                    }
                }
            }

            if ($failures)
            {
                if (count($ids) == 1)
                {
                    $message = 'SelectedCourseSectionNotDeleted';
                }
                else
                {
                    $message = 'SelectedCourseSectionsNotDeleted';
                }
            }
            else
            {
                if (count($ids) == 1)
                {
                    $message = 'SelectedCourseSectionDeleted';
                }
                else
                {
                    $message = 'SelectedCourseSectionsDeleted';
                }
            }

            $this->redirect(Translation :: get($message), ($failures != 0 ? true : false), array(
                    CourseSectionsTool :: PARAM_ACTION => CourseSectionsTool :: ACTION_VIEW_COURSE_SECTIONS));
        }
        else
        {
            $this->display_error_page(htmlentities(Translation :: get('NoCourseSectionsSelected')));
        }
    }
}
?>