<?php
namespace application\weblcms\tool\document;

use application\weblcms\ContentObjectPublication;
use application\weblcms\WeblcmsDataManager;
use application\weblcms\WeblcmsRights;
use application\weblcms\WeblcmsManager;
use repository\ContentObject;
use repository\RepositoryDataManager;
use common\libraries\Filesystem;
use user\User;
use common\libraries\Display;
use common\libraries\OrCondition;
use common\libraries\InCondition;
use common\libraries\BreadcrumbTrail;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use common\libraries\Path;
use common\libraries\Translation;
use common\libraries\SubselectCondition;
use repository\content_object\document\Document;
use application\weblcms\ContentObjectPublicationUser;
use application\weblcms\ContentObjectPublicationCourseGroup;
use common\libraries\Filecompression;

/**
 * $Id: document_zip_and_download.class.php 216 2009-11-13 14:08:06Z kariboe $
 * 
 * @package application.lib.weblcms.tool.document.component
 */

class DocumentToolZipAndDownloadComponent extends DocumentTool
{
    private $action_bar;
    private $zip_name;

    function run()
    {
        $trail = BreadcrumbTrail :: get_instance();
        $trail->add_help('courses document tool');
        // $this->display_header();
        $archive_url = $this->create_document_archive();
        
        Filesystem :: file_send_for_download($archive_url, true, $this->zip_name . '.zip');
        Filesystem :: remove($archive_url);
    }

    private function create_document_archive()
    {
        $parent = $this->get_parent();
        $count = 0;
        
        $datamanager = WeblcmsDataManager :: get_instance();
        
        $course_name = $this->get_course()->get_title();
        $this->zip_name = $course_name . ' - ' . Translation :: get("Document");
        
        $category_id = $parent->get_parameter(WeblcmsManager :: PARAM_CATEGORY);
        if (! isset($category_id) || $category_id == 0 || strlen($category_id) == 0)
        {
            $category_id = 0;
        }
        else
        {
            $category = $datamanager->retrieve_content_object_publication_category($category_id);
            $this->zip_name .= ' -_' . $category->get_name();
        }
        
        // needed to prevent cutoff at a space char
        $this->zip_name = str_replace(" ", "_", $this->zip_name);
        
        $category_folder_mapping = $this->create_folder_structure($category_id);
        
        $target_path = current($category_folder_mapping);
        foreach ($category_folder_mapping as $category_id => $dir)
        {
            $is_course_admin = $this->get_course()->is_course_admin($this->get_user());
            
            // if we have access, retrieve the publications in the current
            // category
            if ($is_course_admin)
            {
                $conditions = array();
                $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_COURSE_ID, $this->get_course_id());
                $conditions[] = new EqualityCondition(ContentObjectPublication :: PROPERTY_TOOL, 'document');
                $conditions[] = new InCondition(ContentObjectPublication :: PROPERTY_CATEGORY_ID, $category_id);
                
                $subselect_condition = new EqualityCondition(ContentObject :: PROPERTY_TYPE, Document :: get_type_name());
                $conditions[] = new SubselectCondition(ContentObjectPublication :: PROPERTY_CONTENT_OBJECT_ID, ContentObject :: PROPERTY_ID, ContentObject :: get_table_name(), $subselect_condition, null, RepositoryDataManager :: get_instance());
                $condition = new AndCondition($conditions);
                
                $publications = $datamanager->retrieve_content_object_publications($condition);
            }
            else
            {
                if ($category_id == 0)
                {
                    $course_module_id = $this->get_tool_registration()->get_id();
                    $location_id = WeblcmsRights :: get_instance()->get_weblcms_location_by_identifier_from_courses_subtree(WeblcmsRights :: TYPE_COURSE_MODULE, $course_module_id, $this->get_course_id());
                }
                else
                {
                    $location_id = WeblcmsRights :: get_instance()->get_weblcms_location_by_identifier_from_courses_subtree(WeblcmsRights :: TYPE_COURSE_CATEGORY, $category_id, $this->get_course_id());
                }
                
                $publications = $datamanager->retrieve_content_object_publications_with_view_right_granted_in_category_location($location_id, $this->get_entities(), null, array(), 0, -1, $this->get_user_id());
            }
            
            if ($publications)
            {
                while ($publication = $publications->next_result())
                {
                    if (! $is_course_admin && $publication->is_hidden())
                    {
                        if (! $this->is_allowed(WeblcmsRights :: EDIT_RIGHT, $publication))
                        {
                            continue;
                        }
                    }
                    
                    $count ++;
                    $document = $publication->get_content_object();
                    
                    if (! $document instanceof Document)
                    {
                        continue;
                    }
                    
                    $document_path = $document->get_full_path();
                    $archive_file_location = $dir . '/' . Filesystem :: create_unique_name($dir, $document->get_filename());
                    Filesystem :: copy_file($document_path, $archive_file_location);
                }
            }
        }
        
        if ($count == 0)
        {
            $this->display_header();
            $this->get_parent()->display_warning_message(Translation :: get('NoDocumentsPublished'));
            $this->display_footer();
            exit();
        }
        
        $compression = Filecompression :: factory();
        $archive_file = $compression->create_archive($target_path);
        Filesystem :: remove($target_path);
        $archive_url = Path :: get(SYS_PATH) . str_replace(DIRECTORY_SEPARATOR, '/', str_replace(realpath($this->get_parent()->get_path(SYS_PATH)), '', $archive_file));
        return $archive_url;
    }

    /**
     * Creates a folder structure from the given categories.
     * 
     * @param $categories array|int           
     * @param $category_folder_mapping array           
     * @param
     *            $path
     * @return array An array mapping the category id to the folder.
     */
    private function create_folder_structure($parent_cat, &$category_folder_mapping = array(), $path = null)
    {
        if (is_null($path))
        {
            $path = realpath(Path :: get(SYS_TEMP_PATH));
            $path = Filesystem :: create_unique_name($path . '/weblcms_document_download_' . $this->get_course_id());
            $category_folder_mapping[$parent_cat] = $path;
            Filesystem :: create_dir($path);
        }
        
        $conditions[] = new EqualityCondition('course_id', $this->get_course_id());
        $conditions[] = new EqualityCondition('tool', $this->get_tool_id());
        $conditions[] = new EqualityCondition('parent_id', $parent_cat);
        $condition = new AndCondition($conditions);
        $categories = WeblcmsDataManager :: get_instance()->retrieve_content_object_publication_categories($condition);
        
        while ($category = $categories->next_result())
        {
            // Make safe name
            $safe_name = strtr($category->get_name(), 'ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖØÙÚÛÜÝàáâãäåçèéêëìíîïðñòóôõöøùúûüýÿ', 'aaaaaaaceeeeiiiidnoooooouuuuyaaaaaaceeeeiiiidnoooooouuuuyy');
            $safe_name = preg_replace('/[^0-9a-zA-Z\-\s\(\),]/', '_', $safe_name);
            
            $category_path = Filesystem :: create_unique_name($path . '/' . $safe_name);
            $category_folder_mapping[$category->get_id()] = $category_path;
            Filesystem :: create_dir($category_path);
            $this->create_folder_structure($category->get_id(), $category_folder_mapping, $category_path);
        
        }
        
        return $category_folder_mapping;
    }
}

?>