<?php
namespace application\weblcms\tool\glossary;

use repository\content_object\glossary\GlossaryComplexDisplaySupport;
use repository\ComplexDisplay;
use repository\RepositoryRights;

use common\libraries\Request;
use common\libraries\DelegateComponent;
use common\libraries\Translation;

use application\weblcms\Tool;
use application\weblcms\ToolComponent;
use application\weblcms\WeblcmsDataManager;
use application\weblcms\WeblcmsRights;
use common\libraries\Utilities;

/**
 * $Id: glossary_viewer.class.php 216 2009-11-13 14:08:06Z kariboe $
 *
 * @package application.lib.weblcms.tool.glossary.component
 */

/**
 * Represents the view component for the assessment tool.
 */
class GlossaryToolComplexDisplayComponent extends GlossaryTool implements 
        DelegateComponent, 
        GlossaryComplexDisplaySupport
{
    private $publication;

    function run()
    {
        $publication_id = Request :: get(Tool :: PARAM_PUBLICATION_ID);
        $this->set_parameter(Tool :: PARAM_PUBLICATION_ID, $publication_id);
        
        $this->publication = WeblcmsDataManager :: get_instance()->retrieve_content_object_publication($publication_id);
        
        if (! $this->is_allowed(WeblcmsRights :: VIEW_RIGHT, $this->publication))
        {
            $this->redirect(Translation :: get("NotAllowed", null, Utilities :: COMMON_LIBRARIES), true, array(), array(
                    Tool :: PARAM_ACTION, Tool :: PARAM_PUBLICATION_ID));
        }
        
        ComplexDisplay :: launch($this->publication->get_content_object()->get_type(), $this);
    }

    function get_root_content_object()
    {
        return $this->publication->get_content_object();
    }

    function get_additional_parameters()
    {
        return array(Tool :: PARAM_PUBLICATION_ID);
    }

    function display_header()
    {
        return parent :: display_header();
    }
    
    // METHODS FOR COMPLEX DISPLAY RIGHTS
    public function is_allowed_to_edit_content_object()
    {
        return $this->publication->get_content_object()->has_right(RepositoryRights :: COLLABORATE_RIGHT, $this->get_user_id());
    }

    public function is_allowed_to_view_content_object()
    {
        return $this->is_allowed(WeblcmsRights :: VIEW_RIGHT, $this->publication);
    }

    function is_allowed_to_add_child()
    {
        return $this->publication->get_content_object()->has_right(RepositoryRights :: COLLABORATE_RIGHT, $this->get_user_id());
    }

    function is_allowed_to_delete_child()
    {
        return $this->publication->get_content_object()->has_right(RepositoryRights :: COLLABORATE_RIGHT, $this->get_user_id());
    }

    function is_allowed_to_delete_feedback()
    {
        return $this->is_allowed(WeblcmsRights :: EDIT_RIGHT, $this->publication);
    }

    function is_allowed_to_edit_feedback()
    {
        return $this->is_allowed(WeblcmsRights :: EDIT_RIGHT, $this->publication);
    }

}

?>