<?php
namespace application\weblcms\tool\learning_path;

use common\libraries\DelegateComponent;

use repository\content_object\learning_path\LearningPathComplexDisplay;

use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Path;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\WebApplication;
use common\libraries\EqualityCondition;
use common\libraries\AndCondition;
use common\libraries\Display;
use common\libraries\Utilities;

use repository\ComplexDisplay;
use repository\RepositoryDataManager;

use repository\content_object\learning_path\LearningPathComplexDisplaySupport;
use repository\content_object\learning_path\LearningPathDisplay;

use repository\content_object\assessment\AssessmentComplexDisplaySupport;
use repository\content_object\assessment\FeedbackDisplayConfiguration;

use repository\content_object\forum\ForumComplexDisplaySupport;
use repository\content_object\wiki\WikiComplexDisplaySupport;
use repository\content_object\blog\BlogComplexDisplaySupport;
use repository\content_object\glossary\GlossaryComplexDisplaySupport;

use application\weblcms\ToolComponent;
use application\weblcms\Tool;
use application\weblcms\WeblcmsDataManager;
use application\weblcms\WeblcmsManager;
use application\weblcms\WeblcmsLpAttemptTracker;
use application\weblcms\WeblcmsLpiAttemptTracker;
use application\weblcms\WeblcmsLearningPathQuestionAttemptsTracker;
use application\weblcms\WeblcmsForumTopicViewsTracker;
use application\weblcms\WeblcmsRights;

use tracking\Event;

use Exception;
use repository\content_object\learning_path\LearningPathContentObjectDisplay;

class LearningPathToolComplexDisplayComponent extends LearningPathTool implements 
        LearningPathComplexDisplaySupport, 
        AssessmentComplexDisplaySupport, 
        ForumComplexDisplaySupport, 
        GlossaryComplexDisplaySupport, 
        BlogComplexDisplaySupport, 
        WikiComplexDisplaySupport, 
        DelegateComponent
{
    
    private $publication;

    function run()
    {
        $publication_id = Request :: get(Tool :: PARAM_PUBLICATION_ID);
        $this->set_parameter(Tool :: PARAM_PUBLICATION_ID, $publication_id);
        $this->publication = WeblcmsDataManager :: get_instance()->retrieve_content_object_publication($publication_id);
        
        if (! $this->is_allowed(WeblcmsRights :: VIEW_RIGHT, $this->publication))
        {
            $this->redirect(Translation :: get("NotAllowed", null, Utilities :: COMMON_LIBRARIES), true, array(), array(
                    Tool :: PARAM_ACTION, Tool :: PARAM_PUBLICATION_ID));
        }
        BreadcrumbTrail :: get_instance()->add(new Breadcrumb(null, $this->get_root_content_object()->get_title()));
        
        ComplexDisplay :: launch($this->get_root_content_object()->get_type(), $this);
    }

    function get_root_content_object()
    {
        $embedded_content_object_id = LearningPathContentObjectDisplay :: get_embedded_content_object_id();
        
        if ($embedded_content_object_id)
        {
            $this->set_parameter(LearningPathContentObjectDisplay :: PARAM_EMBEDDED_CONTENT_OBJECT_ID, $embedded_content_object_id);
            return RepositoryDataManager :: get_instance()->retrieve_content_object($embedded_content_object_id);
        }
        else
        {
            $this->set_parameter(LearningPathComplexDisplay :: PARAM_LEARNING_PATH_ITEM_ID, Request :: get(LearningPathComplexDisplay :: PARAM_LEARNING_PATH_ITEM_ID));
            $this->set_parameter(ComplexDisplay :: PARAM_COMPLEX_CONTENT_OBJECT_ITEM_ID, Request :: get(ComplexDisplay :: PARAM_COMPLEX_CONTENT_OBJECT_ITEM_ID));
            return $this->publication->get_content_object();
        }
    }

    function display_header()
    {
        $embedded_content_object_id = LearningPathContentObjectDisplay :: get_embedded_content_object_id();
        
        if ($embedded_content_object_id)
        {
            Display :: small_header();
        }
        else
        {
            parent :: display_header();
        }
    }

    function display_footer()
    {
        $embedded_content_object_id = LearningPathContentObjectDisplay :: get_embedded_content_object_id();
        
        if ($embedded_content_object_id)
        {
            Display :: small_footer();
        }
        else
        {
            parent :: display_footer();
        }
    }

    function get_publication()
    {
        return $this->publication;
    }

    function get_additional_parameters()
    {
        return array(Tool :: PARAM_PUBLICATION_ID);
    }

    function retrieve_learning_path_tracker()
    {
        $conditions[] = new EqualityCondition(WeblcmsLpAttemptTracker :: PROPERTY_COURSE_ID, $this->get_course_id());
        $conditions[] = new EqualityCondition(WeblcmsLpAttemptTracker :: PROPERTY_LP_ID, $this->get_publication()->get_id());
        $conditions[] = new EqualityCondition(WeblcmsLpAttemptTracker :: PROPERTY_USER_ID, $this->get_user_id());
        $condition = new AndCondition($conditions);
        
        $dummy = new WeblcmsLpAttemptTracker();
        $trackers = $dummy->retrieve_tracker_items($condition);
        $learning_path_tracker = $trackers[0];
        
        if (! $learning_path_tracker)
        {
            $parameters = array();
            $parameters[WeblcmsLpAttemptTracker :: PROPERTY_USER_ID] = $this->get_user_id();
            $parameters[WeblcmsLpAttemptTracker :: PROPERTY_COURSE_ID] = $this->get_course_id();
            $parameters[WeblcmsLpAttemptTracker :: PROPERTY_LP_ID] = $this->get_publication()->get_id();
            $parameters[WeblcmsLpAttemptTracker :: PROPERTY_PROGRESS] = 0;
            
            $return = Event :: trigger('attempt_learning_path', WeblcmsManager :: APPLICATION_NAME, $parameters);
            $learning_path_tracker = $return[0];
        }
        
        return $learning_path_tracker;
    }

    function retrieve_learning_path_tracker_items($learning_path_tracker)
    {
        $learning_path_item_attempt_data = array();
        
        $condition = new EqualityCondition(WeblcmsLpiAttemptTracker :: PROPERTY_LP_VIEW_ID, $learning_path_tracker->get_id());
        
        $dummy = new WeblcmsLpiAttemptTracker();
        $trackers = $dummy->retrieve_tracker_items($condition);
        
        foreach ($trackers as $tracker)
        {
            $item_id = $tracker->get_lp_item_id();
            
            if (! $learning_path_item_attempt_data[$item_id])
            {
                $learning_path_item_attempt_data[$item_id]['score'] = 0;
                $learning_path_item_attempt_data[$item_id]['time'] = 0;
            }
            
            $learning_path_item_attempt_data[$item_id]['trackers'][] = $tracker;
            $learning_path_item_attempt_data[$item_id]['size'] ++;
            $learning_path_item_attempt_data[$item_id]['score'] += $tracker->get_score();
            
            if ($tracker->get_total_time())
            {
                $learning_path_item_attempt_data[$item_id]['time'] += $tracker->get_total_time();
            }
            
            if ($tracker->get_status() == 'completed' || $tracker->get_status() == 'passed')
            {
                $learning_path_item_attempt_data[$item_id]['completed'] = 1;
            }
            else
            {
                $learning_path_item_attempt_data[$item_id]['active_tracker'] = $tracker;
            }
        }
        
        return $learning_path_item_attempt_data;
    }

    function get_learning_path_tree_menu_url()
    {
        return Path :: get(WEB_PATH) . 'index.php?go=course_viewer&course=' . Request :: get('course') . '&application=weblcms&tool=learning_path&tool_action=complex_display&publication=' . $this->publication->get_id() . '&' . LearningPathComplexDisplay :: PARAM_STEP . '=%s';
    }

    /**
     *
     * @param $total_steps int           
     */
    function get_learning_path_previous_url($total_steps)
    {
        return $this->get_url(array(Tool :: PARAM_ACTION => LearningPathTool :: ACTION_DISPLAY_COMPLEX_CONTENT_OBJECT, 
                LearningPathTool :: PARAM_PUBLICATION_ID => Request :: get(Tool :: PARAM_PUBLICATION_ID), 
                'step' => $total_steps));
    }

    /**
     * Creates a learning path item tracker
     *
     * @param $learning_path_tracker LearningPathAttemptTracker           
     * @param $current_complex_content_object_item ComplexContentObjectItem           
     * @return array LearningPathItemAttemptTracker
     */
    function create_learning_path_item_tracker($learning_path_tracker, $current_complex_content_object_item)
    {
        $parameters = array();
        $parameters[WeblcmsLpiAttemptTracker :: PROPERTY_LP_VIEW_ID] = $learning_path_tracker->get_id();
        $parameters[WeblcmsLpiAttemptTracker :: PROPERTY_LP_ITEM_ID] = $current_complex_content_object_item->get_id();
        $parameters[WeblcmsLpiAttemptTracker :: PROPERTY_START_TIME] = time();
        $parameters[WeblcmsLpiAttemptTracker :: PROPERTY_TOTAL_TIME] = 0;
        $parameters[WeblcmsLpiAttemptTracker :: PROPERTY_SCORE] = 0;
        $parameters[WeblcmsLpiAttemptTracker :: PROPERTY_MIN_SCORE] = 0;
        $parameters[WeblcmsLpiAttemptTracker :: PROPERTY_MAX_SCORE] = 0;
        $parameters[WeblcmsLpiAttemptTracker :: PROPERTY_STATUS] = 'not attempted';
        
        $result = Event :: trigger('attempt_learning_path_item', WeblcmsManager :: APPLICATION_NAME, $parameters);
        return $result[0];
    }

    /**
     *
     * @param $complex_content_object_id int           
     */
    function get_learning_path_content_object_item_details_url($complex_content_object_id)
    {
        return $this->get_url(array(Tool :: PARAM_ACTION => LearningPathTool :: ACTION_DISPLAY_COMPLEX_CONTENT_OBJECT, 
                Tool :: PARAM_PUBLICATION_ID => $this->publication->get_id(), 
                LearningPathComplexDisplay :: PARAM_SHOW_PROGRESS => 'true', 
                ComplexDisplay :: PARAM_COMPLEX_CONTENT_OBJECT_ITEM_ID => $complex_content_object_id, 
                'attempt_id' => Request :: get('attempt_id')));
    }

    /**
     * Get the url of the assessment result
     *
     * @param $complex_content_object_id int           
     * @param $details unknown_type           
     */
    function get_learning_path_content_object_assessment_result_url($complex_content_object_id, $details)
    {
        return $this->get_url(array(Tool :: PARAM_ACTION => LearningPathTool :: ACTION_DISPLAY_COMPLEX_CONTENT_OBJECT, 
                Tool :: PARAM_PUBLICATION_ID => $this->publication->get_id(), 
                LearningPathComplexDisplay :: PARAM_SHOW_PROGRESS => 'true', 
                ComplexDisplay :: PARAM_COMPLEX_CONTENT_OBJECT_ITEM_ID => $complex_content_object_id, 
                LearningPathComplexDisplay :: PARAM_DETAILS => $details));
    }

    /**
     *
     * @return array
     */
    function get_learning_path_attempt_progress_details_reporting_template_name()
    {
        return 'learning_path_attempt_progress_details_reporting_template';
    }

    /**
     *
     * @return array
     */
    function get_learning_path_attempt_progress_reporting_template_name()
    {
        return 'learning_path_attempt_progress_reporting_template';
    }

    function get_learning_path_template_application_name()
    {
        return WeblcmsManager :: APPLICATION_NAME;
    }

    function save_assessment_answer($complex_question_id, $answer, $score)
    {
        $tracker = $this->retrieve_learning_path_tracker();
        $items = $this->retrieve_learning_path_tracker_items($tracker);
        
        $parameters = array();
        $parameters[WeblcmsLearningPathQuestionAttemptsTracker :: PROPERTY_LPI_ATTEMPT_ID] = $this->get_parameter(LearningPathComplexDisplay :: PARAM_LEARNING_PATH_ITEM_ID);
        $parameters[WeblcmsLearningPathQuestionAttemptsTracker :: PROPERTY_QUESTION_CID] = $complex_question_id;
        $parameters[WeblcmsLearningPathQuestionAttemptsTracker :: PROPERTY_ANSWER] = $answer;
        $parameters[WeblcmsLearningPathQuestionAttemptsTracker :: PROPERTY_SCORE] = $score;
        $parameters[WeblcmsLearningPathQuestionAttemptsTracker :: PROPERTY_FEEDBACK] = '';
        
        Event :: trigger('attempt_learning_path_question', WeblcmsManager :: APPLICATION_NAME, $parameters);
    }

    function save_assessment_result($total_score)
    {
        $condition = new EqualityCondition(WeblcmsLpiAttemptTracker :: PROPERTY_ID, $this->get_parameter(LearningPathComplexDisplay :: PARAM_LEARNING_PATH_ITEM_ID));
        
        $dummy = new WeblcmsLpiAttemptTracker();
        $trackers = $dummy->retrieve_tracker_items($condition);
        $lpi_tracker = $trackers[0];
        
        if (! $lpi_tracker)
        {
            return;
        }
        
        $lpi_tracker->set_score($total_score);
        $lpi_tracker->set_total_time($lpi_tracker->get_total_time() + (time() - $lpi_tracker->get_start_time()));
        
        $cloi = RepositoryDataManager :: get_instance()->retrieve_complex_content_object_item(Request :: get(ComplexDisplay :: PARAM_COMPLEX_CONTENT_OBJECT_ITEM_ID));
        $lp_item = RepositoryDataManager :: get_instance()->retrieve_content_object($cloi->get_ref());
        $mastery_score = $lp_item->get_mastery_score();
        
        if ($mastery_score)
        {
            $status = ($total_score >= $mastery_score) ? 'passed' : 'failed';
        }
        else
        {
            $status = 'completed';
        }
        
        $lpi_tracker->set_status($status);
        $lpi_tracker->update();
    }

    function get_assessment_current_attempt_id()
    {
        return $this->get_parameter(LearningPathComplexDisplay :: PARAM_LEARNING_PATH_ITEM_ID);
    }

    function get_assessment_feedback_configuration($complex_content_object_item)
    {
        $default_configuration = new FeedbackDisplayConfiguration();
        $default_configuration->set_feedback_type(FeedbackDisplayConfiguration :: TYPE_BOTH);
        $default_configuration->disable_feedback_per_page();
        $default_configuration->enable_feedback_summary();
        return $default_configuration;
    }

    function get_assessment_parameters()
    {
        return array(LearningPathComplexDisplay :: PARAM_LEARNING_PATH_ITEM_ID, 
                ComplexDisplay :: PARAM_COMPLEX_CONTENT_OBJECT_ITEM_ID, LearningPathComplexDisplay :: PARAM_STEP);
    }

    function get_assessment_question_attempts()
    {
        $assessment_question_attempt_data = array();
        
        $condition = new EqualityCondition(WeblcmsLearningPathQuestionAttemptsTracker :: PROPERTY_LPI_ATTEMPT_ID, $this->get_parameter(LearningPathComplexDisplay :: PARAM_LEARNING_PATH_ITEM_ID));
        
        $dummy = new WeblcmsLearningPathQuestionAttemptsTracker();
        $trackers = $dummy->retrieve_tracker_items($condition);
        
        foreach ($trackers as $tracker)
        {
            $assessment_question_attempt_data[$tracker->get_question_cid()] = $tracker;
        }
        
        return $assessment_question_attempt_data;
    }

    function get_assessment_question_attempt($complex_question_id)
    {
        $answers = $this->get_assessment_question_attempts($complex_question_id);
        return $answers[$complex_question_id];
    }

    function forum_topic_viewed($complex_topic_id)
    {
        $parameters = array();
        $parameters[WeblcmsForumTopicViewsTracker :: PROPERTY_USER_ID] = $this->get_user_id();
        $parameters[WeblcmsForumTopicViewsTracker :: PROPERTY_PUBLICATION_ID] = $this->get_publication()->get_id();
        $parameters[WeblcmsForumTopicViewsTracker :: PROPERTY_FORUM_TOPIC_ID] = $complex_topic_id;
        
        Event :: trigger('view_forum_topic', WeblcmsManager :: APPLICATION_NAME, $parameters);
    }

    function forum_count_topic_views($complex_topic_id)
    {
        $conditions[] = new EqualityCondition(WeblcmsForumTopicViewsTracker :: PROPERTY_PUBLICATION_ID, $this->get_publication()->get_id());
        $conditions[] = new EqualityCondition(WeblcmsForumTopicViewsTracker :: PROPERTY_FORUM_TOPIC_ID, $complex_topic_id);
        $condition = new AndCondition($conditions);
        
        $dummy = new WeblcmsForumTopicViewsTracker();
        return $dummy->count_tracker_items($condition);
    }

    /**
     * Returns whether or not the logged in user is a forum manager
     *
     * @return boolean
     */
    function is_forum_manager($user)
    {
        return $this->get_course()->is_course_admin($user);
    }

    public function get_wiki_page_statistics_reporting_template_name()
    {
    
    }

    public function get_wiki_statistics_reporting_template_name()
    {
    
    }

    public function get_wiki_publication()
    {
        throw new Exception("Unimplemented method : " . "application\\weblcms\\tool\\learning_path\\" . _CLASS__ . "get_wiki_publication()");
    }

    function get_assessment_continue_url()
    {
    
    }

    function get_assessment_back_url()
    {
    
    }

    function get_assessment_current_url()
    {
        return sprintf($this->get_learning_path_tree_menu_url(), Request :: get(LearningPathComplexDisplay :: PARAM_STEP));
    }
    
    
    // METHODS FOR COMPLEX DISPLAY RIGHTS
    public function is_allowed_to_edit_content_object()
    {
        return $this->is_allowed(WeblcmsRights :: EDIT_RIGHT, $this->publication);
    }
    
    public function is_allowed_to_view_content_object()
    {
        return $this->is_allowed(WeblcmsRights :: VIEW_RIGHT, $this->publication);
    }
    
    function is_allowed_to_add_child()
    {
        return $this->is_allowed(WeblcmsRights :: EDIT_RIGHT, $this->publication);
    }
    
    function is_allowed_to_delete_child()
    {
        return $this->is_allowed(WeblcmsRights :: EDIT_RIGHT, $this->publication);
    }
    
    function is_allowed_to_delete_feedback()
    {
        return $this->is_allowed(WeblcmsRights :: EDIT_RIGHT, $this->publication);
    }
    
    function is_allowed_to_edit_feedback()
    {
        return $this->is_allowed(WeblcmsRights :: EDIT_RIGHT, $this->publication);
    }
}
?>
