<?php
namespace application\weblcms\tool\user;
use common\libraries\Utilities;
use common\libraries\Translation;
use common\libraries\Request;
use common\libraries\ObjectTable;
use common\libraries\ObjectTableFormActions;
use common\libraries\ObjectTableFormAction;
use common\libraries\Path;
use application\weblcms\Tool;

use application\weblcms\WeblcmsRights;

/**
 * * ***************************************************************************
 * Table to display a list of groups directly subscribed to a course.
 *
 * @author Stijn Van Hoecke
 *        
 *         ****************************************************************************
 */
class DirectSubscribedPlatformGroupBrowserTable extends ObjectTable
{
    const DEFAULT_ROW_COUNT = 20;

    /**
     * Constructor
     * 
     * @see ContentObjectTable::ContentObjectTable()
     */
    function __construct($browser, $parameters, $condition, $direct_subscription = true)
    {
        // model - cell renderer - data provider
        $model = new DirectSubscribedPlatformGroupBrowserTableColumnModel();
        $renderer = new DirectSubscribedPlatformGroupBrowserTableCellRenderer($browser);
        $data_provider = new DirectSubscribedPlatformGroupBrowserTableDataProvider($browser, $condition);
        
        // parent construct
        parent :: __construct($data_provider, Utilities :: get_classname_from_namespace(__CLASS__, true), $model, $renderer);
        
        // defaults
        $this->set_additional_parameters($parameters);
        $this->set_default_row_count(self :: DEFAULT_ROW_COUNT);
        
        // actions
        if ($browser->is_allowed(WeblcmsRights :: EDIT_RIGHT))
        {
            $actions = new ObjectTableFormActions(__NAMESPACE__, Tool :: PARAM_ACTION);
            
            // unsubscribe
            $actions->add_form_action(new ObjectTableFormAction(UserTool :: ACTION_UNSUBSCRIBE_GROUPS, Translation :: get('UnsubscribeSelectedGroups'), false));
            
            // make teacher
            $actions->add_form_action(new ObjectTableFormAction(UserTool :: ACTION_CHANGE_PLATFORMGROUP_STATUS_TEACHER, Translation :: get('MakeTeacher'), false));
            
            // make student
            $actions->add_form_action(new ObjectTableFormAction(UserTool :: ACTION_CHANGE_PLATFORMGROUP_STATUS_STUDENT, Translation :: get('MakeStudent'), false));
            
            $this->set_form_actions($actions);
        
        }
    
    }

    static function handle_table_action()
    {
        $class = Utilities :: get_classname_from_namespace(__CLASS__, true);
        $ids = self :: get_selected_ids($class);
        Request :: set_get(UserTool :: PARAM_TAB, Request :: get(UserTool :: PARAM_TAB));
        Request :: set_get(UserTool :: PARAM_OBJECTS, $ids); // objects for
                                                             // status changer
    }
}
?>