<?php
namespace application\weblcms\tool\user;
use common\libraries\WebApplication;
use common\libraries\Utilities;
use common\libraries\Translation;
use common\libraries\EqualityCondition;
use common\libraries\ToolbarItem;
use common\libraries\Toolbar;
use common\libraries\Theme;
use common\libraries\Path;
use group\DefaultGroupTableCellRenderer;
use group\Group;
use application\weblcms\WeblcmsManager;
use application\weblcms\WeblcmsRights;
use application\weblcms\Tool;
use common\libraries\Request;
use application\weblcms\course\CourseGroupRelation;
use application\weblcms\CourseManagementRights;

/**
 * * ***************************************************************************
 * Cell renderer for a direct subscribed course group browser table.
 *
 * @author Stijn Van Hoecke
 *
 *         ****************************************************************************
 */
class DirectSubscribedPlatformGroupBrowserTableCellRenderer extends DefaultGroupTableCellRenderer
{

    /**
     * The repository browser component
     */
    private $browser;

    /**
     * Constructor
     *
     * @param $browser RepositoryManagerBrowserComponent
     */
    function __construct($browser)
    {
        parent :: __construct();
        $this->browser = $browser;
    }

    // Inherited
    function render_cell($column, $group_with_subscription_status)
    {
        if ($column === DirectSubscribedPlatformGroupBrowserTableColumnModel :: get_modification_column())
        {
            return $this->get_modification_links($group_with_subscription_status);
        }
        // Add special features here
        switch ($column->get_name())
        {
            // Exceptions that need post-processing go here ...
            case Group :: PROPERTY_DESCRIPTION :
                $description = strip_tags(parent :: render_cell($column, $group_with_subscription_status));
                return Utilities :: truncate_string($description);
            case CourseGroupRelation :: PROPERTY_STATUS :
                switch ($group_with_subscription_status->get_optional_property(CourseGroupRelation :: PROPERTY_STATUS))
                {
                    case CourseGroupRelation :: STATUS_TEACHER :
                        return Translation :: get('CourseAdmin');
                    case CourseGroupRelation :: STATUS_STUDENT :
                        return Translation :: get('Student');
                    default :
                        return Translation :: get('Unknown');
                }
        }

        return parent :: render_cell($column, $group_with_subscription_status);
    }

    /**
     * Gets the action links to display
     *
     * @param $content_object ContentObject
     *            The learning object for which the
     *            action links should be returned
     * @return string A HTML representation of the action links
     */
    private function get_modification_links($group_with_subscription_status)
    {
        $toolbar = new Toolbar();

        if ($this->browser->is_allowed(WeblcmsRights :: EDIT_RIGHT))
        {
            if($this->browser->get_user()->is_platform_admin() || (
                $this->browser->is_allowed(WeblcmsRights :: EDIT_RIGHT) &&
                CourseManagementRights :: get_instance()->is_allowed_for_platform_group(
                    CourseManagementRights :: TEACHER_UNSUBSCRIBE_RIGHT, $group_with_subscription_status->get_id(),
                    $this->browser->get_course_id())))
        	{
                    // unsubscribe group
                        $parameters[Tool :: PARAM_ACTION] = UserTool :: ACTION_UNSUBSCRIBE_GROUPS;
                    $parameters[UserTool :: PARAM_TAB] = Request :: get(UserTool :: PARAM_TAB);
                        $parameters[UserTool :: PARAM_OBJECTS] = $group_with_subscription_status->get_id();
                    $toolbar->add_item(new ToolbarItem(Translation :: get('UnsubscribeGroup'), Theme :: get_common_image_path() . 'action_unsubscribe.png', $this->browser->get_url($parameters), ToolbarItem :: DISPLAY_ICON));
        	}
                
            // change status
            switch ($group_with_subscription_status->get_optional_property(CourseGroupRelation :: PROPERTY_STATUS))
            {
                case CourseGroupRelation :: STATUS_TEACHER :
                    $status_change_url = $this->browser->get_platformgroup_status_changer_url($group_with_subscription_status->get_id(), CourseGroupRelation :: STATUS_STUDENT);
                    $toolbar->add_item(new ToolbarItem(Translation :: get('MakeStudent'), Theme :: get_image_path(WebApplication :: determine_namespace(WeblcmsManager :: APPLICATION_NAME)) . 'action_subscribe_student.png', $status_change_url, ToolbarItem :: DISPLAY_ICON));
                    break;
                case CourseGroupRelation :: STATUS_STUDENT :
                    $status_change_url = $this->browser->get_platformgroup_status_changer_url($group_with_subscription_status->get_id(), CourseGroupRelation :: STATUS_TEACHER);
                    $toolbar->add_item(new ToolbarItem(Translation :: get('MakeTeacher'), Theme :: get_image_path(WebApplication :: determine_namespace(WeblcmsManager :: APPLICATION_NAME)) . 'action_subscribe_teacher.png', $status_change_url, ToolbarItem :: DISPLAY_ICON));
                    break;
            }
        }

        return $toolbar->as_html();
    }

}

?>