<?php
namespace application\weblcms\tool\user;

use application\weblcms\Tool;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Translation;
use application\weblcms\WeblcmsManager;
use application\weblcms\WeblcmsDataManager;
use common\libraries\Application;
use common\libraries\Request;
use common\libraries\Utilities;
use common\libraries\Display;
use application\weblcms\WeblcmsRights;

abstract class UserToolStatusChangerComponent extends UserTool
{
    
    protected $object;

    function run()
    {
        if (! $this->is_allowed(WeblcmsRights :: EDIT_RIGHT))
        {
            Display :: not_allowed();
        }
        
        $objects = Request :: get(self :: PARAM_OBJECTS);
        // $status = Request :: get(self :: PARAM_STATUS);
        
        if (! $objects/* || !$status*/)
        {
            $this->display_error_page(Translation :: get('NoObjectSelected', null, Utilities :: COMMON_LIBRARIES));
            exit();
        }
        
        if (! is_array($objects))
        {
            $objects = array($objects);
        }
        
        $failed = 0;
        
        foreach ($objects as $this->object)
        {
            $relation = $this->get_relation(); // abstract -> implementation
                                               // gets user or group relation
            if (! $relation)
            {
                $failed ++;
            }
            
            // $relation->set_status($status);
            $relation->set_status($this->get_status());
            if (! $relation->update())
            {
                $failed ++;
            }
        }
        
        $message = $this->get_general_result($failed, count($objects), Translation :: get('UserStatus'), Translation :: get('UserStatusses'), Application :: RESULT_TYPE_UPDATED);
        
        $this->redirect($message, $failed > 0, array(Tool :: PARAM_ACTION => UserTool :: ACTION_UNSUBSCRIBE_BROWSER, 
                UserTool :: PARAM_TAB => Request :: get(UserTool :: PARAM_TAB)));
    
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add(new Breadcrumb($this->get_url(array(
                Tool :: PARAM_ACTION => UserTool :: ACTION_UNSUBSCRIBE_BROWSER, 
                UserTool :: PARAM_TAB => Request :: get(UserTool :: PARAM_TAB))), Translation :: get('UserToolUnsubscribeUserBrowserComponent')));
    }

    function get_additional_parameters()
    {
        $params = array();
        $params[] = self :: PARAM_TAB;
        if (Request :: get(WeblcmsManager :: PARAM_GROUP))
        {
            $params[] = WeblcmsManager :: PARAM_GROUP;
        }
        return $params;
    }

    abstract function get_relation();

    abstract function get_status();
}
?>