<?php
namespace application\weblcms\tool\user;

use application\weblcms\Tool;
use application\weblcms\course\CourseDataManager;
use common\libraries\Request;
use common\libraries\Translation;
use application\weblcms\WeblcmsRights;
use common\libraries\Display;
use application\weblcms\CourseManagementRights;
use application\weblcms\WeblcmsDataManager;

/**
 * $Id: subscribe.class.php 218 2009-11-13 14:21:26Z kariboe $
 * @package application.lib.weblcms.weblcms_manager.component
 */
/**
 * Weblcms component which allows the user to manage his or her course subscriptions
 */
class UserToolSubscribeComponent extends UserTool
{

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        if(! $this->is_allowed(WeblcmsRights :: EDIT_RIGHT))
        {
            Display :: not_allowed();
        }
        
        $course = $this->get_course();
        $users = Request :: get(UserTool :: PARAM_OBJECTS);
        if (isset($users) && ! is_array($users))
        {
            $users = array($users);
        }
        if (isset($course))
        {
            if (isset($users) && count($users) > 0)
            {
                $failures = 0;

                $course_management_rights = CourseManagementRights :: get_instance();
                $dm = WeblcmsDataManager :: get_instance();

                foreach ($users as $user_id)
                {
                    $status = Request :: get(UserTool :: PARAM_STATUS) ? Request :: get(UserTool :: PARAM_STATUS) :
                        5;

                    if(CourseDataManager :: is_user_direct_subscribed_to_course($user_id, $course) || (!$this->get_user()
                        ->is_platform_admin() && !$course_management_rights->is_allowed(
                            CourseManagementRights :: TEACHER_DIRECT_SUBSCRIBE_RIGHT, $course->get_id(),
                            CourseManagementRights :: TYPE_COURSE, $user_id)))
                    {
                        $failures++;
                        continue;
                    }

                    if (! $this->get_parent()->subscribe_user_to_course($course, $status, '0', $user_id))
                    {
                        $failures ++;
                    }
                }

                if ($failures == 0)
                {
                    $success = true;

                    if (count($users) == 1)
                    {
                        $message = 'UserSubscribedToCourse';
                    }
                    else
                    {
                        $message = 'UsersSubscribedToCourse';
                    }
                }
                elseif ($failures == count($users))
                {
                    $success = false;

                    if (count($users) == 1)
                    {
                        $message = 'UserNotSubscribedToCourse';
                    }
                    else
                    {
                        $message = 'UsersNotSubscribedToCourse';
                    }
                }
                else
                {
                    $success = false;
                    $message = 'PartialUsersNotSubscribedToCourse';
                }

                $this->redirect(Translation :: get($message), ($success ? false : true), array(Tool :: PARAM_ACTION => UserTool :: ACTION_SUBSCRIBE_USER_BROWSER));
            }
        }
    }
}
?>