<?php

namespace application\weblcms\tool\user;

use application\weblcms\course\CourseUserRelation;
use application\weblcms\WeblcmsRights;
use application\weblcms\WeblcmsManager;
use application\weblcms\Tool;
use common\libraries\PatternMatchCondition;
use common\libraries\ActionBarRenderer;
use common\libraries\NotCondition;
use common\libraries\ToolbarItem;
use user\User;
use common\libraries\Display;
use common\libraries\Theme;
use common\libraries\OrCondition;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use common\libraries\Translation;
use common\libraries\ActionBarSearchForm;
use common\libraries\Request;
use common\libraries\ConditionProperty;
use common\libraries\NewObjectTableSupport;

/**
 * $Id: user_subscribe_browser.class.php 216 2009-11-13 14:08:06Z kariboe $
 * 
 * @package application.lib.weblcms.tool.user.component
 */
class UserToolSubscribeBrowserComponent extends UserTool implements NewObjectTableSupport
{
    
    private $action_bar;

    function run()
    {
        if (! $this->is_allowed(WeblcmsRights :: EDIT_RIGHT))
        {
            Display :: not_allowed();
        }
        
        $this->action_bar = $this->get_action_bar();
        $trail = BreadcrumbTrail :: get_instance();
        
        $this->display_header();
        
        // echo '<br /><a name="top"></a>';
        // echo $this->perform_requested_actions();
        echo $this->action_bar->as_html();
        echo $this->get_user_subscribe_html();
        
        $this->display_footer();
    }

    function get_user_subscribe_html()
    {
        $table = new UnsubscribedUserBrowserTable($this);
        
        $html = array();
        $html[] = $table->as_html();
        
        return implode($html, "\n");
    }

    function get_action_bar()
    {
        $action_bar = new ActionBarRenderer(ActionBarRenderer :: TYPE_HORIZONTAL);
        
        $action_bar->set_search_url($this->get_url());
        
        $action_bar->add_common_action(new ToolbarItem(Translation :: get('ViewUsers'), Theme :: get_common_image_path() . 'action_browser.png', $this->get_url(array(
                UserTool :: PARAM_ACTION => UserTool :: ACTION_UNSUBSCRIBE_BROWSER)), ToolbarItem :: DISPLAY_ICON_AND_LABEL));
        
        return $action_bar;
    }

    function get_condition()
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(User :: PROPERTY_ACTIVE, true);

        $query = $this->action_bar->get_query();
        if (isset($query) && $query != '')
        {
            // $conditions[] = new PatternMatchCondition(User ::
            // PROPERTY_USERNAME, '*' . $query . '*', User :: get_table_name());
            // $conditions[] = new PatternMatchCondition(User ::
            // PROPERTY_FIRSTNAME, '*' . $query . '*', User ::
            // get_table_name());
            // $conditions[] = new PatternMatchCondition(User ::
            // PROPERTY_LASTNAME, '*' . $query . '*', User :: get_table_name());
            // return new OrCondition($conditions);

            $storage_unit = User :: get_table_name();

            $conditions[] = $this->action_bar->get_conditions(array(
                    new ConditionProperty(User :: PROPERTY_OFFICIAL_CODE, $storage_unit),
                    new ConditionProperty(User :: PROPERTY_LASTNAME, $storage_unit),
                    new ConditionProperty(User :: PROPERTY_FIRSTNAME, $storage_unit),
                    new ConditionProperty(User :: PROPERTY_USERNAME, $storage_unit)));
        }

        return new AndCondition($conditions);
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add_help('weblcms_user_subscribe_browser');
    }

    function get_additional_parameters()
    {
        return array(self :: PARAM_TAB, WeblcmsManager :: PARAM_GROUP);
    }

    public function get_object_table_condition($object_table_class_name)
    {
        return $this->get_condition();
    }

    public function get_parameters()
    {
        $parameters = parent :: get_parameters();
        $parameters[ActionBarSearchForm :: PARAM_SIMPLE_SEARCH_QUERY] = $this->action_bar->get_query();
        return $parameters;
    }

}

?>