<?php
namespace application\weblcms\tool\user;

use application\weblcms\WeblcmsManager;
use application\weblcms\Tool;
use common\libraries\Utilities;
use common\libraries\Request;
use common\libraries\ObjectTable;
use common\libraries\Translation;
use common\libraries\ObjectTableFormActions;
use common\libraries\ObjectTableFormAction;
use common\libraries\NewObjectTable;
use common\libraries\NewObjectTableFormActionsSupport;


/** * ***************************************************************************
 * Table to display a list of users in a course (direct subscribed or platform group).
 *
 * @author Stijn Van Hoecke
 * **************************************************************************** */
class SubscribedUserBrowserTable extends NewObjectTable implements NewObjectTableFormActionsSupport
{
    //**************************************************************************
    // GENERAL CONSTANTS
    //**************************************************************************
    const DEFAULT_NAME = 'direct_subscribed_user_browser_table';
    const DEFAULT_ROW_COUNT = 20;

    //**************************************************************************
    // CONSTRUCTOR
    //**************************************************************************
    /**
     * Constructor
     
    function __construct($browser, $parameters = array(), $condition = null, $allow_actions = true)
    {        
        // model - renderer - dataprovider
        $model = new SubscribedUserBrowserTableColumnModel();
        $renderer = new SubscribedUserBrowserTableCellRenderer($browser, $allow_actions);
        $data_provider = new SubscribedUserBrowserTableDataProvider($browser, $condition);
        
        // parent construct
        parent :: __construct($data_provider, Utilities :: get_classname_from_namespace(__CLASS__, true), $model, $renderer);
        
        // default settings
        $this->set_default_row_count(self :: DEFAULT_ROW_COUNT);
        $this->set_additional_parameters($parameters);

        // TABLE ACTIONS
        if($allow_actions)
        {
            // if we are course admin
            if ($browser->get_course()->is_course_admin($browser->get_user()))
            {            
                // if we are not editing groups
                if (! Request :: get(WeblcmsManager :: PARAM_GROUP))
                {
                    $actions = new ObjectTableFormActions(__NAMESPACE__, Tool :: PARAM_ACTION);
                    
                    // add unsubscribe option
                    $actions->add_form_action(new ObjectTableFormAction(UserTool :: ACTION_UNSUBSCRIBE, Translation :: get('UnsubscribeSelected'), false));
                    
                    // make teacher
                    $actions->add_form_action(new ObjectTableFormAction(UserTool :: ACTION_CHANGE_USER_STATUS_TEACHER, Translation :: get('MakeTeacher'), false));

                    // make student
                    $actions->add_form_action(new ObjectTableFormAction(UserTool :: ACTION_CHANGE_USER_STATUS_STUDENT, Translation :: get('MakeStudent'), false));
                    
                    $this->set_form_actions($actions);
                }
            }
        }
    }*/

    public function get_implemented_form_actions()
    {
        $actions = new ObjectTableFormActions(__NAMESPACE__, Tool :: PARAM_ACTION);

        if ($this->get_component()->is_course_admin($this->get_component()->get_user()))
        {
            // if we are not editing groups
            if (! Request :: get(WeblcmsManager :: PARAM_GROUP))
            {
                $actions->add_form_action(new ObjectTableFormAction(UserTool :: ACTION_UNSUBSCRIBE,
                            Translation :: get('UnsubscribeSelected'), false));

                // make teacher
                $actions->add_form_action(new ObjectTableFormAction(UserTool :: ACTION_CHANGE_USER_STATUS_TEACHER, Translation :: get('MakeTeacher'), false));

                // make student
                $actions->add_form_action(new ObjectTableFormAction(UserTool :: ACTION_CHANGE_USER_STATUS_STUDENT, Translation :: get('MakeStudent'), false));
            }
        }

        return $actions;
    }
    static function handle_table_action()
    {
        $class = Utilities :: get_classname_from_namespace(__CLASS__, true);
        $ids = self :: get_selected_ids($class);
        Request :: set_get(UserTool :: PARAM_TAB, Request :: get(UserTool :: PARAM_TAB));
        Request :: set_get(UserTool :: PARAM_OBJECTS, $ids);
    }
}
?>
