<?php

namespace application\weblcms\tool\user;

use common\libraries\Request;
use common\libraries\Translation;
use application\weblcms\WeblcmsRights;
use common\libraries\Display;
use application\weblcms\CourseManagementRights;

/**
 * $Id: unsubscribe.class.php 218 2009-11-13 14:21:26Z kariboe $
 * 
 * @package application.lib.weblcms.weblcms_manager.component
 */

/**
 * Weblcms component which allows the user to manage his or her course
 * subscriptions
 */
class UserToolUnsubscribeComponent extends UserTool
{

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        if (!$this->is_allowed(WeblcmsRights :: EDIT_RIGHT))
        {
            Display :: not_allowed();
        }

        $course = $this->get_course();
        $users = Request :: get(UserTool :: PARAM_OBJECTS);
        if (!is_array($users))
        {
            $users = array($users);
        }
        if (isset($course))
        {
            if (isset($users))
            {
                $failures = 0;

                $course_management_rights = CourseManagementRights :: get_instance();

                foreach ($users as $user_id)
                {
                    if (!is_null($user_id) && $user_id != $this->get_user_id())
                    {
                        if (!$this->get_user()->is_platform_admin() &&
                            (!$course_management_rights->is_allowed(
                                CourseManagementRights :: TEACHER_UNSUBSCRIBE_RIGHT, $course->get_id(),
                                CourseManagementRights :: TYPE_COURSE, $user_id
                            ) || !$course->is_course_admin($this->get_user()))
                        )
                        {
                            $failures++;
                            continue;
                        }

                        if (!$this->get_parent()->unsubscribe_user_from_course($course, $user_id))
                        {
                            $failures++;
                        }
                    }
                    else
                    {
                        $failures++;
                    }
                }

                if ($failures == 0)
                {
                    $success = true;

                    if (count($users) == 1)
                    {
                        $message = 'UserUnsubscribedFromCourse';
                    }
                    else
                    {
                        $message = 'UsersUnsubscribedFromCourse';
                    }
                }
                elseif ($failures == count($users))
                {
                    $success = false;

                    if (count($users) == 1)
                    {
                        $message = 'UserNotUnsubscribedFromCourse';
                    }
                    else
                    {
                        $message = 'UsersNotUnsubscribedFromCourse';
                    }
                }
                else
                {
                    $success = false;
                    $message = 'PartialUsersNotUnsubscribedFromCourse';
                }

                $this->redirect(Translation :: get($message), ($success ? false : true),
                    array(
                    UserTool :: PARAM_ACTION => UserTool :: ACTION_UNSUBSCRIBE_BROWSER,
                    UserTool :: PARAM_TAB => Request :: get(UserTool :: PARAM_TAB)));
            }
        }
    }

}

?>