<?php
namespace application\weblcms\tool\user;

use group\DefaultGroupTableCellRenderer;
use application\weblcms\WeblcmsRights;
use application\weblcms\WeblcmsManager;
use application\weblcms\Tool;
use application\weblcms\CourseManagementRights;
use common\libraries\Toolbar;
use common\libraries\ToolbarItem;
use group\Group;
use common\libraries\PlatformSetting;
use common\libraries\Theme;
use common\libraries\Request;
use common\libraries\Path;
use common\libraries\Translation;
use common\libraries\WebApplication;
use common\libraries\Utilities;

/**
 * * ***************************************************************************
 * Cell renderer for an unsubscribed course group browser table.
 *
 * @author Stijn Van Hoecke
 *
 *         ****************************************************************************
 */
class UnsubscribedGroupBrowserTableCellRenderer extends DefaultGroupTableCellRenderer
{
    // **************************************************************************
    // VARIABLES
    // **************************************************************************
    /**
     * The weblcms browser component
     */
    private $browser;

    // **************************************************************************
    // CONSTRUCTOR
    // **************************************************************************
    /**
     * Constructor
     *
     * @param $browser WeblcmsBrowserComponent
     */
    function __construct($browser)
    {
        parent :: __construct();
        $this->browser = $browser;
    }

    // **************************************************************************
    // GENERAL FUNCTIONS
    // **************************************************************************
    // Inherited
    /**
     * Renders a given cell.
     *
     * @param $column type
     * @param $group_with_subscription_status type
     *            Group from the advanced join query in weblcms database class
     *            that includes his subscription status.
     * @return type
     */
    function render_cell($column, $group_with_subscription_status)
    {
        if ($column === UnsubscribedGroupBrowserTableColumnModel :: get_modification_column())
        {
            return $this->get_modification_links($group_with_subscription_status);
        }

        // Add special features here
        switch ($column->get_name())
        {
            // Exceptions that need post-processing go here ...
            case Group :: PROPERTY_NAME :
                $title_short = parent :: render_cell($column, $group_with_subscription_status);
                if (strlen($title_short) > 53)
                {
                    $title_short = mb_substr($title_short, 0, 50) . '&hellip;';
                }
                return $title_short;
            case Group :: PROPERTY_DESCRIPTION :
                $description = strip_tags(parent :: render_cell($column, $group_with_subscription_status));
                return Utilities :: truncate_string($description);
        }
        return parent :: render_cell($column, $group_with_subscription_status);
    }

    /**
     * Gets the action links to display
     *
     * @param $group_with_subscription_status Group
     *            The group for which the action links should be returned
     * @return string A HTML representation of the action links
     */
    private function get_modification_links($group_with_subscription_status)
    {
        // construct
        $toolbar = new Toolbar(Toolbar :: TYPE_HORIZONTAL);

        if($this->browser->get_user()->is_platform_admin() || (
                $this->browser->is_allowed(WeblcmsRights :: EDIT_RIGHT) &&
                CourseManagementRights :: get_instance()->is_allowed_for_platform_group(
                    CourseManagementRights :: TEACHER_DIRECT_SUBSCRIBE_RIGHT, $group_with_subscription_status->get_id(),
                    $this->browser->get_course_id())))
        {
            // subscribe users of group
            $parameters[Tool :: PARAM_ACTION] = UserTool :: ACTION_SUBSCRIBE_USERS_FROM_GROUP;
            $parameters[UserTool :: PARAM_TAB] = Request :: get(UserTool :: PARAM_TAB);
            $parameters[UserTool :: PARAM_OBJECTS] = $group_with_subscription_status->get_id();
            $toolbar->add_item(new ToolbarItem(Translation :: get('SubscribeUsersFromGroup'), Theme :: get_common_image_path() . 'action_copy.png', $this->browser->get_url($parameters), ToolbarItem :: DISPLAY_ICON));

            // subscribe group
            $parameters[Tool :: PARAM_ACTION] = UserTool :: ACTION_SUBSCRIBE_GROUPS;
            $parameters[UserTool :: PARAM_TAB] = Request :: get(UserTool :: PARAM_TAB);
            $parameters[UserTool :: PARAM_OBJECTS] = $group_with_subscription_status->get_id();
            $toolbar->add_item(new ToolbarItem(Translation :: get('SubscribeGroup'), Theme :: get_common_image_path() . 'action_subscribe.png', $this->browser->get_url($parameters), ToolbarItem :: DISPLAY_ICON));
        }

        // return
        return $toolbar->as_html();
    }
}
?>