<?php
namespace application\weblcms\tool\user;

use application\weblcms\WeblcmsManager;
use application\weblcms\Tool;
use common\libraries\Utilities;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\ObjectTableFormActions;
use common\libraries\ObjectTableFormAction;
use application\weblcms\WeblcmsRights;
use common\libraries\NewObjectTable;
use common\libraries\NewObjectTableFormActionsSupport;

/**
 * * ***************************************************************************
 * Table to display a list of users not in a course.
 *
 * @author Stijn Van Hoecke
 *        
 *         ****************************************************************************
 */
class UnsubscribedUserBrowserTable extends NewObjectTable implements NewObjectTableFormActionsSupport
{
    // **************************************************************************
    // GENERAL CONSTANTS
    // **************************************************************************
    const DEFAULT_NAME = 'unsubscribed_user_browser_table';
    const DEFAULT_ROW_COUNT = 20;
    
    // **************************************************************************
    // CONSTRUCTOR
    // **************************************************************************
    /**
     * Constructor
     *
     * function __construct($browser, $parameters = array(), $condition = null)
     * {
     * // model - renderer - dataprovider
     * $model = new UnsubscribedUserBrowserTableColumnModel();
     * $renderer = new UnsubscribedUserBrowserTableCellRenderer($browser);
     * $data_provider = new UnsubscribedUserBrowserTableDataProvider($browser,
     * $condition);
     *
     * // parent construct
     * parent :: __construct($data_provider, Utilities ::
     * get_classname_from_namespace(__CLASS__, true), $model, $renderer);
     *
     * // default settings
     * $this->set_default_row_count(self :: DEFAULT_ROW_COUNT);
     * $this->set_additional_parameters($parameters);
     *
     * // TABLE ACTIONS
     * if($browser->is_allowed(WeblcmsRights :: EDIT_RIGHT))
     * {
     * // if we are not editing groups
     * if (! Request :: get(WeblcmsManager :: PARAM_GROUP))
     * {
     * // add subscribe options
     * $actions = new ObjectTableFormActions(__NAMESPACE__, Tool ::
     * PARAM_ACTION);
     * $actions->add_form_action(new ObjectTableFormAction(UserTool ::
     * ACTION_SUBSCRIBE, Translation :: get('SubscribeSelectedAsStudent'),
     * false));
     * $actions->add_form_action(new ObjectTableFormAction(UserTool ::
     * ACTION_SUBSCRIBE_AS_ADMIN, Translation ::
     * get('SubscribeSelectedAsAdmin'), false));
     * $this->set_form_actions($actions);
     * }
     * }
     * }
     */
    
    static function handle_table_action()
    {
        $class = Utilities :: get_classname_from_namespace(__CLASS__, true);
        $ids = self :: get_selected_ids($class);
        Request :: set_get(UserTool :: PARAM_TAB, Request :: get(UserTool :: PARAM_TAB));
        Request :: set_get(UserTool :: PARAM_OBJECTS, $ids);
    }

    public function get_implemented_form_actions()
    {
        if (! Request :: get(WeblcmsManager :: PARAM_GROUP))
        {
            // add subscribe options
            $actions = new ObjectTableFormActions(__NAMESPACE__, Tool :: PARAM_ACTION);
            $actions->add_form_action(new ObjectTableFormAction(UserTool :: ACTION_SUBSCRIBE, Translation :: get('SubscribeSelectedAsStudent'), false));
            $actions->add_form_action(new ObjectTableFormAction(UserTool :: ACTION_SUBSCRIBE_AS_ADMIN, Translation :: get('SubscribeSelectedAsAdmin'), false));
            return $actions;
        }
    }
}
?>
