<?php

namespace application\weblcms\tool\user;

use common\libraries\EqualityCondition;
use common\libraries\GenericTree;
use common\libraries\Path;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Utilities;
use group\Group;
use group\GroupDataManager;
use application\weblcms\WeblcmsManager;

class PlatformgroupMenuRenderer extends GenericTree
{
    // **************************************************************************
    // GENERAL CONSTANTS
    // **************************************************************************
    const TREE_NAME = __CLASS__;
    const PATH_TO_XML_FEED = 'group/php/xml_feeds/xml_group_menu_feed.php';
    const ROOT_NODE_CLASS = 'home';
    const NODE_CLASS = 'category';
    
    // **************************************************************************
    // VARIABLES
    // **************************************************************************
    /**
     * The browser holding additional data.
     * 
     * @var PersonalMessengerManager
     */
    private $browser;
    
    // **************************************************************************
    // CONSTRUCTOR
    // **************************************************************************
    /**
     * Constructor.
     * Creates a new group navigation menu for subscribed groups.
     * 
     * @param $browser PersonalMessengerManager
     *            The browser
     */
    function __construct($browser, $root_ids, $fake_root = false)
    {
        $this->browser = $browser;
        parent :: __construct($fake_root, $root_ids);
    }
    
    // **************************************************************************
    // INHERITED FUNCTIONS
    // **************************************************************************
    /**
     * Returns the url of a node
     * 
     * @param $node_id int           
     * @return string
     */
    public function get_node_url($node_id)
    {
        $params = array();
        $params[WeblcmsManager :: PARAM_GROUP] = $node_id;
        return $this->browser->get_url($params);
    }

    /**
     * Returns the current node id.
     * 
     * @return int
     */
    public function get_current_node_id()
    {
        return Request :: get(WeblcmsManager :: PARAM_GROUP);
    }

    /**
     * Returns the node based on the given node_id.
     * 
     * @param $node_id int
     *            The id of the node
     * @return Node
     */
    public function get_node($node_id)
    {
        return GroupDataManager :: get_instance()->retrieve_group($node_id);
    }

    /**
     * Returns the nodes below the given parent(_id).
     * 
     * @param $parent_node_id int
     *            The parent id
     * @return GroupResultSet
     */
    public function get_node_children($parent_node_id)
    {
        $condition = new EqualityCondition(Group :: PROPERTY_PARENT, $parent_node_id);
        
        // fetch groups
        return GroupDataManager :: get_instance()->retrieve_groups($condition);
    }

    /**
     * Returns if the node has children.
     * 
     * @param $node_id int
     *            The node id
     * @return boolean
     */
    public function node_has_children($node_id)
    {
        $condition = new EqualityCondition(Group :: PROPERTY_PARENT, $node_id);
        
        return (GroupDataManager :: get_instance()->count_groups($condition) > 0);
    }

    /**
     * Returns the url to the xml feed.
     * 
     * @return string
     */
    public function get_search_url()
    {
        return Path :: get(WEB_PATH) . self :: PATH_TO_XML_FEED;
    }

    public function get_url_format()
    {
        $url_format = '?application=weblcms';
        $url_format .= '&' . WeblcmsManager :: PARAM_COURSE . '=' . Request :: get(WeblcmsManager :: PARAM_COURSE);
        $url_format .= '&' . WeblcmsManager :: PARAM_ACTION . '=' . Request :: get(WeblcmsManager :: PARAM_ACTION);
        $url_format .= '&' . WeblcmsManager :: PARAM_TOOL . '=' . Request :: get(WeblcmsManager :: PARAM_TOOL);
        $url_format .= '&' . WeblcmsManager :: PARAM_TOOL_ACTION . '=' . Request :: get(WeblcmsManager :: PARAM_TOOL_ACTION);
        $url_format .= '&' . UserTool :: PARAM_BROWSER_TYPE . '=' . Request :: get(UserTool :: PARAM_BROWSER_TYPE);
        $url_format .= '&' . UserTool :: PARAM_TAB . '=' . Request :: get(UserTool :: PARAM_TAB);
        $url_format .= '&' . WeblcmsManager :: PARAM_GROUP . '=%s';
        return $url_format;
    }

    public function get_root_node_class()
    {
        return self :: ROOT_NODE_CLASS;
    }

    public function get_node_class($node)
    {
        return self :: NODE_CLASS;
    }

    public function get_root_node_title()
    {
        return Translation :: get('Course', null, Utilities :: COMMON_LIBRARIES);
    }

    public function get_node_title($node)
    {
        return $node->get_name();
    }

    public function get_node_id($node)
    {
        return $node->get_id();
    }

    public function get_node_parent($node)
    {
        return $node->get_parent();
    }

}

?>