<?php
namespace application\weblcms\tool\user;

use application\weblcms\Tool;
use application\weblcms\WeblcmsDataManager;
use common\libraries\EqualityCondition;
use common\libraries\Request;
use application\weblcms\course\CourseGroupRelation;

/**
 * $Id: user_tool.class.php 216 2009-11-13 14:08:06Z kariboe $
 * 
 * @package application.lib.weblcms.tool.user.component
 */

/**
 * This tool allows a user to publish users in his or her course.
 */
class UserTool extends Tool
{
    const ACTION_SUBSCRIBE_USER_BROWSER = 'subscribe_browser';
    const ACTION_SUBSCRIBE_GROUP_BROWSER = 'group_subscribe_browser';
    const ACTION_UNSUBSCRIBE_BROWSER = 'unsubscribe_browser';
    const ACTION_UNSUBSCRIBE = 'unsubscribe';
    const ACTION_SUBSCRIBE = 'subscribe';
    const ACTION_SUBSCRIBE_AS_ADMIN = 'subscribe_as_admin';
    const ACTION_SUBSCRIBE_GROUPS = 'group_subscribe';
    const ACTION_SUBSCRIBE_USERS_FROM_GROUP = 'group_users_subscribe';
    const ACTION_UNSUBSCRIBE_GROUPS = 'group_unsubscribe';
    const ACTION_REQUEST_SUBSCRIBE_USER = 'request_subscribe_user';
    const ACTION_USER_DETAILS = 'details';
    const ACTION_EMAIL = 'emailer';
    const ACTION_REPORTING = 'reporting_viewer';
    const ACTION_CHANGE_USER_STATUS_STUDENT = 'status_changer_user_student';
    const ACTION_CHANGE_USER_STATUS_TEACHER = 'status_changer_user_teacher';
    const ACTION_CHANGE_PLATFORMGROUP_STATUS_STUDENT = 'status_changer_platformgroup_student';
    const ACTION_CHANGE_PLATFORMGROUP_STATUS_TEACHER = 'status_changer_platformgroup_teacher';
    const ACTION_VIEW_AS = 'view_as';
    
    const DEFAULT_ACTION = self :: ACTION_UNSUBSCRIBE_BROWSER;
    
    const PARAM_REFERER = 'referer';
    const PARAM_OBJECTS = 'objects';
    const PARAM_STATUS = 'status';
    const PARAM_TAB = 'tab';

    function get_application_component_path()
    {
        return dirname(__FILE__) . '/component/';
    }

    /**
     * Helper function for the SubManager class,
     * pending access to class constants via variables in PHP 5.3
     * e.g.
     * $name = $class :: DEFAULT_ACTION
     *
     * DO NOT USE IN THIS SUBMANAGER'S CONTEXT
     * Instead use:
     * - self :: DEFAULT_ACTION in the context of this class
     * - YourSubManager :: DEFAULT_ACTION in all other application classes
     */
    static function get_default_action()
    {
        return self :: DEFAULT_ACTION;
    }

    /**
     * Helper function for the SubManager class,
     * pending access to class constants via variables in PHP 5.3
     * e.g.
     * $name = $class :: PARAM_ACTION
     *
     * DO NOT USE IN THIS SUBMANAGER'S CONTEXT
     * Instead use:
     * - self :: PARAM_ACTION in the context of this class
     * - YourSubManager :: PARAM_ACTION in all other application classes
     */
    static function get_action_parameter()
    {
        return self :: PARAM_ACTION;
    }

    function get_status_changer_url($user, $status)
    {
        // return $this->get_url(array(self :: PARAM_ACTION => self ::
        // ACTION_CHANGE_STATUS, self :: PARAM_OBJECTS => $user, self ::
        // PARAM_STATUS => $status, self :: PARAM_TAB => Request :: get(self ::
        // PARAM_TAB)));
        switch ($status)
        {
            case 1 :
                $url = $this->get_url(array(self :: PARAM_ACTION => self :: ACTION_CHANGE_USER_STATUS_TEACHER, 
                        self :: PARAM_OBJECTS => $user, self :: PARAM_TAB => Request :: get(self :: PARAM_TAB)));
                break;
            case 5 :
                $url = $this->get_url(array(self :: PARAM_ACTION => self :: ACTION_CHANGE_USER_STATUS_STUDENT, 
                        self :: PARAM_OBJECTS => $user, self :: PARAM_TAB => Request :: get(self :: PARAM_TAB)));
                break;
        }
        return $url;
    }

    function get_platformgroup_status_changer_url($group, $status)
    {
        // return $this->get_url(array(self :: PARAM_ACTION => self ::
        // ACTION_CHANGE_PLATFORMGROUP_STATUS, self :: PARAM_OBJECTS => $group,
        // self :: PARAM_STATUS => $status, self :: PARAM_TAB => Request ::
        // get(self :: PARAM_TAB)));
        switch ($status)
        {
            case 1 :
                $url = $this->get_url(array(self :: PARAM_ACTION => self :: ACTION_CHANGE_PLATFORMGROUP_STATUS_TEACHER, 
                        self :: PARAM_OBJECTS => $group, self :: PARAM_TAB => Request :: get(self :: PARAM_TAB)));
                break;
            case 5 :
                $url = $this->get_url(array(self :: PARAM_ACTION => self :: ACTION_CHANGE_PLATFORMGROUP_STATUS_STUDENT, 
                        self :: PARAM_OBJECTS => $group, self :: PARAM_TAB => Request :: get(self :: PARAM_TAB)));
                break;
        }
        return $url;
    }

    function get_subscribed_platformgroup_ids($course_id)
    {
        $condition = new EqualityCondition(CourseGroupRelation :: PROPERTY_COURSE_ID, $course_id);
        $relations = WeblcmsDataManager :: get_instance()->retrieve_course_group_relations($condition);
        $group_ids = array();
        while ($group = $relations->next_result())
        {
            $group_ids[] = $group->get_group_id();
        }
        return $group_ids;
    }
}
?>