<?php
use common\libraries\Path;
use common\libraries\Utilities;
use common\libraries\Session;
use common\libraries\Connection;
use common\libraries\PlatformSetting;
use common\libraries\LocalSetting;
use common\libraries\Request;

use admin\AdminDataManager;
use common\libraries\DebugUtilities;

/**
 * Configure the environment. This file shall be included after including init.inc.php. This file calls the DB to
 * retrieve the configuration.
 *
 * @package common
 */

Utilities :: register_autoload();
/*
 * -------------------------------------------- CHAMILO CONFIG SETTINGS --------------------------------------------
 */

if (PlatformSetting :: get('server_type') == 'test')
{
    /*
     * Server type is test - high error reporting level - only do add slashes on $_GET and $_POST
     */

    error_reporting(E_ALL & ~ E_NOTICE & ~ E_DEPRECATED & ~ E_WARNING);
    
    /* FEAT: Lets do some serious debugging: instead of showing an empty page when a
     * syntax error occurs, show the error message in the browser.
     * Parcifal Aertssen
     */
    error_reporting(E_ALL);
    ini_set('display_errors', '1');    

    // Does this still belong here or should this be moved to the security class?
    // Addslashes to all $_GET variables
    /*
     * BUGFIX: Parcifal Aertssen (Howest)
     * In test environment the code below changes all GET and POST variables
     * in such a way that it may cause corrupt data because when these variables
     * are saved to the database, addslashes is called again. Calling this
     * function twice only results in incorrect data being present in the data-
     * base. You should only call addslashes once. Since the data managers do
     * not take this into account, an additional call to addslashes here will
     * only result in corrupt data.
     * On every save (even without changing the data), this will result in
     * an additional call to addslashes, which will simply add more slashes to 
     * your data. If you enable the code below, you can test this with html-
     * editor: on every save a new backslash is added. In production environment,
     * this code is not called, yet it is saved correctly to the database, so
     * again this does not add extra security.
     */
    /*
    foreach ($_GET as $key => $val)
    {
        if (! ini_get('magic_quotes_gpc'))
        {
            if (is_string($val))
            {
                // Request :: set_get($key,addslashes($val))
                Request :: set_get($key, addslashes($val));
            }
        }
    }

    // Addslashes to all $_POST variables
    foreach ($_POST as $key => $val)
    {
        if (! ini_get('magic_quotes_gpc'))
        {
            if (is_string($val))
            {
                $_POST[$key] = addslashes($val);
            }
        }
    }//*/
}
else
{
    /*
     * Server type is not test - normal error reporting level - full fake register globals block
     */
    // TODO: Restore the normal error reporting for production software release.
    // error_reporting(E_COMPILE_ERROR | E_ERROR | E_CORE_ERROR);
    // The following error reporting setting is for software under development, these lines are to be disabled.
    /* Use the PHP ini file setting, as the administrator wants it, so do not
     * change it when running in production.
     *//*
    if (phpversion() >= 5.3)
    {
        error_reporting(E_ALL & ~ E_NOTICE & ~ E_DEPRECATED & ~ E_WARNING);
    }
    else
    {
        error_reporting(E_ALL & ~ E_NOTICE & ~ E_WARNING);
    }//*/
}

// moved to common header to control order of headers
// $htmlHeadXtra[] = '<script type="text/javascript">var rootWebPath="' . Path :: get(WEB_PATH) . '";</script>';
$htmlHeadXtra = array();

$language_interface = LocalSetting :: get('platform_language');
if (! AdminDataManager :: is_language_active($language_interface))
{
    $language_interface = PlatformSetting :: get('platform_language');
}

$timezone = LocalSetting :: get('platform_timezone');
date_default_timezone_set($timezone);

/**
 * Dump functionality with decent output
 */
function dump($variable)
{
    echo '<pre style="background-color: white; color: black; padding: 5px; margin: 0px;">';
    print_r($variable);
    echo '</pre>';
}

/**
 * Globaly available function that call the DebugUtilities :: show() static function
 *
 * @param $object mixed The object to print in the page
 * @return void
 */
function debug($object, $title = null, $backtrace_index = 1)
{
    DebugUtilities :: show($object, $title, $backtrace_index);
}
?>