<?php
namespace common\extensions\category_manager;

use common\libraries\Display;
use common\libraries\Translation;
use common\libraries\Request;
use common\libraries\BreadcrumbTrail;
use common\libraries\Breadcrumb;
use common\libraries\EqualityCondition;
/**
 * $Id: deleter.class.php 205 2009-11-13 12:57:33Z vanpouckesven $
 * @package application.common.category_manager.component
 */
/**
 * Component to delete a category
 * @author Sven Vanpoucke
 * @author Stijn Van Hoecke
 */
class CategoryManagerDeleterComponent extends CategoryManagerComponent
{
    /*¨*
     * Variable that holds the parent to redirect to.
     */
    private $redirect_to_parent = 0;

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        $ids = Request :: get(CategoryManager :: PARAM_CATEGORY_ID);

        if (! $this->get_user())
        {
            $this->display_header();
            Display :: error_message(Translation :: get("NotAllowed"));
            $this->display_footer();
            exit();
        }

        if ($ids)
        {
            if (! is_array($ids))
            {
                $ids = array($ids);
            }

            $bool = true;

            foreach ($ids as $id)
            {
                /*
                 * ORIGINAL NON-RECURSIVE
                 */
                //                if (! $this->allowed_to_delete_category($id))
                //                {
                //                    $bool = false;
                //                    continue;
                //                }
                //
                //                $categories = $this->retrieve_categories(new EqualityCondition(PlatformCategory :: PROPERTY_ID, $id));
                //                $category = $categories->next_result();
                //
                //                if ($parent == - 1)
                //                    $parent = $category->get_parent();
                //                if (! $category->delete())
                //                    $bool = false;


                /*
                 * RECURSIVE DELETE
                 */
                if ($bool)
                {
                    $bool = $this->delete_categories_recursive($id);
                }

            }

            if (count($ids) == 1)
            {
                $message = $bool ? 'CategoryDeleted' : 'CategoryNotDeleted';
            }
            else
            {
                $message = $bool ? 'CategoriesDeleted' : 'CategoriesNotDeleted';
            }

            $this->redirect(Translation :: get($message), ($bool ? false : true), array(
                    CategoryManager :: PARAM_ACTION => CategoryManager :: ACTION_BROWSE_CATEGORIES,
                    CategoryManager :: PARAM_CATEGORY_ID => $this->redirect_to_parent));
        }
        else
        {
            $trail = BreadcrumbTrail :: get_instance();
            $trail->add_help('category_manager_deleter');
            $trail->add(new Breadcrumb($this->get_url(array(
                    CategoryManager :: PARAM_ACTION => CategoryManager :: ACTION_BROWSE_CATEGORIES)), Translation :: get('CategoryManagerBrowserComponent')));
            $this->set_parameter(CategoryManager :: PARAM_CATEGORY_ID, Request :: get(CategoryManager :: PARAM_CATEGORY_ID));
            $trail->add(new Breadcrumb($this->get_url(), Translation :: get('CategoryManagerDeleterComponent')));

            $this->display_header();
            echo Translation :: get("NoObjectSelected");
            $this->display_footer();
        }
    }

    function delete_categories_recursive($id)
    {
        $continue = true;
        $children = $this->retrieve_categories(new EqualityCondition(PlatformCategory :: PROPERTY_PARENT, $id));
        foreach ($children as $child)
        {
            $continue = $this->delete_categories_recursive($child);
        }

        if ($continue)
        {
            if ($this->allowed_to_delete_category($id))
            {
                $categories = $this->retrieve_categories(new EqualityCondition(PlatformCategory :: PROPERTY_ID, $id));
                $category = $categories->next_result();
                $this->redirect_to_parent = $category->get_parent();
                return $category->delete();
            }
        }
        return false;
    }

}
?>