<?php
namespace common\extensions\category_manager;
use common\libraries\ObjectTableCellRenderer;
use common\libraries\Translation;
use common\libraries\Theme;
use common\libraries\EqualityCondition;
use common\libraries\Toolbar;
use common\libraries\ToolbarItem;
use common\libraries\Utilities;
/**
 * $Id: category_browser_table_cell_renderer.class.php 205 2009-11-13 12:57:33Z vanpouckesven $
 * @package application.common.category_manager.component.category_browser
 */
/**
 * Cell rendere for the learning object browser table
 */
class CategoryBrowserTableCellRenderer extends ObjectTableCellRenderer
{
    /**
     * The repository browser component
     */
    protected $browser;
    private $count;
    
    private $count_all;

    /**
     * Constructor
     * @param RepositoryManagerBrowserComponent $browser
     */
    function __construct($browser)
    {
        //parent :: __construct();
        $this->browser = $browser;
        $this->count = $browser->count_categories($browser->get_condition());
        $this->count_all = $browser->count_categories();
    }

    // Inherited
    function render_cell($column, $category)
    {
        // modification column
        if ($column === CategoryBrowserTableColumnModel :: get_modification_column())
        {
            return $this->get_modification_links($category);
        }
        
        // category column
        if ($column === CategoryBrowserTableColumnModel :: get_category_column())
        {
            $img = Theme :: get_common_image_path() . 'treemenu_types/category.png';
            return '<img src="' . $img . '"alt="category" />';
        }
        
        // name column
        if ($column === CategoryBrowserTableColumnModel :: get_name_column())
        {
            $url = $this->browser->get_browse_categories_url($category->get_id());
            return '<a href="' . $url . '" alt="' . $category->get_name() . '">' . $category->get_name() . '</a>';
        }
        
        // subcategories column
        if ($column === CategoryBrowserTableColumnModel :: get_subcat_column())
        {
            $count = $this->browser->count_categories(new EqualityCondition(PlatformCategory :: PROPERTY_PARENT, $category->get_id()));
            return $count;
        }
        
        return '&nbsp;';
    }

    function render_id_cell($object)
    {
        return $object->get_id();
    }

    /**
     * Gets the action links to display
     * @param ContentObject $content_object The learning object for which the
     * action links should be returned
     * @return string A HTML representation of the action links
     */
    private function get_modification_links($category)
    {
        $toolbar = new Toolbar(Toolbar :: TYPE_HORIZONTAL);
        
        /**
         * Added support for CategoryVisibilitySupported marker interface
         * If present, the visibility attribute should be checked.
         */
        if ($category instanceof CategoryVisibilitySupported) {
            if ($this->browser->allowed_to_change_category_visibility($category->get_id())) 
            {
                $image = 'action_visible.png';
                $text = 'Visible';
                if (!$category->get_visibility())
                {
                    $image = 'action_visible_na.png';
                    $text = 'Invisible';
                }
                $toolbar->add_item(new ToolbarItem(Translation :: get($text, null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . $image, $this->browser->get_toggle_visibility_category_url($category->get_id()), ToolbarItem :: DISPLAY_ICON));
            }
            else 
            {
                $toolbar->add_item(new ToolbarItem(Translation :: get('VisibleNA', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_visible_na.png', null, ToolbarItem :: DISPLAY_ICON));
            }
        }
        
        if ($this->browser->allowed_to_edit_category($category->get_id()))
        {
            $toolbar->add_item(new ToolbarItem(Translation :: get('Edit', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_edit.png', $this->browser->get_update_category_url($category->get_id()), ToolbarItem :: DISPLAY_ICON));
        }
        else
        {
            $toolbar->add_item(new ToolbarItem(Translation :: get('EditNA', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_edit_na.png', null, ToolbarItem :: DISPLAY_ICON));
        }
        

        if($this->browser->supports_impact_view($category->get_id()))
        {
            $toolbar->add_item(new ToolbarItem(Translation :: get('Delete', null, Utilities :: COMMON_LIBRARIES),
                    Theme :: get_common_image_path() . 'action_delete.png',
                    $this->browser->get_impact_view_url($category->get_id()), ToolbarItem :: DISPLAY_ICON));
        }
        else
        {
            if ($this->browser->allowed_to_delete_category($category->get_id()))
            {
                $toolbar->add_item(new ToolbarItem(Translation :: get('Delete', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_delete.png', $this->browser->get_delete_category_url($category->get_id()), ToolbarItem :: DISPLAY_ICON, true));
            }
            else
            {
                $toolbar->add_item(new ToolbarItem(Translation :: get('Delete', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_delete_na.png', null, ToolbarItem :: DISPLAY_ICON, true));
            }
        }
        
        if ($category->get_display_order() > 1)
        {
            $toolbar->add_item(new ToolbarItem(Translation :: get('MoveUp', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_up.png', $this->browser->get_move_category_url($category->get_id(), - 1), ToolbarItem :: DISPLAY_ICON));
        }
        else
        {
            $toolbar->add_item(new ToolbarItem(Translation :: get('MoveUpNA', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_up_na.png', null, ToolbarItem :: DISPLAY_ICON));
        }
        
        if ($category->get_display_order() < $this->count)
        {
            $toolbar->add_item(new ToolbarItem(Translation :: get('MoveDown', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_down.png', $this->browser->get_move_category_url($category->get_id(), 1), ToolbarItem :: DISPLAY_ICON));
        }
        else
        {
            $toolbar->add_item(new ToolbarItem(Translation :: get('MoveDownNA', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_down_na.png', null, ToolbarItem :: DISPLAY_ICON));
        }
        
        if ($this->browser->get_subcategories_allowed())
        {
            if ($this->count_all > 1)
            {
                $toolbar->add_item(new ToolbarItem(Translation :: get('Move', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_move.png', $this->browser->get_change_category_parent_url($category->get_id()), ToolbarItem :: DISPLAY_ICON));
            }
            else
            {
                $toolbar->add_item(new ToolbarItem(Translation :: get('MoveNA', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_move_na.png', null, ToolbarItem :: DISPLAY_ICON));
            }
        }
        
        return $toolbar->as_html();
    }
}
?>