<?php
namespace common\extensions\category_manager;
use common\libraries\ObjectTableColumnModel;
use common\libraries\StaticTableColumn;
use common\libraries\Translation;
use common\libraries\Utilities;
/**
 * $Id: category_browser_table_column_model.class.php 191 2009-11-13 11:50:28Z chellee $
 * @package application.common.category_manager.component.category_browser
 */

/**
 * Table column model for the user browser table
 */
class CategoryBrowserTableColumnModel extends ObjectTableColumnModel
{
    /**
     * The tables modification column
     */
    private static $modification_column;
    
    /**
     * The default columns to override
     */
    private static $category_column;
    private static $name_column;
    private static $subcat_column;

    /**
     * Constructor
     */
    function __construct($browser)
    {
        parent :: __construct(self :: get_default_columns($browser), 1);
        $this->set_default_order_column(1);
        $this->add_column(self :: get_modification_column());
    }

    /**
     * Gets the modification column
     * @return ContentObjectTableColumn
     */
    static function get_modification_column()
    {
        if (! isset(self :: $modification_column))
        {
            self :: $modification_column = new StaticTableColumn('');
        }
        return self :: $modification_column;
    }

    /**
     * Gets the category column
     * @return ContentObjectTableColumn
     */
    static function get_category_column()
    {
        if (! isset(self :: $category_column))
        {
            self :: $category_column = new StaticTableColumn('');
        }
        return self :: $category_column;
    }

    /**
     * Gets the name column
     * @return ContentObjectTableColumn
     */
    static function get_name_column()
    {
        if (! isset(self :: $name_column))
        {
            self :: $name_column = new StaticTableColumn(Translation :: get(Utilities :: underscores_to_camelcase(PlatformCategory :: PROPERTY_NAME)));
        }
        return self :: $name_column;
    }

    /**
     * Gets the subcategories column
     * @return ContentObjectTableColumn
     */
    static function get_subcat_column()
    {
        if (! isset(self :: $subcat_column))
        {
            self :: $subcat_column = new StaticTableColumn(Translation :: get('Subcategories'));
        }
        return self :: $subcat_column;
    }

    private static function get_default_columns($browser)
    {
        $columns = array();
        $columns[] = self :: get_category_column();
        $columns[] = self :: get_name_column();
        
        if ($browser->get_subcategories_allowed())
        {
            $columns[] = self :: get_subcat_column();
        }
        
        return $columns;
    }
}
?>