<?php
namespace common\extensions\external_repository_manager\implementation\google_docs;

use repository\content_object\document\Document;

use common\libraries\OrCondition;
use common\libraries\PatternMatchCondition;
use common\libraries\Path;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\ToolbarItem;
use common\libraries\Theme;

class Manager extends \common\extensions\external_repository_manager\Manager
{
    const REPOSITORY_TYPE = 'google_docs';
    
    const PARAM_EXPORT_FORMAT = 'export_format';
    const PARAM_FOLDER = 'folder';
    
    /*
     * (non-PHPdoc) @see
     * common/extensions/external_repository_manager/Manager#validate_settings()
     */
    function validate_settings($external_repository)
    {
        return true;
    }
    
    /*
     * (non-PHPdoc) @see
     * common/extensions/external_repository_manager/Manager#support_sorting_direction()
     */
    function support_sorting_direction()
    {
        return false;
    }

    /**
     *
     * @param $object ExternalObject           
     * @return string
     */
    function get_external_repository_object_viewing_url(\common\extensions\external_repository_manager\ExternalObject $object)
    {
        $parameters = array();
        $parameters[self :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION] = self :: ACTION_VIEW_EXTERNAL_REPOSITORY;
        $parameters[self :: PARAM_EXTERNAL_REPOSITORY_ID] = $object->get_id();
        
        return $this->get_url($parameters);
    }

    /**
     *
     * @return array
     */
    function get_menu_items()
    {
        $menu_items = array();
        
        $line = array();
        $line['title'] = '';
        $line['class'] = 'divider';
        
        // Basic list of all documents
        $all_items = array();
        $all_items['title'] = Translation :: get('AllItems');
        $all_items['url'] = $this->get_url(array(self :: PARAM_FOLDER => null));
        $all_items['class'] = 'home';
        
        // Special lists of documents
        $owned = array();
        $owned['title'] = Translation :: get('OwnedByMe');
        $owned['url'] = $this->get_url(array(self :: PARAM_FOLDER => DataConnector :: DOCUMENTS_OWNED));
        $owned['class'] = 'user';
        
        $viewed = array();
        $viewed['title'] = Translation :: get('OpenedByMe');
        $viewed['url'] = $this->get_url(array(self :: PARAM_FOLDER => DataConnector :: DOCUMENTS_VIEWED));
        $viewed['class'] = 'userview';
        
        $shared = array();
        $shared['title'] = Translation :: get('SharedWithMe');
        $shared['url'] = $this->get_url(array(self :: PARAM_FOLDER => DataConnector :: DOCUMENTS_SHARED));
        $shared['class'] = 'external_repository';
        
        $starred = array();
        $starred['title'] = Translation :: get('Starred');
        $starred['url'] = $this->get_url(array(self :: PARAM_FOLDER => DataConnector :: DOCUMENTS_STARRED));
        $starred['class'] = 'template';
        
        $hidden = array();
        $hidden['title'] = Translation :: get('Hidden');
        $hidden['url'] = $this->get_url(array(self :: PARAM_FOLDER => DataConnector :: DOCUMENTS_HIDDEN));
        $hidden['class'] = 'hidden';
        
        $trashed = array();
        $trashed['title'] = Translation :: get('Trash');
        $trashed['url'] = $this->get_url(array(self :: PARAM_FOLDER => DataConnector :: DOCUMENTS_TRASH));
        $trashed['class'] = 'trash';
        
        // Document types
        $types = array();
        $types['title'] = Translation :: get('DocumentTypes');
        $types['url'] = '#';
        $types['class'] = 'category';
        $types['sub'] = array();
        
        $pdfs = array();
        $pdfs['title'] = Translation :: get('PDFs');
        $pdfs['url'] = $this->get_url(array(self :: PARAM_FOLDER => DataConnector :: DOCUMENTS_FILES));
        $pdfs['class'] = 'google_docs_pdf';
        $types['sub'][] = $pdfs;
        
        $documents = array();
        $documents['title'] = Translation :: get('Documents');
        $documents['url'] = $this->get_url(array(self :: PARAM_FOLDER => DataConnector :: DOCUMENTS_DOCUMENTS));
        $documents['class'] = 'google_docs_document';
        $types['sub'][] = $documents;
        
        $presentations = array();
        $presentations['title'] = Translation :: get('Presentations');
        $presentations['url'] = $this->get_url(array(self :: PARAM_FOLDER => DataConnector :: DOCUMENTS_PRESENTATIONS));
        $presentations['class'] = 'google_docs_presentation';
        $types['sub'][] = $presentations;
        
        $spreadsheets = array();
        $spreadsheets['title'] = Translation :: get('Spreadsheets');
        $spreadsheets['url'] = $this->get_url(array(self :: PARAM_FOLDER => DataConnector :: DOCUMENTS_SPREADSHEETS));
        $spreadsheets['class'] = 'google_docs_spreadsheet';
        $types['sub'][] = $spreadsheets;
        
        $menu_items[] = $all_items;
        $menu_items[] = $line;
        
        $menu_items[] = $owned;
        $menu_items[] = $viewed;
        $menu_items[] = $shared;
        $menu_items[] = $starred;
        $menu_items[] = $hidden;
        $menu_items[] = $trashed;
        $menu_items[] = $types;
        
        // User defined folders
        $menu_items[] = $line;
        $folders = $this->get_external_repository_manager_connector()->retrieve_folders($this->get_url(array(
                self :: PARAM_FOLDER => '__PLACEHOLDER__')));
        $menu_items = array_merge($menu_items, $folders);
        
        return $menu_items;
    }
    
    /*
     * (non-PHPdoc) @see
     * common/extensions/external_repository_manager/Manager#is_ready_to_be_used()
     */
    function is_ready_to_be_used()
    {
        return false;
    }
    
    /*
     * (non-PHPdoc) @see
     * common/extensions/external_repository_manager/Manager#get_external_repository_actions()
     */
    function get_external_repository_actions()
    {
        return array(self :: ACTION_BROWSE_EXTERNAL_REPOSITORY, self :: ACTION_UPLOAD_EXTERNAL_REPOSITORY);
    }

    function run()
    {
        $parent = $this->get_parameter(Manager :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION);
        
        switch ($parent)
        {
            case Manager :: ACTION_VIEW_EXTERNAL_REPOSITORY :
                $component = $this->create_component('Viewer');
                break;
            case Manager :: ACTION_EXPORT_EXTERNAL_REPOSITORY :
                $component = $this->create_component('Exporter');
                break;
            case Manager :: ACTION_IMPORT_EXTERNAL_REPOSITORY :
                $component = $this->create_component('Importer');
                break;
            case Manager :: ACTION_BROWSE_EXTERNAL_REPOSITORY :
                $component = $this->create_component('Browser', $this);
                break;
            case Manager :: ACTION_DOWNLOAD_EXTERNAL_REPOSITORY :
                $component = $this->create_component('Downloader');
                break;
            case Manager :: ACTION_UPLOAD_EXTERNAL_REPOSITORY :
                $component = $this->create_component('Uploader');
                break;
            case Manager :: ACTION_SELECT_EXTERNAL_REPOSITORY :
                $component = $this->create_component('Selecter');
                break;
            case Manager :: ACTION_EDIT_EXTERNAL_REPOSITORY :
                $component = $this->create_component('Editor');
                break;
            case Manager :: ACTION_DELETE_EXTERNAL_REPOSITORY :
                $component = $this->create_component('Deleter');
                break;
            default :
                $component = $this->create_component('Browser');
                $this->set_parameter(Manager :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION, Manager :: ACTION_BROWSE_EXTERNAL_REPOSITORY);
                break;
        }
        
        $component->run();
    }
    
    /*
     * (non-PHPdoc) @see
     * common/extensions/external_repository_manager/Manager#get_content_object_type_conditions()
     */
    function get_content_object_type_conditions()
    {
        $document_conditions = array();
        $document_conditions[] = new PatternMatchCondition(Document :: PROPERTY_FILENAME, '*.doc', Document :: get_type_name());
        $document_conditions[] = new PatternMatchCondition(Document :: PROPERTY_FILENAME, '*.xls', Document :: get_type_name());
        $document_conditions[] = new PatternMatchCondition(Document :: PROPERTY_FILENAME, '*.ppt', Document :: get_type_name());
        return new OrCondition($document_conditions);
    }

    /**
     *
     * @param $object ExternalObject           
     * @return array
     */
    function get_external_repository_object_actions(common\extensions\external_repository_manager\ExternalObject $object)
    {
        $actions = parent :: get_external_repository_object_actions($object);
        if (in_array(Manager :: ACTION_IMPORT_EXTERNAL_REPOSITORY, array_keys($actions)))
        {
            unset($actions[Manager :: ACTION_IMPORT_EXTERNAL_REPOSITORY]);
            $export_types = $object->get_export_types();
            
            foreach ($export_types as $export_type)
            {
                $actions[$export_type] = new ToolbarItem(Translation :: get('Import' . Utilities :: underscores_to_camelcase($export_type)), Theme :: get_image_path() . 'import/' . $export_type . '.png', $this->get_url(array(
                        self :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION => self :: ACTION_IMPORT_EXTERNAL_REPOSITORY, 
                        self :: PARAM_EXTERNAL_REPOSITORY_ID => $object->get_id(), 
                        self :: PARAM_EXPORT_FORMAT => $export_type)), ToolbarItem :: DISPLAY_ICON);
            }
        }
        
        return $actions;
    }

    /**
     *
     * @return string
     */
    function get_repository_type()
    {
        return self :: REPOSITORY_TYPE;
    }

    /**
     * Helper function for the SubManager class, pending access to class
     * constants via variables in PHP 5.3 e.g.
     * $name =
     * $class :: DEFAULT_ACTION DO NOT USE IN THIS SUBMANAGER'S CONTEXT Instead
     * use: - self :: DEFAULT_ACTION in the
     * context of this class - YourSubManager :: DEFAULT_ACTION in all other
     * application classes
     */
    static function get_default_action()
    {
        return self :: DEFAULT_ACTION;
    }

    /**
     * Helper function for the SubManager class, pending access to class
     * constants via variables in PHP 5.3 e.g.
     * $name =
     * $class :: PARAM_ACTION DO NOT USE IN THIS SUBMANAGER'S CONTEXT Instead
     * use: - self :: PARAM_ACTION in the context
     * of this class - YourSubManager :: PARAM_ACTION in all other application
     * classes
     */
    static function get_action_parameter()
    {
        return self :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION;
    }
}
?>