<?php
namespace common\extensions\external_repository_manager\implementation\slideshare;

use common\extensions\external_repository_manager\ExternalRepositoryRenderer;

use common\libraries\Path;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\ActionBarSearchForm;
use common\libraries\PatternMatchCondition;
use common\libraries\OrCondition;
use common\libraries\Utilities;

use repository\ExternalSetting;
use repository\content_object\document\Document;

class Manager extends \common\extensions\external_repository_manager\Manager
{
    const REPOSITORY_TYPE = 'slideshare';
    
    const PARAM_FEED_TYPE = 'feed';
    
    const FEED_TYPE_GENERAL = 1;

    /**
     *
     * @param $application Application
     */
    function __construct($external_repository, $application)
    {
        parent :: __construct($external_repository, $application);
        $this->set_parameter(self :: PARAM_FEED_TYPE, Request :: get(self :: PARAM_FEED_TYPE));
    }
    
    /*
     * (non-PHPdoc) @see common/extensions/external_repository_manager/Manager#validate_settings()
     */
    function validate_settings($external_repository)
    {
        $key = ExternalSetting :: get('consumer_key', $external_repository->get_id());
        $secret = ExternalSetting :: get('consumer_secret', $external_repository->get_id());
        
        if (! $key || ! $secret)
        {
            return false;
        }
        return true;
    }
    
    /*
     * (non-PHPdoc) @see
     * common/extensions/external_repository_manager/Manager#support_sorting_direction()
     */
    function support_sorting_direction()
    {
        return true;
    }

    /**
     *
     * @param $object ExternalObject
     * @return string
     */
    function get_external_repository_object_viewing_url(
            \common\extensions\external_repository_manager\ExternalObject $object)
    {
        $parameters = array();
        $parameters[self :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION] = self :: ACTION_VIEW_EXTERNAL_REPOSITORY;
        $parameters[self :: PARAM_EXTERNAL_REPOSITORY_ID] = $object->get_id();
        
        return $this->get_url($parameters);
    }
    
    /*
     * (non-PHPdoc) @see common/extensions/external_repository_manager/Manager#get_menu_items()
     */
    function get_menu_items()
    {
        $menu_items = array();
        
        $my_photos = array();
        $my_photos['title'] = Translation :: get('Slideshare');
        $my_photos['url'] = $this->get_url();
        $my_photos['class'] = 'user';
        $menu_items[] = $my_photos;
        
        return $menu_items;
    }
    
    /*
     * (non-PHPdoc) @see common/extensions/external_repository_manager/Manager#is_ready_to_be_used()
     */
    function is_ready_to_be_used()
    {
        return false;
    }
    
    /*
     * (non-PHPdoc) @see
     * common/extensions/external_repository_manager/Manager#get_external_repository_actions()
     */
    function get_external_repository_actions()
    {
        $actions = array(self :: ACTION_BROWSE_EXTERNAL_REPOSITORY, self :: ACTION_UPLOAD_EXTERNAL_REPOSITORY, 
                self :: ACTION_EXPORT_EXTERNAL_REPOSITORY);
        
        $is_platform = $this->get_user()->is_platform_admin() && (count(
                ExternalSetting :: get_all($this->get_external_repository()->get_id())) > 0);
        
        if ($is_platform)
        {
            $actions[] = self :: ACTION_CONFIGURE_EXTERNAL_REPOSITORY;
        }
        
        return $actions;
    }
    
    /*
     * (non-PHPdoc) @see
     * common/extensions/external_repository_manager/Manager#get_available_renderers()
     */
    function get_available_renderers()
    {
        return array(ExternalRepositoryRenderer :: TYPE_GALLERY, ExternalRepositoryRenderer :: TYPE_TABLE);
    }
    
    /*
     * (non-PHPdoc) @see
     * common/extensions/external_repository_manager/Manager#get_content_object_type_conditions()
     */
    function get_content_object_type_conditions()
    {
        $image_types = Document :: get_video_types();
        $image_conditions = array();
        foreach ($image_types as $image_type)
        {
            $image_conditions[] = new PatternMatchCondition(Document :: PROPERTY_FILENAME, '*.' . $image_type, 
                    Document :: get_type_name());
        }
        
        return new OrCondition($image_conditions);
    }

    /**
     *
     * @return string
     */
    function get_repository_type()
    {
        return self :: REPOSITORY_TYPE;
    }

    /**
     * Helper function for the SubManager class, pending access to class constants via variables in PHP 5.3 e.g. $name =
     * $class :: DEFAULT_ACTION DO NOT USE IN THIS SUBMANAGER'S CONTEXT Instead use: - self :: DEFAULT_ACTION in the
     * context of this class - YourSubManager :: DEFAULT_ACTION in all other application classes
     */
    static function get_default_action()
    {
        return self :: DEFAULT_ACTION;
    }

    /**
     * Helper function for the SubManager class, pending access to class constants via variables in PHP 5.3 e.g. $name =
     * $class :: PARAM_ACTION DO NOT USE IN THIS SUBMANAGER'S CONTEXT Instead use: - self :: PARAM_ACTION in the context
     * of this class - YourSubManager :: PARAM_ACTION in all other application classes
     */
    static function get_action_parameter()
    {
        return self :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION;
    }
}
?>