<?php
namespace common\extensions\external_repository_manager\implementation\youtube;

use common\extensions\external_repository_manager\ExternalRepositoryRenderer;

use repository\ExternalUserSetting;

use common\libraries\Path;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\ActionBarSearchForm;
use common\libraries\PatternMatchCondition;
use common\libraries\OrCondition;

use repository\ExternalSetting;
use repository\content_object\document\Document;

class Manager extends \common\extensions\external_repository_manager\Manager
{
    const REPOSITORY_TYPE = 'youtube';
    
    const PARAM_FEED_TYPE = 'feed';
    const PARAM_FEED_IDENTIFIER = 'identifier';
    
    const FEED_TYPE_GENERAL = 1;
    const FEED_TYPE_MYVIDEOS = 2;
    const FEED_STANDARD_TYPE = 3;
    
    const ACTION_LOGIN = 'login';
    const ACTION_LOGOUT = 'logout';

    /**
     *
     * @param $application Application
     */
    function __construct($application)
    {
        if (Request :: get(self :: PARAM_FEED_TYPE) == self :: FEED_TYPE_MYVIDEOS && ! $application->get_external_instance()->get_user_setting(
                'session_token'))
        {
            Request :: set_get(self :: PARAM_FEED_TYPE, self :: FEED_TYPE_GENERAL);
        }
        parent :: __construct($application);
        $this->set_parameter(self :: PARAM_FEED_TYPE, Request :: get(self :: PARAM_FEED_TYPE));
    
    }
    
    /*
     * (non-PHPdoc) @see common/extensions/external_repository_manager/Manager#validate_settings()
     */
    function validate_settings($external_repository)
    {
        $developer_key = ExternalSetting :: get('developer_key', $external_repository->get_id());
        
        if (! $developer_key)
        {
            return false;
        }
        return true;
    }
    
    /*
     * (non-PHPdoc) @see
     * common/extensions/external_repository_manager/Manager#support_sorting_direction()
     */
    function support_sorting_direction()
    {
        return false;
    }

    /**
     *
     * @param $object ExternalObject
     * @return string
     */
    function get_external_repository_object_viewing_url(
            \common\extensions\external_repository_manager\ExternalObject $object)
    {
        $parameters = array();
        $parameters[self :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION] = self :: ACTION_VIEW_EXTERNAL_REPOSITORY;
        $parameters[self :: PARAM_EXTERNAL_REPOSITORY_ID] = $object->get_id();
        
        return $this->get_url($parameters);
    }
    
    /*
     * (non-PHPdoc) @see common/extensions/external_repository_manager/Manager#get_menu_items()
     */
    function get_menu_items()
    {
        $menu_items = array();
        
        if ($this->get_external_repository()->get_user_setting('session_token'))
        {
            $my_videos = array();
            $my_videos['title'] = Translation :: get('MyVideos');
            $my_videos['url'] = $this->get_url(array(self :: PARAM_FEED_TYPE => self :: FEED_TYPE_MYVIDEOS), 
                    array(ActionBarSearchForm :: PARAM_SIMPLE_SEARCH_QUERY, self :: PARAM_FEED_IDENTIFIER));
            $my_videos['class'] = 'user';
            $menu_items[] = $my_videos;
        }
        
        $browser = array();
        $browser['title'] = Translation :: get('Public');
        $browser['url'] = $this->get_url(array(self :: PARAM_FEED_TYPE => self :: FEED_TYPE_GENERAL), 
                array(ActionBarSearchForm :: PARAM_SIMPLE_SEARCH_QUERY, self :: PARAM_FEED_IDENTIFIER));
        $browser['class'] = 'home';
        $menu_items[] = $browser;
        
        $standard_feeds = array();
        $standard_feeds['title'] = Translation :: get('StandardFeeds');
        $standard_feeds['url'] = $this->get_url(array(self :: PARAM_FEED_TYPE => self :: FEED_STANDARD_TYPE), 
                array(ActionBarSearchForm :: PARAM_SIMPLE_SEARCH_QUERY, self :: PARAM_FEED_IDENTIFIER));
        $standard_feeds['class'] = 'category';
        
        $standard_feed_items = array();
        
        $standard_feed_item = array();
        $standard_feed_item['title'] = Translation :: get('MostViewed');
        $standard_feed_item['url'] = $this->get_url(
                array(self :: PARAM_FEED_TYPE => self :: FEED_STANDARD_TYPE, 
                        self :: PARAM_FEED_IDENTIFIER => 'most_viewed'), 
                array(ActionBarSearchForm :: PARAM_SIMPLE_SEARCH_QUERY));
        $standard_feed_item['class'] = 'feed';
        $standard_feed_items[] = $standard_feed_item;
        
        $standard_feed_item = array();
        $standard_feed_item['title'] = Translation :: get('TopRated');
        $standard_feed_item['url'] = $this->get_url(
                array(self :: PARAM_FEED_TYPE => self :: FEED_STANDARD_TYPE, 
                        self :: PARAM_FEED_IDENTIFIER => 'top_rated'), 
                array(ActionBarSearchForm :: PARAM_SIMPLE_SEARCH_QUERY));
        $standard_feed_item['class'] = 'feed';
        $standard_feed_items[] = $standard_feed_item;
        $standard_feeds['sub'] = $standard_feed_items;
        
        $standard_feed_item = array();
        $standard_feed_item['title'] = Translation :: get('RecentlyFeatured');
        $standard_feed_item['url'] = $this->get_url(
                array(self :: PARAM_FEED_TYPE => self :: FEED_STANDARD_TYPE, 
                        self :: PARAM_FEED_IDENTIFIER => 'recently_featured'), 
                array(ActionBarSearchForm :: PARAM_SIMPLE_SEARCH_QUERY));
        $standard_feed_item['class'] = 'feed';
        $standard_feed_items[] = $standard_feed_item;
        
        $standard_feed_item = array();
        $standard_feed_item['title'] = Translation :: get('WatchOnMobile');
        $standard_feed_item['url'] = $this->get_url(
                array(self :: PARAM_FEED_TYPE => self :: FEED_STANDARD_TYPE, 
                        self :: PARAM_FEED_IDENTIFIER => 'watch_on_mobile'), 
                array(ActionBarSearchForm :: PARAM_SIMPLE_SEARCH_QUERY));
        $standard_feed_item['class'] = 'feed';
        $standard_feed_items[] = $standard_feed_item;
        
        $standard_feed_item = array();
        $standard_feed_item['title'] = Translation :: get('MostDiscussed');
        $standard_feed_item['url'] = $this->get_url(
                array(self :: PARAM_FEED_TYPE => self :: FEED_STANDARD_TYPE, 
                        self :: PARAM_FEED_IDENTIFIER => 'most_discussed'), 
                array(ActionBarSearchForm :: PARAM_SIMPLE_SEARCH_QUERY));
        $standard_feed_item['class'] = 'feed';
        $standard_feed_items[] = $standard_feed_item;
        
        $standard_feed_item = array();
        $standard_feed_item['title'] = Translation :: get('TopFavorites');
        $standard_feed_item['url'] = $this->get_url(
                array(self :: PARAM_FEED_TYPE => self :: FEED_STANDARD_TYPE, 
                        self :: PARAM_FEED_IDENTIFIER => 'top_favorites'), 
                array(ActionBarSearchForm :: PARAM_SIMPLE_SEARCH_QUERY));
        $standard_feed_item['class'] = 'feed';
        $standard_feed_items[] = $standard_feed_item;
        
        $standard_feed_item = array();
        $standard_feed_item['title'] = Translation :: get('MostResponded');
        $standard_feed_item['url'] = $this->get_url(
                array(self :: PARAM_FEED_TYPE => self :: FEED_STANDARD_TYPE, 
                        self :: PARAM_FEED_IDENTIFIER => 'most_responded'), 
                array(ActionBarSearchForm :: PARAM_SIMPLE_SEARCH_QUERY));
        $standard_feed_item['class'] = 'feed';
        $standard_feed_items[] = $standard_feed_item;
        $standard_feed_item = array();
        $standard_feed_item['title'] = Translation :: get('MostRecent');
        $standard_feed_item['url'] = $this->get_url(
                array(self :: PARAM_FEED_TYPE => self :: FEED_STANDARD_TYPE, 
                        self :: PARAM_FEED_IDENTIFIER => 'most_recent'), 
                array(ActionBarSearchForm :: PARAM_SIMPLE_SEARCH_QUERY));
        $standard_feed_item['class'] = 'feed';
        $standard_feed_items[] = $standard_feed_item;
        
        $standard_feeds['sub'] = $standard_feed_items;
        
        $menu_items[] = $standard_feeds;
        
        return $menu_items;
    }
    
    /*
     * (non-PHPdoc) @see common/extensions/external_repository_manager/Manager#is_ready_to_be_used()
     */
    function is_ready_to_be_used()
    {
        // $action = $this->get_parameter(self ::
        // PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION);
        //
        // return self :: any_object_selected() && ($action == self ::
        // ACTION_PUBLISHER);
        return false;
    }
    
    /*
     * (non-PHPdoc) @see
     * common/extensions/external_repository_manager/Manager#get_external_repository_actions()
     */
    function get_external_repository_actions()
    {
        $actions = array(self :: ACTION_BROWSE_EXTERNAL_REPOSITORY);
        if ($this->get_external_repository()->get_user_setting('session_token'))
        {
            $actions[] = self :: ACTION_UPLOAD_EXTERNAL_REPOSITORY;
            $actions[] = self :: ACTION_EXPORT_EXTERNAL_REPOSITORY;
        }
        
        $is_platform = $this->get_user()->is_platform_admin();
        $has_setting = $this->get_external_repository()->has_settings();
        $has_user_setting = $this->get_external_repository()->has_user_settings();
        
        if (! ((! $has_setting || ! $this->get_external_repository()->get_user_setting('session_token')) || (! $has_user_setting && ! $is_platform)))
        {
            $actions[] = self :: ACTION_CONFIGURE_EXTERNAL_REPOSITORY;
        }
        
        if (! $this->get_external_repository()->get_user_setting('session_token'))
        {
            $actions[] = self :: ACTION_LOGIN;
        }
        else
        {
            $actions[] = self :: ACTION_LOGOUT;
        }
        return $actions;
    }
    
    /*
     * (non-PHPdoc) @see
     * common/extensions/external_repository_manager/Manager#get_available_renderers()
     */
    function get_available_renderers()
    {
        return array(ExternalRepositoryRenderer :: TYPE_GALLERY, ExternalRepositoryRenderer :: TYPE_SLIDESHOW, 
                ExternalRepositoryRenderer :: TYPE_TABLE);
    }
    
    /*
     * (non-PHPdoc) @see
     * common/extensions/external_repository_manager/Manager#get_content_object_type_conditions()
     */
    function get_content_object_type_conditions()
    {
        $video_types = Document :: get_video_types();
        $video_conditions = array();
        foreach ($video_types as $video_type)
        {
            $video_conditions[] = new PatternMatchCondition(Document :: PROPERTY_FILENAME, '*.' . $video_type, 
                    Document :: get_type_name());
        }
        
        return new OrCondition($video_conditions);
    }

    /**
     * Helper function for the SubManager class, pending access to class constants via variables in PHP 5.3 e.g. $name =
     * $class :: DEFAULT_ACTION DO NOT USE IN THIS SUBMANAGER'S CONTEXT Instead use: - self :: DEFAULT_ACTION in the
     * context of this class - YourSubManager :: DEFAULT_ACTION in all other application classes
     */
    static function get_default_action()
    {
        return self :: DEFAULT_ACTION;
    }

    /**
     * Helper function for the SubManager class, pending access to class constants via variables in PHP 5.3 e.g. $name =
     * $class :: PARAM_ACTION DO NOT USE IN THIS SUBMANAGER'S CONTEXT Instead use: - self :: PARAM_ACTION in the context
     * of this class - YourSubManager :: PARAM_ACTION in all other application classes
     */
    static function get_action_parameter()
    {
        return self :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION;
    }
}
?>