<?php
namespace common\extensions\external_repository_manager;

use common\libraries\Utilities;
use common\libraries\Translation;

use Exception;
/**
 *
 * @author Hans De Bisschop
 */
abstract class DataConnector
{
    /**
     *
     * @var array
     */
    private static $instances = array();

    /**
     *
     * @var ExternalRepository
     */
    private $external_repository_instance;

    /**
     *
     * @param $external_repository_instance ExternalRepository
     */
    function __construct($external_repository_instance)
    {
        $this->external_repository_instance = $external_repository_instance;
    }

    /**
     *
     * @return ExternalRepository
     */
    function get_external_repository_instance()
    {
        return $this->external_repository_instance;
    }

    /**
     *
     * @param $external_repository_instance ExternalRepository
     */
    function set_external_repository_instance($external_repository_instance)
    {
        $this->external_repository_instance = $external_repository_instance;
    }

    /**
     *
     * @return int
     */
    function get_external_repository_instance_id()
    {
        return $this->get_external_repository_instance()->get_id();
    }

    /**
     *
     * @param $external_repository ExternalInstance
     * @return DataConnector
     */
    static function factory($external_instance)
    {
        $class = $external_instance->get_type() . '\DataConnector';
        return new $class($external_instance);
    }

    /**
     *
     * @param $external_repository_instance ExternalRepository
     * @return DataConnector
     */
    static function get_instance($external_repository_instance)
    {
        if (! isset(self :: $instances[$external_repository_instance->get_id()]))
        {
            self :: $instances[$external_repository_instance->get_id()] = self :: factory($external_repository_instance);
        }
        return self :: $instances[$external_repository_instance->get_id()];
    }

    /**
     *
     * @param $id string
     */
    abstract function retrieve_external_repository_object($id);

    function retrieve_external_object(ExternalSync $external_sync)
    {
        return $this->retrieve_external_repository_object($external_sync->get_external_object_id());
    }

    /**
     *
     * @param $condition mixed
     * @param $order_property ObjectTableOrder
     * @param $offset int
     * @param $count int
     */
    abstract function retrieve_external_repository_objects($condition, $order_property, $offset, $count);

    /**
     *
     * @param $condition mixed
     */
    abstract function count_external_repository_objects($condition);

    /**
     *
     * @param $id string
     */
    abstract function delete_external_repository_object($id);

    /**
     *
     * @param $id string
     */
    abstract function export_external_repository_object($id);

    /**
     *
     * @param $query string
     */
    abstract static function translate_search_query($query);

    /**
     *
     * @return array
     */
    static function get_sort_properties()
    {
        return array();

    }
}
?>