<?php
namespace common\extensions\external_repository_manager;

use common\libraries\DelegateComponent;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Utilities;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Toolbar;
use common\libraries\ToolbarItem;
use common\libraries\Theme;

use repository\ExternalSync;

class ViewerComponent extends Component implements DelegateComponent
{

    function run()
    {
        $id = Request :: get(Manager :: PARAM_EXTERNAL_REPOSITORY_ID);
        
        if ($id)
        {
            $object = $this->retrieve_external_repository_object($id);
            BreadcrumbTrail :: get_instance()->add(new Breadcrumb(null, $object->get_title()));
            $this->display_header();
            
            $display = ExternalObjectDisplay :: factory($object);
            
            if (! $object->is_importable())
            {
                switch ($object->get_synchronization_status())
                {
                    case ExternalSync :: SYNC_STATUS_INTERNAL :
                        $this->display_warning_message(Translation :: get('ExternalObjectSynchronizationUpdateInternal'));
                        break;
                    case ExternalSync :: SYNC_STATUS_EXTERNAL :
                        if ($object->is_editable())
                        {
                            $this->display_warning_message(Translation :: get('ExternalObjectSynchronizationUpdateExternal'));
                        }
                        break;
                    case ExternalSync :: SYNC_STATUS_CONFLICT :
                        $this->display_warning_message(Translation :: get('ExternalObjectSynchronizationConflict'));
                        break;
                    case ExternalSync :: SYNC_STATUS_IDENTICAL :
                        $this->display_message(Translation :: get('ExternalObjectSynchronizationIdentical'));
                        break;
                    case ExternalSync :: SYNC_STATUS_ERROR :
                        $this->display_warning_message(Translation :: get('ExternalObjectSynchronizationError'));
                        break;
                }
            }
            
            $html = array();
            $html[] = $display->as_html();
            
            $toolbar = new Toolbar();
            $toolbar_item = new ToolbarItem(Translation :: get('Back', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_prev.png', 'javascript:history.back();');
            $toolbar->add_item($toolbar_item);
            
            $type_actions = $this->get_external_repository_object_actions($object);
            foreach ($type_actions as $type_action)
            {
                
                $toolbar_item = new ToolbarItem(Translation :: get($type_action->get_label()), $type_action->get_image(), $type_action->get_href());
                $toolbar->add_item($toolbar_item);
            }
            
            $html[] = '<br/>' . $toolbar->as_html();
            echo (implode("\n", $html));
            
            $this->display_footer();
        }
        else
        {
            $this->display_error_page(htmlentities(Translation :: get('NoObjectSelected', array(
                    'OBJECT' => Translation :: get('ExternalObject')), Utilities :: COMMON_LIBRARIES)));
        }
    
    }
}
?>