<?php
namespace common\extensions\external_repository_manager;

use common\libraries\CommonDataManager;

use core\lynx\PackageList;

use common\libraries\Filesystem;
use common\libraries\Display;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\SubManager;
use common\libraries\Path;
use common\libraries\Utilities;
use common\libraries\Request;
use common\libraries\Application;
use common\libraries\Translation;
use common\libraries\DynamicVisualTabsRenderer;
use common\libraries\DynamicVisualTab;
use common\libraries\Theme;
use common\libraries\LauncherApplication;
use common\libraries\ToolbarItem;
use common\libraries\EqualityCondition;
use common\libraries\AndCondition;

use repository\ExternalSync;
use repository\RepositoryManager;

use common\libraries\Registration;
use admin\AdminDataManager;

use Exception;

abstract class Manager extends SubManager
{
    const PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION = 'repository_action';
    
    const ACTION_VIEW_EXTERNAL_REPOSITORY = 'viewer';
    const ACTION_EXPORT_EXTERNAL_REPOSITORY = 'exporter';
    const ACTION_IMPORT_EXTERNAL_REPOSITORY = 'importer';
    const ACTION_BROWSE_EXTERNAL_REPOSITORY = 'browser';
    const ACTION_DOWNLOAD_EXTERNAL_REPOSITORY = 'downloader';
    const ACTION_UPLOAD_EXTERNAL_REPOSITORY = 'uploader';
    const ACTION_SELECT_EXTERNAL_REPOSITORY = 'selecter';
    const ACTION_EDIT_EXTERNAL_REPOSITORY = 'editor';
    const ACTION_DELETE_EXTERNAL_REPOSITORY = 'deleter';
    const ACTION_CONFIGURE_EXTERNAL_REPOSITORY = 'configurer';
    const ACTION_SYNCHRONIZE_EXTERNAL_REPOSITORY = 'external_syncer';
    const ACTION_SYNCHRONIZE_INTERNAL_REPOSITORY = 'internal_syncer';
    const ACTION_NEW_FOLDER_EXTERNAL_REPOSITORY = 'new_folder';
    
    const DEFAULT_ACTION = self :: ACTION_BROWSE_EXTERNAL_REPOSITORY;
    
    const PARAM_EXTERNAL_REPOSITORY_ID = 'external_repository_id';
    const PARAM_EXTERNAL_REPOSITORY = 'external_instance';
    const PARAM_QUERY = 'query';
    const PARAM_RENDERER = 'renderer';
    const PARAM_FOLDER = 'folder';
    const PARAM_USER_QUOTUM = 'default_user_quotum';
    
    const CLASS_NAME = __CLASS__;
    const NAMESPACE_NAME = __NAMESPACE__;
    
    /**
     *
     * @var ExternalRepository
     */
    private $external_repository;
    private $tabs;

    /**
     *
     * @param $application Application           
     */
    function __construct($application)
    {
        parent :: __construct($application);
        $this->external_repository = $application->get_external_instance();
        $external_repository_manager_action = Request :: get(self :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION);
        if ($external_repository_manager_action)
        {
            $this->set_parameter(self :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION, $external_repository_manager_action);
        }
        BreadcrumbTrail :: get_instance()->add(new Breadcrumb(null, $this->external_repository->get_title()));
        
        $this->set_optional_parameters();
        if ($this->validate_settings($this->external_repository))
        {
            $this->initialize_external_repository($this);
        }
    }

    /**
     *
     * @return ExternalRepository
     */
    function get_external_repository()
    {
        return $this->external_repository;
    }

    /**
     *
     * @param $external_repository ExternalRepository           
     */
    function set_external_repository(ExternalRepository $external_repository)
    {
        $this->external_repository = $external_repository;
    }

    /**
     *
     * @return DataConnector
     */
    function get_external_repository_manager_connector()
    {
        return DataConnector :: get_instance($this->get_external_repository());
    }

    function set_optional_parameters()
    {
        $this->set_parameter(self :: PARAM_RENDERER, $this->get_renderer());
    }

    /**
     *
     * @return boolean
     */
    function is_stand_alone()
    {
        return $this->get_parent() instanceof LauncherApplication;
    }

    /**
     *
     * @param $external_repository ExternalRepository           
     * @param $application Application           
     */
    static function launch($application)
    {
        $classname = static :: class_name();
        if (is_subclass_of($classname, __CLASS__))
        {
            parent :: launch(null, $application);
        }
        else
        {
            $external_repository = $application->get_external_instance();
            $type = $external_repository->get_type();
            
            $class = $type . '\\Manager';
            
            $settings_validated = call_user_func(array($class, 'validate_settings'), $external_repository);
            
            if (! $settings_validated)
            {
                if ($application->get_user()->is_platform_admin())
                {
                    Request :: set_get(Application :: PARAM_ERROR_MESSAGE, Translation :: get('PleaseReviewSettings'));
                    Request :: set_get(self :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION, self :: ACTION_CONFIGURE_EXTERNAL_REPOSITORY);
                }
                else
                {
                    Display :: display_header();
                    $application->display_warning_message('TemporarilyUnavailable');
                    Display :: display_footer();
                    exit();
                }
            }
            
            $class :: launch($application);
        }
    }

    /**
     *
     * @return string
     */
    function is_ready_to_be_used()
    {
        return false;
    }

    function any_object_selected()
    {
    }

    /**
     *
     * @return string
     */
    function get_action()
    {
        return $this->get_parameter(self :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION);
    }

    function display_header()
    {
        $action = $this->get_action();
        parent :: display_header();
        
        $html = array();
        $external_repository_actions = $this->get_external_repository_actions();
        
        if ($action == self :: ACTION_EDIT_EXTERNAL_REPOSITORY)
        {
            $external_repository_actions[] = self :: ACTION_EDIT_EXTERNAL_REPOSITORY;
        }
        
        if ($action == self :: ACTION_VIEW_EXTERNAL_REPOSITORY)
        {
            $external_repository_actions[] = self :: ACTION_VIEW_EXTERNAL_REPOSITORY;
        }
        
        $this->tabs = new DynamicVisualTabsRenderer(Utilities :: get_classname_from_object($this, true));
        
        foreach ($external_repository_actions as $external_repository_action)
        {
            if ($action == $external_repository_action)
            {
                $selected = true;
            }
            else
            {
                $selected = false;
            }
            
            $parameters = $this->get_parameters();
            $parameters[self :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION] = $external_repository_action;
            
            if ($external_repository_action == self :: ACTION_VIEW_EXTERNAL_REPOSITORY)
            {
                $parameters[self :: PARAM_EXTERNAL_REPOSITORY_ID] = Request :: get(self :: PARAM_EXTERNAL_REPOSITORY_ID);
            }
            
            $label = htmlentities(Translation :: get(Utilities :: underscores_to_camelcase($external_repository_action) . 'Title'));
            $link = $this->get_url($parameters);
            
            $icon = 'place_tab_' . $external_repository_action . '.png';
            $icon_path = Theme :: get_image_path($this->get_external_repository()->get_type()) . $icon;
            $icon_system_path = Theme :: get_image_system_path($this->get_external_repository()->get_type()) . $icon;
            
            if (! file_exists($icon_system_path))
            {
                $icon_path = Theme :: get_common_image_path() . $icon;
            }
            $this->tabs->add_tab(new DynamicVisualTab($external_repository_action, $label, $icon_path, $link, $selected));
        }
        $html[] = $this->tabs->header();
        $html[] = $this->tabs->body_header();
        
        echo implode("\n", $html);
    }

    /**
     *
     * @return array
     */
    function get_external_repository_actions()
    {
        $actions = array();
        $actions[] = self :: ACTION_BROWSE_EXTERNAL_REPOSITORY;
        $actions[] = self :: ACTION_UPLOAD_EXTERNAL_REPOSITORY;
        
        $is_platform = $this->get_user()->is_platform_admin();
        $has_setting = $this->get_external_repository()->has_settings();
        $has_user_setting = $this->get_external_repository()->has_user_settings();
        
        if (! ((! $has_setting) || (! $has_user_setting && ! $is_platform)))
        {
            $actions[] = self :: ACTION_CONFIGURE_EXTERNAL_REPOSITORY;
        }
        
        return $actions;
    }

    /**
     *
     * @return multitype:string
     */
    function get_instance_identifier()
    {
        return array();
    }

    function display_footer()
    {
        $html = array();
        $html[] = $this->tabs->body_footer();
        $html[] = $this->tabs->footer();
        echo implode("\n", $html);
        
        parent :: display_footer();
    }

    static function get_object_viewing_parameters($external_instance_sync)
    {
        return array(self :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION => self :: ACTION_VIEW_EXTERNAL_REPOSITORY, 
                self :: PARAM_EXTERNAL_REPOSITORY_ID => $external_instance_sync->get_external_object_id());
    }

    /**
     *
     * @param $condition mixed           
     */
    function count_external_repository_objects($condition)
    {
        return $this->get_external_repository_manager_connector()->count_external_repository_objects($condition);
    }

    /**
     *
     * @param $condition mixed           
     * @param $order_property ObjectTableOrder           
     * @param $offset int           
     * @param $count int           
     * @return ArrayResultSet
     */
    function retrieve_external_repository_objects($condition, $order_property, $offset, $count)
    {
        return $this->get_external_repository_manager_connector()->retrieve_external_repository_objects($condition, $order_property, $offset, $count);
    }

    /**
     *
     * @param $external_repository_manager Manager           
     */
    function initialize_external_repository(Manager $external_repository_manager)
    {
        $this->get_external_repository_manager_connector();
    }

    /**
     *
     * @return boolean
     */
    abstract function validate_settings($external_repository);

    /**
     *
     * @return string
     */
    function support_sorting_direction()
    {
        return true;
    }

    /**
     *
     * @param $query mixed           
     */
    function translate_search_query($query)
    {
        return $this->get_external_repository_manager_connector()->translate_search_query($query);
    }

    /**
     *
     * @return array
     */
    abstract function get_menu_items();

    /**
     *
     * @param $object ExternalObject           
     * @return string
     */
    abstract function get_external_repository_object_viewing_url(ExternalObject $object);

    /**
     *
     * @param $id string           
     * @return ExternalObject
     */
    function retrieve_external_repository_object($id)
    {
        return $this->get_external_repository_manager_connector()->retrieve_external_repository_object($id);
    }

    /**
     *
     * @param $id string           
     * @return boolean
     */
    function delete_external_repository_object($id)
    {
        return $this->get_external_repository_manager_connector()->delete_external_repository_object($id);
    }

    /**
     *
     * @param $id string           
     * @return boolean
     */
    function export_external_repository_object($id)
    {
        return $this->get_external_repository_manager_connector()->export_external_repository_object($id);
    }

    /**
     *
     * @param $object ExternalObject           
     * @return array
     */
    function get_external_repository_object_actions(ExternalObject $object)
    {
        $toolbar_items = array();
        
        if ($object->is_editable())
        {
            $toolbar_items[self :: ACTION_EDIT_EXTERNAL_REPOSITORY] = new ToolbarItem(Translation :: get('Edit', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_edit.png', $this->get_url(array(
                    self :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION => self :: ACTION_EDIT_EXTERNAL_REPOSITORY, 
                    self :: PARAM_EXTERNAL_REPOSITORY_ID => $object->get_id())), ToolbarItem :: DISPLAY_ICON);
        }
        
        if ($object->is_deletable())
        {
            $toolbar_items[self :: ACTION_DELETE_EXTERNAL_REPOSITORY] = new ToolbarItem(Translation :: get('Delete', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_delete.png', $this->get_url(array(
                    self :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION => self :: ACTION_DELETE_EXTERNAL_REPOSITORY, 
                    self :: PARAM_EXTERNAL_REPOSITORY_ID => $object->get_id())), ToolbarItem :: DISPLAY_ICON);
        }
        if ($object->is_usable())
        {
            if ($this->is_stand_alone())
            {
                $toolbar_items[] = new ToolbarItem(Translation :: get('Select', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_publish.png', $this->get_url(array(
                        self :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION => self :: ACTION_SELECT_EXTERNAL_REPOSITORY, 
                        self :: PARAM_EXTERNAL_REPOSITORY_ID => $object->get_id())), ToolbarItem :: DISPLAY_ICON);
            }
            else
            {
                if ($object->is_importable())
                {
                    $toolbar_items[self :: ACTION_IMPORT_EXTERNAL_REPOSITORY] = new ToolbarItem(Translation :: get('Import', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_import.png', $this->get_url(array(
                            self :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION => self :: ACTION_IMPORT_EXTERNAL_REPOSITORY, 
                            self :: PARAM_EXTERNAL_REPOSITORY_ID => $object->get_id())), ToolbarItem :: DISPLAY_ICON);
                }
                else
                {
                    switch ($object->get_synchronization_status())
                    {
                        case ExternalSync :: SYNC_STATUS_INTERNAL :
                            $toolbar_items[self :: ACTION_SYNCHRONIZE_INTERNAL_REPOSITORY] = new ToolbarItem(Translation :: get('UpdateRepositoryObject'), Theme :: get_common_image_path() . 'action_synchronize.png', $this->get_url(array(
                                    self :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION => self :: ACTION_SYNCHRONIZE_INTERNAL_REPOSITORY, 
                                    self :: PARAM_EXTERNAL_REPOSITORY_ID => $object->get_id())), ToolbarItem :: DISPLAY_ICON);
                            break;
                        case ExternalSync :: SYNC_STATUS_EXTERNAL :
                            if ($object->is_editable())
                            {
                                $toolbar_items[self :: ACTION_SYNCHRONIZE_EXTERNAL_REPOSITORY] = new ToolbarItem(Translation :: get('UpdateExternalObject', array(
                                        'TYPE' => $this->get_external_repository()->get_name())), Theme :: get_image_path($object :: context()) . 'logo/16.png', $this->get_url(array(
                                        self :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION => self :: ACTION_SYNCHRONIZE_EXTERNAL_REPOSITORY, 
                                        self :: PARAM_EXTERNAL_REPOSITORY_ID => $object->get_id())), ToolbarItem :: DISPLAY_ICON);
                            }
                            break;
                        case ExternalSync :: SYNC_STATUS_CONFLICT :
                            $toolbar_items[self :: ACTION_SYNCHRONIZE_INTERNAL_REPOSITORY] = new ToolbarItem(Translation :: get('UpdateRepositoryObject'), Theme :: get_common_image_path() . 'action_synchronize.png', $this->get_url(array(
                                    self :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION => self :: ACTION_SYNCHRONIZE_INTERNAL_REPOSITORY, 
                                    self :: PARAM_EXTERNAL_REPOSITORY_ID => $object->get_id())), ToolbarItem :: DISPLAY_ICON);
                            if ($object->is_editable())
                            {
                                $toolbar_items[self :: ACTION_SYNCHRONIZE_EXTERNAL_REPOSITORY] = new ToolbarItem(Translation :: get('UpdateExternalObject', array(
                                        'TYPE' => $this->get_external_repository()->get_name())), Theme :: get_image_path($object :: context()) . 'logo/16.png', $this->get_url(array(
                                        self :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION => self :: ACTION_SYNCHRONIZE_EXTERNAL_REPOSITORY, 
                                        self :: PARAM_EXTERNAL_REPOSITORY_ID => $object->get_id())), ToolbarItem :: DISPLAY_ICON);
                            }
                            break;
                    }
                }
            }
        }
        return $toolbar_items;
    }

    /**
     *
     * @return string
     */
    function get_renderer()
    {
        $renderer = Request :: get(self :: PARAM_RENDERER);
        
        if ($renderer && in_array($renderer, $this->get_available_renderers()))
        {
            return $renderer;
        }
        else
        {
            $renderers = $this->get_available_renderers();
            return $renderers[0];
        }
    }

    /**
     *
     * @return array
     */
    function get_available_renderers()
    {
        return array(ExternalRepositoryRenderer :: TYPE_TABLE);
    }

    /**
     *
     * @return Condition
     */
    abstract function get_content_object_type_conditions();

    /**
     *
     * @param $type string           
     * @return boolean
     */
    static public function exists($type)
    {
        $path = Path :: get_common_extensions_path() . 'external_repository_manager/implementation';
        $external_repository_path = $path . '/' . $type;
        $external_repository_manager_path = $external_repository_path . '/php/' . $type . '_external_repository_manager.class.php';
        
        if (file_exists($external_repository_path) && is_dir($external_repository_path) && file_exists($external_repository_manager_path))
        {
            return true;
        }
        else
        {
            return false;
        }
    }

    static function get_namespace($type = null)
    {
        if ($type)
        {
            return __NAMESPACE__ . '\implementation\\' . $type;
        }
        else
        {
            return __NAMESPACE__;
        }
    }

    static function get_registered_types($status = Registration :: STATUS_ACTIVE)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(Registration :: PROPERTY_TYPE, __NAMESPACE__ . '\implementation');
        $conditions[] = new EqualityCondition(Registration :: PROPERTY_STATUS, $status);
        $condition = new AndCondition($conditions);
        
        return CommonDataManager :: retrieves(Registration :: class_name(), $condition);
    }

    static function get_repository_menu_parameter()
    {
        return array(self :: PARAM_EXTERNAL_REPOSITORY_MANAGER_ACTION => self :: ACTION_BROWSE_EXTERNAL_REPOSITORY);
    }

    public static function get_packages_from_filesystem()
    {
        $external_repository_managers = array();
        
        $path = Path :: get_common_extensions_path() . 'external_repository_manager/implementation';
        $directories = Filesystem :: get_directory_content($path, Filesystem :: LIST_DIRECTORIES, false);
        
        foreach ($directories as $directory)
        {
            $manager_name = basename($directory);
            $external_repository_managers[] = self :: get_namespace($manager_name);
        }
        
        return $external_repository_managers;
    }

    static function get_installable_packages($include_installed = false)
    {
        $package_list = new PackageList(__NAMESPACE__ . '\implementation', Translation :: get('TypeName', null, __NAMESPACE__), Theme :: get_image_path() . 'logo/16.png');
        
        foreach (self :: get_packages_from_filesystem() as $implementation)
        {
            if (! CommonDataManager :: get_registration($implementation) || $include_installed)
            {
                $package_list->add_package($implementation);
            }
        }
        
        return $package_list;
    }
}
?>