<?php
namespace common\extensions\feedback_manager;

use admin\AdminDataManager;
use admin\FeedbackPublication;

use common\libraries\Display;
use common\libraries\EqualityCondition;
use common\libraries\AndCondition;
use common\libraries\NotAllowedException;
use common\libraries\Request;

use repository\RepositoryDataManager;
use repository\ContentObjectRenditionImplementation;
use repository\ContentObjectRendition;

/**
 * Views attachments for feedback objects
 *
 * @author Sven Vanpoucke - Hogeschool Gent
 */
class FeedbackManagerAttachmentViewerComponent extends FeedbackManager
{
    /**
     * The attachment content object
     *
     * @var ContentObject
     */
    protected $attachment_content_object;

    /****************************************************************************************************************
    * Main functionality											    *
    ****************************************************************************************************************/

    /**
     * Runs this component and display's it's output
     */
    function run()
    {
        if(!$this->is_valid_request())
        {
            throw new NotAllowedException();
        }

        $html = $this->as_html();

        Display :: small_header();
        echo $html;
        Display :: small_footer();
    }

    /**
     * Returns this component's output as html
     *
     * @return string
     */
    function as_html()
    {
        $rendition_implementation = ContentObjectRenditionImplementation :: factory($this->attachment_content_object,
                ContentObjectRendition :: FORMAT_HTML, ContentObjectRendition :: VIEW_FULL, $this);

        return $rendition_implementation->render();
    }

    /****************************************************************************************************************
    * Implemented functionality											    *
    ****************************************************************************************************************/

    /**
     * Returns the attachment url
     *
     * @param ContentObject $attachment
     *
     * @return string
     */
    function get_content_object_display_attachment_url($attachment)
    {
        return $this->get_url(array(
                FeedbackManager :: PARAM_ATTACHMENT_ID => $attachment->get_id()
        ));
    }

    /****************************************************************************************************************
    * Helper functionality											    *
    ****************************************************************************************************************/

    protected function is_valid_request()
    {
        $feedback_object_id = Request :: get(self :: PARAM_FEEDBACK_ID);
        $attachment_object_id = Request :: get(self :: PARAM_ATTACHMENT_ID);

        $admin_data_manager = AdminDataManager :: get_instance();

        $conditions = array();

        $conditions[] = new EqualityCondition(FeedbackPublication :: PROPERTY_PID, $this->get_publication_id());
        $conditions[] = new EqualityCondition(FeedbackPublication :: PROPERTY_CID, $this->get_complex_wrapper_id());
        $conditions[] = new EqualityCondition(FeedbackPublication :: PROPERTY_APPLICATION, $this->get_application());
        $conditions[] = new EqualityCondition(FeedbackPublication :: PROPERTY_FID, $feedback_object_id);

        $condition = new AndCondition($conditions);

        if($admin_data_manager->count_objects(FeedbackPublication :: get_table_name(), $condition) == 0)
        {
            return false;
        }

        if(!RepositoryDataManager :: is_attached_or_included_to($feedback_object_id, $attachment_object_id))
        {
            return false;
        }

        $this->attachment_content_object = RepositoryDataManager :: get_instance()->retrieve_content_object(
                $attachment_object_id);

        return (!is_null($this->attachment_content_object));
    }
    
}
?>