<?php
namespace common\extensions\new_feedback_manager;

use common\libraries\Utilities;
use common\libraries\SubManager;
use common\libraries\Path;
use common\libraries\Translation;

use Exception;

abstract class FeedbackComponent extends SubManager
{
    const BROWSER_COMPONENT = 'browser';
    const BROWSER_ONLY_COMPONENT = 'browser_only';
    const CREATOR_COMPONENT = 'creator';
    const UPDATER_COMPONENT = 'updater';
    const DELETER_COMPONENT = 'deleter';

    static function factory($type, $application)
    {
        $file = dirname(__FILE__) . '/component/' . $type . '.class.php';
        if (! file_exists($file))
        {
            throw new Exception(Translation :: get('FeedbackComponentTypeDoesNotExist', array('type' => $type)));
        }

        $class = __NAMESPACE__ . '\\' . 'FeedbackComponent' . Utilities :: underscores_to_camelcase($type) . 'Component';
        return new $class($application);
    }

    function get_application_component_path()
    {
        return Path :: get_common_extensions_path() . 'new_feedback_manager/php/component/';
    }

    function retrieve_feedback_publications()
    {
        return $this->get_parent()->retrieve_feedback_publications();
    }

    function retrieve_feedback_publication($id)
    {
        return $this->get_parent()->retrieve_feedback_publication($id);
    }

    function create_feedback_publication($object)
    {
        return $this->get_parent()->create_feedback_publication($object);
    }

    function get_publication_parameters()
    {
        return $this->get_parent()->get_publication_parameters();
    }

    /**
     * Helper function for the SubManager class,
     * pending access to class constants via variables in PHP 5.3
     * e.g. $name = $class :: DEFAULT_ACTION
     *
     * DO NOT USE IN THIS SUBMANAGER'S CONTEXT
     * Instead use:
     * - self :: DEFAULT_ACTION in the context of this class
     * - YourSubManager :: DEFAULT_ACTION in all other application classes
     */
    static function get_default_action()
    {
        return FeedbackManager :: DEFAULT_ACTION;
    }

    /**
     * Helper function for the SubManager class,
     * pending access to class constants via variables in PHP 5.3
     * e.g. $name = $class :: PARAM_ACTION
     *
     * DO NOT USE IN THIS SUBMANAGER'S CONTEXT
     * Instead use:
     * - self :: PARAM_ACTION in the context of this class
     * - YourSubManager :: PARAM_ACTION in all other application classes
     */
    static function get_action_parameter()
    {
        return FeedbackManager :: PARAM_ACTION;
    }

    /**
     * @param Application $application
     */
    static function launch($application)
    {
        parent :: launch(__CLASS__, $application, false);
    }
}
?>