<?php
namespace common\extensions\repo_viewer;

use common\libraries\Session;
use repository\ContentObject;
use repository\RepositoryRights;
use repository\RepositoryManager;
use repository\ContentObjectCategoryMenu;
use common\libraries\NewObjectTableSupport;
use common\libraries\InCondition;
use common\libraries\Path;
use common\libraries\Application;
use common\libraries\ComplexDisplayPreviewLauncher;
use common\libraries\ComplexContentObjectSupport;
use common\libraries\Toolbar;
use common\libraries\ToolbarItem;
use common\libraries\Translation;
use common\libraries\Theme;
use common\libraries\Request;
use common\libraries\FormValidator;
use common\libraries\OptionsMenuRenderer;
use common\libraries\Utilities;
use repository\SharedRepositoryCategoryTreeMenu;

class RepoViewerImportedSelecterComponent extends RepoViewer implements NewObjectTableSupport
{

    /**
     * The browser actions
     */
    private $browser_actions;

    /*
     * Inherited
     */
    function run()
    {
        $table = new ImportTable($this);

        $this->display_header();
        echo $table->as_html();
        $this->display_footer();
    }

    public function get_object_table_condition($object_table_class_name)
    {
        $content_object_ids = Session :: retrieve(self :: PARAM_IMPORTED_CONTENT_OBJECT_IDS);
        return new InCondition(ContentObject :: PROPERTY_ID, $content_object_ids);
    }

    function get_browser_actions()
    {
        return $this->browser_actions;
    }

    function set_browser_actions($browser_actions)
    {
        $this->browser_actions = $browser_actions;
    }

    function get_default_browser_actions($content_object)
    {
        $toolbar = new Toolbar(Toolbar :: TYPE_HORIZONTAL);

        if ($content_object->has_right(RepositoryRights :: USE_RIGHT, $this->get_user_id()))
        {
            $toolbar->add_item(
                    new ToolbarItem(Translation :: get('Publish', null, Utilities :: COMMON_LIBRARIES),
                            Theme :: get_common_image_path() . 'action_publish.png',
                            $this->get_url(
                                    array_merge($this->get_parameters(),
                                            array(RepoViewer :: PARAM_ACTION => RepoViewer :: ACTION_PUBLISHER,
                                                    RepoViewer :: PARAM_ID => $content_object->get_id())), false),
                            ToolbarItem :: DISPLAY_ICON));
        }

        if ($content_object->has_right(RepositoryRights :: VIEW_RIGHT, $this->get_user_id()))
        {
            $toolbar->add_item(
                    new ToolbarItem(Translation :: get('Preview'),
                            Theme :: get_common_image_path() . 'action_browser.png',
                            $this->get_url(
                                    array_merge($this->get_parameters(),
                                            array(RepoViewer :: PARAM_ACTION => RepoViewer :: ACTION_VIEWER,
                                                    RepoViewer :: PARAM_ID => $content_object->get_id())), false),
                            ToolbarItem :: DISPLAY_ICON));
        }

        if ($content_object->has_right(RepositoryRights :: COLLABORATE_RIGHT, $this->get_user_id()))
        {
            $toolbar->add_item(
                    new ToolbarItem(Translation :: get('EditAndPublish'),
                            Theme :: get_common_image_path() . 'action_editpublish.png',
                            $this->get_url(
                                    array_merge($this->get_parameters(),
                                            array(RepoViewer :: PARAM_ACTION => RepoViewer :: ACTION_CREATOR,
                                                    RepoViewer :: PARAM_EDIT_ID => $content_object->get_id())), false),
                            ToolbarItem :: DISPLAY_ICON));
        }

        if ($content_object instanceof ComplexContentObjectSupport)
        {

            $preview_url = Path :: get_launcher_application_path(true) . 'index.php?' . Application :: PARAM_APPLICATION . '=' . ComplexDisplayPreviewLauncher :: APPLICATION_NAME . '&' . RepositoryManager :: PARAM_CONTENT_OBJECT_ID . '=' . $content_object->get_id();
            $onclick = '" onclick="javascript:openPopup(\'' . $preview_url . '\'); return false;';
            $toolbar->add_item(
                    new ToolbarItem(Translation :: get('Preview', null, Utilities :: COMMON_LIBRARIES),
                            Theme :: get_common_image_path() . 'action_preview.png', $preview_url,
                            ToolbarItem :: DISPLAY_ICON, false, $onclick, '_blank'));
        }

        return $toolbar;
    }
}
?>