<?php
namespace common\extensions\repo_viewer;

use common\libraries\DelegateComponent;

use common\libraries\FileProperties;
use common\libraries\Display;
use common\libraries\AndCondition;
use common\libraries\InCondition;
use common\libraries\Filesystem;
use common\libraries\Path;
use common\libraries\Theme;
use common\libraries\Utilities;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Application;
use common\libraries\Session;
use common\libraries\Translation;
use common\libraries\StringUtilities;
use common\libraries\Request;
use common\libraries\NotAllowedException;
use repository\RepositoryDataManager;
use repository\ContentObjectImportImplementation;
use repository\RepositoryManager;
use repository\ContentObjectImportController;
use repository\ImportParameters;
use repository\RepositoryCategory;
use repository\ContentObject;
use repository\ContentObjectImportForm;

class RepoViewerImporterComponent extends RepoViewer implements DelegateComponent
{

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        if ($this->get_user()->is_anonymous_user())
        {
            throw new NotAllowedException();
        }

        $type = Request :: get(self :: PARAM_IMPORT_TYPE);

        if ($type)
        {
            $import_form = ContentObjectImportForm :: factory($type, $this, 'post',
                    $this->get_url(array(self :: PARAM_IMPORT_TYPE => $type)));

            if ($import_form->validate())
            {
                $values = $import_form->exportValues();
                $parent_id = $values[ContentObject :: PROPERTY_PARENT_ID];
                $new_category_name = $values[ContentObjectImportForm :: NEW_CATEGORY];

                if (! StringUtilities :: is_null_or_empty($new_category_name, true))
                {
                    $new_category = new RepositoryCategory();
                    $new_category->set_name($new_category_name);
                    $new_category->set_parent($parent_id);
                    $new_category->set_user_id($this->get_user_id());
                    $new_category->set_type(RepositoryCategory :: TYPE_NORMAL);
                    if (! $new_category->create())
                    {
                        throw new \Exception(Translation :: get('CategoryCreationFailed'));
                    }
                    else
                    {
                        $category_id = $new_category->get_id();
                    }
                }
                else
                {
                    $category_id = $parent_id;
                }

                if (isset($_FILES[ContentObjectImportForm :: IMPORT_FILE_NAME]))
                {
                    $file = FileProperties :: from_upload($_FILES[ContentObjectImportForm :: IMPORT_FILE_NAME]);
                }
                else
                {
                    $file = null;
                }

                $parameters = ImportParameters :: factory(
                        $import_form->exportValue(ContentObjectImportForm :: PROPERTY_TYPE), $this->get_user_id(),
                        $category_id, $file, $values);
                $controller = ContentObjectImportController :: factory($parameters);
                $content_object_ids = $controller->run();
                $filtered_content_object_ids = $this->filter_content_object_ids($content_object_ids);

                $messages = $controller->get_messages_for_url();

                Session :: register(Application :: PARAM_MESSAGES, $messages);

                if (! $controller->has_messages(ContentObjectImportController :: TYPE_ERROR))
                {
                    if (count($filtered_content_object_ids) == 1)
                    {
                        if (count($content_object_ids) > 1)
                        {
                            $messages = Session :: retrieve(Application :: PARAM_MESSAGES);
                            $messages[Application :: PARAM_MESSAGE][] = Translation :: get(
                                    'MultipleObjectsImportedButOneUseable');
                            $messages[Application :: PARAM_MESSAGE_TYPE][] = ContentObjectImportController :: TYPE_ERROR;
                            Session :: register(Application :: PARAM_MESSAGES, $messages);
                        }

                        $this->simple_redirect(
                                array(self :: PARAM_ACTION => self :: ACTION_VIEWER,
                                        self :: PARAM_ID => $content_object_ids[0]));
                    }
                    elseif (count($filtered_content_object_ids) == 0)
                    {
                        if (count($content_object_ids) > 0)
                        {
                            $messages = Session :: retrieve(Application :: PARAM_MESSAGES);
                            $message = (count($content_object_ids) == 1 ? 'ObjectImportedButNoneUseable' : 'ObjectsImportedButNoneUseable');
                            $messages[Application :: PARAM_MESSAGE][] = Translation :: get($message);
                            $messages[Application :: PARAM_MESSAGE_TYPE][] = ContentObjectImportController :: TYPE_ERROR;
                            Session :: register(Application :: PARAM_MESSAGES, $messages);
                        }

                        $this->simple_redirect();
                    }
                    else
                    {
                        Session :: register(self :: PARAM_IMPORTED_CONTENT_OBJECT_IDS, $content_object_ids);
                        $this->simple_redirect(array(self :: PARAM_ACTION => self :: ACTION_IMPORTED_SELECTER));
                    }
                }
                else
                {
                    $this->simple_redirect();
                }

            /**
             * TODO: Do something with the result here 1. If the import produces no errors AND only 1 object was
             * returned: select it 2. If the import produces no errors AND results in multiple objects: show selection
             * table ALWAYS filter on allowed types (since CPO can result in multiple objects of multiple types)
             */
            }
            else
            {
                BreadcrumbTrail :: get_instance()->add(
                        new Breadcrumb($this->get_url(),
                                Translation :: get('ImportType',
                                        array(
                                                'TYPE' => Translation :: get(
                                                        'ImportType' . Utilities :: underscores_to_camelcase($type),  null,
                                                        RepositoryManager :: context())), RepositoryManager :: context())));

                $this->display_header();
                $import_form->display();
                $this->display_footer();
            }
        }
        else
        {
            BreadcrumbTrail :: get_instance()->add(
                    new Breadcrumb($this->get_url(), Translation :: get('ChooseImportFormat')));

            $this->display_header();

            $html = array();
            foreach ($this->get_import_types() as $type => $name)
            {

                $html[] = '<a href="' . $this->get_url(array(self :: PARAM_IMPORT_TYPE => $type)) . '">';
                $html[] = '<div class="create_block" style="background-image: url(' . Theme :: get_image_path(
                        RepositoryManager :: context()) . 'import/' . $type . '.png);">';
                $html[] = $name;
                $html[] = '</div>';
                $html[] = '</a>';
            }
            echo implode("\n", $html);

            $this->display_footer();
        }
    }

    function get_import_types()
    {
        $import_types = array();

        foreach ($this->get_types() as $type)
        {
            $object_import_types = ContentObjectImportImplementation :: get_types_for_object(
                    ContentObject :: get_content_object_type_namespace($type));

            foreach ($object_import_types as $object_import_type)
            {
                if (! array_key_exists($object_import_type, $import_types))
                {
                    $import_types[$object_import_type] = Translation :: get(
                            'ImportType' . Utilities :: underscores_to_camelcase($object_import_type), null,
                            RepositoryManager :: context());
                }
            }
        }

        return $import_types;
    }

    function filter_content_object_ids($content_object_ids)
    {
        $repository_data_manager = RepositoryDataManager :: get_instance();

        $conditions = array();
        $conditions[] = new InCondition(ContentObject :: PROPERTY_ID, $content_object_ids);
        $conditions[] = new InCondition(ContentObject :: PROPERTY_TYPE, $this->get_types());
        $condition = new AndCondition($conditions);

        return $repository_data_manager->retrieve_distinct(ContentObject :: get_table_name(),
                ContentObject :: PROPERTY_ID, $condition);
    }
}
?>