<?php
namespace common\extensions\repo_viewer;

use common\libraries\ObjectTable;
use common\libraries\ObjectTableFormActions;
use common\libraries\ObjectTableFormAction;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\Request;

/**
 * $Id: content_object_table.class.php 191 2009-11-13 11:50:28Z chellee $
 *
 * @package application.common.repo_viewer.component.content_object_table
 */
/**
 * This class represents a table with learning objects which are candidates for publication.
 */
class ContentObjectTable extends ObjectTable
{
    const DEFAULT_NAME = 'content_object_table';

    /**
     * Constructor.
     *
     * @param int $owner The id of the current user.
     * @param array $types The types of objects that can be published in current location.
     * @param string $query The search query, or null if none.
     * @param string $publish_url_format URL for publishing the selected learning object.
     * @param string $edit_and_publish_url_format URL for editing and publishing the selected learning object.
     * @see PublicationCandidateTableCellRenderer::PublicationCandidateTableCellRenderer()
     */
    function __construct($parent, $owner, $types, $query)
    {
        $data_provider = new ContentObjectTableDataProvider($owner, $types, $query, $parent);
        $column_model = new ContentObjectTableColumnModel();
        $cell_renderer = new ContentObjectTableCellRenderer($parent);
        parent :: __construct($data_provider, ContentObjectTable :: DEFAULT_NAME, $column_model, $cell_renderer);

        $action = new ObjectTableFormActions(__NAMESPACE__);
        $action->set_action(RepoViewer :: PARAM_ACTION);
        if ($parent->get_maximum_select() != RepoViewer :: SELECT_SINGLE)
        {
            $action->add_form_action(
                    new ObjectTableFormAction(RepoViewer :: ACTION_PUBLISHER, Translation :: get('PublishSelected'),
                            false));
        }

        $this->set_form_actions($action);
    }

    static function handle_table_action()
    {
        $class = Utilities :: get_classname_from_namespace(__CLASS__, true);
        $ids = self :: get_selected_ids($class);
        Request :: set_get(RepoViewer :: PARAM_ID, $ids);
    }
}
?>