<?php
namespace common\libraries\form;

class Autoloader
{

    /**
     * The array mapping class names to paths
     *
     * @var multitype:string
     */
     private static $map = array(
         'Attribute' => '/attribute.class.php',
         'Autoloader' => '/autoloader.class.php',
         'Container' => '/container.class.php',
         'Element' => '/element.class.php',
         'Form' => '/form.class.php',
         'MergedForm' => '/merged_form.class.php',
         'Renderer' => '/renderer.class.php',
         'Accesskey' => '/attribute/accesskey.class.php',
         'Alt' => '/attribute/alt.class.php',
         'AttributeClass' => '/attribute/attribute_class.class.php',
         'AttributeMaxlength' => '/attribute/attribute_maxlength.class.php',
         'Checked' => '/attribute/checked.class.php',
         'Cols' => '/attribute/cols.class.php',
         'Disabled' => '/attribute/disabled.class.php',
         'Onclick' => '/attribute/onclick.class.php',
         'Readonly' => '/attribute/readonly.class.php',
         'Rows' => '/attribute/rows.class.php',
         'Size' => '/attribute/size.class.php',
         'Source' => '/attribute/source.class.php',
         'Style' => '/attribute/style.class.php',
         'Tabindex' => '/attribute/tabindex.class.php',
         'Title' => '/attribute/title.class.php',
         'Datepicker' => '/container/datepicker.class.php',
         'ElementFinder' => '/container/element_finder.class.php',
         'Fieldset' => '/container/fieldset.class.php',
         'Grouping' => '/container/grouping.class.php',
         'ImageSelecter' => '/container/image_selecter.class.php',
         'Menus' => '/container/menus.class.php',
         'Tabs' => '/container/tabs.class.php',
         'Timepicker' => '/container/timepicker.class.php',
         'UserGroupFinder' => '/container/user_group_finder.class.php',
         'Button' => '/element/button.class.php',
         'CheckBox' => '/element/checkbox.class.php',
         'Hidden' => '/element/hidden.class.php',
         'AddHtml' => '/element/html.class.php',
         'Image' => '/element/image.class.php',
         'ImageButton' => '/element/image_button.class.php',
         'Label' => '/element/label.class.php',
         'Link' => '/element/link.class.php',
         'Password' => '/element/password.class.php',
         'RadioButton' => '/element/radiobutton.class.php',
         'ResetButton' => '/element/reset_button.class.php',
         'Select' => '/element/select.class.php',
         'SelectLanguage' => '/element/select_language.class.php',
         'StyleButton' => '/element/style_button.class.php',
         'StyleResetbutton' => '/element/style_reset_button.class.php',
         'StyleSubmitButton' => '/element/style_submit_button.class.php',
         'SubmitButton' => '/element/submit_button.class.php',
         'Text' => '/element/text.class.php',
         'TextArea' => '/element/textarea.class.php',
         'Upload' => '/element/upload.class.php',
         'DefaultRenderer' => '/renderer/default.class.php',
         'DefaultContainerRenderer' => '/renderer/default/container.class.php',
         'DefaultElementRenderer' => '/renderer/default/element.class.php',
         'DefaultFormLibraryRenderer' => '/renderer/default/form_library.class.php',
         'DefaultFieldsetRenderer' => '/renderer/default/container/fieldset.class.php',
         'DefaultGroupingRenderer' => '/renderer/default/container/grouping.class.php',
         'DefaultMenusRenderer' => '/renderer/default/container/menus.class.php',
         'DefaultTabsRenderer' => '/renderer/default/container/tabs.class.php',
         'DefaultStyleButtonRenderer' => '/renderer/default/element/style_button.class.php',
         'Alpha' => '/rule/alpha.class.php',
         'AlphaNum' => '/rule/alpha_num.class.php',
         'Bool' => '/rule/bool.class.php',
         'Digit' => '/rule/digit.class.php',
         'Email' => '/rule/email.class.php',
         'File' => '/rule/file.class.php',
         'Filetypes' => '/rule/filetypes.class.php',
         'Float' => '/rule/float.class.php',
         'Integer' => '/rule/integer.class.php',
         'Maxlength' => '/rule/maxlength.class.php',
         'Minlength' => '/rule/minlength.class.php',
         'Radio' => '/rule/radio.class.php',
         'Required' => '/rule/required.class.php',
         'Rule' => '/rule/rule.class.php',
         'URL' => '/rule/url.class.php',
         'Vcheckbox' => '/rule/vcheckbox.class.php',
         'Vconfirmpassword' => '/rule/vconfirmpassword.class.php',
         'Vpassword' => '/rule/vpassword.class.php',
         'AttributeStorage' => '/storage/attribute.class.php',
         'ElementStorage' => '/storage/element.class.php',
         'RuleStorage' => '/storage/rule.class.php',
         'Action' => '/wizards/action.interface.php',
         'Controller' => '/wizards/controller.class.php',
         'Page' => '/wizards/page.class.php',
         'ActionStorage' => '/wizards/storages/action_storage.class.php',
         'PageStorage' => '/wizards/storages/page_storage.class.php'
    );

    /**
     * Try to load the class
     *
     * @param $classname string
     * @return boolean
     */
    static function load($classname)
    {
        if (isset(self :: $map[$classname]))
        {
            require_once __DIR__ . self :: $map[$classname];
            return true;
        }

        return false;
    }

    /**
     * Synchronize the autoloader
     *
     * @param $update boolean
     * @return multitype:string
     */
    static function synch($update)
    {
        return \common\libraries\AutoloaderUtilities :: synch(__DIR__, __DIR__, $update);
    }

}
?>