<?php
namespace common\libraries\form;

class StyleButton extends Element
{
    const TEMPLATE = '<button type="{TYPE}" name="{NAME}" id="{ID}" value="{VALUE}" class="{CLASS}"{ATTRIBUTES}>{LABEL}</button>';

    private $type;
    private $class;

    public function __construct($type, $elementName = null, $elementLabel = null, $value = null, $class = 'normal')
    {
        parent :: __construct($elementName, $value, $elementLabel);
        $this->type = $type;
        $this->class = $class;

        if (isset($value))
        {
            $this->set_value($value);
        }
        else
        {
            $this->set_value($elementName);
        }
    }

    public function html()
    {
        $parameters = array();
        $parameters['VALUE'] = $this->get_value();
        $parameters['NAME'] = $this->get_fully_qualified_name();
        $parameters['ID'] = $this->get_fully_qualified_id();
        $parameters['TYPE'] = $this->get_type();
        $parameters['LABEL'] = $this->get_label();
        $parameters['CLASS'] = $this->get_class();

        $attributes = $this->get_attribute_storage()->get_attributes();
        if ($attributes)
        {
            $parameters['ATTRIBUTES'] = ' ' . $attributes;
        }

        return Renderer :: process(self :: TEMPLATE, $parameters);
    }

    function get_type()
    {
        return $this->type;
    }

    function get_class()
    {
        return $this->class;
    }

    function render()
    {
        $renderer = $this->get_renderer() ? $this->get_renderer() : new DefaultStyleButtonRenderer($this);
        return $renderer->render();
    }
}
?>