<?php
namespace common\libraries;

class CommonDataManager extends DataManager
{
    static $registrations;

    const REGISTRATION_CONTEXT = 1;
    const REGISTRATION_TYPE = 2;

    /**
     * Gets the type of DataManager to be instantiated
     *
     * @return string
     */
    static function get_type()
    {
        return 'doctrine';
    }

    static function is_registered($context)
    {
        $registration = self :: get_registration($context);
        return ($registration instanceof Registration);
    }

    /**
     *
     * @param $registration Registration
     */
    static function update_registration_cache($registration)
    {
        self :: $registrations[self :: REGISTRATION_TYPE][$registration->get_type()][$registration->get_context()] = $registration;
        self :: $registrations[self :: REGISTRATION_CONTEXT][$registration->get_context()] = $registration;
    }

    static function get_registration($context)
    {
        if (! self :: $registrations)
        {
            self :: init_registrations();
        }

        return self :: $registrations[self :: REGISTRATION_CONTEXT][$context];
    }

    static function get_registrations()
    {
        return self :: $registrations;
    }

    static function get_registrations_by_type($type)
    {
        if (! self :: $registrations)
        {
            self :: init_registrations();
        }

        return self :: $registrations[self :: REGISTRATION_TYPE][$type];
    }

    static function reset_registrations()
    {
        SystemCache :: system()->admin_data_manager_registrations = null;
        self :: $registrations = array();
        SystemCache :: reset_system();
        DataClassResultSetCache :: truncate(Registration :: class_name());
    }

    static function init_registrations()
    {
        if ($registrations = SystemCache :: system()->admin_data_manager_registrations)
        {
            self :: $registrations = $registrations;
            return;
        }

        self :: $registrations = array();

        $registrations = self :: retrieves(Registration :: class_name());
        while ($registration = $registrations->next_result())
        {
            self :: $registrations[self :: REGISTRATION_TYPE][$registration->get_type()][$registration->get_context()] = $registration;
            self :: $registrations[self :: REGISTRATION_CONTEXT][$registration->get_context()] = $registration;
        }

        SystemCache :: system()->admin_data_manager_registrations = self :: $registrations;
    }

    static function retrieve_setting_contexts(Condition $condition = null)
    {
        return self :: distinct(Setting :: class_name(), Setting :: PROPERTY_CONTEXT, $condition);
    }

    static function retrieve_setting_from_variable_name($variable, $context = 'admin')
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(Setting :: PROPERTY_CONTEXT, $context);
        $conditions[] = new EqualityCondition(Setting :: PROPERTY_VARIABLE, $variable);
        $condition = new AndCondition($conditions);

        return self :: retrieve(Setting :: class_name(), $condition);
    }
}
?>