<?php
namespace common\libraries;

/**
 * A ConditionVariable that describes a regular DataClass property
 *
 * @author Hans De Bisschop
 * @package common.libraries
 */
class PropertyConditionVariable extends ConditionVariable
{
    /**
     * The fully qualified class name of the DataClass object the property belongs to
     *
     * @var string
     */
    private $class;

    /**
     * The property name of the DataClass object
     *
     * @var string
     */
    private $property;

    /**
     * Constructor
     *
     * @param $class string
     * @param $property string
     */
    function __construct($class, $property)
    {
        $this->class = $class;
        $this->property = $property;
    }

    /**
     * Get the fully qualified class name of the DataClass object the property belongs to
     *
     * @return string
     */
    public function get_class()
    {
        return $this->class;
    }

    /**
     * Get the property name of the DataClass object
     *
     * @return string
     */
    public function get_property()
    {
        return $this->property;
    }

    /**
     * Set the fully qualified class name of the DataClass object the property belongs to
     *
     * @param $class string
     */
    public function set_class($class)
    {
        $this->class = $class;
    }

    /**
     * Set the property name of the DataClass object
     *
     * @param $property string
     */
    public function set_property($property)
    {
        $this->property = $property;
    }

}
?>