<?php
namespace common\libraries;
/**
 * $Id: core_application.class.php 128 2009-11-09 13:13:20Z vanpouckesven $
 *
 * @package common
 */
use admin\AdminDataManager;

use core\lynx\PackageList;

abstract class CoreApplication extends BasicApplication
{
    const CLASS_NAME = __CLASS__;

    static $application_path_cache = array();

    /**
     *
     * @see Application::is_active()
     */
    function is_active($application = null)
    {
        if (\is_null($application))
        {
            if (is_object($this))
            {
                $application = $this->get_application_name();
            }
            else
            {
                return false;
            }
        }
        return self :: exists($application);
    }

    /**
     * Determines if a given application exists
     *
     * @param $name string
     * @return boolean
     * @deprecated Deprecated method
     */
    public static function is_application($name)
    {
        return self :: exists($name);
    }

    /**
     * Get a list of available core packages
     *
     * @deprecated Use get_packages_from_filesystem() now
     * @return multitype:string
     */
    public static function get_list()
    {
        $applications = array();
        $applications[] = 'admin';
        $applications[] = 'tracking';
        $applications[] = 'repository';
        $applications[] = 'migration';
        $applications[] = 'user';
        $applications[] = 'group';
        $applications[] = 'help';
        $applications[] = 'rights';
        $applications[] = 'home';
        $applications[] = 'menu';
        $applications[] = 'webservice';
        $applications[] = 'reporting';
        $applications[] = 'metadata';
        $applications[] = 'context_linker';
        $applications[] = 'core\lynx';

        return $applications;
    }

    /**
     * Gets a link to the personal calendar application
     *
     * @param $parameters array
     * @param $encode boolean
     */
    public function get_link($parameters = array (), $filter = array(), $encode_entities = false, $application_type = Redirect :: TYPE_CORE)
    {
        return parent :: get_link($parameters, $filter, $encode_entities, $application_type);
    }

    /**
     *
     * @see Application :: simple_redirect
     */
    function simple_redirect($parameters = array (), $filter = array(), $encode_entities = false, $redirect_type = Redirect :: TYPE_URL,
            $application_type = Redirect :: TYPE_CORE)
    {
        return parent :: simple_redirect($parameters, $filter, $encode_entities, $redirect_type, $application_type);
    }

    /**
     *
     * @see Application :: redirect
     */
    function redirect($message = '', $error_message = false, $parameters = array (), $filter = array(), $encode_entities = false,
            $redirect_type = Redirect :: TYPE_URL, $application_type = Redirect :: TYPE_CORE)
    {
        return parent :: redirect($message, $error_message, $parameters, $filter, $encode_entities, $redirect_type,
                $application_type);
    }

    public static function get_application_path($application_name)
    {
        $path = Path :: get(SYS_PATH) . 'core/' . $application_name . '/';
        if (is_dir($path))
        {
            return $path;
        }
        else
        {
            return Path :: get(SYS_PATH) . $application_name . '/';
        }
    }

    public static function get_application_web_path($application_name)
    {
        $path = Path :: get(SYS_PATH) . 'core/' . $application_name . '/';
        if (is_dir($path))
        {
            return Path :: get(WEB_PATH) . 'core/' . $application_name . '/';
        }
        else
        {
            return Path :: get(WEB_PATH) . $application_name . '/';
        }
    }

    /**
     * Deprecated method
     *
     * @deprecated Deprecated method
     */
    public function get_application_component_path()
    {
        $application_name = $this->get_application_name();
        return $this->get_application_path($application_name) . 'lib/' . $application_name . '_manager/component/';
    }

    static function get_application_namespace($application_name)
    {
        $path = Path :: get(SYS_PATH) . 'core/' . $application_name . '/';
        if (is_dir($path))
        {
            return 'core\\' . $application_name;
        }
        else
        {
            return $application_name;
        }
    }

    /**
     * Deprecated method
     *
     * @deprecated Deprecated method
     */
    static function factory($application, $user = null)
    {
        $class = self :: get_application_namespace($application) . '\\' . self :: get_application_class_name(
                $application);
        return new $class($user);
    }

    static function exists($application)
    {
        if (! isset(self :: $application_path_cache[$application]))
        {
            $application_path = self :: get_application_path($application);
            self :: $application_path_cache[$application] = is_dir($application_path);
        }
        return self :: $application_path_cache[$application];
    }

    public static function get_packages_from_filesystem()
    {
        $applications = array();

        $applications[] = 'admin';
        $applications[] = 'tracking';
        $applications[] = 'repository';
        $applications[] = 'migration';
        $applications[] = 'user';
        $applications[] = 'group';
        $applications[] = 'help';
        $applications[] = 'rights';
        $applications[] = 'home';
        $applications[] = 'menu';
        $applications[] = 'webservice';
        $applications[] = 'reporting';
        $applications[] = 'metadata';
        $applications[] = 'context_linker';

        $directories = Filesystem :: get_directory_content(Path :: get_core_path(), Filesystem :: LIST_DIRECTORIES,
                false);

        foreach ($directories as $directory)
        {
            $application_name = basename($directory);

            if (self :: is_application_name($application_name))
            {
                $applications[] = self :: get_application_namespace($application_name);
            }
        }

        return $applications;
    }

    static function get_installable_packages($include_installed = false)
    {
        $package_list = new PackageList('core', Translation :: get('Core', null, Utilities :: COMMON_LIBRARIES));

        foreach (self :: get_packages_from_filesystem() as $application)
        {
            $class = $application . '\Manager';

            if (! CommonDataManager :: get_registration($application) || $include_installed)
            {
                $package_list->add_package($application);
            }

            if (! class_exists($class))
            {
                $class = $application . '\\' . Utilities :: underscores_to_camelcase(Utilities :: get_package_name_from_namespace($application)) . 'Manager';
            }

            if (class_exists($class))
            {
                $application_package_list = $class :: get_installable_application_packages($include_installed);
                if ($application_package_list instanceof PackageList)
                {
                    $package_list->add_child($application_package_list);
                }
            }
        }

        return $package_list;
    }

    static function get_installable_application_packages($include_installed = false)
    {
        return false;
    }
}
?>