<?php
namespace common\libraries;

use \finfo;

class FileProperties
{
    const CLASS_NAME = __CLASS__;
    const PROPERTY_NAME = 'name';
    const PROPERTY_EXTENSION = 'extension';
    const PROPERTY_TYPE = 'type';
    const PROPERTY_SIZE = 'size';
    const PROPERTY_PATH = 'path';

    /**
     *
     * @var multitype:string
     */
    private $properties;

    function get_properties()
    {
        return $this->properties;
    }

    function set_properties($properties)
    {
        $this->properties = $properties;
    }

    function set_property($property, $value)
    {
        $this->properties[$property] = $value;
    }

    function get_property($property)
    {
        return $this->properties[$property];
    }

    function get_name()
    {
        return $this->get_property(self :: PROPERTY_NAME);
    }

    function set_name($name)
    {
        $this->set_property(self :: PROPERTY_NAME, $name);
    }

    function get_extension()
    {
        return $this->get_property(self :: PROPERTY_EXTENSION);
    }

    function set_extension($extension)
    {
        $this->set_property(self :: PROPERTY_EXTENSION, $extension);
    }

    function get_name_extension()
    {
        return $this->get_name() . '.' . $this->get_extension();
    }

    function get_type()
    {
        return $this->get_property(self :: PROPERTY_TYPE);
    }

    function set_type($type)
    {
        $this->set_property(self :: PROPERTY_TYPE, $type);
    }

    function get_size()
    {
        return $this->get_property(self :: PROPERTY_SIZE);
    }

    function set_size($size)
    {
        $this->set_property(self :: PROPERTY_SIZE, $size);
    }

    function get_path()
    {
        return $this->get_property(self :: PROPERTY_PATH);
    }

    function set_path($path)
    {
        $this->set_property(self :: PROPERTY_PATH, $path);
    }

    static function from_upload($file)
    {
        $path_info = pathinfo($file['name']);
        $file_info = new finfo(FILEINFO_MIME_TYPE);

        $properties = new self();
        $properties->set_name($path_info['filename']);
        $properties->set_extension($path_info['extension']);

        if (! $file_info)
        {
            $properties->set_type($file['type']);
        }
        else
        {
            $properties->set_type($file_info->file($file['tmp_name']));
        }

        $properties->set_size($file['size']);
        $properties->set_path($file['tmp_name']);

        return $properties;
    }

    static function from_path($path)
    {
        $path_info = pathinfo($path);
        $file_info = new finfo(FILEINFO_MIME_TYPE);

        $properties = new self();
        $properties->set_name($path_info['filename']);
        $properties->set_extension($path_info['extension']);

        if (! $file_info)
        {
            $properties->set_type('application/octet-stream');
        }
        else
        {
            $properties->set_type($file_info->file($path));
        }

        $properties->set_size(filesize($path));
        $properties->set_path($path);

        return $properties;
    }

    static function from_url($url)
    {
        $url_info = parse_url($url);
        $path_info = pathinfo($url_info['path']);

        $properties = new self();

        if (in_array($url_info['scheme'], array('http', 'ftp', 'https')))
        {
            if ($path_info['filename'])
            {
                $properties->set_name($path_info['filename']);
            }
            else
            {
                $properties->set_name('index');
            }
            if ($path_info['extension'])
            {
                $properties->set_extension($path_info['extension']);
            }
            else
            {
                $properties->set_extension('htm');
            }

            $curl = curl_init();
            curl_setopt($curl, CURLOPT_URL, $url);
            curl_setopt($curl, CURLOPT_FILETIME, true);
            curl_setopt($curl, CURLOPT_NOBODY, true);
            curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
            $header = curl_exec($curl);
            $info = curl_getinfo($curl);
            curl_close($curl);

            $valid_http = $url_info['scheme'] == 'http' && $info['http_code'] == 200;
            $valid_ftp = $url_info['scheme'] == 'ftp' && $info['http_code'] == 350;
            $valid_https = $url_info['scheme'] == 'https' && $info['http_code'] == 200;

            if ($valid_http || $valid_ftp || $valid_https)
            {
                if (! is_null($info['content_type']))
                {
                    $properties->set_type($info['content_type']);
                }
                else
                {
                    $properties->set_type('application/octet-stream');
                }

                $properties->set_size((int) $info['download_content_length']);
                $properties->set_path($url);
            }
        }

        return $properties;
    }
}
?>