<?php

require_once 'HTML/QuickForm/checkbox.php';

/**
 * Extension on the HTML Quickform Checkbox element to support returnable values if the checkbox is not selected
 *
 * @author Sven Vanpoucke - Hogeschool Gent
 */
class HTML_QuickForm_extended_checkbox extends HTML_QuickForm_checkbox
{
    /**
     * The return value if the checkbox is not selected
     *
     * @var mixed
     */
    private $return_value;

    /**
     * Class constructor
     *
     * @param     string    $elementName    (optional)Input field name attribute
     * @param     string    $elementLabel   (optional)Input field value
     * @param     string    $text           (optional)Checkbox display text
     * @param     mixed     $attributes     (optional)Either a typical HTML attribute string
     * or an associative array
     * @param    string     $value	    (optional)The value for the checkbox
     * @param	 string	    $return_value   (optional)The return value when the checkbox is not selected
     *
     * @since     1.0
     * @access    public
     * @return    void
     */
    function __construct($elementName = null, $elementLabel = null, $text = '', $attributes = null, $value = 1,
	    $return_value = null)
    {
        parent :: __construct($elementName, $elementLabel, $text, $attributes, $value);

	$this->return_value = $return_value;
    } 


    /**
     * Return true if the checkbox is checked, or the return value if it is not checked (getValue() returns false)
     *
     * @return mixed
     */
    function exportValue(&$submitValues, $assoc = false)
    {
        $value = $this->_findValue($submitValues);
	
        if (null === $value)
        {
            $value = $this->getChecked() ? true : $this->return_value;
        }

        return $this->_prepareValue($value, $assoc);
    }

}
?>
