<?php
namespace common\libraries;
/**
 * The combination of options available for the FormValidatorHtmlEditor Should be implemented for each specific editor
 * to translate the generic option values
 *
 * @author Scaramanga
 */

use common\libraries\Registration;
use admin\AdminDataManager;

use repository\content_object\template\Template;
use repository\ContentObject;
use repository\RepositoryDataManager;

abstract class FormValidatorHtmlEditorTemplates
{

    /**
     *
     * @param $options Array
     */
    function __construct()
    {
    }

    function get_templates()
    {
        $rdm = RepositoryDataManager :: get_instance();

        $conditions = array();
        $conditions[] = new EqualityCondition(ContentObject :: PROPERTY_OWNER_ID, Session :: get_user_id());
        $conditions[] = new EqualityCondition(ContentObject :: PROPERTY_TYPE, Template :: get_type_name());
        $condition = new AndCondition($conditions);

        return $rdm->retrieve_content_objects($condition, array(new ObjectTableOrder(ContentObject :: PROPERTY_TITLE)));
    }

    function template_object_exists()
    {
        $adm = AdminDataManager :: get_instance();

        $conditions = array();
        $conditions[] = new EqualityCondition(Registration :: PROPERTY_TYPE, Registration :: TYPE_CONTENT_OBJECT);
        $conditions[] = new EqualityCondition(Registration :: PROPERTY_NAME, Template :: get_type_name());
        $condition = new AndCondition($conditions);

        return CommonDataManager :: count(Registration :: class_name(), $condition);
    }

    /**
     *
     * @param $type String
     * @param $options Array
     * @return FormValidatorHtmlEditorOptions
     */
    public static function factory($type)
    {
        $file = dirname(__FILE__) . '/html_editor_templates/' . $type . '_html_editor_templates.class.php';
        $class = 'FormValidator' . Utilities :: underscores_to_camelcase($type) . 'HtmlEditorTemplates';

        if (file_exists($file))
        {
            return new $class();
        }
        else
        {
            return null;
        }
    }
}
?>