<?php
namespace common\libraries;

use repository\ContentObject;
/**
 * $Id: theme.class.php 128 2009-11-09 13:13:20Z vanpouckesven $
 * @package common.html
 */
// Theme-paths
define('WEB_THEME_PATH', 'WEB_THEME_PATH');
define('SYS_THEME_PATH', 'SYS_THEME_PATH');
define('WEB_IMG_PATH', 'WEB_IMG_PATH');
define('SYS_IMG_PATH', 'SYS_IMG_PATH');
define('WEB_CSS_PATH', 'WEB_CSS_PATH');
define('SYS_CSS_PATH', 'SYS_CSS_PATH');

class Theme
{
    const ICON_MINI = 16;
    const ICON_SMALL = 22;
    const ICON_MEDIUM = 32;
    const ICON_BIG = 48;
    const ICON_HUGE = 64;
    
    /**
     * Instance of this class for the singleton pattern.
     */
    private static $instance;
    
    /**
     * The theme we're currently using
     */
    private $theme;
    
    /**
     * The application we're currently rendering
     */
    private $application;
    
    /**
     * The template engine
     * @var ChamiloTemplate The chamilo templating object
     */
    private $template;
    
    /**
     * Cache for results of get_path() method.
     */
    private $path;

    function __construct()
    {
        $this->theme = PlatformSetting :: get('theme');
        $this->template = new Phpbb2TemplateWrapper($this->theme);
        //        $this->template = ChamiloTemplate :: get_instance($this->theme);
        

        $this->path = array();
    }

    /**
     * Returns the template engine
     * @return Phpbb2TemplateWrapper
     */
    static function get_template()
    {
        return self :: get_instance()->template;
    }

    static function get_theme()
    {
        return self :: get_instance()->theme;
    }

    static function set_theme($theme)
    {
        $instance = self :: get_instance();
        $instance->theme = $theme;
        
        $template = $instance->get_template();
        $template->set_theme($theme);
        $template->reset();
        
        $instance->path = array();
    }

    static function get_application()
    {
        return self :: get_instance()->application;
    }

    static function set_application($application)
    {
        $instance = self :: get_instance();
        $instance->application = $application;
    }

    function get_path($path_type)
    {
        if (isset($this->path[$path_type]))
        {
            return $this->path[$path_type];
        }
        
        switch ($path_type)
        {
            case WEB_IMG_PATH :
                return $this->path[$path_type] = Path :: get(WEB_LAYOUT_PATH) . $this->get_theme() . '/images/';
            case SYS_IMG_PATH :
                return $this->path[$path_type] = Path :: get(SYS_LAYOUT_PATH) . $this->get_theme() . '/images/';
            case WEB_CSS_PATH :
                return $this->path[$path_type] = Path :: get(WEB_LAYOUT_PATH) . $this->get_theme() . '/css/';
            case SYS_CSS_PATH :
                return $this->path[$path_type] = Path :: get(SYS_LAYOUT_PATH) . $this->get_theme() . '/css/';
            case WEB_THEME_PATH :
                return $this->path[$path_type] = Path :: get(WEB_LAYOUT_PATH) . $this->get_theme() . '/';
            case SYS_THEME_PATH :
                return $this->path[$path_type] = Path :: get(SYS_LAYOUT_PATH) . $this->get_theme() . '/';
        }
    }

    /**
     * Get the web path to the theme's folder
     */
    static function get_theme_path()
    {
        return self :: get_instance()->get_path(WEB_THEME_PATH);
    }

    /**
     * Get the web path to the application's css file
     */
    static function get_css_path($application = null, $web = true)
    {
        $instance = self :: get_instance();
        $application = (is_null($application) ? $instance->get_application() : $application);
        if ($web)
        {
            return BasicApplication :: get_application_web_resources_css_path($application) . $instance->get_theme() . '/' . $instance->get_theme() . '.css';
        }
        else
        {
            return BasicApplication :: get_application_resources_css_path($application) . $instance->get_theme() . '/' . $instance->get_theme() . '.css';
        }
    }

    /**
     * Get the web path to the general css file
     */
    static function get_common_css_path($web = true)
    {
        $instance = self :: get_instance();
        return Path :: get_common_libraries_path($web) . 'resources/css/' . $instance->get_theme() . '/' . $instance->get_theme() . '.css';
    
     //return Path :: get_web_common_libraries_path() . 'resources/css/' . $instance->get_theme() . '/' . $instance->get_theme() . '.css';
    }

    /**
     * Get the path to the application's image folder
     */
    static function get_image_path($context = null)
    {
        $instance = self :: get_instance();
        
        if (! $context)
        {
            $backtrace = debug_backtrace();
            $called_class = $backtrace[1]['class'];
            //$called_class = get_called_class();
            $context = Utilities :: get_namespace_from_classname($called_class);
        }
        
        $called_class = explode('\\', $context);
        return Path :: get(WEB_PATH) . implode('/', $called_class) . '/resources/images/' . $instance->get_theme() . '/';
    }

    /**
     * Get the system path to the application's image folder
     */
    static function get_image_system_path($context = null)
    {
        $instance = self :: get_instance();
        
        if (! $context)
        {
            $backtrace = debug_backtrace();
            //$called_class = $backtrace[1]['class'];
            $called_class = get_called_class();
            $context = Utilities :: get_namespace_from_classname($called_class);
        }
        
        $called_class = explode('\\', $context);
        return Path :: get(SYS_PATH) . implode('/', $called_class) . '/resources/images/' . $instance->get_theme() . '/';
    
     //        $instance = self :: get_instance();
    //        $application = (is_null($application) ? $instance->get_application() : $application);
    //        return BasicApplication :: get_application_resources_images_path($application) . $instance->get_theme() . '/';
    }

    /**
     * Get the path to the general image folder
     */
    static function get_common_image_path()
    {
        $instance = self :: get_instance();
        return Path :: get_web_common_libraries_path() . 'resources/images/' . $instance->get_theme() . '/';
    }

    static function get_content_object_image_path($image, $size = self :: ICON_MINI)
    {
        return Theme :: get_image_path(ContentObject :: get_content_object_type_namespace($image)) . 'logo/' . $size . '.png';
    }

    /**
     * Get the system path to the general image folder
     */
    static function get_common_image_system_path()
    {
        $instance = self :: get_instance();
        return Path :: get_common_libraries_path() . 'resources/images/' . $instance->get_theme() . '/';
    }

    static function get_instance()
    {
        if (! isset(self :: $instance))
        {
            self :: $instance = new self();
        }
        return self :: $instance;
    }

    static function get_themes()
    {
        $options = array();
        
        $path = Path :: get(SYS_LAYOUT_PATH);
        $directories = Filesystem :: get_directory_content($path, Filesystem :: LIST_DIRECTORIES, false);
        
        foreach ($directories as $index => & $directory)
        {
            if (substr($directory, 0, 1) != '.')
            {
                $options[$directory] = Utilities :: underscores_to_camelcase($directory);
            }
        }
        
        return $options;
    }

    static function get_common_image($image, $extension = 'png', $label = null, $href = null, $display = ToolbarItem :: DISPLAY_ICON_AND_LABEL, $confirmation = false)
    {
        $icon = new ToolbarItem($label, self :: get_common_image_path() . $image . '.' . $extension, $href, $display, $confirmation);
        return $icon->as_html();
    }

    static function get_image($image, $extension = 'png', $label = null, $href = null, $display = ToolbarItem :: DISPLAY_ICON_AND_LABEL, $confirmation = false, $context = null)
    {        
        if (! $context)
        {
            $backtrace = debug_backtrace();
            $called_class = $backtrace[1]['class'];
            $context = Utilities :: get_namespace_from_classname($called_class);
        }
        
        $icon = new ToolbarItem($label, self :: get_image_path($context) . $image . '.' . $extension, $href, $display, $confirmation);
        return $icon->as_html();
    }

    static function get_content_object_image($image, $extension = 'png', $label = null, $href = null, $display = ToolbarItem :: DISPLAY_ICON_AND_LABEL, $confirmation = false)
    {
        //return self :: get_common_image('content_object/' . $image, $extension, $label, $href, $display, $confirmation);
        return '<img src="' . Theme :: get_image_path(ContentObject :: get_content_object_type_namespace($image)) . 'logo/' . self :: ICON_SMALL . '.png" alt="' . htmlentities(Translation :: get('TypeName', null, ContentObject :: get_content_object_type_namespace($image))) . '"/>';
    }

    static function get_treemenu_image($image, $extension = 'png', $label = null, $href = null, $display = ToolbarItem :: DISPLAY_ICON_AND_LABEL, $confirmation = false)
    {
        return self :: get_common_image('treemenu/' . $image, $extension, $label, $href, $display, $confirmation);
    }

    static function get_treemenu_type_image($image, $extension = 'png', $label = null, $href = null, $display = ToolbarItem :: DISPLAY_ICON_AND_LABEL, $confirmation = false)
    {
        return self :: get_common_image('treemenu_types/' . $image, $extension, $label, $href, $display, $confirmation);
    }
}
?>