<?php
namespace common\libraries;

abstract class NewObjectTableCellRenderer
{
    /**
     * The object table
     *
     * @var NewObjectTable
     */
    private $object_table;

    /**
     * Constructor
     *
     * @param $object_table NewObjectTable
     */
    function __construct($object_table)
    {
        $this->object_table = $object_table;

        if($object_table->get_column_model() instanceof NewObjectTableColumnModelActionsColumnSupport)
        {
            if(!$this instanceof NewObjectTableCellRendererActionsColumnSupport)
            {
                throw new \Exception(Translation :: get('ActionsColumnSupportError'));
            }
        }
    }

    /**
     *
     * @return \common\libraries\NewObjectTable
     */
    function get_object_table()
    {
        return $this->object_table;
    }

    /**
     * Returns the component of the object table
     *
     * @param Application
     */
    function get_component()
    {
        return $this->get_object_table()->get_component();
    }

    /**
     * Renders a single cell
     *
     * @param TableColumn $column
     * @param DataClass $object
     *
     * @return String
     */
    function render_cell($column, $object)
    {
        if($column instanceof NewObjectTableActionsColumn)
        {
            return $this->get_object_actions($object);
        }

        if ($object instanceof DataClass)
        {
            return $object->get_default_property($column->get_name());
        }
    }

    /**
     * Define the unique identifier for the row
     * needed for e.g.
     * checkboxes
     *
     * @param $object <type>
     */
    function render_id_cell($object)
    {
        return $object->get_id();
    }
}
?>