<?php
namespace common\libraries;

use Exception;

/**
 * A class to allow caching of DataClass object counts
 *
 * @author Hans De Bisschop
 * @package common.libraries
 */
class DataClassCountCache extends DataClassCache
{

    /**
     * Add a DataClass object count to the cache
     *
     * @param $class string
     * @param $parameters \common\libraries\DataClassCountParameters|\common\libraries\DataClassCountDistinctParameters
     * @param $count int
     * @return boolean
     */
    static function add($class, $parameters, $count)
    {
        if (! $parameters instanceof DataClassCountParameters && ! $parameters instanceof DataClassCountDistinctParameters)
        {
            throw new Exception('Illegal parameters passed to the DataClassCountCache');
        }

        if (! is_integer($count))
        {
            $type = is_object($count) ? get_class($count) : gettype($count);
            throw new Exception('The DataClassCountCache cache only allows for caching of integers. Currently trying to add: ' . $type . '.');
        }

        if (! self :: exists($class, $parameters))
        {
            self :: set_cache($class, $parameters->hash(), $count);
        }

        return true;
    }
}
?>