<?php
namespace common\libraries;

use Exception;

/**
 * The optional parameters for a DataClass storage layer action
 *
 * @author Hans De Bisschop
 * @package common.libraries
 */
abstract class DataClassParameters implements Hashable
{

    /**
     * The condition to be applied to the action
     *
     * @var \common\libraries\Condition
     */
    private $condition;

    /**
     * Constructor
     *
     * @param $condition \common\libraries\Condition
     */
    function __construct($condition = null)
    {
        $this->condition = $condition;
    }

    /**
     * Get the condition to be applied to the action
     *
     * @return \common\libraries\Condition
     */
    public function get_condition()
    {
        return $this->condition;
    }

    /**
     * Set the condition to be applied to the action
     *
     * @param $condition \common\libraries\Condition
     */
    public function set_condition($condition)
    {
        $this->condition = $condition;
    }

    /**
     * Get the fully qualified class name
     *
     * @return string
     */
    static function class_name()
    {
        return get_called_class();
    }

    /**
     * Get an md5 representation of this object for identification purposes
     *
     * @param $hash_parts multitype:string
     * @return string
     */
    function hash($hash_parts = array())
    {
        $hash_parts[] = self :: class_name();

        return md5(serialize($hash_parts));
    }
}
?>