<?php
namespace common\libraries;

/**
 * This class allows you to wrap a set of DataClass objects in an array result set.
 *
 * @author Hans De Bisschop
 * @package common.libraries
 */
class DataClassResultSet extends ArrayResultSet
{
    /**
     * The DataClass class name
     *
     * @var string
     */
    private $class_name;

    /**
     * Constructor
     *
     * @param $class_name string
     */
    function __construct($class_name, $objects)
    {
        parent :: __construct($objects);
        
        $this->class_name = $class_name;
    }

    /**
     * Get the DataClass class name
     *
     * @return string
     */
    function get_class_name()
    {
        return $this->class_name;
    }

    /**
     * Process the record returned by the storage layer
     *
     * @param $record multitype:string
     * @return multitype:string
     */
    function process_record($record)
    {
        foreach ($record as &$field)
        {
            if (is_resource($field))
            {
                $data = '';
                while (! feof($field))
                {
                    $data .= fread($field, 1024);
                }
                $field = $data;
            }
        }
        
        return $record;
    }

    /**
     * Convert the record to a DataClass object
     *
     * @param $class_name string
     * @param $record multitype:string
     * @return \common\libraries\DataClass
     */
    function get_object($class_name, $record)
    {
        $cached = false;
        foreach ($class_name :: get_cacheable_property_names() as $cacheable_property)
        {
            $value = $record[$cacheable_property];
            if (isset($value) && ! is_null($value))
            {
                $cacheable_property_parameters = new DataClassRetrieveParameters(new EqualityCondition($cacheable_property, $value));
                
                if (DataClassCache :: exists($class_name, $cacheable_property_parameters))
                {
                    $object = DataClassResultCache :: get($class_name, $cacheable_property_parameters);
                    $cached = true;
                    break;
                }
            }
        }
        
        if (! $cached)
        {
            $base = (is_subclass_of($class_name, CompositeDataClass :: class_name()) ? CompositeDataClass :: class_name() : DataClass :: class_name());
            $object = $base :: factory($class_name, $record);
            DataClassResultCache :: add($object);
        }
        
        return $object;
    }
}
?>