<?php
namespace common\libraries;

use Exception;

/**
 * The optional parameters for a DataClass storage layer RETRIEVE action
 *
 * @author Hans De Bisschop
 * @package common.libraries
 */
class DataClassRetrieveParameters extends DataClassParameters
{
    
    /**
     * The ordering of the DataClass objects to be applied to the result set
     *
     * @var multitype:\common\libraries\ObjectTableOrder
     */
    private $order_by;

    /**
     * Constructor
     *
     * @param $condition \common\libraries\Condition           
     * @param $order_by multitype:\common\libraries\ObjectTableOrder           
     */
    function __construct($condition = null, $order_by = array())
    {
        parent :: __construct($condition);
        $this->order_by = $order_by;
    }

    /**
     * Get the ordering of the DataClass objects to be applied to the result set
     *
     * @return multitype:\common\libraries\ObjectTableOrder
     */
    public function get_order_by()
    {
        return $this->order_by;
    }

    /**
     * Set the ordering of the DataClass objects to be applied to the result set
     *
     * @param $order_by \multitype:\common\libraries\ObjectTableOrder           
     */
    public function set_order_by($order_by)
    {
        $this->order_by = $order_by;
    }

    /**
     * Get an md5 representation of this object for identification purposes
     *
     * @param $hash_parts multitype:string           
     * @return string
     */
    function hash($hash_parts = array())
    {
        $hash_parts[] = ($this->get_condition() instanceof Condition ? $this->get_condition()->hash() : null);
        $hash_parts[] = $this->get_order_by();
        
        return parent :: hash($hash_parts);
    }

    /**
     * Dynamically generate a valid DataClassRetrieveParameters object based on
     * the type of the input parameter
     *
     * @param $parameter int|\common\libraries\Condition|\common\libraries\DataClassRetrieveParameters           
     * @return \common\libraries\DataClassRetrieveParameters boolean
     */
    static function generate($parameter)
    {
        // So you think you're being funny, eh? Right back at you ... you
        // dog-blasted, ornery, no-account, long-eared
        // varmint!
        if (is_object($parameter) && $parameter instanceof DataClassRetrieveParameters)
        {
            return $parameter;
        }
        
        // If the parameter is a Condition, generate a new
        // DataClassRetrieveParameters instance using the Condition
        // provided by the context
        elseif (is_object($parameter) && $parameter instanceof Condition)
        {
            return new self($parameter);
        }
        
        // If it's an integer, generate an EqualityCondition using the unique
        // identifier
        elseif (is_integer($parameter))
        {
            return new self(new EqualityCondition(DataClass :: PROPERTY_ID, $parameter));
        }
        
        // If the parameter is an array, determine whether it's an array of
        // ObjectTableOrder objects and if so generate
        // a DataClassResultParameters
        elseif (is_array($parameter) && count($parameter) > 0 && $parameter[0] instanceof ObjectTableOrder)
        {
            return new self(null, $parameter);
        }
        elseif (is_null($parameter))
        {
            return new self();
        }
        else
        {
            throw new Exception('Illegal parameter passed to the DataManager :: retrieve() method.');
        }
    }

}
?>