<?php
namespace common\libraries;

use Exception;

/**
 * The optional parameters for a DataClass storage layer RETRIEVES action
 *
 * @author Hans De Bisschop
 * @package common.libraries
 */
class DataClassRetrievesParameters extends DataClassRetrieveParameters
{
    /**
     * The number of results to return
     *
     * @var int
     */
    private $count;

    /**
     * The offset of the result set relative to the first ordered result
     *
     * @var int
     */
    private $offset;

    /**
     * Constructor
     *
     * @param $condition \common\libraries\Condition
     * @param $count int
     * @param $offset int
     * @param $order_by multitype:\common\libraries\ObjectTableOrder
     */
    function __construct($condition = null, $count = null, $offset = null, $order_by = array())
    {
        parent :: __construct($condition, $order_by);

        $this->count = $count;
        $this->offset = $offset;
    }

    /**
     * Get the number of results to return
     *
     * @return int
     */
    public function get_count()
    {
        return $this->count;
    }

    /**
     * Set the number of results to return
     *
     * @param $count int
     */
    public function set_count($count)
    {
        $this->count = $count;
    }

    /**
     * Get the offset of the result set relative to the first ordered result
     *
     * @return int
     */
    public function get_offset()
    {
        return $this->offset;
    }

    /**
     * Set the offset of the result set relative to the first ordered result
     *
     * @param $offset number
     */
    public function set_offset($offset)
    {
        $this->offset = $offset;
    }

    /**
     * Get an md5 representation of this object for identification purposes
     *
     * @param $hash_parts multitype:string
     * @return string
     */
    function hash($hash_parts = array())
    {
        $hash_parts[] = ($this->get_condition() instanceof Condition ? $this->get_condition()->hash() : null);
        $hash_parts[] = $this->get_count();
        $hash_parts[] = $this->get_offset();
        $hash_parts[] = $this->get_order_by();

        return DataClassParameters :: hash($hash_parts);
    }

    /**
     * Dynamically generate a valid DataClassRetrievesParameters object based on the type of the input parameter
     *
     * @param $parameter int|\common\libraries\Condition|\common\libraries\DataClassRetrievesParameters
     * @return \common\libraries\DataClassRetrievesParameters boolean
     */
    static function generate($parameter = null)
    {
        // So you think you're being funny, eh? Right back at you ... you dog-blasted, ornery, no-account, long-eared
        // varmint!
        if (is_object($parameter) && $parameter instanceof DataClassRetrievesParameters)
        {
            return $parameter;
        }

        // If the parameter is a Condition, generate a new DataClassRetrievesParameters instance using the Condition
        // provided by the context
        elseif (is_object($parameter) && $parameter instanceof Condition)
        {
            return new self($parameter);
        }

        // If it's an integer, assume it will be the count and generate a new DataClassRetrievesParameters
        elseif (is_integer($parameter))
        {
            return new self(null, $parameter);
        }

        // If the parameter is an array, determine whether it's an array of ObjectTableOrder objects and if so generate
        // a DataClassResultParameters
        elseif (is_array($parameter) && count($parameter) > 0 && $parameter[0] instanceof ObjectTableOrder)
        {
            return new self(null, null, null, $parameter);
        }
        elseif (is_null($parameter))
        {
            return new self();
        }
        else
        {
            throw new Exception('Illegal parameter passed to the DataManager :: retrieves() method.');
        }
    }

}
?>