<?php
namespace common\libraries;

use Exception;

/**
 *
 * @package common.libraries.storage.mdb2
 * @author Hans De Bisschop
 */

class Mdb2PatternMatchConditionTranslator extends NewConditionTranslator
{

    function translate()
    {
        return ConditionVariableTranslator :: render($this, $this->get_condition()->get_name()) . ' LIKE ' . $this->get_data_manager()->quote($this->search_string($this->get_condition()->get_pattern()));
    }

    /**
     * Translates a string with wildcard characters "?" (single character) and "*" (any character sequence) to a SQL
     * pattern for use in a LIKE condition. Should be suitable for any SQL flavor.
     *
     * @param $string string The string that contains wildcard characters.
     * @return string The escaped string.
     */
    function search_string($string)
    {
        /*
         * ====================================================================== A brief explanation of these regexps:
         * - The first one escapes SQL wildcard characters, thus prefixing %, ', \ and _ with a backslash. - The second
         * one replaces asterisks that are not prefixed with a backslash (which escapes them) with the SQL equivalent,
         * namely a percent sign. - The third one is similar to the second: it replaces question marks that are not
         * escaped with the SQL equivalent _. ======================================================================
         */
        return preg_replace(array('/([%\'\\\\_])/e', '/(?<!\\\\)\*/', '/(?<!\\\\)\?/'), array("'\\\\\\\\' . '\\1'",
                '%', '_'), $string);
    }
}
?>