<?php
namespace common\libraries;

use admin\AdminDataManager;

/**
 * Used to synchronize caches when working in a distributed environment. I.e. there are more than one application
 * server. usage - CacheSynch::get(my_name) to retrieve a cache synch value - CacheSynch::reset(my_name) to reset the
 * cache synch value - CacheSynch::is_fresh(my_name, time) to check if the cache value is fresh
 *
 * @author laurent
 */
class CacheSynch
{

    const VARIABLE_NAME = __CLASS__;

    private static $params = array();

    /**
     * Called automatically. Retrieve data from the database. Note that we MUST retrieve the values from the DB to
     * ensure they are fresh.
     */
    public static function load($force = false)
    {
        if (! empty(self :: $params) && ! $force)
        {
            return;
        }
        $setting = CommonDataManager :: retrieve_setting_from_variable_name(self :: VARIABLE_NAME);
        if ($setting)
        {
            $value = $setting->get_value();
            self :: $params = unserialize($value);
        }
        else
        {
            self :: $params = array();
        }
    }

    /**
     * Save synch data to the database. Called automatically.
     */
    public static function store()
    {
        $setting = CommonDataManager :: retrieve_setting_from_variable_name(self :: VARIABLE_NAME);
        $value = serialize(self :: $params);
        if ($setting)
        {
            $setting->set_value($value);
            $setting->update();
        }
        else
        {
            $setting = new Setting();
            $setting->set_value($value);
            $setting->set_variable(self :: VARIABLE_NAME);
            $setting->set_application('admin');
            $setting->set_user_setting(0);
            $setting->create();
        }
    }

    /**
     * Reset the cache synch to now().
     */
    public static function reset($name)
    {
        self :: $params[$name] = time();
        self :: store();
    }

    public static function is_fresh($name, $time_of_the_copy)
    {
        $last_modified_time = self :: get($name);
        return $time_of_the_copy >= $last_modified_time;
    }

    /**
     * Get the cache synch value. I.e. the last time the cache was modified.
     *
     * @param $name string
     * @param $default int
     * @return int
     */
    public static function get($name, $default = null)
    {
        self :: load();

        if (isset(self :: $params[$name]))
        {
            return self :: $params[$name];
        }
        if (! is_null($default))
        {
            return self :: $params[$name] = $result;
        }
        $result = filemtime(Path :: get(SYS_PATH) . 'common/configuration/configuration.php');
        self :: $params[$name] = $result;
        self :: store(); // if we have several application server the file date can be different. We want to avoid that
                         // because we want all to be in synch
        return $result;
    }
}

?>
