<?php
namespace common\libraries;

use admin\AdminDataManager;

/**
 * Manage client/browser caching.
 *
 * @author laurent
 */
class ClientCache
{
    const START_DATE = 'InstallDate';

    /**
     * Reset the cache start time to now().
     */
    public static function reset()
    {
        CacheSynch :: reset(self :: START_DATE);
    }

    public static function is_fresh($time_of_the_copy)
    {
        return CacheSynch :: is_fresh(self :: START_DATE, $time_of_the_copy);
    }

    /**
     * Anything before this date should be considered stale. Used in urls to tell the navigator cache to refresh
     *
     * @return int
     */
    public static function get_start_time()
    {
        return CacheSynch :: get(self :: START_DATE);

     //        $result = PlatformSetting::get_instance()->get(self::START_DATE);
    //        $result = $result ? $result : filemtime(Path::get(SYS_PATH) . 'common/configuration/configuration.php');
    //        return $result;
    }

    /**
     * Returns the (default) Time To Live in seconds. I.e. how much time an entry is supposed to stay in the cache.
     * Used by the browser cache.
     *
     * @return int
     */
    public static function ttl()
    {
        return (int) (3600 * 24 * 7 * 365 * 5);
    }

    /**
     * Returns a unix int timestamp that tells when a resource is going to expire.
     * Used by the browser cache.
     *
     * @param int $time
     * @return int
     */
    public static function expires($time)
    {
        $time = (int) $time;
        $ttl = self :: ttl();
        $result = $time + $ttl;
        $result = (int) min($result, PHP_INT_MAX);
        return $result;
    }

    /**
     * Send cache headers as required. If the resource has not been modified exit program.
     *
     * @param string $key
     * @param int $time
     * @param bool $caching
     */
    public static function prolog($key, $time = null, $caching = true)
    {
        if (! $caching)
        {
            HttpHeader :: cache_control(HttpHeader :: CACHE_NO_CACHE);
            HttpHeader :: pragma(HttpHeader :: CACHE_NO_CACHE);
            return;
        }

        $client_time = Request :: server(HttpHeader :: HEADER_IF_MODIFIED_SINCE);
        $client_time = $client_time ? strtotime($client_time) : 0;

        $time = $time ? $time : Request :: get('time');
        $time = $time ? $time : time();

        $expire_time = self :: expires($time);
        HttpHeader :: expires($expire_time);

        HttpHeader :: cache_control(HttpHeader :: CACHE_PUBLIC);
        HttpHeader :: last_modified($time);
        HttpHeader :: etag(md5($key));
        HttpHeader :: remove(HttpHeader :: HEADER_PRAGMA);

        /*
         * We don't call is_fresh to avoid a DB call in the prolog
         * to keep performances
         */
        if ($client_time >= $time)
        {
            HttpHeader :: not_modified();
            $list = headers_list();
            $apache = apache_response_headers();
            exit();
        }
    }

}

?>