<?php

namespace common\libraries;

/**
 * A cache resources. I.e. CSS, Javascript, Images, etc that comes with
 * the application. As opposed to files uploaded by end users.
 * 
 * A new key is generated when content changes. This is required by the
 * client/browser cache. So ResourceCache does not check the file modification
 * date. If a file resoure is available for the key then it means it is fresh.
 * 
 * Backed by a file cache.
 * 
 * All entries are kept until they are deleted.
 * 
 */
class ResourceCache
{
    const ROOT = 'resource';
    
    private static $store = null;

    /**
     * @return FileCache
     */
    public static function get_store()
    {
        if (empty(self :: $store))
        {
            self :: $store = new FileCache(self :: ROOT);
        }
        return self :: $store;
    }

    public static function get_root()
    {
        return self :: get_store()->get_root();
    }

    /**
     * If the resource is available in the cash send it and exit.
     * 
     * @param string $key
     * @param int $time
     * @param bool $caching
     */
    public static function prolog($key, $time = null, $caching = true)
    {
        self :: get_store()->prolog($key, $time, $caching);
    }

    public static function path($key)
    {
        self :: get_store()->path($key);
    }

    public static function reset()
    {
        self :: get_store()->reset();
    }

    public static function has($key)
    {
        return self :: get_store()->has($key);
    }

    public static function get($key)
    {
        return self :: get_store()->has($key);
    }

    public static function read($key)
    {
        return self :: get_store()->read($key);
    }

    public static function set($key, $value)
    {
        return self :: get_store()->set($key, $value);
    }

    public static function clear()
    {
        self :: get_store()->clear();
    }

/**
 * We could implement magic method for delegation but cache should be 
 * as fast as possible
 */

}

?>