<?php
namespace common\libraries;

/**
 * Abstract test case that checks the php syntax for the php files of a package
 * 
 * @author Sven Vanpoucke - Hogeschool Gent
 */
abstract class CheckSourceCodeTest extends \PHPUnit_Framework_TestCase
{
    /****************************************************************************************************************
    * Caching variables												    *
    ****************************************************************************************************************/
    
    /**
     * Caches the source files for reuse in multiple tests
     * 
     * @var string[] 
     */
    private $source_files;
    
    /****************************************************************************************************************
    * Tests													    *
    ****************************************************************************************************************/
    
    /**
     * This test checks if the syntax for a given php file is correct
     * (Uses php lint for the check)
     * 
     * @dataProvider php_syntax_data_provider
     */
    public function test_php_syntax($file)
    {
	$lint_result = exec('php -l ' . $file);
	$syntax_correct = (strpos($lint_result, 'No syntax errors detected') !== false);
		
	$this->assertTrue($syntax_correct);
    }
    
    /****************************************************************************************************************
    * Data Providers												    *
    ****************************************************************************************************************/
    
    /**
     * Provides the data for the check php syntax test
     * 
     * @return string[]  
     */
    public function php_syntax_data_provider()
    {
        if(!isset($this->source_files))
	{
	    $directory = new \RecursiveDirectoryIterator($this->get_source_path());
	    $iterator = new \RecursiveIteratorIterator($directory);
	    $regex = new \RegexIterator($iterator, '/^.+\.class\.php$/i', \RecursiveRegexIterator :: GET_MATCH);

	    $source_files = array();

	    foreach ($regex as $matches)
	    {
		$source_files[] = array($matches[0]);
	    }
	    
	    $this->source_files = $source_files;
	}
	
	return $this->source_files;
    }
    
    /****************************************************************************************************************
    * Helper functionality											    *
    ****************************************************************************************************************/
    
    /**
     * Returns the path to the source files
     * 
     * @return string 
     */
    protected function get_source_path()
    {
	return Path :: namespace_to_full_path(Utilities :: get_namespace_from_classname(get_called_class()) . 
		'/../php/');
    }
}
