<?php
namespace common\libraries\data_class_generator;

use common\libraries\Path;

use common\libraries\Utilities;

/**
 * Dataclass generator used to generate dataclasses with given properties
 * 
 * @author Sven Vanpoucke
 */
class DataClassGenerator
{
    private $template;

    /**
     * Constructor
     */
    function __construct()
    {
    }

    /**
     * Generate a dataclass with the given info
     * 
     * @param $location string
     *            - The location of the class
     * @param $classname string
     *            the classname
     * @param
     *            array of strings $properties the properties
     * @param $package string
     *            the package
     * @param $description string
     *            the description
     * @param $author, string
     *            the author
     */
    function generate_data_class($xml_definition, $author, $package, $application)
    {
        $this->template = new MyTemplate();
        $this->template->set_rootdir(dirname(__FILE__));
        
        $location = dirname(__FILE__) . '/../xml_schemas/php/';
        
        if (! is_dir($location))
            mkdir($location, 0777, true);
        
        if (! is_dir($location . Path :: namespace_to_path($xml_definition['namespace']) . '/php/lib/'))
            mkdir($location . Path :: namespace_to_path($xml_definition['namespace']) . '/php/lib/', 0777, true);
        
        $file = fopen($location . Path :: namespace_to_path($xml_definition['namespace']) . '/php/lib/' . $xml_definition['name'] . '.class.php', 'w+');
        
        if ($file)
        {
            $this->template->set_filenames(array('dataclass' => 'data_class.template'));
            
            $property_names = array();
            
            $this->template->assign_vars(array(
                    'PACKAGE' => str_replace('\\', '.', $xml_definition['namespace']) . '.' . $application, 
                    'AUTHOR' => $author, 
                    'OBJECT_CLASS' => Utilities :: underscores_to_camelcase($xml_definition['name']), 
                    'L_OBJECT_CLASS' => $xml_definition['name'], 
                    'APPLICATION_NAME' => Utilities :: underscores_to_camelcase($application), 
                    'NAMESPACE' => $xml_definition['namespace']));
            
            foreach ($xml_definition['properties'] as $property_name => $property_attributes)
            {
                if ($property_name != 'id')
                {
                    $property_const = 'PROPERTY_' . strtoupper($property_name);
                    $property_names[] = 'self :: ' . $property_const;
                    
                    $this->template->assign_block_vars("CONSTS", array('PROPERTY_CONST' => $property_const, 
                            'PROPERTY_NAME' => $property_name));
                    
                    $this->template->assign_block_vars("DEFAULT_PROPERTY", array('PROPERTY_CONST' => $property_const));
                    
                    $this->template->assign_block_vars("PROPERTY", array('PROPERTY_CONST' => $property_const, 
                            'PROPERTY_NAME' => $property_name, 'PROPERTY_TYPE' => $property_attributes['type']));
                }
            }
            
            $this->template->assign_vars(array(
                    'APPLICATION_NAME' => Utilities :: underscores_to_camelcase($application)));
            
            $string = $this->template->pparse_return('dataclass');
            fwrite($file, $string);
            fclose($file);
        }
    }
}

?>