<?php
namespace common\libraries;

use core\lynx\PackageList;

require_once dirname(__FILE__) . '/../../../../../../global.inc.php';

$sizes = array(Theme :: ICON_MINI, Theme :: ICON_SMALL, Theme :: ICON_MEDIUM, Theme :: ICON_BIG);

$total_failures = 0;
$total_packages = 0;
$total_missing_icons = 0;

$html = array();

$package_list = PackageList :: get()->get_all_packages();

foreach ($package_list as $category => $packages)
{
    $total_packages += count($packages);
    $failures = 0;
    $data = array();

    foreach ($packages as $package)
    {
        $data_row = array();
        $data_row[] = Utilities :: get_package_name_from_namespace($package);

        $row_failures = 0;

        foreach ($sizes as $size)
        {
            // Regular
            $size_icon_path = Theme :: get_image_system_path($package) . 'logo/' . $size . '.png';

            if (! file_exists($size_icon_path))
            {
                $row_failures ++;
                $failures ++;
                $data_row[] = '<img src="' . Theme :: get_common_image_path() . 'error/' . $size . '.png" />';
            }
            else
            {
                $data_row[] = '<img src="' . Theme :: get_image_path($package) . 'logo/' . $size . '.png" />';
            }

            // Not available
            $icon_path = Theme :: get_image_system_path($package) . 'logo/' . $size . '_na.png';

            if (! file_exists($icon_path))
            {
                if (file_exists($size_icon_path) && Request :: get('copy'))
                {
                    Filesystem :: copy_file($size_icon_path, $icon_path);
                }
                $row_failures ++;
                $failures ++;
                $data_row[] = '<img src="' . Theme :: get_common_image_path() . 'error/' . $size . '.png" />';
            }
            else
            {
                $data_row[] = '<img src="' . Theme :: get_image_path($package) . 'logo/' . $size . '_na.png" />';
            }

            // New
            $icon_path = Theme :: get_image_system_path($package) . 'logo/' . $size . '_new.png';

            if (! file_exists($icon_path))
            {
                if (file_exists($size_icon_path) && Request :: get('copy'))
                {
                    Filesystem :: copy_file($size_icon_path, $icon_path);
                }
                $row_failures ++;
                $failures ++;
                $data_row[] = '<img src="' . Theme :: get_common_image_path() . 'error/' . $size . '.png" />';
            }
            else
            {
                $data_row[] = '<img src="' . Theme :: get_image_path($package) . 'logo/' . $size . '_new.png" />';
            }
        }

        if ($row_failures > 0 || Request :: get('show_all'))
        {
            $data[] = $data_row;
        }
    }

    $table = new SortableTableFromArray($data, 0, 200);
    $header = $table->getHeader();
    $table->set_header(0, 'Application');

    foreach ($sizes as $key => $header_size)
    {
        $table->set_header(($key * 3) + 1, $header_size);
        $table->set_header(($key * 3) + 2, $header_size . ' NA');
        $table->set_header(($key * 3) + 3, $header_size . ' NEW');
    }

    if ($failures || Request :: get('show_all'))
    {
        $html[] =  '<h3>' . $category . ' ( '. count($packages) .' packages)</h3>';
        $html[] =  $table->as_html();
        $html[] =  '<b>Missing icons: ' . $failures . '</b>';

        $total_failures += $failures;
        $total_missing_icons += $failures;
    }
}

if (!$total_failures && ! Request :: get('show_all'))
{
    $html[] = Display :: message(Display :: MESSAGE_TYPE_CONFIRM, 'Th-th-th-th-That\'s all, folks! All icons for the collected ' . $total_packages . ' packages are available!', true);
}
else
{
    $html[] =  '<h3>Total number of packages: ' . $total_packages .'</h3>';
    $html[] =  '<h3>Total number of missing icons: ' . $total_missing_icons .'</h3>';
}

Display :: small_header();

$html[] =  '<style>';
$html[] =  'table td {text-align: center;}';
$html[] =  'table td:first-child {text-align: left;}';
$html[] =  'table th {width: 70px; text-align: center !important;}';
$html[] =  'table th:first-child {width: auto; text-align: left !important;}';
$html[] =  '</style>';

echo implode("\n", $html);

Display :: small_footer();
?>