<?php
namespace common\libraries;

use core\lynx\PackageList;

/**
 * $Id: web_application.class.php 237 2009-11-16 13:04:53Z vanpouckesven $
 *
 * @package application
 */
abstract class WebApplication extends BasicApplication
{
    const CLASS_NAME = __CLASS__;

    static $application_path_cache = array();

    /**
     * Determines whether the given learning object cab be edited in this application.
     *
     * @param $object_id int The ID of the learning object.
     * @return boolean True if the object is currently editable, false otherwise.
     */
    static function is_content_object_editable($object_id)
    {
        return true;
    }

    /**
     * Determines whether the given learning object has been published in this application.
     *
     * @param $object_id int The ID of the learning object.
     * @return boolean True if the object is currently published, false otherwise.
     */
    static function content_object_is_published($object_id)
    {
        return false;
    }

    /**
     * Determines whether any of the given learning objects has been published in this application.
     *
     * @param $object_ids array The Id's of the learning objects
     * @return boolean True if at least one of the given objects is published in this application, false otherwise
     */
    static function any_content_object_is_published($object_ids)
    {
        return false;
    }

    /**
     * Determines where in this application the given learning object has been published.
     *
     * @param $object_id int The ID of the learning object.
     * @return array An array of ContentObjectPublicationAttributes objects; empty if the object has not been published
     *         anywhere.
     */
    static function get_content_object_publication_attributes($object_id, $type = null, $offset = null, $count = null,
            $order_property = null)
    {
        return array();
    }

    /**
     * Determines where in this application the given learning object publication is published.
     *
     * @param $publication_id int The ID of the learning object publication.
     * @return ContentObjectPublicationAttributes
     */
    static function get_content_object_publication_attribute($publication_id)
    {
        return null;
    }

    /**
     * Counts the number of publications
     *
     * @param $type string
     * @param $condition Condition
     * @return int
     */
    static function count_publication_attributes($user = null, $object_id, $condition = null)
    {
        return 0;
    }

    /**
     * Deletes all publications of a given learning object
     *
     * @param $object_id int The id of the learning object
     */
    static function delete_content_object_publications($object_id)
    {
        return true;
    }

    static function delete_content_object_publication($publication_id)
    {
        return true;
    }

    static function get_content_object_publication_locations($content_object)
    {
        return array();
    }

    static function publish_content_object($content_object, $location, $attributes)
    {
        return null;
    }

    static function add_publication_attributes_elements($form)
    {

    }

    /**
     * Loads the applications installed on the system. Applications are classes in the /application/lib subdirectory.
     * Each application is a directory, which in its turn contains a class file named after the application. For
     * instance, the weblcms application is the class Weblcms, defined in /application/lib/weblcms/weblcms.class.php.
     * Applications must extend the Application class.
     */
    public static function load_all_from_filesystem($include_application_classes = true,
            $only_registered_applications = false)
    {
        $applications = array();
        $path = Path :: get_application_path();

        $directories = Filesystem :: get_directory_content($path, Filesystem :: LIST_DIRECTORIES, false);

        foreach ($directories as $directory)
        {
            $application_name = basename($directory);
            if ($only_registered_applications && ! CommonDataManager :: is_registered(
                    'application\\' . $application_name))
            {
                continue;
            }

            if (Application :: is_application_name($application_name))
            {
                if (! in_array($application_name, $applications))
                {
                    $applications[] = $application_name;
                }
            }
        }
        return $applications;
    }

    public static function load_all()
    {
        $applications = CommonDataManager :: get_registrations_by_type(Registration :: TYPE_APPLICATION);

        $active_applications = array();

        foreach ($applications as $application)
        {
            if (! $application->is_active())
            {
                continue;
            }

            $active_applications[] = $application->get_name();
        }
        return $active_applications;
    }

    /**
     * Determines if a given application exists
     *
     * @param $name string
     * @return boolean
     *
     * @deprecated Deprecated method
     */
    public static function is_application($name)
    {
        return self :: exists($name);
    }

    public function is_active($context = null)
    {
        if (self :: exists($context))
        {
            $registration = CommonDataManager :: get_registration($context);

            if ($registration && $registration->is_active())
            {
                return true;
            }
            else
            {
                return false;
            }
        }
        else
        {
            return false;
        }
    }

    public static function get_application_path($application_name)
    {
        return Path :: get_application_path() . $application_name . '/';
    }

    public static function get_application_web_path($application_name)
    {
        return Path :: get_application_web_path() . $application_name . '/';
    }

    /**
     * Deprecated method
     *
     * @deprecated Deprecated method
     */
    public function get_application_component_path()
    {
        $application_name = $this->get_application_name();
        return $this->get_application_path($application_name) . 'lib/' . $application_name . '_manager/component/';
    }

    static function get_application_namespace($application_name)
    {
        return 'application\\' . $application_name;
    }

    /**
     * Deprecated method
     *
     * @deprecated Deprecated method
     */
    static function factory($application, $user = null)
    {
        $class = self :: get_application_namespace($application) . '\\' . self :: get_application_class_name(
                $application);
        return new $class($user);
    }

    function get_additional_user_information($user)
    {
        return null;
    }

    static function exists($application)
    {
        if (! isset(self :: $application_path_cache[$application]))
        {
            $application_path = self :: get_application_path(Utilities :: get_package_name_from_namespace($application));
            self :: $application_path_cache[$application] = is_dir($application_path);
        }
        return self :: $application_path_cache[$application];
    }

    public static function get_packages_from_filesystem()
    {
        $applications = array();

        $directories = Filesystem :: get_directory_content(Path :: get_application_path(),
                Filesystem :: LIST_DIRECTORIES, false);

        foreach ($directories as $directory)
        {
            $application_name = basename($directory);

            if (Application :: is_application_name($application_name))
            {
                $applications[] = self :: determine_namespace($application_name);
            }
        }

        return $applications;
    }

    static function get_installable_packages($include_installed = false)
    {
        $package_list = new PackageList('application',
                Translation :: get('Application', null, Utilities :: COMMON_LIBRARIES));

        foreach (self :: get_packages_from_filesystem() as $application)
        {
            $class = $application . '\Manager';

            if (! CommonDataManager :: get_registration($application) || $include_installed)
            {
                $package_list->add_package($application);
            }

            if (! class_exists($class))
            {
                $class = $application . '\\' . Utilities :: underscores_to_camelcase(
                        Utilities :: get_package_name_from_namespace($application)) . 'Manager';
            }

            if (class_exists($class))
            {
                $application_package_list = $class :: get_installable_application_packages($include_installed);
                if ($application_package_list instanceof PackageList)
                {
                    $package_list->add_child($application_package_list);
                }
            }
        }

        return $package_list;
    }

    static function get_installable_application_packages($include_installed = false)
    {
        return false;
    }

}
?>