<?php
namespace common\libraries;

use core\lynx\package\Package;
use admin\AdminDataManager;
use install\InstallManager;
use menu\CategoryItem;
use menu\Item;
use menu\ItemTitles;
use menu\ItemTitle;
use menu\ApplicationItem;

/**
 * Base class for specific installation extensions of web applications
 *
 * @author Hans De Bisschop
 */
class WebApplicationInstaller extends \common\libraries\package\Installer
{

    /**
     * Always add a menu-item for a web application. Don't forget to call this method via parent :: install_extra() in
     * application installers that implement additional logic for this method.
     *
     * @return boolean
     */
    public function install_extra()
    {
        $context = $this->context();

        // Determine whether the category already exists, if not create it
        $info = Package :: get($context);
        $category_name = Translation :: get(Utilities :: underscores_to_camelcase($info->get_category()), null,
            InstallManager :: determine_namespace(InstallManager :: APPLICATION_NAME), Translation :: get_instance()->get_language());

        $conditions = array();
        $conditions[] = new EqualityCondition(ItemTitle :: PROPERTY_TITLE, $category_name);
        $conditions[] = new EqualityCondition(ItemTitle :: PROPERTY_ISOCODE,
                Translation :: get_instance()->get_language());
        $titles = \menu\DataManager :: distinct(ItemTitle :: class_name(), ItemTitle :: PROPERTY_ITEM_ID,
                new AndCondition($conditions));

        if (count($titles) > 0)
        {
            $conditions = array();
            $conditions[] = new EqualityCondition(Item :: PROPERTY_TYPE, CategoryItem :: class_name());
            $conditions[] = new InCondition(Item :: PROPERTY_ID, $titles);

            $category = \menu\DataManager :: retrieve(Item :: class_name(), new AndCondition($conditions));
        }
        else
        {
            $languages = AdminDataManager :: get_languages();
            $category = new CategoryItem();
            $category->set_parent(0);

            $item_titles = new ItemTitles();
            foreach ($languages as $isocode => $language)
            {
                $item_title = new ItemTitle();
                $item_title->set_title(
                    Translation :: get(Utilities :: underscores_to_camelcase($info->get_category()), null,
                        InstallManager :: determine_namespace(InstallManager :: APPLICATION_NAME), $isocode));
                $item_title->set_isocode($isocode);
                $item_titles->add($item_title);
            }

            $category->set_titles($item_titles);

            if (! $category->create())
            {
                return false;
            }
        }

        // Create the actual menu item
        $item = new ApplicationItem();
        $item_title = new ItemTitle();
        $item_title->set_title(Translation :: get('TypeName', null, $context));
        $item_title->set_isocode(Translation :: get_instance()->get_language());
        $item_titles = new ItemTitles(new ArrayResultSet(array($item_title)));

        $item->set_titles($item_titles);
        $item->set_application(Utilities :: get_package_name_from_namespace($context));
        $item->set_parent($category->get_id());
        $item->set_use_translation(1);

        if (! $item->create())
        {
            return false;
        }

        return true;
    }
}
?>