<?php
namespace common\libraries;

use webservice\WebserviceManager;
use user\UserDataManager;
use Exception;

/**
 * Class to provide authentication for webservices
 */
abstract class WebserviceAuthentication extends MessageLogger
{
    /**
     * Keeps track of the active user which is given to the authentication method
     *
     * @var User
     */
    private $user;

    static function factory()
    {
        // Digest for testing with browser
        $type = 'chamilo';

        $path = dirname(__FILE__) . '/' . $type . '/' . $type . '_webservice_authentication.class.php';
        if (! file_exists($path))
        {
            throw new Exception(
                    Translation :: get('CouldNotCreateWebserviceAuthenticationType', array('TYPE' => $type),
                            WebserviceManager :: APPLICATION_NAME));
        }

        $class = __NAMESPACE__ . '\\' . Utilities :: underscores_to_camelcase($type) . 'WebserviceAuthentication';
        return new $class();
    }

    /**
     * Loads the user by username
     *
     * @param $username String
     * @return User
     */
    function load_user_by_username($username)
    {
        $this->user = UserDataManager :: get_instance()->retrieve_user_by_username($username);
        return $this->user;
    }

    /**
     * Returns the user
     *
     * @return User
     */
    function get_user()
    {
        return $this->user;
    }

    abstract function is_valid();
}

?>
