<?php

namespace common\libraries;

/**
 * Abstract class to define the business logic of the creation of an object (data class) into the database
 * @author Sven Vanpoucke
 */
abstract class CreateObjectWebserviceHandler extends WebserviceHandler
{

    /**
     * Creates an object in the database
     */
    function run()
    {
        $object = $this->get_object();
        if (! $object instanceof DataClass)
        {
            return new SuccessRestMessage(false, Translation :: get('CouldNotCreateObjectInstance', array(
                    'OBJECT' => $this->get_object_translation()), Utilities :: COMMON_LIBRARIES));
        }
        
        $data = $this->get_data();
        if ($this->default_properties_required() && empty($data[self :: PROPERTIES][DataClass :: PROPERTIES_DEFAULT]))
        {
            return new SuccessRestMessage(false, Translation :: get('DefaultPropertiesCanNotBeNull', null, Utilities :: COMMON_LIBRARIES));
        }
        
        $object->set_properties($data[self :: PROPERTIES]);
        
        $object = $this->manipulate_data($object, $data[self :: PROPERTIES_EXTRA]);
        if (! $object)
        {
            return new SuccessRestMessage(false, Translation :: get('InvalidExtraProperties'));
        }
        
        if (! $this->is_allowed_to_create_object($object))
        {
            return new SuccessRestMessage(false, Translation :: get('NotAllowed', null, Utilities :: COMMON_LIBRARIES));
        }
        
        $succes = $object->create();
        if (! $succes)
        {
            return new SuccessRestMessage(false, Translation :: get('FailedToCreateObject', array(
                    'OBJECT' => $this->get_object_translation(), 'REASON' => implode(', ', $object->get_errors())), Utilities :: COMMON_LIBRARIES));
        }
        
        return new SuccessRestMessage(true, $object->get_id());
    }

    function default_properties_required()
    {
        return true;
    }

    function is_allowed_to_create_object($object)
    {
        return $this->get_user()->is_platform_admin();
    }

    abstract function get_object();

    abstract function get_object_translation();

    abstract function manipulate_data($object, $extra_properties = null);

}

?>
