<?php

namespace common\libraries;

/**
 * Abstract class to define the business logic of the deletion of an object (data class) in the database
 * @author Sven Vanpoucke
 */
abstract class DeleteObjectWebserviceHandler extends WebserviceHandler
{

    /**
     * Deletes one content object
     */
    function run()
    {
        $object = $this->get_object();
        $translation = $this->get_object_translation();
        
        if (! $object)
        {
            return new SuccessRestMessage(false, Translation :: get('ObjectNotFound', array('OBJECT' => $translation), Utilities :: COMMON_LIBRARIES));
        }
        
        if (! $this->is_allowed_to_delete_object($object))
        {
            return new SuccessRestMessage(false, Translation :: get('NotAllowed', null, Utilities :: COMMON_LIBRARIES));
        }
        
        $succes = $object->delete();
        if (! $succes)
        {
            return new SuccessRestMessage(false, Translation :: get('FailedToDeleteObject', array(
                    'OBJECT' => $translation, 'REASON' => implode(', ', $object->get_errors())), Utilities :: COMMON_LIBRARIES));
        }
        
        return new SuccessRestMessage(true, Translation :: get('ObjectDeleted', array('OBJECT' => $translation), Utilities :: COMMON_LIBRARIES));
    }

    function is_allowed_to_delete_object($object)
    {
        return $this->get_user()->is_platform_admin();
    }

    abstract function get_object();

    abstract function get_object_translation();

}

?>
