<?php

namespace common\libraries;

/**
 * Abstract class to define the business logic of the update of an object (data class) into the database
 * @author Sven Vanpoucke
 */
abstract class UpdateObjectWebserviceHandler extends WebserviceHandler
{

    /**
     * Updates one content object
     */
    function run()
    {
        $object = $this->get_object();
        $translation = $this->get_object_translation();
        
        if (! $object)
        {
            return new SuccessRestMessage(false, Translation :: get('ObjectNotFound', array('OBJECT' => $translation), Utilities :: COMMON_LIBRARIES));
        }
        
        if (! $this->is_allowed_to_update_object($object))
        {
            return new SuccessRestMessage(false, Translation :: get('NotAllowed', null, Utilities :: COMMON_LIBRARIES));
        }
        
        $data = $this->get_data();
        
        if (empty($data[self :: PROPERTIES][DataClass :: PROPERTIES_DEFAULT]))
        {
            return new SuccessRestMessage(false, Translation :: get('DefaultPropertiesCanNotBeNull', null, Utilities :: COMMON_LIBRARIES));
        }
        
        $object->set_properties($data[self :: PROPERTIES]);
        
        $object = $this->manipulate_data($object, $data[self :: PROPERTIES_EXTRA]);
        if (! $object)
        {
            return new SuccessRestMessage(false, Translation :: get('NoExtraPropertiesImplementedForObjectType', null, Utilities :: COMMON_LIBRARIES));
        }
        
        $succes = $object->update();
        if (! $succes)
        {
            return new SuccessRestMessage(false, Translation :: get('FailedToUpdateObject', array(
                    'OBJECT' => $translation, 'REASON' => implode(', ', $object->get_errors())), Utilities :: COMMON_LIBRARIES));
        }
        
        return new SuccessRestMessage(true, Translation :: get('ObjectUpdated', array('OBJECT' => $translation), Utilities :: COMMON_LIBRARIES));
    }

    function is_allowed_to_update_object($object)
    {
        return $this->get_user()->is_platform_admin();
    }

    abstract function get_object();

    abstract function get_object_translation();

    abstract function manipulate_data($object, $extra_properties = null);

}

?>
