<?php

namespace common\libraries;

/**
 * A rest message renderer to json format
 */

class XmlRestMessageRenderer extends RestMessageRenderer
{

    /**
     * Renders one object
     * @param DataClass $object 
     */
    function render_object(DataClass $object)
    {
        $this->render_xml_header();
        echo $this->render_object_body($object);
    }

    /**
     * Renders an array of objects
     * @param array $objects
     */
    function render_multiple_objects(array $objects)
    {
        $this->render_xml_header();
        
        $xml = array();
        $xml[] = '<objects>';
        
        foreach ($objects as $object)
        {
            $xml[] = $this->render_object_body($object);
        }
        
        $xml[] = '</objects>';
        echo implode("\n", $xml);
    
    }

    /**
     * Renders the xml of one object
     * @param DataClass $object
     * @return String
     */
    private function render_object_body(DataClass $object)
    {
        $xml = array();
        $xml[] = '<object>';
        
        foreach ($object->get_properties() as $type => $properties)
        {
            $xml[] = '<' . $type . '>';
            foreach ($properties as $name => $value)
            {
                $xml[] = '<' . $name . '>' . urlencode($value) . '</' . $name . '>';
            }
            $xml[] = '</' . $type . '>';
        }
        
        $xml[] = '</object>';
        return implode("\n", $xml);
    }

    /**
     * Renders the xml header
     */
    private function render_xml_header()
    {
        header('Content-Type: application/xml');
        
        $xml = array();
        $xml[] = '<?xml version="1.0" encoding="UTF-8"?>';
        
        echo implode("\n", $xml);
    }
}

?>