<?php
namespace context_linker;

use common\libraries\Toolbar;
use common\libraries\ToolbarItem;
use common\libraries\Translation;
use common\libraries\Theme;
use repository\ContentObject;
use metadata\MetadataElement;
use metadata\MetadataElementValue;
use common\libraries\Utilities;

/**
 * Cell rendere for the learning object browser table
 *
 * @author Sven Vanpoucke
 * @author Jens Vanderheyden
 */

class ContextLinkBrowserTableCellRenderer extends DefaultContextLinkTableCellRenderer
{
    /**
     * The browser component
     */
    private $browser;

    /**
     * Constructor
     *
     * @param $browser ApplicationComponent
     */
    function __construct($browser)
    {
        parent :: __construct();
        $this->browser = $browser;
    }

    // Inherited
    function render_cell($column, $context_link)
    {

        if ($column === ContextLinkBrowserTableColumnModel :: get_modification_column())
        {
            return $this->get_modification_links($context_link);
        }
        elseif ($column->get_name() == DefaultContextLinkTableColumnModel :: COLUMN_ORIGINAL_TYPE)
        {
            return Theme :: get_content_object_image($context_link['orig_' . ContentObject :: PROPERTY_TYPE]);
        }
        elseif ($column->get_name() == DefaultContextLinkTableColumnModel :: COLUMN_ORIGINAL_TITLE)
        {
            return $context_link['orig_' . ContentObject :: PROPERTY_TITLE];
        }
        elseif ($column->get_name() == DefaultContextLinkTableColumnModel :: COLUMN_ALTERNATIVE_TYPE)
        {
            return Theme :: get_content_object_image($context_link['alt_' . ContentObject :: PROPERTY_TYPE]);
        }
        elseif ($column->get_name() == DefaultContextLinkTableColumnModel :: COLUMN_ALTERNATIVE_TITLE)
        {
            return $context_link['alt_' . ContentObject :: PROPERTY_TITLE];
        }
        elseif ($column->get_name() == DefaultContextLinkTableColumnModel :: COLUMN_METADATA_ELEMENT)
        {
            return $context_link[MetadataElement :: PROPERTY_NS_PREFIX] . ':' . $context_link[MetadataElement :: PROPERTY_NAME];
        }
        elseif ($column->get_name() == DefaultContextLinkTableColumnModel :: COLUMN_METADATA_PROPERTY_VALUE)
        {
            return $context_link[MetadataElementValue :: PROPERTY_VALUE];
        }
        elseif ($column->get_name() == DefaultContextLinkTableColumnModel :: COLUMN_DATE)
        {
            return date('Y-m-d h:i:s', $context_link[ContextLink :: PROPERTY_DATE]);
        }
        return parent :: render_cell($column, $context_link);
    }

    /**
     * Gets the action links to display
     *
     * @param $content_object ContentObject The learning object for which the action links should be returned
     * @return string A HTML representation of the action links
     */
    private function get_modification_links($context_link)
    {
        $toolbar = new Toolbar(Toolbar :: TYPE_HORIZONTAL);

        $toolbar->add_item(
                new ToolbarItem(
                        Translation :: get('DeleteObject', array('OBJECT' => Translation :: get('ContextLink')),
                                Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_delete.png',
                        $this->browser->get_delete_context_link_url($context_link), ToolbarItem :: DISPLAY_ICON, true));

        return $toolbar->as_html();
    }
}
?>