<?php
namespace context_linker;

use common\libraries\CommonDataManager;

use common\libraries\FormValidator;
use common\libraries\Translation;
use common\libraries\Request;
use admin\AdminDataManager;
use metadata\MetadataDataManager;
use metadata\MetadataElementValue;
use metadata\MetadataForm;

/**
 * This class describes the form for a ContextLink object.
 *
 * @author Sven Vanpoucke
 * @author Jens Vanderheyden
 */
class ContextLinkForm extends MetadataForm
{
    const TYPE_ORIGINAL = 1; // for original content object
    const TYPE_ALTERNATIVE = 2; // for ...

    const TYPE = 'content_object';

    private $context_link;
    private $user;
    private $metadata_element_values;

    function __construct($name, $form_type, $context_link, $metadata_element_values = array(), $action)
    {

        $this->set_parent_type(self :: TYPE);

        parent :: __construct($name, 'post', $action);

        $this->context_link = $context_link;
        $this->metadata_element_values = $metadata_element_values;

        $this->form_type = $form_type;

        if ($this->form_type == self :: TYPE_ORIGINAL)
        {
            $this->build_basic_form();
            $this->setDefaults(array(parent :: PARENT_ID => $context_link->get_original_content_object_id()));
        }
        elseif ($this->form_type == self :: TYPE_ALTERNATIVE)
        {
            $this->build_alternative_form();

            $default_element = CommonDataManager :: retrieve_setting_from_variable_name(ContextLinkerManager :: SETTING_DEFAULT_ELEMENT, ContextLinkerManager :: APPLICATION_NAME);

            foreach ($this->metadata_element_values as $id => $value)
            {
                // if existing element value corresponds with default element => select
                if ($value["element_id"] == $default_element->get_value() && $default_element)
                {
                    $selected_value_id = $id;
                }
                // else the first element is default selected
                else
                {
                    $selected_value_id = $id;
                    break;
                }
            }

            $defaults[ContextLink :: PROPERTY_METADATA_PROPERTY_VALUE_ID] = $selected_value_id;
            $defaults[parent :: PARENT_ID] = $context_link->get_alternative_content_object_id();
            $this->setDefaults($defaults);
        }
    }

    function get_object_id()
    {
        if ($this->form_type == self :: TYPE_ORIGINAL)
        {
            $id = ContextLinkerManager :: PARAM_CONTENT_OBJECT_ID;
        }
        else
        {
            $id = ContextLinkerManager :: PARAM_ALTERNATIVE_CONTENT_OBJECT_ID;
        }

        return Request :: get($id);
    }

    function build_basic_form()
    {

        $this->addElement('hidden', parent :: PARENT_ID);

        $this->addElement('hidden', ContextLink :: PROPERTY_ORIGINAL_CONTENT_OBJECT_ID);

        $this->addElement('hidden', ContextLink :: PROPERTY_ALTERNATIVE_CONTENT_OBJECT_ID);

        $this->build_empty_element_value();

        $this->addElement('hidden', ContextLink :: PROPERTY_DATE, Translation :: get('Date'));

        $buttons[] = $this->createElement('style_submit_button', 'submit', Translation :: get('Create'), array(
                'class' => 'positive'));
        $buttons[] = $this->createElement('style_reset_button', 'reset', Translation :: get('Reset'), array(
                'class' => 'normal empty'));

        $this->addGroup($buttons, 'buttons', null, '&nbsp;', false);
    }

    function build_alternative_form()
    {
        if (count($this->metadata_element_values))
        {
            foreach ($this->metadata_element_values as $id => $value)
            {
                $this->addElement('radio', ContextLink :: PROPERTY_METADATA_PROPERTY_VALUE_ID, '', $value["value"], $id, $attributes);
            }
        }

        $this->build_basic_form();
    }

    function create_context_link()
    {
        $context_link = $this->context_link;
        $values = $this->exportValues();

        $value = Request :: post(MetadataElementValue :: PROPERTY_VALUE);
        if (! empty($value))
        {
            if (! $metadata_element_value = $this->create_metadata_element_value())
            {
                return 0;
            }
            $context_link->set_metadata_element_value_id($metadata_element_value->get_id());
        }
        else
        {
            $context_link->set_metadata_element_value_id($values[ContextLink :: PROPERTY_METADATA_PROPERTY_VALUE_ID]);
        }

        $context_link->set_original_content_object_id($values[ContextLink :: PROPERTY_ORIGINAL_CONTENT_OBJECT_ID]);
        $context_link->set_alternative_content_object_id($values[ContextLink :: PROPERTY_ALTERNATIVE_CONTENT_OBJECT_ID]);

        $context_link->set_date($values[ContextLink :: PROPERTY_DATE]);

        return $context_link->create();
    }

    /**
     * Sets default values.
     *
     * @param $defaults array Default values for this form's parameters.
     */
    function setDefaults($defaults = array())
    {
        $context_link = $this->context_link;

        $defaults[ContextLink :: PROPERTY_ORIGINAL_CONTENT_OBJECT_ID] = $context_link->get_original_content_object_id();
        $defaults[ContextLink :: PROPERTY_ALTERNATIVE_CONTENT_OBJECT_ID] = $context_link->get_alternative_content_object_id();
        $defaults[ContextLink :: PROPERTY_DATE] = $context_link->get_date();

        parent :: setDefaults($defaults);
    }

}

?>