<?php
namespace core\lynx\package;

use common\libraries\Translation;
use common\libraries\Path;
use common\libraries\Utilities;
use PEAR;
use XML_Unserializer;
use Exception;
use DOMDocument;
use DOMXPath;

class Info
{

    /**
     *
     * @var string
     */
    private $context;

    /**
     *
     * @var \admin\RemotePackage
     */
    private $package;

    /**
     *
     * @var DOMDocument
     */
    private $dom_document;

    /**
     *
     * @var DOMXPath
     */
    private $dom_xpath;

    /**
     *
     * @param string $context
     * @throws Exception
     */
    function __construct($context)
    {
        $this->context = $context;
        $this->dom_document = new DOMDocument('1.0', 'UTF-8');

        $path = Path :: namespace_to_full_path($this->get_context()) . 'php/package/package.info';

        if (file_exists($path))
        {
            $this->dom_document->load($path);
            $this->dom_xpath = new DOMXPath($this->dom_document);
        }
        else
        {
            throw new Exception(Translation :: get('InvalidPackageContext'));
        }
    }

    function get_context()
    {
        return $this->context;
    }

    function get_package()
    {
        if (! isset($this->package))
        {
            $package_list = $this->dom_xpath->query('/packages/package');

            if ($package_list->length > 1)
            {
                throw new Exception(Translation :: get('MultipackageFileNotAllowed'));
            }
            else
            {
                $package_node = $package_list->item(0);

                $simple_properties = array(Package :: PROPERTY_CODE, Package :: PROPERTY_CONTEXT, Package :: PROPERTY_NAME, Package :: PROPERTY_SECTION,
                        Package :: PROPERTY_CATEGORY, Package :: PROPERTY_AUTHORS, Package :: PROPERTY_VERSION,
                        Package :: PROPERTY_CYCLE, Package :: PROPERTY_FILENAME, Package :: PROPERTY_SIZE, Package :: PROPERTY_MD5,
                        Package :: PROPERTY_SHA1, Package :: PROPERTY_SHA256, Package :: PROPERTY_SHA512,
                        Package :: PROPERTY_TAGLINE, Package :: PROPERTY_DESCRIPTION, Package :: PROPERTY_HOMEPAGE,
                        Package :: PROPERTY_PRE_DEPENDS, Package :: PROPERTY_DEPENDS, Package :: PROPERTY_RECOMMENDS,
                        Package :: PROPERTY_SUGGESTS, Package :: PROPERTY_ENHANCES, Package :: PROPERTY_EXTRA);


                var_dump($package_node);
                exit();
            }

            $package_info = $this->get_package_info();

            $package_info['package']['authors'] = serialize($package_info['package']['authors']['author']);
            $package_info['package']['cycle'] = serialize($package_info['package']['cycle']);
            $package_info['package']['dependencies'] = serialize($package_info['package']['dependencies']);

            if (isset($package_info['package']['extra']))
            {
                $package_info['package']['extra'] = serialize($package_info['package']['extra']);
            }

            $this->package = new Package();
            $this->package->set_default_properties($package_info['package']);
        }

        return $this->package;
    }

    static function get($context)
    {
        $package_info = new self($context);
        return $package_info->get_package();
    }
}
?>
