<?php
namespace core\lynx\package;

use common\libraries\Utilities;
use common\libraries\Translation;
use common\libraries\MessageLogger;
use Exception;

/**
 *
 * @author Hans De Bisschop
 * @package core.lynx
 */
class Dependencies
{
    const PROPERTY_OPERATOR = 'operator';
    const PROPERTY_DEPENDENCIES = 'dependencies';
    const OPERATOR_AND = 1;
    const OPERATOR_OR = 2;

    /**
     *
     * @var int
     */
    private $operator;

    /**
     *
     * @var multitype:\core\lynx\Dependency
     */
    private $dependencies;

    /**
     *
     * @var \common\libraries\MessageLogger
     */
    protected $logger;

    /**
     *
     * @param int $operator
     * @param \core\lynx\Dependency $dependencies
     */
    function __construct($operator, $dependencies)
    {
        $this->set_operator($operator);
        $this->set_dependencies($dependencies);

        $this->logger = MessageLogger :: get_instance($this);
    }

    /**
     *
     * @return \common\libraries\MessageLogger
     */
    function get_logger()
    {
        return $this->logger;
    }

    /**
     *
     * @return int
     */
    public function get_operator()
    {
        return $this->operator;
    }

    /**
     *
     * @param int $operator
     */
    public function set_operator($operator)
    {
        $this->operator = $operator;
    }

    /**
     *
     * @return multitype:\core\lynx\Dependency
     */
    public function get_dependencies()
    {
        return $this->dependencies;
    }

    /**
     *
     * @param multitype:\core\lynx\Dependency $dependencies
     */
    public function set_dependencies($dependencies)
    {
        $this->dependencies = $dependencies;
    }

    /**
     *
     * @param \core\lynx\Dependency $dependency
     */
    public function add_dependency($dependency)
    {
        $this->dependencies[] = $dependency;
    }

    /**
     *
     * @return string
     */
    public function as_html()
    {
        $html = array();

        foreach ($this->get_dependencies() as $dependency)
        {
            $html[] = $dependency->as_html();
        }

        if ($this->get_operator() == self :: OPERATOR_AND)
        {
            $operator = Translation :: get('And');
        }
        elseif ($this->get_operator() == self :: OPERATOR_OR)
        {
            $operator = Translation :: get('Or');
        }
        else
        {
            $operator = '?';
        }

        return implode(' ' . $operator . ' ', $html);
    }

    /**
     *
     * @return boolean
     */
    public function check()
    {
        $success = 0;
        $messages = array();

        foreach ($this->get_dependencies() as $dependency)
        {
            if ($dependency->check())
            {
                $success ++;
            }

            $messages[] = $dependency->get_logger()->render();
        }

        if ($this->get_operator() == self :: OPERATOR_AND)
        {
            $result = ($success == count($this->get_dependencies()));
        }
        elseif ($this->get_operator() == self :: OPERATOR_OR)
        {
            $result = ($success > 0);
        }
        else
        {
            $result = false;
        }

//         if (! $result)
//         {
            if ($this->get_operator() == self :: OPERATOR_AND)
            {
                $operator = Translation :: get('And');
            }
            elseif ($this->get_operator() == self :: OPERATOR_OR)
            {
                $operator = Translation :: get('Or');
            }
            else
            {
                $operator = '?';
            }

            $this->get_logger()->add_message(implode(' ' . $operator . ' ', $messages));
//         }

        return $result;
    }
}
?>