<?php
namespace core\lynx\package;

use common\libraries\Registration;
use common\libraries\CommonDataManager;
use common\libraries\Utilities;
use common\libraries\Translation;
use common\libraries\EqualityCondition;
use common\libraries\AndCondition;
use common\libraries\MessageLogger;
use admin\AdminDataManager;
use repository\ContentObject;

/**
 * Abstract class that describes a chamilo package depedency, can be used for all elements (applications, objects,
 * tools, subapplications) from chamilo
 *
 * @author Sven Vanpoucke - Hogeschool Gent
 * @package admin.lib.package_installer.dependency
 */
class RegistrationDependency extends Dependency
{
    const PROPERTY_VERSION = 'version';

    /**
     *
     * @var \core\lynx\package\Version
     */
    private $version;

    /**
     *
     * @return \core\lynx\package\Version
     */
    public function get_version()
    {
        return $this->version;
    }

    /**
     *
     * @param \core\lynx\package\Version $version
     */
    public function set_version($version)
    {
        $this->version = $version;
    }

    /**
     * Creates a dependency information string as html
     *
     * @return String
     */
    function as_html()
    {
        $parameters = array();
        $parameters['OPERATOR'] = $this->get_version()->get_operator_name();
        $parameters['ID'] = Translation :: get('TypeName', null, $this->get_id());
        $parameters['VERSION'] = $this->get_version()->get_release();

        return Translation :: get('RegistrationDependency', $parameters);
    }

    /**
     * Checks the dependency in the registration table of the administration
     *
     * @return boolean
     */
    function check()
    {
        $parameters = array();
        $parameters['REQUIREMENT'] = $this->as_html();

        $message = Translation :: get('DependencyCheckRegistration') . ': ' . $this->as_html() . ' ' .
                 Translation :: get('Found', array(), Utilities :: COMMON_LIBRARIES) . ': ';
        $registration = CommonDataManager :: get_registration($this->get_id());
        if (! $registration instanceof Registration)
        {
            $parameters['CURRENT'] = '--' . Translation :: get('Nothing', array(), Utilities :: COMMON_LIBRARIES) . '--';
            $this->logger->add_message(Translation :: get('CurrentRegistrationDependency', $parameters),
                    MessageLogger :: TYPE_ERROR);
            return false;
        }
        else
        {
            $target_version = Version :: compare($this->get_version()->get_operator(),
                    $this->get_version()->get_release(), $registration->get_version());
            if (! $target_version)
            {
                $parameters['CURRENT'] = '--' .
                         Translation :: get('WrongVersion', array(), Utilities :: COMMON_LIBRARIES) . '--';
                $this->logger->add_message(Translation :: get('CurrentRegistrationDependency', $parameters),
                        MessageLogger :: TYPE_ERROR);
                return false;
            }
            else
            {
                if (! $registration->is_active())
                {
                    $parameters['CURRENT'] = '--' .
                             Translation :: get('InactiveObject', array(), Utilities :: COMMON_LIBRARIES) . '--';
                    $this->logger->add_message(Translation :: get('CurrentRegistrationDependency', $parameters),
                            MessageLogger :: TYPE_ERROR);
                    return false;
                }
                else
                {
                    $this->logger->add_message($parameters['REQUIREMENT']);
                    return true;
                }
            }
        }
    }

    static function dom_node($dom_xpath, $dom_node)
    {
        $dependency = parent :: dom_node($dom_xpath, $dom_node);

        $version_node = $dom_xpath->query('version', $dom_node)->item(0);
        $version = new Version($version_node->nodeValue, $version_node->getAttribute('operator'));

        $dependency->set_version($version);
        return $dependency;
    }
}
?>