<?php
namespace core\lynx\package;

use common\libraries\Translation;
use common\libraries\Utilities;

/**
 * $Id: server.class.php 126 2009-11-09 13:11:05Z vanpouckesven $
 *
 * @package admin.lib.package_installer.dependency
 */
class ServerDependency extends Dependency
{
    const PROPERTY_VERSION = 'version';

    /**
     *
     * @var \core\lynx\package\Version
     */
    private $version;

    /**
     *
     * @return \core\lynx\package\Version
     */
    public function get_version()
    {
        return $this->version;
    }

    /**
     *
     * @param \core\lynx\package\Version $version
     */
    public function set_version($version)
    {
        $this->version = $version;
    }

    function check()
    {
        $parameters = array();
        $parameters['REQUIREMENT'] = $this->as_html();

        switch ($this->get_id())
        {
            case 'php' :
                $parameters['CURRENT'] = phpversion();
                $result = Version :: compare($this->get_version()->get_operator(), $this->get_version()->get_release(),
                        phpversion());
                break;
            default :
                $result = false;
        }

        if ($result)
        {
            $this->logger->add_message($parameters['REQUIREMENT']);
        }
        else
        {
            $this->logger->add_message(Translation :: get('CurrentServerDependency', $parameters));
        }

        return $result;
    }

    function as_html()
    {
        $parameters = array();
        $parameters['ID'] = $this->get_id();
        $parameters['OPERATOR'] = $this->get_version()->get_operator_name();
        $parameters['VERSION'] = $this->get_version()->get_release();

        return Translation :: get('ServerDependency', $parameters);
    }

    static function dom_node($dom_xpath, $dom_node)
    {
        $dependency = parent :: dom_node($dom_xpath, $dom_node);

        $version_node = $dom_xpath->query('version', $dom_node)->item(0);
        $version = new Version($version_node->nodeValue, $version_node->getAttribute('operator'));

        $dependency->set_version($version);
        return $dependency;
    }
}
?>