<?php
namespace core\lynx;

use core\lynx\package\DependencyVerifier;
use core\lynx\package\Package;
use common\libraries\MessageLogger;
use common\libraries\Theme;
use common\libraries\Translation;
use common\libraries\Utilities;

/**
 * Abstract class that describes an action for a package.
 * Makes use of the message logger to log messages.
 *
 * @author Sven Vanpoucke
 */
abstract class Action extends MessageLogger
{
    
    private $package;

    /**
     * Constructor Initializes the source action
     *
     * @param $source_type String           
     */
    function __construct($context)
    {
        parent :: __construct();
        $this->package = Package :: get($context);
    }

    /**
     * Returns the context
     *
     * @return string
     */
    function get_context()
    {
        return $this->package->get_context();
    }

    function get_package()
    {
        return $this->package;
    }

    /**
     * Sets the action as failed for a given block with a given message
     *
     * @param $type String           
     * @param $error_message String           
     *
     * @return false
     */
    function action_failed($title, $image, $error_message = null)
    {
        $this->process_result($title, $image, $error_message, self :: TYPE_ERROR);
        return false;
    }

    /**
     * Sets the action for a given block as success with a given message
     *
     * @param $type String           
     * @param $message String           
     *
     * @return true
     */
    function action_successful($title, $image, $message = null)
    {
        $this->process_result($title, $image, $message);
        return true;
    }

    /**
     * Processes a result for a given block
     *
     * @param $type String           
     */
    function process_result($title, $image, $final_message = null, $final_message_type = self :: TYPE_CONFIRM)
    {
        if ($final_message)
        {
            $this->add_message($final_message, $final_message_type);
        }
        
        $html[] = '<div class="content_object" style="padding: 15px 15px 15px 76px; background-image: url(' . $image . ');">';
        $html[] = '<div class="title">' . $title . '</div>';
        $html[] = '<div class="description">';
        $html[] = $this->render();
        $html[] = '</div>';
        $html[] = '</div>';
        
        echo implode("\n", $html);
        
        flush();
    }
}
?>