<?php
namespace core\lynx\remote;

use core\lynx\PackageList;
use core\lynx\package\Package;
use core\lynx\manager\PackageTypeMenu;
use core\lynx\manager\RegistrationTable;

use common\libraries\CommonDataManager;
use common\libraries\Toolbar;
use common\libraries\Registration;
use common\libraries\Display;
use common\libraries\DataClassCountParameters;
use common\libraries\SortableTableFromArray;
use common\libraries\DynamicContentTab;
use common\libraries\DynamicTabsRenderer;
use common\libraries\NewObjectTableSupport;
use common\libraries\PatternMatchCondition;
use common\libraries\Utilities;
use common\libraries\Translation;
use common\libraries\Path;
use common\libraries\ActionBarRenderer;
use common\libraries\ToolbarItem;
use common\libraries\Theme;
use common\libraries\Request;
use common\libraries\ActionBarSearchForm;
use common\libraries\DynamicVisualTabsRenderer;
use common\libraries\DynamicVisualTab;
use common\libraries\EqualityCondition;
use common\libraries\AndCondition;

class BrowserComponent extends Manager implements NewObjectTableSupport
{

    private $action_bar;

    private $current_type;
    const STATUS_INSTALLED = 1;
    const STATUS_AVAILABLE = 2;

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        $this->action_bar = $this->get_action_bar();

        $this->current_type = Request :: get(Manager :: PARAM_REGISTRATION_TYPE);
        $this->current_type = $this->current_type ? $this->current_type : 'application';

        $this->set_parameter(Manager :: PARAM_REGISTRATION_TYPE, $this->current_type);

        $menu = new PackageTypeMenu($this, $this->current_type,
                $this->get_url(array(Manager :: PARAM_REGISTRATION_TYPE => '__type__')));

        $this->display_header();

        echo $this->action_bar->as_html();

        echo '<div style="float: left; width: 17%;">';
        echo $menu->render_as_tree();
        echo '</div>';
        echo '<div style="float: right; width: 82%;">';

        echo $this->get_content();

        echo '<div class="clear">&nbsp;</div>';
        echo '</div>';

        $this->display_footer();
    }

    function get_content()
    {
        $tabs = new DynamicTabsRenderer(Utilities :: get_classname_from_object($this, true));

        $count = CommonDataManager :: count(Registration :: class_name(),
                new DataClassCountParameters($this->get_object_table_condition()));

        if ($count > 0)
        {
            $registration_table = new RegistrationTable($this);
            $tabs->add_tab(
                    new DynamicContentTab(self :: STATUS_INSTALLED, Translation :: get('InstalledPackages'),
                            Theme :: get_image_path() . 'status/' . self :: STATUS_INSTALLED . '.png',
                            $registration_table->as_html()));
        }

        $packages = PackageList :: get(false)->get_all_packages();

        if (count($packages[$this->get_type()]) > 0)
        {
            $tabs->add_tab(
                    new DynamicContentTab(self :: STATUS_AVAILABLE, Translation :: get('AvailablePackages'),
                            Theme :: get_image_path() . 'status/' . self :: STATUS_AVAILABLE . '.png',
                            $this->get_available_packages_table()));
        }

        if ($tabs->size() > 0)
        {
            return $tabs->render();
        }
        else
        {
            return Display :: normal_message(Translation :: get('NoPackagesAvailableInContextGetSomeNow'), true);
        }
    }

    function get_available_packages_table()
    {
        $packages = PackageList :: get(false)->get_all_packages();

        $table_data = array();

        foreach ($packages[$this->current_type] as $package)
        {
            $package_info = Package :: get($package);

            $toolbar = new Toolbar();
            $toolbar->add_item(
                    new ToolbarItem(Translation :: get('ViewPackageDetails'),
                            Theme :: get_common_image_path() . 'action_details.png',
                            $this->get_url(
                                    array(self :: PARAM_ACTION => self :: ACTION_VIEW,
                                            self :: PARAM_CONTEXT => $package_info->get_context())),
                            ToolbarItem :: DISPLAY_ICON));
            $toolbar->add_item(
                    new ToolbarItem(Translation :: get('Install'), Theme :: get_image_path() . 'action_install.png',
                            $this->get_url(
                                    array(self :: PARAM_ACTION => self :: ACTION_INSTALL,
                                            self :: PARAM_CONTEXT => $package_info->get_context())),
                            ToolbarItem :: DISPLAY_ICON));

            $row = array();
            $row[] = Translation :: get('TypeName', null, $package);
            $row[] = $toolbar->as_html();

            $table_data[] = $row;
        }

        $table = new SortableTableFromArray($table_data, 0);
        $table->set_additional_parameters($this->get_parameters());
        $table->set_header(0, Translation :: get('Package'));
        $table->set_header(1, '', false);
        return $table->as_html();
    }

    function get_object_table_condition($object_table_class_name)
    {
        // $query = $this->action_bar->get_query();
        $conditions = array();
        $conditions[] = new EqualityCondition(Registration :: PROPERTY_TYPE, $this->get_type());

        // if (isset($query) && $query != '')
        // {
        // $conditions[] = new PatternMatchCondition(Registration :: PROPERTY_NAME, '*' . $query . '*');
        // }

        return new AndCondition($conditions);
    }

    function get_action_bar()
    {
        $action_bar = new ActionBarRenderer(ActionBarRenderer :: TYPE_HORIZONTAL);
        // $action_bar->set_search_url($this->get_url());

        // $action_bar->add_common_action(
        // new ToolbarItem(Translation :: get('InstallLocal'),
        // Theme :: get_image_path() . 'action_install_local.png',
        // $this->get_url(array(Manager :: PARAM_ACTION => Manager :: ACTION_LOCAL_PACKAGE)),
        // ToolbarItem :: DISPLAY_ICON_AND_LABEL));
        // $action_bar->add_common_action(
        // new ToolbarItem(Translation :: get('InstallRemote'),
        // Theme :: get_image_path() . 'action_install_remote.png',
        // $this->get_url(array(Manager :: PARAM_ACTION => Manager :: ACTION_REMOTE_PACKAGE)),
        // ToolbarItem :: DISPLAY_ICON_AND_LABEL));

        return $action_bar;
    }

    function get_type()
    {
        return $this->current_type;
    }
}
?>