<?php

namespace group;

use rights\PlatformGroupEntity;

use rights\UserEntity;

use common\libraries\Request;

use common\libraries\PatternMatchCondition;
use common\libraries\EqualityCondition;
use common\libraries\InCondition;
use common\libraries\AndCondition;
use common\libraries\ObjectTableOrder;

use common\libraries\AdvancedElementFinderElement;
use common\libraries\CommonAjaxGroupsFeed;
use common\libraries\OrCondition;

/**
 * Feed to return the platform groups
 *
 * @author Sven Vanpoucke
 * @package application.weblcms
 */
class GroupAjaxPlatformGroupsFeed extends CommonAjaxGroupsFeed
{
    /**
     * The length for the filter prefix to remove
     */
    const FILTER_PREFIX_LENGTH = 2;

    const PARAM_GROUP = 'group';
    const PARAM_USER = 'user';

    function required_parameters()
    {
        return array();
    }

    /**
     * Returns all the groups for this feed
     * @return ResultSet
     */
    function retrieve_groups()
    {
        // Set the conditions for the search query
        $search_query = Request :: post(self :: PARAM_SEARCH_QUERY);
        if ($search_query && $search_query != '')
        {
            $q = '*' . $search_query . '*';
          	$name_conditions[] = new PatternMatchCondition(Group :: PROPERTY_NAME, $q);
            $name_conditions[] = new PatternMatchCondition(Group :: PROPERTY_CODE, $q);
            $conditions[] = new OrCondition($name_conditions);
        }

        $filter_id = $this->get_filter();

        if ($filter_id)
        {
            $conditions[] = new EqualityCondition(Group :: PROPERTY_PARENT, $filter_id);
        }
        else
        {
            $conditions[] = new EqualityCondition(Group :: PROPERTY_PARENT, 0);
        }

        // Combine the conditions
        $count = count($conditions);
        if ($count > 1)
        {
            $condition = new AndCondition($conditions);
        }

        if ($count == 1)
        {
            $condition = $conditions[0];
        }

        return GroupDataManager :: get_instance()->retrieve_groups($condition, null, null, array(
                new ObjectTableOrder(Group :: PROPERTY_NAME)));
    }

    /**
     * Retrieves all the users for the selected group
     */
    function get_user_ids()
    {
       $filter_id = $this->get_filter();

        if (! $filter_id)
        {
            return;
        }

        $condition = new EqualityCondition(GroupRelUser :: PROPERTY_GROUP_ID, $filter_id);
        $relations = GroupDataManager :: get_instance()->retrieve_group_rel_users($condition);

        $user_ids = array();

        while ($relation = $relations->next_result())
        {
            $user_ids[] = $relation->get_user_id();
        }

        return $user_ids;
    }

    /**
     * Returns the element for a specific group
     * @return AdvancedElementFinderElement
     */
    function get_group_element($group)
    {
        return new AdvancedElementFinderElement(
            self :: PARAM_GROUP . '_' . $group->get_id(), 'type type_group', $group->get_name(
        ), $group->get_code(), AdvancedElementFinderElement :: TYPE_SELECTABLE_AND_FILTER);
    }

    /**
     * Returns the element for a specific user
     * @return AdvancedElementFinderElement
     */
    function get_user_element($user)
    {
        return new AdvancedElementFinderElement(
            self :: PARAM_USER . '_' . $user->get_id(), 'type type_user', $user->get_fullname(
        ), $user->get_official_code());
    }

    /**
     * Returns the id of the selected filter
     */
    protected function get_filter()
    {
	$filter = Request :: post(self :: PARAM_FILTER);
	return substr($filter, static :: FILTER_PREFIX_LENGTH);
    }

}

?>