<?php
namespace help;

use common\libraries\Display;
use common\libraries\Application;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\Request;
use common\libraries\AdministrationComponent;
use common\libraries\DelegateComponent;
use common\libraries\Breadcrumb;

use common\extensions\rights_editor_manager\RightsEditorManager;

/**
 * $Id: deleter.class.php 224 2009-11-13 14:40:30Z kariboe $
 * @package group.lib.group_manager.component
 */

class HelpManagerRightsEditorComponent extends HelpManager implements AdministrationComponent, DelegateComponent
{

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        $help_ids = Request :: get(HelpManager :: PARAM_HELP_ITEM);

        if (! is_array($help_ids))
        {
            $help_ids = array($help_ids);
        }

        $locations = array();

        foreach ($help_ids as $help_id)
        {
            $locations[] = HelpRights :: get_location_by_identifier_from_help_subtree($help_id);
        }

        if ($this->get_user()->is_platform_admin())
        {
            $manager = new RightsEditorManager($this, $locations);

            $manager->exclude_users(array($this->get_user_id()));
            $manager->run();
        }
        else
        {
            $this->display_header();
            Display :: error_message(Translation :: get('NotAllowed', null, Utilities :: COMMON_LIBRARIES));
            $this->display_footer();
            exit();
        }
    }

    function get_available_rights()
    {
        $array = HelpRights :: get_available_rights();
        return $array;
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add(new Breadcrumb($this->get_url(array(
                Application :: PARAM_ACTION => HelpManager :: ACTION_BROWSE_HELP_ITEMS)), Translation :: get('HelpManagerBrowserComponent')));
        $breadcrumbtrail->add_help('help_updater');
    }

    function get_additional_parameters()
    {
        return array(HelpManager :: PARAM_HELP_ITEM);
    }
}
?>