<?php
namespace home;

use common\libraries\Utilities;
use common\libraries\Session;
use common\libraries\Block;
use common\libraries\Authentication;
use common\libraries\PlatformSetting;
use common\libraries\Translation;
use common\libraries\AjaxManager;
use common\libraries\JsonAjaxResult;
use common\libraries\Request;

use user\UserDataManager;

/**
 *
 * @author Hans De Bisschop @dependency repository.content_object.assessment_multiple_choice_question;
 */
class HomeAjaxBlockAdd extends AjaxManager
{
    const PARAM_CONTEXT = 'block_context';
    const PARAM_COMPONENT = 'block_component';
    const PARAM_COLUMN = 'column';
    const PARAM_ORDER = 'order';

    const PROPERTY_BLOCK = 'block';

    /*
     * (non-PHPdoc) @see common\libraries.AjaxManager::required_parameters()
     */
    function required_parameters()
    {
        return array(self :: PARAM_CONTEXT, self :: PARAM_COMPONENT, self :: PARAM_COLUMN, self :: PARAM_ORDER);
    }

    function unserialize_jquery($jquery)
    {
        $block_data = explode('&', $jquery);
        $blocks = array();

        foreach ($block_data as $block)
        {
            $block_split = explode('=', $block);
            $blocks[] = $block_split[1];
        }

        return $blocks;
    }

    /*
     * (non-PHPdoc) @see common\libraries.AjaxManager::run()
     */
    function run()
    {
        $user_id = DataManager :: determine_user_id();

        if ($user_id === false)
        {
            JsonAjaxResult :: not_allowed();
        }

        $column_data = explode('_', $this->get_parameter(self :: PARAM_COLUMN));
        $blocks = $this->unserialize_jquery($this->get_parameter(self :: PARAM_ORDER));

        $block = new HomeBlock();
        $block->set_column($column_data[2]);
        $block->set_title(Translation :: get(Utilities :: underscores_to_camelcase($this->get_parameter(self :: PARAM_COMPONENT)), null, $this->get_parameter(self :: PARAM_CONTEXT)));
        $registration = DataManager :: retrieve_home_block_registration_by_context_and_block($this->get_parameter(self :: PARAM_CONTEXT), $this->get_parameter(self :: PARAM_COMPONENT));
        $block->set_registration_id($registration->get_id());
        $block->set_visibility('1');
        $block->set_user($user_id);
        $block->create();

        $user = UserDataManager :: get_instance()->retrieve_user(Session ::get_user_id());

        $renderer = HomeRenderer :: factory(HomeRenderer :: TYPE_DEFAULT, $user);
        $html = Block :: factory($renderer, $block)->as_html();

        $result = new JsonAjaxResult(200);
        $result->set_property(self :: PROPERTY_BLOCK, $html);
        $result->display();
    }
}
?>