<?php
namespace home;

use common\libraries\Translation;
use common\libraries\Theme;
use common\libraries\CoreApplication;
use common\libraries\StringUtilities;
use common\libraries\Block;
use common\libraries\Application;

use home\HomeManager;

use repository\RepositoryDataManager;
use repository\ContentObjectBlock;

/**
 * A "Static" block. I.e. a block that display the title and description of an object. Usefull to display free html
 * text.
 *
 * @copyright (c) 2011 University of Geneva
 * @license GNU General Public License - http://www.gnu.org/copyleft/gpl.html
 * @author laurent.opprecht@unige.ch
 * @package home.block
 */
class HomeBanner extends ContentObjectBlock
{

    /**
     * Returns the list of type names that this block can map to.
     *
     * @return array
     */
    static function get_supported_types()
    {
        $result = array();
        $result[] = \repository\content_object\announcement\Announcement :: get_type_name();
        $result[] = \repository\content_object\description\Description :: get_type_name();
        $result[] = \repository\content_object\story\Story :: get_type_name();
        $result[] = \repository\content_object\note\Note :: get_type_name();

        return $result;
    }

    function is_visible()
    {
        return true; // i.e.display on homepage when anonymous
    }

    function display_header()
    {

        $block_id = $this->get_block_info()->get_id();
        $icon_url = $this->get_icon();
        $widget_view_url = htmlspecialchars($this->get_block_widget_view_link($this->get_block_info()));

        $title = $this->display_title();
        if ($this->get_view() == self :: BLOCK_VIEW)
        { // i.e. in widget view it is the portal configuration that decides to show/hide
            $description_style = $this->get_block_info()->is_visible() ? '' : ' style="display: none"';
        }
        else
        {
            $description_style = '';
        }

        $html = array();
        $html[] = '<div class="portal_block portal_banner" id="portal_block_' . $block_id . '">';
        $html[] = $title;
        $html[] = '<div class="entry-content description"' . $description_style . '">';

        return implode("\n", $html);
    }

    function display_footer()
    {
        $html = array();

        $html[] = '<div style="clear: both;"></div>';
        $html[] = '</div>';
        $html[] = '</div>';

        return implode("\n", $html);
    }

    function display_title()
    {

        $title = htmlspecialchars($this->get_title());
        $actions = $this->display_actions();

        $html = array();
        $html[] = '<div class="title"><div style="float: left;" class="entry-title">' . $title . '</div>';
        $html[] = $actions;
        $html[] = '<div style="clear: both;"></div>';
        $html[] = '</div>';

        return implode("\n", $html);
    }

    function display_content()
    {
        return $this->get_object()->get_description();
    }

}

?>