<?php
namespace home;

use user\User;

use common\libraries\PlatformSetting;

use common\libraries\SubselectCondition;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use common\libraries\Block;
use common\libraries\Theme;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\WebApplication;
use common\libraries\Configuration;
use common\libraries\DataClassRetrieveParameters;

use DOMDocument;

/**
 * $Id: home_data_manager.class.php 157 2009-11-10 13:44:02Z vanpouckesven $
 *
 * @package home.lib This is a skeleton for a data manager for the Home application.
 * @author Hans De Bisschop
 * @author Dieter De Neef
 */
class DataManager extends \common\libraries\DataManager
{

    /**
     * Gets the type of DataManager to be instantiated
     *
     * @return string
     */
    static function get_type()
    {
        return 'doctrine';
    }

    static function determine_user_id()
    {
        $current_user_id = \common\libraries\Session :: get_user_id();
        $current_user = \user\DataManager :: retrieve(User :: class_name(), intval($current_user_id));

        $user_home_allowed = PlatformSetting :: get('allow_user_home', HomeManager :: APPLICATION_NAME);
        $general_mode = \common\libraries\Session :: retrieve(__NAMESPACE__ . '\general');

        if ($current_user instanceof User)
        {
            if ($general_mode && $current_user->is_platform_admin())
            {
                return 0;
            }
            elseif($user_home_allowed)
            {
                return $current_user->get_id();
            }
            elseif(!$user_home_allowed && $current_user->is_platform_admin())
            {
                return 0;
            }
            else
            {
                return false;
            }
        }
    }

    static function retrieve_block_properties($application, $component)
    {
        if (WebApplication :: is_application($application))
        {
            $path = dirname(__FILE__) . '/../../application/' . $application . '/php/block/' . $application . '_' . $component . '.xml';
        }
        else
        {
            $path = dirname(__FILE__) . '/../../' . $application . '/php/block/' . $application . '_' . $component . '.xml';
        }

        if (file_exists($path))
        {
            $doc = new DOMDocument();
            $doc->load($path);
            $object = $doc->getElementsByTagname('block')->item(0);
            $name = $object->getAttribute('name');
            $xml_properties = $doc->getElementsByTagname('property');
            foreach ($xml_properties as $index => $property)
            {
                $properties[$property->getAttribute('name')] = $property->getAttribute('default');
            }

            return $properties;
        }
        else
        {
            return null;
        }
    }

    static function create_block_properties($block)
    {
        $homeblockconfigs = self :: retrieve_block_properties($block->get_context(), $block->get_component());

        foreach ($homeblockconfigs as $variable => $value)
        {
            $homeblockconfig = new HomeBlockConfig($block->get_id());
            {
                $homeblockconfig->set_variable($variable);
                $homeblockconfig->set_value($value);

                if (! $homeblockconfig->create())
                {
                    return false;
                }
            }
        }

        return true;
    }

    static function get_platform_blocks()
    {
        $blocks = array();

        $registrations = self :: retrieves(HomeBlockRegistration :: class_name());

        while ($registration = $registrations->next_result())
        {
            $context = $registration->get_context();
            $block = $registration->get_block();

            $home_block = new HomeBlock();
            $home_block->set_registration_id($registration->get_id());

            $renderer = HomeRenderer :: factory(HomeRenderer :: TYPE_DEFAULT);
            $block_object = Block :: factory($renderer, $home_block);
            
            if(!$block_object->is_deletable())
            {
                continue;
            }

            $blocks[$context]['name'] = Translation :: get('TypeName', null, $context);
            $blocks[$context]['image'] = Theme :: get_image_path($context) . 'logo/16.png';
            $blocks[$context]['components'][] = array(Block :: BLOCK_PROPERTY_ID => $block,
                    Block :: BLOCK_PROPERTY_NAME => Translation :: get(Utilities :: underscores_to_camelcase($block), null, $context),
                    Block :: BLOCK_PROPERTY_IMAGE => Block :: get_image_path($context, $block));
        }

        return $blocks;
    }

    /**
     *
     * @param $context string
     * @param $block string
     * @return Ambigous <HomeBlockRegistration, null>
     */
    static function retrieve_home_block_registration_by_context_and_block($context, $block)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(HomeBlockRegistration :: PROPERTY_CONTEXT, $context);
        $conditions[] = new EqualityCondition(HomeBlockRegistration :: PROPERTY_BLOCK, $block);
        $condition = new AndCondition($conditions);

        return self :: retrieve(HomeBlockRegistration :: class_name(), new DataClassRetrieveParameters($condition));
    }

    static function retrieve_home_tab_blocks($home_tab)
    {
        $row_condition = new EqualityCondition(HomeRow :: PROPERTY_TAB, $home_tab->get_id());
        $column_condition = new SubselectCondition(HomeColumn :: PROPERTY_ROW, HomeRow :: PROPERTY_ID, HomeRow :: get_table_name(), $row_condition);
        $condition = new SubselectCondition(HomeBlock :: PROPERTY_COLUMN, HomeColumn :: PROPERTY_ID, HomeColumn :: get_table_name(), $column_condition);

        return self :: retrieves(HomeBlock :: class_name(), $condition);
    }

    static function truncate_home($user_id)
    {
        $condition = new EqualityCondition(HomeTab :: PROPERTY_USER, $user_id);
        $tabs = self :: retrieves(HomeTab :: class_name(), $condition);

        while ($tab = $tabs->next_result())
        {
            if (! $tab->delete())
            {
                return false;
            }
        }

        return true;
    }

    static function delete_home_block_configs($home_block)
    {
        $condition = new EqualityCondition(HomeBlockConfig :: PROPERTY_BLOCK_ID, $home_block->get_id());
        return self :: deletes(HomeBlockConfig :: class_name(), $condition);
    }
}
?>