<?php
namespace home;

use common\libraries\Mdb2ResultSet;
use common\libraries\InequalityCondition;
use common\libraries\EqualityCondition;
use common\libraries\AndCondition;
use common\libraries\Mdb2Database;
use common\libraries\ObjectTableOrder;

/**
 * This is a data manager that uses a database for storage. It was written for MySQL, but should be compatible with most
 * SQL flavors.
 *
 * @author Tim De Pauw
 * @author Bart Mollet
 */

class Mdb2DataManager extends Mdb2Database implements HomeDataManagerInterface
{

    function update_home_block($home_block)
    {
        $old_home_block = $this->retrieve_home_block($home_block->get_id());

        if ($old_home_block->get_column() !== $home_block->get_column())
        {
            $condition = new EqualityCondition(HomeBlock :: PROPERTY_COLUMN, $home_block->get_column());
            $sort = $this->retrieve_max_sort_value(HomeBlock :: get_table_name(), HomeBlock :: PROPERTY_SORT, $condition);
            $home_block->set_sort($sort + 1);
        }

        $condition = new EqualityCondition(HomeBlock :: PROPERTY_ID, $home_block->get_id());
        $succes = $this->update($home_block, $condition);

        if ($old_home_block->get_column() !== $home_block->get_column())
        {
            $query = 'UPDATE ' . $this->escape_table_name(HomeBlock :: get_table_name()) . ' SET ' . $this->escape_column_name(HomeBlock :: PROPERTY_SORT) . ' = ' . $this->escape_column_name(HomeBlock :: PROPERTY_SORT) . ' - 1 WHERE ' . $this->escape_column_name(HomeBlock :: PROPERTY_SORT) . ' > ' . $this->quote($old_home_block->get_sort()) . ' AND ' . $this->escape_column_name(HomeBlock :: PROPERTY_COLUMN) . ' = ' . $this->quote($old_home_block->get_column());

            $succes &= $this->exec($query);
        }

        return $succes;
    }

    function update_home_row($home_row)
    {
        $old_home_row = $this->retrieve_home_row($home_row->get_id());

        if ($old_home_row->get_tab() !== $home_row->get_tab())
        {
            $condition = new EqualityCondition(HomeRow :: PROPERTY_TAB, $home_row->get_tab());
            $sort = $this->retrieve_max_sort_value(HomeRow :: get_table_name(), HomeRow :: PROPERTY_SORT, $condition);
            $home_row->set_sort($sort + 1);
        }

        $condition = new EqualityCondition(HomeRow :: PROPERTY_ID, $home_row->get_id());
        $succes = $this->update($home_row, $condition);

        if ($old_home_row->get_tab() !== $home_row->get_tab())
        {
            $query = 'UPDATE ' . $this->escape_table_name(HomeRow :: get_table_name()) . ' SET ' . $this->escape_column_name(HomeRow :: PROPERTY_SORT) . ' = ' . $this->escape_column_name(HomeRow :: PROPERTY_SORT) . ' - 1 WHERE ' . $this->escape_column_name(HomeRow :: PROPERTY_SORT) . ' > ' . $this->quote($old_home_row->get_sort()) . ' AND ' . $this->escape_column_name(HomeRow :: PROPERTY_TAB) . ' = ' . $this->quote($old_home_row->get_tab());
            $succes &= $this->exec($query);
        }

        return $succes;
    }

    function update_home_column($home_column)
    {
        $old_home_column = $this->retrieve_home_column($home_column->get_id());

        if ($old_home_column->get_row() !== $home_column->get_row())
        {
            $condition = new EqualityCondition(HomeColumn :: PROPERTY_ROW, $home_column->get_row());
            $sort = $this->retrieve_max_sort_value(HomeColumn :: get_table_name(), HomeColumn :: PROPERTY_SORT, $condition);
            $home_column->set_sort($sort + 1);
        }

        $condition = new EqualityCondition(HomeColumn :: PROPERTY_ID, $home_column->get_id());
        $succes = $this->update($home_column, $condition);

        if ($old_home_column->get_row() !== $home_column->get_row())
        {
            $query = 'UPDATE ' . $this->escape_table_name(HomeColumn :: get_table_name()) . ' SET ' . $this->escape_column_name(HomeColumn :: PROPERTY_SORT) . ' = ' . $this->escape_column_name(HomeColumn :: PROPERTY_SORT) . ' - 1 WHERE ' . $this->escape_column_name(HomeColumn :: PROPERTY_SORT) . ' > ' . $this->quote($old_home_column->get_sort()) . ' AND ' . $this->escape_column_name(HomeColumn :: PROPERTY_ROW) . ' = ' . $this->quote($old_home_column->get_row());

            $succes &= $this->exec($query);
        }

        return $succes;
    }

    function retrieve_home_block_at_sort($parent, $sort, $direction)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(HomeBlock :: PROPERTY_COLUMN, $parent);

        if ($direction == 'up')
        {
            $conditions[] = new InequalityCondition(HomeBlock :: PROPERTY_SORT, InequalityCondition :: LESS_THAN, $sort);
            $order_direction = SORT_DESC;
        }
        elseif ($direction == 'down')
        {
            $conditions[] = new InequalityCondition(HomeBlock :: PROPERTY_SORT, InequalityCondition :: GREATER_THAN, $sort);
            $order_direction = SORT_ASC;
        }

        $condition = new AndCondition($conditions);

        return $this->retrieve_object(HomeBlock :: get_table_name(), $condition, array(
                new ObjectTableOrder(HomeBlock :: PROPERTY_SORT, $order_direction)), HomeBlock :: CLASS_NAME);
    }

    function retrieve_home_column_at_sort($parent, $sort, $direction)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(HomeColumn :: PROPERTY_ROW, $parent);

        if ($direction == 'up')
        {
            $conditions[] = new InequalityCondition(HomeColumn :: PROPERTY_SORT, InequalityCondition :: LESS_THAN, $sort);
            $order_direction = SORT_DESC;
        }
        elseif ($direction == 'down')
        {
            $conditions[] = new InequalityCondition(HomeColumn :: PROPERTY_SORT, InequalityCondition :: GREATER_THAN, $sort);
            $order_direction = SORT_ASC;
        }

        $condition = new AndCondition($conditions);

        return $this->retrieve_object(HomeColumn :: get_table_name(), $condition, array(
                new ObjectTableOrder(HomeColumn :: PROPERTY_SORT, $order_direction)), HomeColumn :: CLASS_NAME);
    }

    function retrieve_home_row_at_sort($parent, $sort, $direction)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(HomeRow :: PROPERTY_TAB, $parent);

        if ($direction == 'up')
        {
            $conditions[] = new InequalityCondition(HomeRow :: PROPERTY_SORT, InequalityCondition :: LESS_THAN, $sort);
            $order_direction = SORT_DESC;
        }
        elseif ($direction == 'down')
        {
            $conditions[] = new InequalityCondition(HomeRow :: PROPERTY_SORT, InequalityCondition :: GREATER_THAN, $sort);
            $order_direction = SORT_ASC;
        }

        $condition = new AndCondition($conditions);

        return $this->retrieve_object(HomeRow :: get_table_name(), $condition, array(
                new ObjectTableOrder(HomeRow :: PROPERTY_SORT, $order_direction)), HomeRow :: CLASS_NAME);
    }

    function retrieve_home_tab_at_sort($user, $sort, $direction)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(HomeTab :: PROPERTY_USER, $user);

        if ($direction == 'up')
        {
            $conditions[] = new InequalityCondition(HomeTab :: PROPERTY_SORT, InequalityCondition :: LESS_THAN, $sort);
            $order_direction = SORT_DESC;
        }
        elseif ($direction == 'down')
        {
            $conditions[] = new InequalityCondition(HomeTab :: PROPERTY_SORT, InequalityCondition :: GREATER_THAN, $sort);
            $order_direction = SORT_ASC;
        }

        $condition = new AndCondition($conditions);

        return $this->retrieve_object(HomeTab :: get_table_name(), $condition, array(
                new ObjectTableOrder(HomeTab :: PROPERTY_SORT, $order_direction)), HomeTab :: CLASS_NAME);
    }
}
?>