<?php
namespace home;

use common\libraries\Application;
use common\libraries\Block;
use common\libraries\DataClassRetrievesParameters;
use common\libraries\EqualityCondition;
use common\libraries\FormValidator;
use common\libraries\ObjectTableOrder;
use common\libraries\SubselectCondition;
use common\libraries\Translation;
use common\libraries\Utilities;

/**
 * $Id: home_block_form.class.php 227 2009-11-13 14:45:05Z kariboe $
 *
 * @package home.lib.forms
 */

class HomeBlockForm extends FormValidator
{

    const TYPE_CREATE = 1;
    const TYPE_EDIT = 2;
    const RESULT_SUCCESS = 'ObjectUpdated';
    const RESULT_ERROR = 'ObjectUpdateFailed';

    private $homeblock;
    private $form_type;

    function __construct($form_type, $homeblock, $action)
    {
        parent :: __construct('home_block', 'post', $action);

        $this->homeblock = $homeblock;
        $this->form_type = $form_type;
        if ($this->form_type == self :: TYPE_EDIT)
        {
            $this->build_editing_form();
        }
        elseif ($this->form_type == self :: TYPE_CREATE)
        {
            $this->build_creation_form();
        }

        $this->setDefaults();
    }

    function get_blocks_registrations()
    {
        $result = array();
        $registrations = DataManager :: retrieves(HomeBlockRegistration :: class_name());

        while ($registration = $registrations->next_result())
        {
            $context = $registration->get_context();
            $block = $registration->get_block();
            $name = Translation :: get('TypeName', null, $context) . ' - ' . Translation :: get(Utilities :: underscores_to_camelcase($block), null, $context);
            $result[$registration->get_id()] = $name;
        }
        return $result;
    }

    function build_basic_form()
    {
        $this->addElement('text', HomeBlock :: PROPERTY_TITLE, Translation :: get('HomeBlockTitle'), array(
                "size" => "50"));
        $this->addRule(HomeBlock :: PROPERTY_TITLE, Translation :: get('ThisFieldIsRequired', null, Utilities :: COMMON_LIBRARIES), 'required');

        /*
         * $this->addElement('select', HomeBlock :: PROPERTY_, Translation :: get('HomeBlockColumn'),
         * $this->get_columns()); $this->addRule(HomeBlock :: PROPERTY_COLUMN, Translation :: get('ThisFieldIsRequired',
         * null, Utilities :: COMMON_LIBRARIES), 'required');
         */

        $this->addElement('select', HomeBlock :: PROPERTY_COLUMN, Translation :: get('HomeBlockColumn'), $this->get_columns());
        $this->addRule(HomeBlock :: PROPERTY_COLUMN, Translation :: get('ThisFieldIsRequired', null, Utilities :: COMMON_LIBRARIES), 'required');

        $this->addElement('select', HomeBlock :: PROPERTY_REGISTRATION_ID, Translation :: get('HomeBlockComponent'), $this->get_blocks_registrations());
        $this->addRule(HomeBlock :: PROPERTY_REGISTRATION_ID, Translation :: get('ThisFieldIsRequired', null, Utilities :: COMMON_LIBRARIES), 'required');

        $this->addElement('hidden', HomeBlock :: PROPERTY_USER);

    }

    function build_editing_form()
    {
        $this->build_basic_form();
        $this->addElement('hidden', HomeBlock :: PROPERTY_ID);

        $buttons[] = $this->createElement('style_submit_button', 'submit', Translation :: get('Update', null, Utilities :: COMMON_LIBRARIES), array(
                'class' => 'positive update'));
        $buttons[] = $this->createElement('style_reset_button', 'reset', Translation :: get('Reset', null, Utilities :: COMMON_LIBRARIES), array(
                'class' => 'normal empty'));

        $this->addGroup($buttons, 'buttons', null, '&nbsp;', false);
    }

    function build_creation_form()
    {
        $this->build_basic_form();

        $buttons[] = $this->createElement('style_submit_button', 'submit', Translation :: get('Create', null, Utilities :: COMMON_LIBRARIES), array(
                'class' => 'positive'));
        $buttons[] = $this->createElement('style_reset_button', 'reset', Translation :: get('Reset', null, Utilities :: COMMON_LIBRARIES), array(
                'class' => 'normal empty'));

        $this->addGroup($buttons, 'buttons', null, '&nbsp;', false);
    }

    function update_object()
    {
        $homeblock = $this->homeblock;
        $values = $this->exportValues();

        $hdm = HomeDataManager :: get_instance();
        if ($homeblock->get_context() != $component[0] || $homeblock->get_component() != $component[1])
        {
            if (! $hdm->delete_home_block_configs($homeblock))
            {
                return false;
            }
            if (! $homeblock->create_initial_settings())
            {
                return false;
            }
        }

        $homeblock->set_title($values[HomeBlock :: PROPERTY_TITLE]);
        $homeblock->set_column($values[HomeBlock :: PROPERTY_COLUMN]);
        $homeblock->set_registration_id($values[HomeBlock :: PROPERTY_REGISTRATION_ID]);

        return $homeblock->update();
    }

    function create_object()
    {
        $homeblock = $this->homeblock;
        $values = $this->exportValues();

        $homeblock->set_title($values[HomeBlock :: PROPERTY_TITLE]);
        $homeblock->set_column($values[HomeBlock :: PROPERTY_COLUMN]);
        $homeblock->set_registration_id($values[HomeBlock :: PROPERTY_REGISTRATION_ID]);

        if (! $homeblock->create())
        {
            return false;
        }

        $success_config = HomeDataManager :: create_block_properties($homeblock);

        if (! $success_config)
        {
            return false;
        }

        return true;
    }

    function get_columns()
    {
        $user_id = $this->homeblock->get_user();
        $condition = new EqualityCondition(HomeColumn :: PROPERTY_USER, $user_id);
        $order_by = array();
        $order_by[] = new ObjectTableOrder(HomeColumn :: PROPERTY_SORT);

        $parameters = new DataClassRetrievesParameters($condition, null, null, $order_by);
        $columns = HomeDataManager :: retrieves(HomeColumn::class_name(), $parameters);
        $column_options = array();
        while ($column = $columns->next_result())
        {
            $condition = new EqualityCondition(HomeRow :: PROPERTY_ID, $column->get_row());
            $condition = new SubselectCondition(HomeTab :: PROPERTY_ID, HomeRow :: PROPERTY_TAB, HomeRow :: get_table_name(), $condition);
            $order_by = array();
            $order_by[] = new ObjectTableOrder(HomeTab :: PROPERTY_SORT);
            
            $parameters = new DataClassRetrievesParameters($condition, null, null, $order_by);

            $tab = HomeDataManager :: retrieves(HomeTab::class_name(), $parameters)->next_result();

            if ($tab)
                $name = Translation :: get('Tab') . ' ' . $tab->get_title() . ' :';

            $column_options[$column->get_id()] = $name . $column->get_title();
        }

        return $column_options;
    }

    /**
     * Sets default values. Traditionally, you will want to extend this method so it sets default for your learning
     * object type's additional properties.
     *
     * @param $defaults array Default values for this form's parameters.
     */
    function setDefaults($defaults = array ())
    {
        $homeblock = $this->homeblock;
        $defaults[HomeBlock :: PROPERTY_ID] = $homeblock->get_id();
        $defaults[HomeBlock :: PROPERTY_TITLE] = $homeblock->get_title();
        $defaults[HomeBlock :: PROPERTY_COLUMN] = $homeblock->get_column();
        $defaults[HomeBlock :: PROPERTY_REGISTRATION_ID] = $homeblock->get_registration();
        $defaults[HomeBlock :: PROPERTY_USER] = $homeblock->get_user();
        parent :: setDefaults($defaults);
    }
}
?>