<?php

namespace home;

use common\libraries\Session;
use common\libraries\BasicApplication;
use common\libraries\Translation;
use common\libraries\EqualityCondition;
use common\libraries\AndCondition;
use common\libraries\Theme;
use common\libraries\Block;
use common\libraries\PlatformSetting;
use common\libraries\Path;
use user\User;
use common\libraries\Request;
use common\libraries\Display;
use common\libraries\Application;
use DOMDocument;
use common\libraries\StringUtilities;
use common\libraries\Utilities;
use user\UserDataManager;

/**
 * Input: user security token
 * Output: Open Social module defininition for home portal.
 *
 */
class MyChamiloOsHomeRenderer extends HomeRenderer
{

    private $user_id = null;

    /**
     * Returns the user id if the security token is valid or 0.
     *
     * @return int
     */
    function get_user_id()
    {
        if (! is_null($this->user_id))
        {
            return $this->user_id;
        }
        $security_token = $this->get_security_token();
        $user = UserDataManager :: get_instance()->retrieve_user_by_security_token($security_token);
        $this->user_id = $user ? $user->get_id() : 0;
        return $this->user_id;
    }

    /**
     * Returns the security token passed in parameters
     * @return type
     */
    function get_security_token()
    {
        return Request :: get(self :: PARAM_SECURITY_TOKEN, 'notoken');
    }

    function get_sitename()
    {
        return PlatformSetting :: get('site_name');
    }

    function get_administrator_email()
    {
        return PlatformSetting :: get('administrator_email');
    }

    function get_portal_home()
    {
        return PlatformSetting :: get('portal_home');
    }

    private $_blocks = null;

    /**
     * Returns the list of blocks that is displayed by home.
     * @return array
     */
    function get_blocks()
    {
        $titles_count = array();
        if (! is_null($this->_blocks))
        {
            return $this->_blocks;
        }
        $result = array();

        $current_tab = $this->get_current_tab();
        $user_home_allowed = PlatformSetting :: get('allow_user_home', HomeManager :: APPLICATION_NAME);
        $user_id = $user_home_allowed ? $this->get_user_id() : 0;
        $user_id = $user_id ? $user_id : 0;

        $tabs_condition = new EqualityCondition(HomeTab :: PROPERTY_USER, $user_id);
        $tabs = DataManager :: retrieves(HomeTab :: class_name(), $tabs_condition);

        while ($tab = $tabs->next_result())
        {
            $rows_conditions = array();
            $rows_conditions[] = new EqualityCondition(HomeRow :: PROPERTY_TAB, $tab->get_id());
            $rows_conditions[] = new EqualityCondition(HomeRow :: PROPERTY_USER, $user_id);
            $rows_condition = new AndCondition($rows_conditions);
            $rows = DataManager :: retrieves(HomeRow :: class_name(), $rows_condition);

            while ($row = $rows->next_result())
            {
                $rows_position = $rows->position();

                $conditions = array();
                $conditions[] = new EqualityCondition(HomeColumn :: PROPERTY_ROW, $row->get_id());
                $conditions[] = new EqualityCondition(HomeColumn :: PROPERTY_USER, $user_id);
                $condition = new AndCondition($conditions);

                // Get the user or platform columns
                $columns = DataManager :: retrieves(HomeColumn :: class_name(), $condition);

                while ($column = $columns->next_result())
                {
                    $conditions = array();
                    $conditions[] = new EqualityCondition(HomeBlock :: PROPERTY_COLUMN, $column->get_id());
                    $conditions[] = new EqualityCondition(HomeBlock :: PROPERTY_USER, $user_id);
                    $condition = new AndCondition($conditions);

                    $blocks = DataManager :: retrieves(HomeBlock :: class_name(), $condition);

                    while ($block = $blocks->next_result())
                    {
                        $block_component = Block :: factory($this, $block);
                        $title = $tab->get_title() . ' - ' . $block_component->get_title();
                        $id = $block->get_id();
                        if ($block_component->is_visible())
                        {
                            if (isset($titles_count[$title]))
                            {
                                $count = $titles_count[$title] += 1;
                                $title .= " ($count)";
                            }
                            else
                            {
                                $titles_count[$title] = 1;
                            }
                            $result[$id] = $title;
                        }
                    }
                }
            }
        }

        return $this->_blocks = $result;
    }

    function get_widget_view_url($id)
    {
        $base_url = Path :: get(WEB_PATH);
        if ($id)
        {
            return $base_url . '/index.php?view_type=widget&' . HomeManager :: PARAM_WIDGET_ID . '=' . $id;
        }
        else
        {
            return $base_url . '/index.php?view_type=widget';
        }
    }

    /**
     *
     * Create user Preferences
     *
     * name  Required "symbolic" name of the user preference; displayed to the user during editing if no display_name is defined. Must contain only letters, number and underscores, i.e. the regular expression ^[a-zA-Z0-9_]+$. Must be unique.
     * display_name  Optional string to display alongside the user preferences in the edit window. Must be unique.
     * urlparam  Optional string to pass as the parameter name for content type="url".
     * datatype  Optional string that indicates the data type of this attribute. Can be string, bool, enum, hidden (a string that is not visible or user editable), or list (dynamic array generated from user input). The default is string.
     * required  Optional boolean argument (true or false) indicating whether this user preference is required. The default is false.
     * default_value  Optional string that indicates a user preference's default value.
     *
     * For example, this <UserPref> lets users set the level of difficulty for a game. Each value that will appear in the menu (Easy, Medium, and Hard) is defined using an <EnumValue> tag.
     *
     * <UserPref name="difficulty"
     * display_name="Difficulty"
     * datatype="enum"
     * default_value="4">
     * <EnumValue value="3" display_value="Easy"/>
     * <EnumValue value="4" display_value="Medium"/>
     * <EnumValue value="5" display_value="Hard"/>
     * </UserPref>
     *
     * The following table lists the <EnumValue> attributes:
     *
     * value           Required string that provides a unique value. This value is displayed in the menu in the user preferences edit box unless a display_value is provided.
     * display_value   Optional string that is displayed in the menu in the user preferences edit box. If you do not specify a display_value, the value is displayed in the user interface.
     *
     * @param string $name
     * @param string $display_name
     * @param string $urlparam
     * @param string $datatype
     * @param string $required
     * @param string $default_value
     * @param array $enums
     * @return string
     */
    function create_user_pref($name, $display_name = '', $urlparam = '', $datatype = '', $required = false, $default_value = null, $enums = array())
    {
        $required = $required ? 'true' : 'false';

        $result = array();
        $result[] = '<UserPref';
        $result[] = ' name="' . $name . '" ';
        $result[] = $display_name ? ' display_name="' . $display_name . '" ' : '';
        $result[] = $urlparam ? ' urlparam="' . $urlparam . '" ' : '';
        $result[] = $datatype ? ' datatype="' . $datatype . '" ' : '';
        $result[] = $required ? ' required="' . $required . '" ' : '';
        $result[] = ! is_null($default_value) ? ' default_value="' . $default_value . '" ' : '';
        $result[] = '>';
        foreach ($enums as $value => $display_name)
        {
            $result[] = '<EnumValue';
            $result[] = ' value="' . $value . '" ';
            $result[] = ' display_value="' . $display_name . '" ';
            $result[] = '/>';
        }
        $result[] = '</UserPref>';

        return implode('', $result);
    }

    function get_user_prefs()
    {
        $result = array();
        $name = 'blockid';
        $display_name = Translation :: get('block');
        $datatype = 'enum';
        $urlparam = $name;
        $required = true;
        $blocks = $this->get_blocks();
        $default_value = reset(array_keys($blocks));
        $result[] = $this->create_user_pref($name, $display_name, $urlparam, $datatype, $required, $default_value, $blocks);
        return implode("\n", $result);
    }

    /**
     * Render an error module. That is one that does nothing but to display a message.
     */
    function render_error($message = '')
    {
        $title = Translation :: get('Error');
        $message = $message ? $message : Translation :: get('Unavailable');
        $title_url = Path :: get(WEB_PATH);
        $icon = Theme :: get_common_image_path() . 'logo_header.png';
        $email = $this->get_administrator_email();

        $result = <<<EOT
<?xml version="1.0" encoding="UTF-8" ?>
<Module>
    <ModulePrefs
        title="$title"
        title_url="$title_url"
        height="200"
        author="Chamilo"
        author_email="$email"
        description=""
        screenshot="$icon"
        thumbnail="$icon"
        />
    <Content type="html">
        $message
</Content>
</Module>
EOT;
        header("content-type:text/xml;charset=utf-8");
        echo $result;
        die();
    }

    /**
     * Render a meta widget. That is one that can display any block based on it's id.
     */
    function render_meta_widget()
    {
        $blocks = $this->get_blocks();

        $title = $this->get_sitename();
        $email = $this->get_administrator_email();
        $title_url = Path :: get(WEB_PATH);
        $icon = Theme :: get_common_image_path() . 'logo_header.png';
        $widget_view_url = $this->get_widget_view_url();
        $user_prefs = $this->get_user_prefs();
        $security_token = $this->get_user_id() ? $this->get_security_token() : 0;
        $height = 250;

        $blocks_javascript = '';
        $blocks = $this->get_blocks();
        foreach ($blocks as $key => $value)
        {
            $value = str_replace("'", "\\'", $value);
            $blocks_javascript .= "blocks[{$key}] = '{$value}';\n";
        }

        $result = <<<EOT
<?xml version="1.0" encoding="UTF-8" ?>
<Module>
    <ModulePrefs
        title="$title"
        title_url="$title_url"
        height="$height"
        author="Chamilo"
        author_email="$email"
        description="Chamilo meta widget. Used to display Chamilo's blocks."
        screenshot="$icon"
        thumbnail="$icon"
        >
            <Require feature="settitle"/>
        </ModulePrefs>
    $user_prefs

    <Content view="home,canvas,profile" type="html"  >
        <![CDATA[
        <script type="text/javascript">
            var blocks = new Array();
            $blocks_javascript

            var prefs = new gadgets.Prefs();
            var id = prefs.getString("blockid");
            var title = blocks[id];
            p = unescape("&#039;");
            title = title.replace(p, "'");
            gadgets.window.setTitle(title);
        </script>
        <iframe src="{$widget_view_url}&amp;widget_id=__UP_blockid__&amp;sid=$security_token" width="100%" height="100%" frameborder="0"></iframe>
        ]]>
    </Content>
</Module>
EOT;
        header("content-type:text/xml;charset=utf-8");
        echo $result;
        die();
    }

    function render()
    {
        $this->render_meta_widget();
    }

    /**
     * Displays an error page.
     * @param string $message The message.
     */
    function display_error_page($message)
    {
        Display :: small_header();
        Display :: error_message($message);
        Display :: small_footer();
    }

}

?>