<?php
namespace home;

use common\libraries\BasicApplication;
use common\libraries\Translation;
use common\libraries\EqualityCondition;
use common\libraries\AndCondition;
use common\libraries\Theme;
use common\libraries\Block;
use common\libraries\PlatformSetting;
use common\libraries\Path;
use common\libraries\Request;
use common\libraries\Display;
use common\libraries\Application;
use common\libraries\Session;
use common\libraries\Authentication;

use user\User;
use user\UserDataManager;

/**
 * Dislay a block in Widget view. That to be displayed in a third part application/portal. I.e. displays only the
 * widget.
 */
class WidgetHomeRenderer extends HomeRenderer
{

    function get_user_id()
    {
        $user = $this->get_user();
        return $user ? $user->get_id() : User :: ANONYMOUS_ID;
    }

    private $user = false;

    function get_user()
    {
        if ($this->user !== false)
        {
            return $this->user;
        }
        $security_token = $this->get_security_token();
        $user = UserDataManager :: get_instance()->retrieve_user_by_security_token($security_token);
        // $user = $user ? $user : UserDataManager :: get_instance()->retrieve_user(User::ANONYMOUS_ID);
        $this->user = $user ? $user : null;
        return $this->user;
    }

    function get_security_token()
    {
        return Request :: get(self :: PARAM_SECURITY_TOKEN, 'notoken');
    }

    /**
     *
     * @return HomeBlock null
     */
    function get_home_block($id)
    {
        return DataManager :: retrieve(HomeBlock :: class_name(), $id);
    }

    /**
     *
     * @return Block null
     */
    function get_block(BlockInfo $block_info)
    {
        if (empty($block_info))
        {
            return null;
        }
        // i.e. user setttings can be overwritten by passing them in the url.
        $items = $block_info->get_configuration();
        // foreach($items as $key=>$value){
        // $items[$key] = Request::get($key, $value);
        // }
        $result = $block_info ? Block :: factory($this, $block_info, $configuration) : null;
        return $result;
    }

    function is_authorized($block_info)
    {
        return $block_info->get_user() == 0 || $block_info->get_user() == $this->get_user_id();
    }

    /**
     *
     * @return string
     */
    function render()
    {
        $id = Request :: get(HomeRenderer :: PARAM_WIDGET_ID);
        if (empty($id))
        {
            $this->display_error_page(htmlentities(Translation :: get('NoHomeBlockSelected')));
            return;
        }

        $block_info = $this->get_home_block($id);
        if (empty($block_info))
        {
            $this->display_error_page(htmlentities(Translation :: get('InvalidBlockId')));
            return;
        }

        if (! $this->is_authorized($block_info))
        {
            $this->display_error_page(htmlentities(Translation :: get('NotAuthorized')));
            return;
        }

        $block = $this->get_block($block_info);
        $this->display_block($block);
    }

    function retrieve_home_block($id)
    {
        return DataManager :: retrieve(HomeBlock :: class_name(), $id);
    }

    function get_inline_css()
    {
        return <<<EOT
        body {
            background-color:white;
            padding:0px;
        }
        .portal_block{
            padding:0px !important;
            margin:0px !important;
            background:none !important;
        }
        .title{
            display: none !important;
        }

EOT;
    }

    /**
     * Displays an error page.
     *
     * @param $message string The message.
     */
    function display_error_page($message)
    {
        Display :: small_header();
        Display :: error_message($message);
        Display :: small_footer();
    }

    function display_login_page()
    {
        Display :: small_header();
        $_SESSION['request_uri'] = $_SERVER['REQUEST_URI']; // required to avoid being redirected to home page
        echo Display :: display_login_form();
        Display :: small_footer();
        return;
    }

    /**
     *
     * @param $block Block
     */
    function display_block($block)
    {
        // $url = $this->get_url(array(Application :: PARAM_ACTION => HomeManager :: ACTION_CONFIGURE_HOME, HomeRenderer
        // :: PARAM_WIDGET_ID => $id));
        // $icon = $block->get_icon();

        Display :: small_header($block->get_title(), $this->get_inline_css());
        echo $block->is_visible() ? $block->as_html(Block :: WIDGET_VIEW, $this->get_user()) : '';
        Display :: small_footer();
    }

    function get_additional_parameters()
    {
        return array(HomeRenderer :: PARAM_WIDGET_ID);
    }
}

?>