<?php
namespace install;

class CommandLineInstaller implements InstallerObserver
{

    const DEFAULT_INSTALL_VALUES_FILE = 'command_line_configuration.dist.php';

    private $config_file;

    private $installer;

    function __construct($config_file)
    {
        $this->config_file = $config_file;
    }

    public function run()
    {
        $installer_config = new InstallerConfig();
        $default_config_file = __DIR__ . '/../' . self :: DEFAULT_INSTALL_VALUES_FILE;
        $installer_config->load_config_file($default_config_file);
        $installer_config->load_config_file($this->config_file);

        $installer_factory = new Factory();
        $this->installer = $installer_factory->build_installer($installer_config);

        $this->installer->add_observer($this);
        $this->installer->perform_install();
    }

    private function check_result(InstallerStepResult $result)
    {
        if ($result->get_success())
        {
            return "Ok";
        }

        $reason = implode(", ", $result->get_messages());
        return "Ko ({$reason})";
    }

    function before_install()
    {
        echo "install started ...\n\n";
    }

    function before_preprod()
    {
        echo "\tPRE-PRODUCTION\n";
    }

    function preprod_db_created(InstallerStepResult $result)
    {
        echo "\t\t DB created ... " . $this->check_result($result) . "\n";
    }

    function preprod_config_file_written(InstallerStepResult $result)
    {
        echo "\t\t Config File Written ... " . $this->check_result($result) . "\n";
    }

    function after_preprod()
    {
        echo "\n";
    }

    function before_core_applications_install()
    {
        echo "\tCORE APPLICATION INSTALLATION\n";
    }

    function after_core_applications_install()
    {
        echo "\n";
    }

    function before_core_applications_configuration()
    {
        echo "\tCORE APPLICATION CONFIGURATION\n";
    }

    function after_core_applications_configuration()
    {
        echo "\n";
    }

    function before_optional_applications_install()
    {
        echo "\tOPTIONAL APPLICATION INSTALLATION\n";
    }

    function after_optional_application_install()
    {
        echo "\n";
    }

    function before_optional_applications_configuration()
    {
        echo "\tOPTIONAL APPLICATION CONFIGURATION\n";
    }

    function after_optional_applications_configuration()
    {
        echo "\n";
    }

    function after_optional_applications_install()
    {
        echo "\n";
    }

    function before_application_install($application)
    {
        echo "\t\t Installing application {$application} ... ";
    }

    function after_application_install(InstallerStepResult $result)
    {
        echo $this->check_result($result) . "\n";
    }

    function before_content_objects_install()
    {
        echo "\tCONTENT OBJECTS INSTALLATION\n";
    }

    function before_content_object_install($content_object)
    {
        echo "\t\t Installing content object {$content_object} ... ";
    }

    function after_content_object_install(InstallerStepResult $result)
    {
        echo $this->check_result($result) . "\n";
    }

    function after_content_objects_install()
    {
        echo "\n";
    }

    function before_external_repository_managers_install()
    {
        echo "\tEXTERNAL REPOSITORY MANAGERS INSTALLATION\n";
    }

    function before_external_repository_manager_install($content_object)
    {
        echo "\t\t Installing content object {$content_object} ... ";
    }

    function after_external_repository_manager_install(InstallerStepResult $result)
    {
        echo $this->check_result($result) . "\n";
    }

    function after_external_repository_managers_install()
    {
        echo "\n";
    }

    function before_video_conferencing_managers_install()
    {
        echo "\tVIDEO CONFERENCING MANAGERS INSTALLATION\n";
    }

    function before_video_conferencing_manager_install($content_object)
    {
        echo "\t\t Installing content object {$content_object} ... ";
    }

    function after_video_conferencing_manager_install(InstallerStepResult $result)
    {
        echo $this->check_result($result) . "\n";
    }

    function after_video_conferencing_managers_install()
    {
        echo "\n";
    }

    function before_additional_packages_install()
    {
        echo "\tADDITIONAL PACKAGES INSTALLATION\n";
    }

    function before_additional_package_install($context)
    {
        echo "\t\t Installing additional package {$context} ... ";
    }

    function after_additional_package_install(InstallerStepResult $result)
    {
        echo $this->check_result($result) . "\n";
    }

    function after_additional_packages_install()
    {
        echo "\n";
    }

    function before_post_process()
    {
        echo "\tPOST PROCESSING\n";
    }

    function before_post_process_for_application($application)
    {
        echo "\t\t Post processing application {$application} ... ";
    }

    function after_post_process_for_application(InstallerStepResult $result)
    {
        echo $this->check_result($result) . "\n";
    }

    function after_post_process()
    {
        echo "\n";
    }

    function before_filesystem_prepared()
    {
        echo "\tFILE SYSTEM PREPARATION\n";
    }

    function after_filesystem_prepared(InstallerStepResult $result)
    {
        echo "\t\t File system prepared ... " . $this->check_result($result) . "\n";
    }

    function after_install()
    {
        echo "\n\nInstallation completed !\n";
    }

}
