<?php
namespace install;

use common\libraries\Mdb2Connection;
use MDB2;
use common\libraries\Translation;

class Mdb2InstallDataManager
{

    /**
     * @var \common\libraries\Mdb2Connection the connection to the db
     */
    private $db_connection = null;

    /**
     * @var boolean did the databse exist before install ?
     */
    private $database_exists = false;

    /**
     * @var InstallerConfig $installer_config
     */
    private $installer_config = null;

    public function set_installer_config(InstallerConfig $installer_config)
    {
        $this->installer_config = $installer_config;
    }

    public function set_db_connection($db_connection)
    {
        $this->db_connection = $db_connection;
    }

    public function get_db_connection()
    {
        return $this->db_connection;
    }

    public function init_storage_access()
    {
        $this->db_connection = $this->connection_from_config();
        MDB2Connection :: set_instance($this->db_connection);
        $name = $this->installer_config->get_db_name();
        $this->database_exists = $this->db_connection->databaseExists($name);
    }

    private function connection_from_config()
    {
        $username = $this->installer_config->get_db_username();
        $password = $this->installer_config->get_db_password();
        $driver = $this->installer_config->get_db_driver();
        $host = $this->installer_config->get_db_host();
        $overwrite = $this->installer_config->get_db_overwrite() == true;

        $connection_string = "{$driver}://{$username}:{$password}@{$host}";

        $connection = \MDB2 :: connect($connection_string);

        if (\MDB2 :: isError($connection))
            throw new \Exception(Translation :: get('CouldNotConnectToDatabase') . "\n {$connection->getMessage()}" . "\n {$connection->getUserInfo()}" . "\n ({$driver}://{$username}:******@{$host})");

        $connection->loadModule('Manager');

        return $connection;
    }

    public function init_storage_structure()
    {
        $name = $this->installer_config->get_db_name();
        $overwrite = $this->installer_config->get_db_overwrite();

        if (! $this->database_exists)
        {
            $this->create_db($name);
        }
        $this->db_connection->setDatabase($name);
        if ($this->database_exists && $overwrite)
        {
            $this->reset_db();
        }
        $this->database_exists = true;
    }

    private function create_db($name)
    {
        $create_result = $this->db_connection->createDatabase($name, array('charset' => 'utf8',
                'collation' => 'utf8_unicode_ci'));

        if (MDB2 :: isError($create_result))
            throw new \Exception(Translation :: get('DatabaseCreateError') . ' ' . $create_result->getMessage());

    }

    private function reset_db()
    {

        if ($this->db_connection instanceof \MDB2_Driver_mysqli)
        {
            $this->db_connection->exec('SET foreign_key_checks = 0;');
        }
        $tables = $this->db_connection->listTables();
        foreach ($tables as $table)
        {
            $drop_result = $this->db_connection->dropTable($table);

            if (MDB2 :: isError($drop_result))
                throw new \Exception(Translation :: get('TableDropError') . ' ' . $drop_result->getMessage());

        }

        if ($this->db_connection instanceof \MDB2_Driver_mysqli)
        {
            $this->db_connection->exec('SET foreign_key_checks = 1;');
        }
    }

}