<?php
namespace install;

use common\libraries\ResourceManager;

use common\libraries\Application;
use common\libraries\Path;
use common\libraries\WebApplication;
use common\libraries\Translation;
use common\libraries\Filesystem;
use common\libraries\Connection;

use HTML_QuickForm_Action;
use MDB2;
use Exception;

use repository\ContentObjectInstaller;
use repository\ContentObject;

/**
 * $Id: install_wizard_process.class.php 225 2009-11-13 14:43:20Z vanpouckesven $
 *
 * @package install.lib.installmanager.component.inc.wizard
 */

/**
 * This class implements the action to take after the user has completed a course maintenance wizard
 */
class InstallWizardProcess extends HTML_QuickForm_Action implements InstallerObserver
{
    /**
     * The repository tool in which the wizard runs.
     */
    private $parent;

    private $current_step;
    private $counter;
    private $optional_application_counter;
    private $optional;

    /**
     * Constructor
     *
     * @param $parent Tool The repository tool in which the wizard runs.
     */
    public function __construct($parent)
    {
        $this->parent = $parent;
        $this->current_step = "";
        $this->counter = 0;
        $this->optional_application_counter = 0;
        $this->optional = false;
    }

    function perform($page, $actionName)
    {
        $this->installer = $this->build_installer($page);
        $this->installer->add_observer($this);

        $this->display_header($page);
        try
        {
            $this->installer->perform_install();
//             $page->controller->container(true);
        }
        catch (Exception $e)
        {
            // TODO change this for a real error box
            $this->process_result(Translation :: get('PlatformInstallFailed'), false, $e->getMessage(), 'resources/images/aqua/place_failed.png');
        }
        $this->parent->display_footer();
    }

    private function build_installer($page)
    {
        if (array_key_exists('config_file', $_FILES))
        {
            $values = array();

            // TODO check why this gives install errors for missing path ??
            if ($_FILES['config_file']['tmp_name'])
            {
                require_once ($_FILES['config_file']['tmp_name']);
            }

        }
        else
        {
            $values = $page->controller->exportValues();
        }
        $url_append = str_replace('/install/index.php', '', $_SERVER['REQUEST_URI']);
        $values['url_append'] = $url_append;

        $factory = new Factory();
        $installer = $factory->build_installer_from_array($values);
        unset($values);
        return $installer;
    }

    function display_header($page)
    {
        $values = $this->values;

        $this->parent->display_header();
        $all_pages = $page->controller->_pages;

        $total_number_of_pages = count($all_pages) + 1;

        $html[] = '<div id="progressbox">';
        $html[] = '<ul id="progresstrail">';

        $page_number = 1;

        foreach ($all_pages as $page)
        {
            $html[] = '<li class="active"><a href="#">' . $page_number . '.&nbsp;&nbsp;' . $page->get_breadcrumb() . '</a></li>';
            $page_number ++;
        }

        $html[] = '<li class="active"><a href="#">' . $total_number_of_pages . '.&nbsp;&nbsp;' . Translation :: get('Installation') . '</a></li>';
        $html[] = '</ul>';
        $html[] = '<div class="clear"></div>';
        $html[] = '</div>';

        $html[] = '<div id="theForm" style="margin: 10px;">';
        $html[] = '<div id="select" class="row"><div class="formc formc_no_margin">';
        $html[] = '<b>' . Translation :: get('Step') . ' ' . $total_number_of_pages . ' ' . Translation :: get('of') . ' ' . $total_number_of_pages . ' &ndash; ' . Translation :: get('Installation') . '</b><br />';

        $html[] = Translation :: get('InstallationDescription');
        $html[] = '</div>';
        $html[] = '</div></div>';
        $html[] = '<div class="clear"></div>';
        // $html[] = '<a href="#" id="showall">' . Translation :: get('ShowAll')
        // . '</a> - <a href="#" id="hideall">' . Translation :: get('HideAll')
        // . '</a><br />';
        $html[] = ResourceManager :: get_instance()->get_resource_html('resources/javascript/install_process.js');

        echo implode("\n", $html);
    }

    function process_result($title, $result, $message, $image)
    {
        echo $this->display_install_block_header($title, $result, $image);
        echo $message;
        echo $this->display_install_block_footer();
    }

    function display_install_block_header($title, $result, $image)
    {
        $counter = $this->counter;

        $result_class = ($result ? 'installation-step-successful' : 'installation-step-failed');

        $html = array();
        $html[] = '<div class="installation-step installation-step-collapsed ' . $result_class . '" style="background-image: url(' . $image . ');">';
        $html[] = '<div class="title">' . $title . '</div>';
        $html[] = '<div class="description">';

        return implode("\n", $html);
    }

    function display_install_block_footer()
    {
        $html = array();
        $html[] = '</div>';
        $html[] = '</div>';
        return implode("\n", $html);
    }

    public function before_application_install($application)
    {
        $this->current_step = $application;
    }

    public function after_application_install(InstallerStepResult $result)
    {
        $path = Path :: namespace_to_path($this->current_step);
        $image = '../' . $path . '/resources/images/aqua/logo/22.png';
        $title = Translation :: get('TypeName', null, $this->current_step);
        $this->process_result($title, $result->get_success(), implode('<br />' . "\n", $result->get_messages()), $image);
        flush();
    }

    public function before_content_objects_install()
    {
        echo '<h3>' . Translation :: get('InstallingContentObjects') . '</h3>';
    }

    public function after_content_objects_install()
    {
        echo '<div class="clear"></div>';
    }

    public function before_external_repository_managers_install()
    {
        echo '<h3>' . Translation :: get('InstallingExternalRepositoryManagers') . '</h3>';
    }

    public function after_external_repository_managers_install()
    {
        echo '<div class="clear"></div>';
    }

    public function before_video_conferencing_managers_install()
    {
        echo '<h3>' . Translation :: get('InstallingVideoConferencingManagers') . '</h3>';
    }

    public function after_video_conferencing_managers_install()
    {
        echo '<div class="clear"></div>';
    }

    public function before_filesystem_prepared()
    {
        echo '<h3>' . Translation :: get('Filesystem') . '</h3>';
    }

    public function after_filesystem_prepared(InstallerStepResult $result)
    {
        $image = 'resources/images/aqua/place_folder.png';
        $this->process_result(Translation :: get('Folders'), $result->get_success(), implode('<br />' . "\n", $result->get_messages()), $image);
        flush();
    }

    public function before_post_process()
    {

    }

    public function after_post_process()
    {
        echo '<div class="clear"></div>';
    }

    public function before_post_process_for_application($application)
    {
        $this->current_step = $application;
    }

    public function after_post_process_for_application(InstallerStepResult $result)
    {
        $path = Path :: namespace_to_path($this->current_step);
        $image = '../' . $path . '/resources/images/aqua/logo/22.png';
        $title = Translation :: get('TypeName', null, $this->current_step);
        $this->process_result($title, $result->get_success(), implode('<br />' . "\n", $result->get_messages()), $image);

    }

    public function after_preprod()
    {
        echo '<div class="clear"></div>';
    }

    public function before_content_object_install($content_object)
    {
        $this->current_step = $content_object;
    }

    public function after_content_object_install(InstallerStepResult $result)
    {
        $path = Path :: namespace_to_path($this->current_step);
        $image = '../' . $path . '/resources/images/aqua/logo/22.png';
        $title = Translation :: get('TypeName', null, $this->current_step);
        $this->process_result($title, $result->get_success(), implode('<br />' . "\n", $result->get_messages()), $image);
        flush();
    }

    public function before_external_repository_manager_install($external_repository_manager)
    {
        $this->current_step = $external_repository_manager;
    }

    public function after_external_repository_manager_install(InstallerStepResult $result)
    {
        $path = Path :: namespace_to_path($this->current_step);
        $image = '../' . $path . '/resources/images/aqua/logo/22.png';
        $title = Translation :: get('TypeName', null, $this->current_step);
        $this->process_result($title, $result->get_success(), implode('<br />' . "\n", $result->get_messages()), $image);
        flush();
    }

    public function before_video_conferencing_manager_install($video_conferencing_manager)
    {
        $this->current_step = $video_conferencing_manager;
    }

    public function after_video_conferencing_manager_install(InstallerStepResult $result)
    {
        $image = '../common/extensions/video_conferencing_manager/implementation/' . $this->current_step . '/resources/images/aqua/logo/22.png';
        $title = Translation :: get('TypeName', null, \common\extensions\video_conferencing_manager\Manager :: get_namespace($this->current_step));
        $this->process_result($title, $result->get_success(), implode('<br />' . "\n", $result->get_messages()), $image);
        flush();
    }

    public function before_core_applications_install()
    {
        $this->optional = false;

        echo '<h3>' . Translation :: get('CoreApplications') . '</h3>';
        echo '<h4>' . Translation :: get('Installation') . '</h4>';
    }

    public function after_core_applications_install()
    {
        echo '<div class="clear"></div>';
    }

    public function before_core_applications_configuration()
    {
        $this->optional = false;
        echo '<h4>' . Translation :: get('Configuration') . '</h4>';
    }

    public function after_core_applications_configuration()
    {
        echo '<div class="clear"></div>';
    }

    public function before_install()
    {

    }

    public function after_install()
    {
        $message = '<a href="../index.php">' . Translation :: get('GoToYourNewlyCreatedPortal') . '</a>';
        $image = 'resources/images/aqua/place_finished.png';
        $this->process_result(Translation :: get('InstallationFinished'), true, $message, $image);
        flush();
    }

    public function before_optional_applications_install()
    {
        $this->optional = true;

        echo '<h3>' . Translation :: get('OptionalApplications') . '</h3>';
        echo '<h4>' . Translation :: get('Installation') . '</h4>';
    }

    public function after_optional_application_install()
    {
        $this->optional_application_counter ++;
    }

    public function after_optional_applications_install()
    {
        if ($this->optional_application_counter == 0)
        {
            $image = 'resources/images/aqua/place_applications.png';
            $this->process_result(Translation :: get('OptionalApplications'), true, Translation :: get('NoOptionalApplicationsSelected'), $image);
        }
        $this->optional = false;

        echo '<div class="clear"></div>';
    }

    public function before_optional_applications_configuration()
    {
        $this->optional = true;
        echo '<h4>' . Translation :: get('Configuration') . '</h4>';
    }

    public function after_optional_applications_configuration()
    {
        echo '<div class="clear"></div>';
    }

    public function before_preprod()
    {
        echo '<h3>' . Translation :: get('PreProduction') . '</h3>';
    }

    public function before_additional_packages_install()
    {
        echo '<h3>' . Translation :: get('AdditionalPackages') . '</h3>';
    }

    public function before_additional_package_install($context)
    {

    }

    public function after_additional_package_install(InstallerStepResult $result)
    {
        $image = Path :: get(WEB_PATH) . '../' . Path :: namespace_to_path($result->get_context()) . '/resources/images/aqua/logo/22.png';
        $title = Translation :: get('TypeName', null, $result->get_context());

        $this->process_result($title, $result->get_success(), implode('<br />' . "\n", $result->get_messages()), $image);
        flush();
    }

    public function after_additional_packages_install()
    {
        echo '<div class="clear"></div>';
    }

    public function preprod_config_file_written(InstallerStepResult $result)
    {
        $image = 'resources/images/aqua/place_config.png';
        $this->process_result(Translation :: get('Configuration'), $result->get_success(), implode('<br />' . "\n", $result->get_messages()), $image);
        flush();
    }

    public function preprod_db_created(InstallerStepResult $result)
    {
        $image = 'resources/images/aqua/place_database.png';
        $this->process_result(Translation :: get('Database'), $result->get_success(), implode('<br />' . "\n", $result->get_messages()), $image);
        flush();
    }

    public function before_extensions_install()
    {
        echo '<h3>' . Translation :: get('InstallingExtensions') . '</h3>';
    }

    public function after_extensions_install()
    {
        echo '<div class="clear"></div>';
    }

    public function before_extension_install($extension)
    {
        $this->current_step = $extension;
    }

    public function after_extension_install(InstallerStepResult $result)
    {
        $path = Path :: namespace_to_path($this->current_step);
        $image = '../' . $path . '/resources/images/aqua/logo/22.png';
        $title = Translation :: get('TypeName', null, $this->current_step);
        $this->process_result($title, $result->get_success(), implode('<br />' . "\n", $result->get_messages()), $image);
        flush();
    }

}
?>