<?php

namespace install;

/**
 * This class helps to notify all the observers at the same time
 */
class InstallerObservers implements InstallerObserver
{
    /**
     *
     * @var array list aof all the observers to be notified
     */
    private $observers;

    public function __construct()
    {
        $this->observers = array();
    }

    public function add_observer(InstallerObserver $observer)
    {
        $this->observers[] = $observer;
    }

    private function call_on_each_observer($method_name, $parameters = null)
    {

        if (is_null($parameters))
        {
            $parameters = array();
        }

        if (! is_array($parameters))
        {
            $parameters = array($parameters);
        }
        foreach ($this->observers as $observer)
        {
            call_user_func_array(array($observer, $method_name), $parameters);
        }
    }

    public function after_application_install(InstallerStepResult $result)
    {
        $this->call_on_each_observer(__FUNCTION__, $result);
    }

    public function after_filesystem_prepared(InstallerStepResult $result)
    {
        $this->call_on_each_observer(__FUNCTION__, $result);
    }

    public function after_install()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function after_post_process()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function after_post_process_for_application(InstallerStepResult $result)
    {
        $this->call_on_each_observer(__FUNCTION__, $result);
    }

    public function after_preprod()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function before_application_install($application)
    {
        $this->call_on_each_observer(__FUNCTION__, $application);
    }

    public function before_filesystem_prepared()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function before_install()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function before_post_process()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function before_post_process_for_application($application)
    {
        $this->call_on_each_observer(__FUNCTION__, $application);
    }

    public function before_preprod()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function preprod_config_file_written(InstallerStepResult $result)
    {
        $this->call_on_each_observer(__FUNCTION__, $result);
    }

    public function preprod_db_created(InstallerStepResult $result)
    {
        $this->call_on_each_observer(__FUNCTION__, $result);
    }

    public function after_content_object_install(InstallerStepResult $result)
    {
        $this->call_on_each_observer(__FUNCTION__, $result);
    }

    public function after_content_objects_install()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function after_external_repository_manager_install(InstallerStepResult $result)
    {
        $this->call_on_each_observer(__FUNCTION__, $result);
    }

    public function after_external_repository_managers_install()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function after_video_conferencing_manager_install(InstallerStepResult $result)
    {
        $this->call_on_each_observer(__FUNCTION__, $result);
    }

    public function after_video_conferencing_managers_install()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function after_core_applications_install()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function after_core_applications_configuration()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function after_optional_application_install()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function after_optional_applications_install()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function after_optional_applications_configuration()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function before_content_object_install($content_object)
    {
        $this->call_on_each_observer(__FUNCTION__, $content_object);
    }

    public function before_content_objects_install()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function before_external_repository_manager_install($content_object)
    {
        $this->call_on_each_observer(__FUNCTION__, $content_object);
    }

    public function before_external_repository_managers_install()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function before_video_conferencing_manager_install($content_object)
    {
        $this->call_on_each_observer(__FUNCTION__, $content_object);
    }

    public function before_video_conferencing_managers_install()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function before_additional_packages_install()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function before_additional_package_install($context)
    {
        $this->call_on_each_observer(__FUNCTION__, $context);
    }

    public function after_additional_package_install(InstallerStepResult $result)
    {
        $this->call_on_each_observer(__FUNCTION__, $result);
    }

    public function after_additional_packages_install()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function before_core_applications_install()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function before_core_applications_configuration()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function before_optional_applications_configuration()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function before_optional_applications_install()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function before_extensions_install()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

    public function before_extension_install($extension)
    {
        $this->call_on_each_observer(__FUNCTION__, $extension);
    }

    public function after_extension_install(InstallerStepResult $result)
    {
        $this->call_on_each_observer(__FUNCTION__, $result);
    }

    public function after_extensions_install()
    {
        $this->call_on_each_observer(__FUNCTION__);
    }

}