<?php
namespace menu;
use common\libraries\DataClassRetrievesParameters;

use common\libraries\PlatformSetting;

use admin\AdminDataManager;

use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\EqualityCondition;
use common\libraries\FormValidator;
use common\libraries\ObjectTableOrder;

class ItemForm extends FormValidator
{

    const TYPE_CREATE = 1;
    const TYPE_EDIT = 2;
    const RESULT_SUCCESS = 'ObjectUpdated';
    const RESULT_ERROR = 'ObjectUpdateFailed';

    private $item;
    private $form_type;

    function __construct($form_type, $item, $action)
    {
        parent :: __construct('item', 'post', $action);

        $this->item = $item;
        $this->form_type = $form_type;
        if ($this->form_type == self :: TYPE_EDIT)
        {
            $this->build_editing_form();
        }
        elseif ($this->form_type == self :: TYPE_CREATE)
        {
            $this->build_creation_form();
        }
        $this->add_footer();
        $this->setDefaults();
    }

    function build_basic_form()
    {
        $this->addElement('category', Translation :: get('General'));
        $this->addElement('select', Item :: PROPERTY_PARENT, Translation :: get('Parent'), $this->get_parents());
        $this->addRule(Item :: PROPERTY_PARENT, Translation :: get('ThisFieldIsRequired'), 'required');

        $this->addElement('checkbox', Item :: PROPERTY_HIDDEN, Translation :: get('Hidden'));
        $this->addElement('category');

        $this->addElement('category', Translation :: get('Titles'));
        $active_languages = AdminDataManager :: get_languages();
        $platform_language = PlatformSetting :: get('platform_language');
        foreach ($active_languages as $isocode => $language)
        {
            $this->addElement('text', ItemTitle :: PROPERTY_TITLE . '[' . $isocode . ']', $language, array(
                    "size" => "50"));
            if ($isocode == $platform_language)
            {
                $this->addRule(ItemTitle :: PROPERTY_TITLE . '[' . $isocode . ']', Translation :: get('ThisFieldIsRequired', null, Utilities :: COMMON_LIBRARIES), 'required');
            }
        }
        $this->addElement('category');
        $this->addElement('hidden', Item :: PROPERTY_TYPE);
    }

    function add_footer()
    {
        switch ($this->form_type)
        {
            case self :: TYPE_CREATE :
                $buttons[] = $this->createElement('style_submit_button', 'submit_button', Translation :: get('Create', null, Utilities :: COMMON_LIBRARIES), array(
                        'class' => 'positive'));
                break;
            case self :: TYPE_EDIT :
                $buttons[] = $this->createElement('style_submit_button', 'submit_button', Translation :: get('Update', null, Utilities :: COMMON_LIBRARIES), array(
                        'class' => 'positive update'));
                break;
        }

        $buttons[] = $this->createElement('style_reset_button', 'reset', Translation :: get('Reset', null, Utilities :: COMMON_LIBRARIES), array(
                'class' => 'normal empty'));
        $this->addGroup($buttons, 'buttons', null, '&nbsp;', false);
    }

    function build_editing_form()
    {
        $this->build_basic_form();
        $this->addElement('hidden', Item :: PROPERTY_ID);
    }

    function build_creation_form()
    {
        $this->build_basic_form();
    }

    function get_parents()
    {
        $condition = new EqualityCondition(Item :: PROPERTY_PARENT, 0);
        $parameters = new DataClassRetrievesParameters($condition, null, null, new ObjectTableOrder(Item :: PROPERTY_SORT));
        $items = DataManager :: retrieves(Item :: class_name(), $parameters);

        $item_options = array();
        $item_options[0] = Translation :: get('Root', null, Utilities :: COMMON_LIBRARIES);

        while ($item = $items->next_result())
        {
            $item_options[$item->get_id()] = '-- ' . $item->get_titles()->get_current_translation();
        }
        return $item_options;
    }

    /**
     * Sets default values. Traditionally, you will want to extend this method so it sets default for your learning
     * object type's additional properties.
     *
     * @param $defaults array Default values for this form's parameters.
     */
    function setDefaults($defaults = array ())
    {
        $item = $this->item;
        $active_languages = AdminDataManager :: get_languages();
        $platform_language = PlatformSetting :: get('platform_language');
        foreach ($active_languages as $isocode => $language)
        {
            $defaults[ItemTitle :: PROPERTY_TITLE][$isocode] = $item->get_titles()->get_translation($isocode, false);
        }
        $defaults[Item :: PROPERTY_ID] = $item->get_id();
        $defaults[Item :: PROPERTY_PARENT] = $item->get_parent();
        $defaults[Item :: PROPERTY_HIDDEN] = $item->get_hidden();
        $defaults[Item :: PROPERTY_TYPE] = $item->get_type();

        parent :: setDefaults($defaults);
    }

    function get_item()
    {
        return $this->item;
    }

    static function factory($form_type, $item, $action = null)
    {
        $class = get_class($item) . 'Form';

        return new $class($form_type, $item, $action);
    }
}
?>