<?php
namespace menu;

use common\libraries\DataClassRetrievesParameters;

use common\libraries\ObjectTableOrder;
use common\libraries\Utilities;
use common\libraries\CompositeDataClass;
use common\libraries\EqualityCondition;

class Item extends CompositeDataClass
{
    const CLASS_NAME = __CLASS__;

    const PROPERTY_PARENT = 'parent';
    const PROPERTY_SORT = 'sort';
    const PROPERTY_HIDDEN = 'hidden';

    const TYPE_APPLICATION = 1;
    const TYPE_LINK = 2;
    const TYPE_CATEGORY = 3;
    const TYPE_LINK_APPLICATION = 4;

    private $titles;

    /**
     * Get the default properties of all items.
     *
     * @return array The property names.
     */
    static function get_default_property_names()
    {
        return parent :: get_default_property_names(array(self :: PROPERTY_PARENT, self :: PROPERTY_TYPE,
                self :: PROPERTY_SORT, self :: PROPERTY_HIDDEN));
    }

    /**
     * inherited
     */
    function get_data_manager()
    {
        return MenuDataManager :: get_instance();
    }

    function get_parent()
    {
        return $this->get_default_property(self :: PROPERTY_PARENT);
    }

    function set_parent($parent)
    {
        $this->set_default_property(self :: PROPERTY_PARENT, $parent);
    }

    function get_sort()
    {
        return $this->get_default_property(self :: PROPERTY_SORT);
    }

    function set_sort($sort)
    {
        $this->set_default_property(self :: PROPERTY_SORT, $sort);
    }

    function get_hidden()
    {
        return $this->get_default_property(self :: PROPERTY_HIDDEN);
    }

    function set_hidden($hidden = 0)
    {
        $this->set_default_property(self :: PROPERTY_HIDDEN, $hidden);
    }

    function create()
    {
        $condition = new EqualityCondition(self :: PROPERTY_PARENT, $this->get_parent());
        $sort = DataManager :: retrieve_next_value(Item :: class_name(), self :: PROPERTY_SORT, $condition);
        $this->set_sort($sort);

        $success = parent :: create($this);
        if (! $success)
        {
            return false;
        }

        foreach ($this->get_titles()->get_titles() as $title)
        {
            $title->set_item_id($this->get_id());
            if (! $title->create())
            {
                return false;
            }
        }
        return true;
    }

    function update()
    {
        $success = parent :: update($this);
        if (! $success)
        {
            return false;
        }

        foreach ($this->get_titles()->get_titles() as $title)
        {
            if ($title->get_id())
            {
                if (! $title->update())
                {
                    return false;
                }
            }
            else
            {
                if (! $title->create())
                {
                    return false;
                }
            }
        }
        return true;
    }

    function delete()
    {
        $success = parent :: delete($this);
        if (! $success)
        {
            return false;
        }

        foreach ($this->get_titles()->get_titles() as $title)
        {
            if (! $title->delete())
            {
                return false;
            }
        }
        return true;
    }

    /**
     *
     * @return string
     */
    function get_type_string()
    {
        return self :: type_string($this->get_type());
    }

    /**
     *
     * @return string
     */
    static function type_string($type)
    {
        switch ($type)
        {
            case ApplicationItem :: class_name() :
                return 'Application';
                break;
            case LinkItem :: class_name() :
                return 'Link';
                break;
            case CategoryItem :: class_name() :
                return 'Category';
                break;
            case LinkApplicationItem :: class_name() :
                return 'LinkApplication';
                break;
        }
    }

    /**
     *
     * @return string
     */
    function get_type_integer()
    {
        return self :: type_integer($this->get_type());
    }

    /**
     *
     * @return string
     */
    static function type_integer($type)
    {
        switch ($type)
        {
            case ApplicationItem :: class_name() :
                return self :: TYPE_APPLICATION;
                break;
            case LinkItem :: class_name() :
                return self :: TYPE_LINK;
                break;
            case CategoryItem :: class_name() :
                return self :: TYPE_CATEGORY;
                break;
            case LinkApplicationItem :: class_name() :
                return self :: TYPE_LINK_APPLICATION;
                break;
        }
    }

    function get_titles()
    {
        if (! isset($this->titles))
        {
            $condition = new EqualityCondition(ItemTitle :: PROPERTY_ITEM_ID, $this->get_id());
            $parameters = new DataClassRetrievesParameters($condition, null, null, array(
                    new ObjectTableOrder(ItemTitle :: PROPERTY_SORT)));
            $titles = DataManager :: retrieves(ItemTitle :: class_name(), $parameters);

            $this->titles = new ItemTitles($titles);
        }
        return $this->titles;
    }

    function set_titles($titles)
    {
        $this->titles = $titles;
    }

    function is_selected()
    {
        return false;
    }
}
?>