<?php
namespace menu;

use common\libraries\DataClassRetrievesParameters;
use common\libraries\ObjectTableOrder;
use common\libraries\EqualityCondition;
use common\libraries\Utilities;

class CategoryItem extends Item
{
    const CLASS_NAME = __CLASS__;

    private $children;

    function __construct($default_properties = array(), $additional_properties = null)
    {
        parent :: __construct($default_properties, $additional_properties);
        $this->set_type(__CLASS__);
    }

    static function get_type_name()
    {
        return Utilities :: camelcase_to_underscores(Utilities :: get_classname_from_namespace(self :: CLASS_NAME));
    }

    function get_children()
    {
        if (! isset($this->children))
        {
            $condition = new EqualityCondition(Item :: PROPERTY_PARENT, $this->get_id());
            $parameters = new DataClassRetrievesParameters($condition, null, null, new ObjectTableOrder(Item :: PROPERTY_SORT));
            $items = DataManager :: retrieves(Item :: class_name(), $parameters);
            $this->children = $items->as_array();
        }
        return $this->children;
    }

    function set_children($children)
    {
        $this->children = $children;
    }

    function has_children()
    {
        return count($this->get_children()) > 0;
    }

    function add_child($child)
    {
        $this->children[] = $child;
    }

    function is_selected()
    {
        foreach ($this->get_children() as $child)
        {
            if ($child->is_selected())
            {
                return true;
            }
        }
        return false;
    }
}

?>