<?php
namespace metadata;

use common\libraries\Path;
use common\libraries\EqualityCondition;
use common\libraries\ComplexContentObjectSupport;
use common\libraries\Filecompression;
use common\libraries\Filesystem;
use repository\ContentObjectExport;

use DOMDocument;

use repository\content_object\document\Document;
use repository\content_object\hotpotatoes\Hotpotatoes;
use repository\content_object\learning_path_item\LearningPathItem;
use repository\content_object\learning_path\LearningPath;
use repository\content_object\hotspot_question\HotspotQuestion;
use metadata\MetadataDataManager;
use repository\RepositoryDataManager;
use repository\ContentObject;
use repository\ComplexContentObjectItem;
use repository\ContentObjectAttachment;
use context_linker\ContextLinkerDataManager;
use context_linker\ContextLink;


/**
 * Exports Metadata schemes & elements to the chamilo learning object format (xml)
 * TODO: this is just a temporary class untill the cpo-export from the repository is refactored
 * TODO: only exports schemas and elements, nothing else
 */
class MetadataCpoExport
//extends ContentObjectExport
{
    /**
     * @var RepositoryDataManager
     */
    private $rdm;
    /**
     * @var DOMDocument
     */
    private $doc;

    /*
	 * Array of files to export
	 */
    private $files;

    /**
     * Array of already exported namespaces
     * @var Array
     */
    private $exported_namespaces;

    /**
     * Array of already exported metadata-elements
     * @var Array
     */
    private $exported_metadata_elements;

    private $metadata;


    function __construct()
    {
        $this->rdm = RepositoryDataManager :: get_instance();
        $this->exported_content_objects = array();
//        parent :: __construct();
    }

    function export_metadata()
    {
       $this->export_categories = $export_categories;

        $this->doc = new DOMDocument('1.0', 'UTF-8');
        $this->doc->formatOutput = true;

        $parent = $this->doc->createElement('export');
        $this->doc->appendChild($parent);

        $this->metadata = $this->doc->createElement('metadata_structure');
        $parent->appendChild($this->metadata);

        $user = null;

        //get metadata
        $metadata_elements = MetadataDataManager::get_instance()->retrieve_metadata_elements();
        
        while($metadata_elements && $element = $metadata_elements->next_result())
        {
             $this->render_metadata_element($element->get_name(), $element->get_ns_prefix());
        }


        $temp_dir = Path :: get(SYS_TEMP_PATH) . $user . '/export_metadata/';

        if (! is_dir($temp_dir))
        {
            mkdir($temp_dir, 0777, true);
        }

        $xml_path = $temp_dir . 'metadata.xml';
        $this->doc->save($xml_path);

        $this->add_files($temp_dir);

        $zip = Filecompression :: factory();
        $zippath = $zip->create_archive($temp_dir);

        Filesystem :: remove($temp_dir);

        return $zippath;
    }

    public function render_metadata_element($element_name , $namespace_prefix)
    {      
        if(!in_array($namespace_prefix, $this->exported_namespaces))
        {
            $this->exported_namespaces[] = $namespace_prefix;
            $doc = $this->doc;
            $root = $this->metadata;
            $schema = $doc->createElement('metadata_schema');
            $root->appendChild($schema);
            $namespace = MetadataDataManager::get_instance()->retrieve_metadata_namespace_by_prefix($namespace_prefix);
            $prefix = $doc->createAttribute('prefix');
            $schema->appendChild($prefix);
            $prefix_value = $doc->createTextNode($namespace_prefix);
            $prefix->appendChild($prefix_value);
            $name = $doc->createAttribute('name');
            $schema->appendChild($name);
            $name_value = $doc->createTextNode($namespace->get_name());
            $name->appendChild($name_value);
            $url = $doc->createAttribute('url');
            $schema->appendChild($url);
            $url_value = $doc->createTextNode($namespace->get_url());
            $url->appendChild($url_value);
        }

        if(!in_array($namespace_prefix.'_'.$element_name, $this->exported_metadata_elements))
        {
            $this->exported_metadata_elements[] = $namespace_prefix.'_'.$element_name;
            $doc = $this->doc;
            $root = $this->metadata;
            $elements = $doc->createElement('metadata_element');
            $root->appendChild($elements);
            $schema_prefix = $doc->createAttribute('schema_prefix');
            $elements->appendChild($schema_prefix);
            $schema_prefix_value = $doc->createTextNode($namespace_prefix);
            $schema_prefix->appendChild($schema_prefix_value);
            $element = $doc->createAttribute('element');
            $elements->appendChild($element);
            $element_value = $doc->createTextNode($element_name);
            $element->appendChild($element_value);
        }
    }

   

    function add_files($temp_dir)
    {
        foreach ($this->files as $hash => $path)
        {
            $newfile = $temp_dir . 'data/' . $hash;
            Filesystem :: copy_file($path, $newfile, true);
        }
        foreach ($this->hotpot_files as $hotpot_dir)
        {
            $newfile = $temp_dir . 'hotpotatoes/' . basename(rtrim($hotpot_dir, '/'));
            Filesystem :: recurse_copy($hotpot_dir, $newfile, true);
        }

        foreach ($this->scorm_files as $scorm_dir)
        {
            $newfile = $temp_dir . 'scorm/' . basename(rtrim($scorm_dir, '/'));
            Filesystem :: recurse_copy($scorm_dir, $newfile, true);
        }
    }

  
}
?>