<?php
namespace metadata;

use common\libraries\FormValidator;
use common\libraries\Translation;
use common\libraries\Utilities;

/**
 * This class describes the form for a MetadataElement object.
 * @author Sven Vanpoucke
 * @author Jens Vanderheyden
 **/
class MetadataDefaultValueForm extends FormValidator
{
    const TYPE_CREATE = 1;
    const TYPE_EDIT = 2;
    
    const OPTION_BLANK = 'blank';
    
    private $metadata_default_value;
    private $metadata_element;
    private $metadata_attributes;

    function __construct($form_type, MetadataDefaultValue $metadata_default_value, MetadataElement $metadata_element, array $metadata_attributes, $action)
    {
        parent :: __construct('metadata_default_value_settings', 'post', $action);
        
        $this->metadata_default_value = $metadata_default_value;
        $this->form_type = $form_type;
        $this->metadata_element = $metadata_element;
        
        //add option blank and make it the first one
        $metadata_attributes[self :: OPTION_BLANK] = '--';
        $this->metadata_attributes = $metadata_attributes;
        
        if ($this->form_type == self :: TYPE_EDIT)
        {
            $this->build_editing_form();
        }
        elseif ($this->form_type == self :: TYPE_CREATE)
        {
            $this->build_creation_form();
        }
        
        $this->setDefaults();
    }

    function build_basic_form()
    {
        $mm = MetadataDataManager :: get_instance();
        $prefixes = $mm->retrieve_metadata_namespaces();
        
        $this->addElement('select', MetadataDefaultValue :: PROPERTY_ATTRIBUTE_ID, Translation :: get('MetadataAttribute'), $this->metadata_attributes);
        
        $this->addElement('text', MetadataDefaultValue :: PROPERTY_VALUE, Translation :: get('Value', null, Utilities :: COMMON_LIBRARIES));
        $this->addRule(MetadataDefaultValue :: PROPERTY_VALUE, Translation :: get('ThisFieldIsRequired', null, Utilities :: COMMON_LIBRARIES), 'required');
    
    }

    function build_editing_form()
    {
        $this->build_basic_form();
        
        $this->addElement('hidden', MetadataDefaultValue :: PROPERTY_ID);
        
        $buttons[] = $this->createElement('style_submit_button', 'submit', Translation :: get('Update', null, Utilities :: COMMON_LIBRARIES), array(
                'class' => 'positive update'));
        $buttons[] = $this->createElement('style_reset_button', 'reset', Translation :: get('Reset', null, Utilities :: COMMON_LIBRARIES), array(
                'class' => 'normal empty'));
        
        $this->addGroup($buttons, 'buttons', null, '&nbsp;', false);
    }

    function build_creation_form()
    {
        $this->build_basic_form();
        
        $buttons[] = $this->createElement('style_submit_button', 'submit', Translation :: get('Create', null, Utilities :: COMMON_LIBRARIES), array(
                'class' => 'positive'));
        $buttons[] = $this->createElement('style_reset_button', 'reset', Translation :: get('Reset', null, Utilities :: COMMON_LIBRARIES), array(
                'class' => 'normal empty'));
        
        $this->addGroup($buttons, 'buttons', null, '&nbsp;', false);
    }

    function update_metadata_default_value()
    {
        $metadata_default_value = $this->metadata_default_value;
        $values = $this->exportValues();
        
        //$metadata_default_value->set_id($values[MetadataDefaultValue :: PROPERTY_ID]);
        if ($values[MetadataDefaultValue :: PROPERTY_ATTRIBUTE_ID] != self :: OPTION_BLANK)
            $metadata_default_value->set_attribute_id($values[MetadataDefaultValue :: PROPERTY_ATTRIBUTE_ID]);
        $metadata_default_value->set_value($values[MetadataDefaultValue :: PROPERTY_VALUE]);
        
        return $metadata_default_value->update();
    }

    function create_metadata_default_value()
    {
        $metadata_default_value = $this->metadata_default_value;
        $values = $this->exportValues();
        
        $metadata_default_value->set_element_id($this->metadata_element->get_id());
        $metadata_default_value->set_id($values[MetadataDefaultValue :: PROPERTY_ID]);
        if ($values[MetadataDefaultValue :: PROPERTY_ATTRIBUTE_ID] != self :: OPTION_BLANK)
            $metadata_default_value->set_attribute_id($values[MetadataDefaultValue :: PROPERTY_ATTRIBUTE_ID]);
        $metadata_default_value->set_value($values[MetadataDefaultValue :: PROPERTY_VALUE]);
        
        if ($metadata_default_value->create())
        {
            return $metadata_default_value;
        }
    }

    /**
     * Sets default values.
     * @param array $defaults Default values for this form's parameters.
     */
    function setDefaults($defaults = array ())
    {
        $metadata_default_value = $this->metadata_default_value;
        
        $defaults[MetadataDefaultValue :: PROPERTY_ID] = $metadata_default_value->get_id();
        $defaults[MetadataDefaultValue :: PROPERTY_ELEMENT_ID] = $metadata_default_value->get_element_id();
        $defaults[MetadataDefaultValue :: PROPERTY_ATTRIBUTE_ID] = $metadata_default_value->get_attribute_id();
        $defaults[MetadataDefaultValue :: PROPERTY_VALUE] = $metadata_default_value->get_value();
        parent :: setDefaults($defaults);
    }
}
?>