<?php
namespace metadata;

use common\libraries\Path;
use common\libraries\EqualityCondition;
use common\libraries\Filecompression;
use common\libraries\Filesystem;
use repository\ContentObjectImport;
use repository\content_object\learning_path_item\LearningPathItem;
use repository\content_object\document\Document;
use repository\content_object\hotspot_question\HotspotQuestion;
use repository\content_object\hotpotatoes\Hotpotatoes;
use repository\content_object\learning_path\LearningPath;
use repository\content_object\scorm_item\ScormItem;
use DOMDocument;
use common\libraries\Text;
use metadata\MetadataNamespace;
use metadata\MetadataElement;
use metadata\MetadataElementValue;
use repository\RepositoryDataManager;
use repository\ContentObject;
use metadata\MetadataDataManager;
use repository\ComplexContentObjectItem;
use metadata\ContentObjectMetadataElementValue;
use repository\content_object\handbook\Metadata;
use context_linker\ContextLink;
use common\libraries\AndCondition;

/**
 * imports metadata schemas and elements
 */
class MetadataCpoImport
//extends ContentObjectImport
{
 
    const LINK_METADATA = 'meta';

    
    
    private $log = array();
  


    function __construct()
    {
        
       
    }

    public function get_log()
    {
        return $this->log;
    }

    public function import_metadata()
    {
        $zip = Filecompression :: factory();
        $temp = $zip->extract_file($_FILES['metadata_file']['tmp_name']);
        $dir = $temp . '/';

        $path = $dir . 'metadata.xml';

        if (!file_exists($path))
        {
            if ($temp)
            {
                Filesystem :: remove($temp);
            }
            return false;
        }

        $this->import_files($dir);

        $doc = $this->doc;
        $doc = new DOMDocument();

        $doc->load($path);
        $metadata_schemas = $doc->getElementsByTagname('metadata_schema');
        $metadata_elements = $doc->getElementsByTagname('metadata_element');

        foreach ($metadata_schemas as $schema)
        {
            $this->create_metadata_schema($schema);
        }
        foreach ($metadata_elements as $element)
        {
            $this->create_metadata_element($element);
        }

        return true;
    }

   

    private function import_files($dir)
    {
        

        $lo_data_dir = $dir . 'data/';
        if (file_exists($lo_data_dir))
        {
            $files = Filesystem :: get_directory_content($lo_data_dir, Filesystem :: LIST_FILES_AND_DIRECTORIES, false);
            $repdir = Path :: get(SYS_REPO_PATH);

            foreach ($files as $f)
            {
                $usr_path = 0 . '/' . Text :: char_at($f, 0);
                $full_path = $repdir . $usr_path;

                $hash = Filesystem :: create_unique_name($full_path, $f);

                Filesystem :: copy_file($dir . 'data/' . $f, $full_path . '/' . $hash, false);
                $this->files[$f] = array('hash' => $hash, 'path' => $usr_path . '/' . $hash);
            }
        }

       
    }

  

    public function create_metadata_schema($schema)
    {
        foreach ($schema->attributes as $attrName => $attrNode)
        {
            if ($attrName == 'prefix')
            {
                $prefix = $attrNode->value;
            }
            elseif ($attrName == 'name')
            {
                $name = $attrNode->value;
            }
            elseif ($attrName == 'url')
            {
                $url = $attrNode->value;
            }
        }

        $namespace = MetadataDataManager::get_instance()->retrieve_metadata_namespace_by_prefix($prefix);

        if (!$namespace)
        {
            //namespace not in system -> create
            $ns = new MetadataNamespace();
            $ns->set_ns_prefix($prefix);
            $ns->set_name($name);
            $ns->set_url($url);
            $success = $ns->create();

            if ($success)
            {
                $this->log[] = 'schema ' . $prefix . '  created ';
            }
            else
            {
                $this->log[] = 'problem! schema ' . $prefix . ' could not be created ';
            }
        }
        else
        {
            $same = true;
            //namespace is in system -> check consistency
            $same &= $namespace->get_name() == $name;
            $same &= $namespace->get_url() == $url;

            if (!$same)
            {
                //TODO: problem-> catch and resolve!
                $this->log[] = 'schema already exists but inconsistency in information: ' . $namespace->get_name() . '/' . $name . '  -  ' . $namespace->get_url() . '/' . $url;
            }
            else
            {
                $this->log[] = 'schema already exists and is consistent: ' . $namespace->get_name();
            }
        }
    }

    public function create_metadata_element($element)
    {
        foreach ($element->attributes as $attrName => $attrNode)
        {
            if ($attrName == 'schema_prefix')
            {
                $namespace_prefix = $attrNode->value;
            }
            elseif ($attrName == 'element')
            {
                $element_name = $attrNode->value;
            }
        }
        $namespace = MetadataDataManager::get_instance()->retrieve_metadata_namespace_by_prefix($namespace_prefix);

        if ($namespace)
        {
            $ns_id = $namespace->get_id();

            $property = MetadataDataManager::get_instance()->retrieve_metadata_element_by_ns_name($ns_id, $element_name);
            if (!$property)
            {
                //property does not exist & needs to be created
                $property = new MetadataElement();
                $property->set_namespace($ns_id);
                $property->set_name($element_name);
                $success = $property->create();
                if ($success)
                {
                    $this->log[] = '<b>property ' . $namespace_prefix . ':' . $element_name . ' created </b>';
                }
                else
                {
                    $this->log[] = 'problem! property ' . $namespace_prefix . ':' . $element_name . ' could not be created in namespace ' . $ns_id;
                }
            }
            else
            {
                $this->log[] = 'property ' . $namespace_prefix . ':' . $element_name . ' already exists in system ';
            }
        }
        else
        {
            //TODO: problem: namespace does not exist -> should have been imported & created: what went wrong?
            $this->log[] = 'import problem: namespace does not exist & was not created: ' . $namespace_prefix;
        }
    }


    public function render_metadata($content_object, $lo, $id)
    {
        //metadata
        $metadata = $content_object->getElementsByTagName('content_object_metadata')->item(0);
        if (is_object($metadata))
        {
            $children = $metadata->childNodes;
            for ($i = 0; $i < $children->length; $i++)
            {
                $co_metadata = $children->item($i);
                if ($co_metadata->nodeName == "#text")
                    continue;
                if ($co_metadata->hasAttributes())
                {
                    foreach ($co_metadata->attributes as $attrName => $attrNode)
                    {
                        if ($attrName == 'name')
                        {
                            $property = $attrNode->value;
                        }
                        elseif ($attrName == 'value')
                        {
                            $value = $attrNode->value;
                        }
                    }
                    list($namespace_prefix, $element_name) = explode(':', $property);
                    $namespace = MetadataDataManager::get_instance()->retrieve_metadata_namespace_by_prefix($namespace_prefix);
                    if ($namespace)
                    {
                        $ns_id = $namespace->get_id();
                        $element = MetadataDataManager::get_instance()->retrieve_metadata_element_by_ns_name($ns_id, $element_name);
                        if ($element)
                        {
                            $mpv = new ContentObjectMetadataElementValue();
                            $mpv->set_content_object_id($lo->get_id());
                            $mpv->set_element_id($element->get_id());
                            $mpv->set_value($value);
                            $success = $mpv->create();
                            if ($success)
                            {
                                $this->log[] = '<b> metadata ' . $property . '=' . $value . ' added to item with id ' . $lo->get_id() . '/' . $id . '</b>';
                            }
                            else
                            {
                                //problem: metadata_element_value not created
                                $this->log[] = 'Problem! metadata ' . $property . '=' . $value . ' was not added to item with id ' . $lo->get_id() . '/' . $id;
                            }
                        }
                        else
                        {
                            //problem: property was not imported
                            $this->log[] = 'Problem! metadata ' . $property . '=' . $value . ' was not added to item with id ' . $lo->get_id() . '/' . $id . ' because property does not exist in namespace with id ' . $namespace_id;
                        }
                    }
                    else
                    {
                        //problem: namespace was not imported
                        $this->log[] = 'Problem! metadata ' . $property . '=' . $value . ' was not added to item with id ' . $lo->get_id() . '/' . $id . ' because namespace ' . $namespace_prefix . ' does not exist';
                    }
                }
            }
        }
    }

}

?>