<?php
namespace metadata;

use common\libraries\Toolbar;
use common\libraries\ToolbarItem;
use common\libraries\Translation;
use common\libraries\Theme;
use common\libraries\Utilities;

use repository\DefaultContentObjectTableCellRenderer;

/**
 * Cell rendere for the learning object browser table
 *
 * @author Sven Vanpoucke
 * @author Jens Vanderheyden
 */

class ContentObjectMetadataElementValueBrowserTableCellRenderer extends DefaultContentObjectTableCellRenderer
{
    /**
     * The browser component
     */
    private $browser;

    /**
     * Constructor
     *
     * @param $browser ApplicationComponent
     */
    function __construct($browser)
    {
        parent :: __construct();
        $this->browser = $browser;
    }

    // Inherited
    function render_cell($column, $content_object)
    {
        if ($column === ContentObjectMetadataElementValueBrowserTableColumnModel :: get_modification_column())
        {
            return $this->get_modification_links($content_object);
        }

        return parent :: render_cell($column, $content_object);
    }

    /**
     * Gets the action links to display
     *
     * @param $content_object ContentObject The learning object for which the action links should be returned
     * @return string A HTML representation of the action links
     */
    private function get_modification_links($content_object)
    {
        $toolbar = new Toolbar(Toolbar :: TYPE_HORIZONTAL);

        $toolbar->add_item(
                new ToolbarItem(Translation :: get('Edit', null, Utilities :: COMMON_LIBRARIES),
                        Theme :: get_common_image_path() . 'action_edit.png',
                        $this->browser->get_edit_content_object_metadata_element_values_url($content_object),
                        ToolbarItem :: DISPLAY_ICON));

        return $toolbar->as_html();
    }
}
?>