<?php
namespace metadata;

use common\libraries\EqualityCondition;
use common\libraries\AndCondition;
use common\libraries\OrCondition;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\DynamicTabsRenderer;
use common\libraries\Redirect;
use common\libraries\BreadcrumbTrail;
use common\libraries\Breadcrumb;

use admin\AdminManager;

use group\GroupManager;
use group\GroupDataManager;

/**
 * Component to edit an existing metadata_element_value object
 * @author Sven Vanpoucke
 * @author Jens Vanderheyden
 */
class MetadataManagerGroupMetadataEditorComponent extends MetadataManager
{

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        $udm = GroupDataManager :: get_instance();

        if ($group = $udm->retrieve_group(Request :: get(MetadataManager :: PARAM_GROUP)))
        {
            $trail = BreadcrumbTrail :: get_instance();

            $trail->add(new BreadCrumb(Redirect :: get_link(AdminManager :: APPLICATION_NAME, array(
                    AdminManager :: PARAM_ACTION => AdminManager :: ACTION_ADMIN_BROWSER), array(), false, Redirect :: TYPE_CORE), Translation :: get('Admin')));
            $trail->add(new BreadCrumb(Redirect :: get_link(GroupManager :: APPLICATION_NAME, array(
                    GroupManager :: PARAM_ACTION => GroupManager :: ACTION_BROWSE_GROUPS,
                    DynamicTabsRenderer :: PARAM_SELECTED_TAB => GroupManager :: APPLICATION_NAME), array(), false, Redirect :: TYPE_CORE), Translation :: get('Groups')));
            $trail->add(new BreadCrumb($this->get_url(), Translation :: get('Metadata')));

            $condition = new EqualityCondition(GroupMetadataElementValue :: PROPERTY_GROUP_ID, $group->get_id());
            $metadata_element_values = $this->retrieve_group_metadata_element_values($condition);
            $metadata_element_values = $this->format_metadata_element_values($metadata_element_values);

            $form = new GroupMetadataEditorForm($group, $metadata_element_values, $this->get_url(array(
                    MetadataManager :: PARAM_GROUP => $group->get_id())), $this);

            if ($form->validate())
            {
                $success = $form->edit_metadata();
                $this->redirect($success ? Translation :: get('ObjectUpdated', array(
                        'OBJECT' => Translation :: get('Metadata')), Utilities :: COMMON_LIBRARIES) : Translation :: get('ObjectNotUpdated', array(
                        'OBJECT' => Translation :: get('Metadata')), Utilities :: COMMON_LIBRARIES), ! $success, array(
                        MetadataManager :: PARAM_ACTION => MetadataManager :: ACTION_EDIT_GROUP_METADATA,
                        MetadataManager :: PARAM_GROUP => $group->get_id()));
            }
            else
            {
                $this->display_header();
                $form->display();
                $this->display_footer();
            }
        }
        else
        {

        }

    }

    function format_metadata_element_values($metadata_element_values)
    {
        $metadata_element_value_arr = array();

        while ($metadata_porperty_value = $metadata_element_values->next_result())
        {
            $metadata_element_value_arr[$metadata_porperty_value->get_id()] = $metadata_porperty_value;
        }
        return $metadata_element_value_arr;
    }
}
?>