<?php
namespace metadata;

use common\libraries\Toolbar;
use common\libraries\Translation;
use common\libraries\Theme;
use common\libraries\ToolbarItem;
use common\libraries\Utilities;
/**
 * Cell rendere for the learning object browser table
 *
 * @author Sven Vanpoucke
 * @author Jens Vanderheyden
 */

class MetadataAttributeBrowserTableCellRenderer extends DefaultMetadataAttributeTableCellRenderer
{
    /**
     * The browser component
     */
    private $browser;

    /**
     * Constructor
     *
     * @param $browser ApplicationComponent
     */
    function __construct($browser)
    {
        parent :: __construct();
        $this->browser = $browser;
    }

    // Inherited
    function render_cell($column, $metadata_attribute)
    {
        switch ($column->get_name())
        {

        }

        if ($column === MetadataAttributeBrowserTableColumnModel :: get_modification_column())
        {
            return $this->get_modification_links($metadata_attribute);
        }

        return parent :: render_cell($column, $metadata_attribute);
    }

    /**
     * Gets the action links to display
     *
     * @param $content_object ContentObject The learning object for which the action links should be returned
     * @return string A HTML representation of the action links
     */
    private function get_modification_links($metadata_attribute)
    {
        $toolbar = new Toolbar(Toolbar :: TYPE_HORIZONTAL);

        $toolbar->add_item(
                new ToolbarItem(Translation :: get('Edit', null, Utilities :: COMMON_LIBRARIES),
                        Theme :: get_common_image_path() . 'action_edit.png',
                        $this->browser->get_update_metadata_attribute_url($metadata_attribute),
                        ToolbarItem :: DISPLAY_ICON));

        $toolbar->add_item(
                new ToolbarItem(Translation :: get('Delete', null, Utilities :: COMMON_LIBRARIES),
                        Theme :: get_common_image_path() . 'action_delete.png',
                        $this->browser->get_delete_metadata_attribute_url($metadata_attribute),
                        ToolbarItem :: DISPLAY_ICON, true));

        return $toolbar->as_html();
    }
}
?>