<?php
namespace metadata;

use common\libraries\Toolbar;
use common\libraries\Translation;
use common\libraries\Theme;
use common\libraries\ToolbarItem;
use common\libraries\Utilities;

/**
 * Cell rendere for the learning object browser table
 *
 * @author Sven Vanpoucke
 * @author Jens Vanderheyden
 */

class MetadataElementBrowserTableCellRenderer extends DefaultMetadataElementTableCellRenderer
{
    /**
     * The browser component
     */
    private $browser;

    /**
     * Constructor
     *
     * @param $browser ApplicationComponent
     */
    function __construct($browser)
    {
        parent :: __construct();
        $this->browser = $browser;
    }

    // Inherited
    function render_cell($column, $metadata_element)
    {
        if ($column === MetadataElementBrowserTableColumnModel :: get_modification_column())
        {
            return $this->get_modification_links($metadata_element);
        }

        return parent :: render_cell($column, $metadata_element);
    }

    /**
     * Gets the action links to display
     *
     * @param $content_object ContentObject The learning object for which the action links should be returned
     * @return string A HTML representation of the action links
     */
    private function get_modification_links($metadata_element)
    {
        $toolbar = new Toolbar(Toolbar :: TYPE_HORIZONTAL);

        $toolbar->add_item(
                new ToolbarItem(Translation :: get('Edit', null, Utilities :: COMMON_LIBRARIES),
                        Theme :: get_common_image_path() . 'action_edit.png',
                        $this->browser->get_update_metadata_element_url($metadata_element), ToolbarItem :: DISPLAY_ICON));

        $toolbar->add_item(
                new ToolbarItem(Translation :: get('Delete', null, Utilities :: COMMON_LIBRARIES),
                        Theme :: get_common_image_path() . 'action_delete.png',
                        $this->browser->get_delete_metadata_element_url($metadata_element), ToolbarItem :: DISPLAY_ICON,
                        true));

        $toolbar->add_item(
                new ToolbarItem(Translation :: get('Associations'), Theme :: get_common_image_path() . 'action_link.png',
                        $this->browser->get_edit_associations_url($metadata_element), ToolbarItem :: DISPLAY_ICON));

        $toolbar->add_item(
                new ToolbarItem(Translation :: get('MetadataDefaultValues'),
                        Theme :: get_common_image_path() . 'action_default.png',
                        $this->browser->get_browse_metadata_default_values_url($metadata_element),
                        ToolbarItem :: DISPLAY_ICON));

        $limit = $this->browser->get_display_order_total($metadata_element->get_namespace());

        // show move down button
        if ($metadata_element->get_order() < $limit)
        {
            $toolbar->add_item(
                    new ToolbarItem(Translation :: get('MoveDown'), Theme :: get_common_image_path() . 'action_down.png',
                            $this->browser->get_move_metadata_element_url($metadata_element, 1),
                            ToolbarItem :: DISPLAY_ICON));

        }

        // show move up button
        if ($metadata_element->get_order() != "1" && $limit != "1")
        {
            $toolbar->add_item(
                    new ToolbarItem(Translation :: get('MoveUp'), Theme :: get_common_image_path() . 'action_up.png',
                            $this->browser->get_move_metadata_element_url($metadata_element, - 1),
                            ToolbarItem :: DISPLAY_ICON));
        }

        return $toolbar->as_html();
    }
}
?>