<?php
namespace metadata;

use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\BreadcrumbTrail;
use common\libraries\Breadcrumb;
use common\libraries\Redirect;
use common\libraries\DynamicTabsRenderer;
use admin\AdminManager;

/**
 * Component to create a new metadata_element object
 * @author Sven Vanpoucke
 * @author Jens Vanderheyden
 */
class MetadataManagerMetadataElementCreatorComponent extends MetadataManager
{

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        $metadata_element = new MetadataElement();
        $form = new MetadataElementForm(MetadataElementForm :: TYPE_CREATE, $metadata_element, $this->get_url(), $this->get_user());

        if ($form->validate())
        {
            if ($success = $form->create_metadata_element())
            {
                if ($form->exportValue(MetadataElementForm :: ACTION_ASSOCIATE))
                {
                    $this->redirect(Translation :: get('ObjectCreated', array(
                            'OBJECT' => Translation :: get('MetadataElement')), Utilities :: COMMON_LIBRARIES), false, array(
                            MetadataManager :: PARAM_ACTION => MetadataManager :: ACTION_EDIT_ASSOCIATIONS,
                            MetadataManager :: PARAM_METADATA_ELEMENT => $success->get_id()));
                }
                else
                {
                    $this->redirect(Translation :: get('ObjectCreated', array(
                            'OBJECT' => Translation :: get('MetadataElement')), Utilities :: COMMON_LIBRARIES), false, array(
                            MetadataManager :: PARAM_ACTION => MetadataManager :: ACTION_BROWSE_METADATA_ELEMENTS));
                }

            }
            else
            {
                $this->redirect(Translation :: get('ObjectNotCreated', array(
                        'OBJECT' => Translation :: get('MetadataElement')), Utilities :: COMMON_LIBRARIES), true);
            }
        }
        else
        {
            $trail = BreadcrumbTrail :: get_instance();

            $trail->add(new BreadCrumb(Redirect :: get_link(AdminManager :: APPLICATION_NAME, array(
                    AdminManager :: PARAM_ACTION => AdminManager :: ACTION_ADMIN_BROWSER), array(), false, Redirect :: TYPE_CORE), Translation :: get('Admin')));
            $trail->add(new BreadCrumb(Redirect :: get_link(AdminManager :: APPLICATION_NAME, array(
                    AdminManager :: PARAM_ACTION => AdminManager :: ACTION_ADMIN_BROWSER,
                    DynamicTabsRenderer :: PARAM_SELECTED_TAB => MetadataManager :: APPLICATION_NAME), array(), false, Redirect :: TYPE_CORE), Translation :: get('Metadata')));
            $trail->add(new BreadCrumb($this->get_url(), Translation :: get('CreateObject', array(
                    'OBJECT' => Translation :: get('MetadataElement')), Utilities :: COMMON_LIBRARIES)));

            $this->display_header();
            $form->display();
            $this->display_footer();
        }
    }
}
?>