<?php
namespace metadata;

use common\libraries\EqualityCondition;
use common\libraries\AndCondition;
use common\libraries\OrCondition;
use common\libraries\Request;
use common\libraries\Translation;

use common\libraries\Utilities;
use common\libraries\BreadcrumbTrail;
use common\libraries\Breadcrumb;
use common\libraries\Redirect;
use admin\AdminManager;

use common\libraries\DynamicTabsRenderer;
use repository\RepositoryDataManager;
use repository\RepositoryManager;
use common\libraries\Application;

/**
 * Component to edit an existing metadata_element_value object
 * @author Sven Vanpoucke
 * @author Jens Vanderheyden
 */
class MetadataManagerMetadataQuickEditComponent extends MetadataManager
{

    /**
     * Runs this component and displays its output.
     */
    function run()
    {

        $ids = Request :: get(MetadataManager :: PARAM_CONTENT_OBJECT);

        $rdm = RepositoryDataManager :: get_instance();

        $trail = BreadcrumbTrail :: get_instance();

        $trail->add(new BreadCrumb(Redirect :: get_link(AdminManager :: APPLICATION_NAME, array(
                AdminManager :: PARAM_ACTION => AdminManager :: ACTION_ADMIN_BROWSER), array(), false, Redirect :: TYPE_CORE), Translation :: get('Admin')));
        $trail->add(new BreadCrumb(Redirect :: get_link(RepositoryManager :: APPLICATION_NAME, array(
                RepositoryManager :: PARAM_ACTION => RepositoryManager :: ACTION_BROWSE_CONTENT_OBJECTS,
                DynamicTabsRenderer :: PARAM_SELECTED_TAB => RepositoryManager :: APPLICATION_NAME), array(), false, Redirect :: TYPE_CORE), Translation :: get('ContentObjects')));
        $trail->add(new BreadCrumb($this->get_url(), Translation :: get('AddMetadata')));

        $form = new MetadataForm('metadata_form', 'post', $this->get_url(array(
                MetadataManager :: PARAM_CONTENT_OBJECT => $ids)));
        $form->set_parent_type(MetadataForm :: PARENT_CONTENT_OBJECT);
        $form->build_basic_form();

        if ($form->validate())
        {

            if (! empty($ids))
            {
                if (! is_array($ids))
                {
                    $ids = array($ids);
                }

                foreach ($ids as $id)
                {
                    $success &= $form->create_metadata_element_value($id);
                }
            }

            $params[Application :: PARAM_APPLICATION] = RepositoryManager :: APPLICATION_NAME;
            $params[RepositoryManager :: PARAM_ACTION] = RepositoryManager :: ACTION_BROWSE_CONTENT_OBJECTS;

            $this->redirect(Translation :: get($success ? 'ObjectUpdated' : 'ObjectnotUpdated', array(
                    'OBJECT' => Translation :: get('Metadata')), Utilities :: COMMON_LIBRARIES), ! $success, $params);
        }
        else
        {
            $this->display_header();
            $form->display();
            $this->display_footer();
        }
    }

    function format_metadata_element_values($metadata_element_values)
    {
        $metadata_element_value_arr = array();

        while ($metadata_porperty_value = $metadata_element_values->next_result())
        {
            $metadata_element_value_arr[$metadata_porperty_value->get_id()] = $metadata_porperty_value;
        }
        return $metadata_element_value_arr;
    }
}
?>