<?php
namespace metadata;

use common\libraries\EqualityCondition;
use common\libraries\AndCondition;
use common\libraries\OrCondition;
use common\libraries\Request;
use common\libraries\Translation;
use user\UserDataManager;
use common\libraries\Utilities;
use common\libraries\BreadcrumbTrail;
use common\libraries\Breadcrumb;
use common\libraries\Redirect;
use admin\AdminManager;
use user\UserManager;
use common\libraries\DynamicTabsRenderer;

/**
 * Component to edit an existing metadata_element_value object
 * @author Sven Vanpoucke
 * @author Jens Vanderheyden
 */
class MetadataManagerUserMetadataEditorComponent extends MetadataManager
{

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        $udm = UserDataManager :: get_instance();
        if ($user = $udm->retrieve_user(Request :: get(MetadataManager :: PARAM_USER)))
        {
            $trail = BreadcrumbTrail :: get_instance();

            $trail->add(new BreadCrumb(Redirect :: get_link(AdminManager :: APPLICATION_NAME, array(
                    AdminManager :: PARAM_ACTION => AdminManager :: ACTION_ADMIN_BROWSER), array(), false, Redirect :: TYPE_CORE), Translation :: get('Admin')));
            $trail->add(new BreadCrumb(Redirect :: get_link(UserManager :: APPLICATION_NAME, array(
                    UserManager :: PARAM_ACTION => UserManager :: ACTION_BROWSE_USERS,
                    DynamicTabsRenderer :: PARAM_SELECTED_TAB => UserManager :: APPLICATION_NAME), array(), false, Redirect :: TYPE_CORE), Translation :: get('Users')));
            $trail->add(new BreadCrumb($this->get_url(), Translation :: get('Metadata')));

            $condition = new EqualityCondition(UserMetadataElementValue :: PROPERTY_USER_ID, $user->get_id());
            $metadata_element_values = $this->retrieve_user_metadata_element_values($condition);
            $metadata_element_values = $this->format_metadata_element_values($metadata_element_values);

            $form = new UserMetadataEditorForm($user, $metadata_element_values, $this->get_url(array(
                    MetadataManager :: PARAM_USER => $user->get_id())), $this);

            if ($form->validate())
            {
                $success = $form->edit_metadata();
                $this->redirect(Translation :: get($success ? 'ObjectUpdated' : 'ObjectnotUpdated', array(
                        'OBJECT' => Translation :: get('Metadata')), Utilities :: COMMON_LIBRARIES), ! $success, array(
                        MetadataManager :: PARAM_ACTION => MetadataManager :: ACTION_EDIT_USER_METADATA,
                        MetadataManager :: PARAM_USER => $user->get_id()));
            }
            else
            {
                $this->display_header();
                $form->display();
                $this->display_footer();
            }
        }
        else
        {
            //no user
        }

    }

    function format_metadata_element_values($metadata_element_values)
    {
        $metadata_element_value_arr = array();

        while ($metadata_porperty_value = $metadata_element_values->next_result())
        {
            $metadata_element_value_arr[$metadata_porperty_value->get_id()] = $metadata_porperty_value;
        }
        return $metadata_element_value_arr;
    }
}
?>