<?php

namespace migration;

use common\libraries\CommonDataManager;

use common\libraries\ObjectTableOrder;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\PlatformSetting;
use common\libraries\DatetimeUtilities;
use admin\AdminDataManager;

/**
 *
 * @package migration
 * @author Sven Vanpoucke
 */
require_once dirname(__FILE__) . '/../../../common/global.inc.php';
ini_set("memory_limit", "-1");
set_time_limit(0);

Utilities :: set_application('migration');

$start_time = microtime(true);

// Temporary because i can't test command line with pear on mac os x
// echo '<pre>';

$setting = PlatformSetting :: get('in_migration', MigrationManager :: APPLICATION_NAME);
if ($setting != 1)
{
    $validate_settings = array();
    $selected_blocks = array();
    $migrated_blocks = array();

    $settings_file = dirname(__FILE__) . '/command_line_migration_settings.php';
    if (! file_exists($settings_file))
    {
        die(Translation :: get('NoCommandLineMigrationSettingsFileFound', array(), MigrationManager :: APPLICATION_NAME));
    }

    $settings = array();
    require_once $settings_file;

    $adm = AdminDataManager :: get_instance();

    $setting_names = array('platform', 'platform_path', 'move_files');
    foreach ($setting_names as $setting_name)
    {
        $value = $settings[$setting_name];
        if (is_null($value))
        {
            $value = 0;
        }

        $setting = CommonDataManager :: retrieve_setting_from_variable_name($setting_name, MigrationManager :: APPLICATION_NAME);
        $setting->set_value($value);
        $setting->update();

        $validate_settings[$setting_name] = $value;
    }

    $setting = CommonDataManager :: retrieve_setting_from_variable_name('in_migration', MigrationManager :: APPLICATION_NAME);
    $setting->set_value(1);
    $setting->update();

    if (! file_exists(dirname(__FILE__) . '/../lib/platform/' . $validate_settings['platform'] . '/'))
    {
        die(Translation :: get('CouldNotFindPlatform', array(), MigrationManager :: APPLICATION_NAME));
    }

    $properties = MigrationProperties :: factory($validate_settings['platform']);
    $blocks = $properties->get_migration_blocks();

    foreach ($blocks as $block)
    {
        if ($settings['blocks'][$block] == 1)
        {
            $migration_block_registration = new MigrationBlockRegistration();
            $migration_block_registration->set_name($block);
            $migration_block_registration->create();
            $selected_blocks[] = $block;
        }
    }

    PlatformSetting :: get_instance()->load_platform_settings();
}
else
{
    $validate_settings = array();
    $selected_blocks = array();
    $migrated_blocks = array();

    $setting_names = array('platform', 'platform_path', 'move_files', 'migrate_deleted_files');
    foreach ($setting_names as $setting_name)
    {
        $validate_settings[$setting_name] = PlatformSetting :: get($setting_name, MigrationManager :: APPLICATION_NAME);
    }

    if (! file_exists(dirname(__FILE__) . '/../lib/platform/' . $validate_settings['platform'] . '/'))
    {
        die(Translation :: get('CouldNotFindPlatform', array(), MigrationManager :: APPLICATION_NAME));
    }

    $properties = MigrationProperties :: factory($validate_settings['platform']);
    $blocks = $properties->get_migration_blocks();

    $migration_block_registrations = MigrationDataManager :: get_instance()->retrieve_migration_block_registrations(null, null, null, new ObjectTableOrder(MigrationBlockRegistration :: PROPERTY_ID));
    while ($migration_block_registration = $migration_block_registrations->next_result())
    {
        $block = $migration_block_registration->get_name();

        if ($migration_block_registration->get_is_migrated())
        {
            $migrated_blocks[] = $block;
        }
        else
        {
            $selected_blocks[] = $block;
        }
    }
}

$validated = $properties->validate_settings($validate_settings, $selected_blocks, $migrated_blocks);
if ($validated)
{
    echo Translation :: get('SettingsValid', array(), MigrationManager :: APPLICATION_NAME) . "\n";
}
else
{
    echo Translation :: get('SettingsNotValid', array(), MigrationManager :: APPLICATION_NAME) . "\n";
    echo $properties->get_message_logger()->render_for_cli();
    exit();
}

$platform = $validate_settings['platform'];

echo Translation :: get('BlocksMigration', array(), MigrationManager :: APPLICATION_NAME) . "\n\n";

foreach ($selected_blocks as $block)
{
    $migration_block = MigrationBlock :: factory($platform, $block);
    $migration_block->migrate();

    echo $migration_block->get_message_logger()->render_for_cli() . "\n\n";
}

echo Translation :: get('PostProcessing', array(), MigrationManager :: APPLICATION_NAME) . "\n\n";

$post_processors = MigrationPostProcess :: get_post_processors($platform);
foreach ($post_processors as $post_processor_name)
{
    $post_processor = MigrationPostProcess :: factory($platform, $post_processor_name);
    $post_processor->process();

    echo $post_processor->get_message_logger()->render_for_cli() . "\n\n";
}

$end_time = microtime(true);
$total_time = $end_time - $start_time;
$total_time = DatetimeUtilities :: convert_seconds_to_hours($total_time);

echo Translation :: get('MigrationComplete', array('TIME' => $total_time), MigrationManager :: APPLICATION_NAME);

?>
