<?php

namespace migration;

use common\libraries\MessageLogger;
use common\libraries\FileLogger;
use common\libraries\Filesystem;
use common\libraries\Timer;

/**
 * Classes can extend this class to create functionality that should run before, in or after the migration
 */
abstract class MigrationElement
{
    /**
     * @var MessageLogger $message_logger - used to log messages on the screen
     */
    private $message_logger;

    /**
     * @var FileLogger $file_logger - used to log messages in a file
     */
    private $file_logger;

    /**
     * @var Timer
     */
    private $timer;

    function __construct()
    {
        $this->message_logger = MessageLogger :: get_instance(__CLASS__);
        $this->timer = new Timer();
    }

    // Messages function

    /**
     * Returns the message logger
     * @return MessageLogger
     */
    function get_message_logger()
    {
        return $this->message_logger;
    }

    /**
     * Renders the message of the message logger
     */
    function render_message()
    {
        return $this->message_logger->render();
    }

    /**
     * Logs a message to both the message logger (onscreen) and to the file logger
     * @param String $message
     * @param Int $type
     */
    function log_message_and_file($message, $type)
    {
        $this->message_logger->add_message($message, $type);
        $this->get_file_logger()->log_message($message);
    }

    /**
     * Returns the file logger
     * @return FileLogger
     */
    protected function get_file_logger()
    {
        if (! $this->file_logger)
        {
            $dir = $this->get_file_logger_path();
            if (! file_exists($dir))
            {
                Filesystem :: create_dir($dir);
            }
            $this->file_logger = new FileLogger($dir . $this->get_file_logger_name() . '.log');
        }
        return $this->file_logger;
    }

    /**
     * Returns the timer
     * @return Timer
     */
    protected function get_timer()
    {
        return $this->timer;
    }

    abstract function get_file_logger_path();
    abstract function get_file_logger_name();
}
?>
