<?php
namespace migration;

use HTML_QuickForm_Action;
use common\libraries\Translation;
use common\libraries\Utilities;

/**
 * This class implements the action to take after the migration is finished
 */
class MigrationWizardProcess extends HTML_QuickForm_Action
{
    private $parent;

    public function __construct($parent)
    {
	$this->parent = $parent;
    }

    function perform($page, $actionName)
    {
        $this->display_header();

	$platform = $this->parent->get_platform();
	$post_processors = MigrationPostProcess :: get_post_processors($platform);
	
	if(count($post_processors) == 0)
	{
	    echo '<div class="normal-message">';
	    echo Translation :: get('NoPostProcessing');
	    echo '</div>';
	}

	foreach($post_processors as $post_processor_name)
	{
	    $post_processor = MigrationPostProcess :: factory($platform, $post_processor_name);
	    $post_processor->process();

	    echo '<div class="migration-step">';
	    echo '<div class="title">' . Translation :: get(Utilities :: underscores_to_camelcase($post_processor_name)
		    . 'PostProcess') . '</div>';
	    echo '<div class="description">';
	    echo $post_processor->get_message_logger()->render();
	    echo '</div></div>';
	}

        $this->display_footer();
    }

    function display_header()
    {
	$this->parent->display_header();

	$counter = 1;

        $html[] = '<div id="progressbox">';
        $html[] = '<ul id="progresstrail">';
	$html[] = '<li class="active"><a href="#">' . $counter . '. ' . Translation :: get('Confirm') . '</a></li>';

	$counter++;
        $blocks = $this->parent->get_blocks();

	foreach ($blocks as $block)
	{
	    $html[] = '<li class="active">';
	    $html[] = '<a href="#">' . $counter . '. ' . Translation :: get('Migrate' . Utilities :: underscores_to_camelcase($block));
	    $html[] = '</a></li>';
	    $counter++;
	}

	$html[] = '<li class="active">';
	$html[] = '<a href="#">' . $counter . '. ' . Translation :: get('Finish') . '</a></li>';
	$html[] = '</li>';
        $html[] = '</div>';
	$html[] = '</ul>';
	$html[] = '<div class="clear"></div>';

	$html[] = '<div class="migration_info">';
	$html[] = Translation :: get('FinishInfo');
	$html[] = '</div>';

	$html[] = '<br />';

	echo implode("\n", $html);
    }

    function display_footer()
    {
	$html[] = '<br />';
	$html[] = '<div class="migration_info">';
	$html[] = Translation :: get('MigrationFinished');
	$html[] = '</div>';

	echo implode("\n", $html);

	$this->parent->display_footer();
    }

}
?>