<?php

namespace migration;

use common\libraries\Text;
use repository\RepositoryDataManager;
use repository\RepositoryManager;
use DOMDocument;

/**
 * Implementation of the dokeos 185 text field parser to parse audio files from the given field
 * @author Sven Vanpoucke
 *
 */
class Dokeos185EmbeddedMediaTextFieldParser extends Dokeos185TextFieldParser
{

    function parse($text_field)
    {
        $dom_document = new DOMDocument();
        $dom_document->loadHTML($text_field);
        $tags = $dom_document->getElementsByTagname('embed');

        foreach ($tags as $tag)
        {
            
            $src = $tag->getAttribute('src');
            $src = str_replace('%3F0','',$src); // urldecode doesnt filter this out in some cases            
            $src = urldecode($src);
            
            $filename = basename($src);

            preg_match("/\..*/", $filename, $extension);
            $extension = $extension[0];

            $embed_element = $dom_document->createElement('embed');

            $embed_element->setAttribute('autosize', 'true');
            $embed_element->setAttribute('autostart', 'true');
            $embed_element->setAttribute('pluginspage', 'http://www.videolan.org/');
            $embed_element->setAttribute('showaudiocontrols', 'true');
            $embed_element->setAttribute('showcontrols', 'true');
            $embed_element->setAttribute('showgotobar', 'true');
            $embed_element->setAttribute('showstatusbar', 'true');
            $embed_element->setAttribute('showtracker', 'true');
            $embed_element->setAttribute('showcontrols', 'true');
            
            if($extension == '.swf')
            {
                $embed_element->setAttribute('type', 'application/x-shockwave-flash');
            }
            else
            {
                $embed_element->setAttribute('type', 'video/mpeg');
            }

            $document = RepositoryDataManager :: get_document_by_filename($filename);

            if ($document)
            {
                $this->add_included_object($document->get_id());

                $url = RepositoryManager :: get_document_downloader_url($document->get_id());

                $embed_element->setAttribute('src', $url);
            }
            else //streaming link
            {
                $embed_element->setAttribute('type', 'application/x-shockwave-flash');
                $embed_element->setAttribute('src', $tag->getAttribute('src'));
            }

            $tag->parentNode->replaceChild($embed_element, $tag);

            $text_field = $dom_document->saveHTML();
        }

        return $text_field;
    }

}