<?php
namespace reporting;

use common\libraries\Path;
use common\libraries\Theme;
use common\libraries\ToolbarItem;
use common\libraries\Toolbar;
use common\libraries\Translation;
use common\libraries\Utilities;

/**
 * $Id: reporting_template_registration_browser_table_cell_renderer.class.php 215 2009-11-13 14:07:59Z vanpouckesven $
 *
 * @package reporting.lib.reporting_manager.component.reporting_template_registration_browser_table
 * @author Michael Kyndt
 */
/**
 * Cell renderer for the reporting template registration browser table
 */
class ReportingTemplateRegistrationBrowserTableCellRenderer extends DefaultReportingTemplateRegistrationTableCellRenderer
{
    /**
     * The reporting template registration browser component
     */
    private $browser;

    /**
     * Constructor
     *
     * @param $browser ReportingTemplateManagerBrowserComponent
     */
    function __construct($browser)
    {
        parent :: __construct();
        $this->browser = $browser;
    }

    // Inherited
    function render_cell($column, $reporting_template_registration)
    {
        if ($column === ReportingTemplateRegistrationBrowserTableColumnModel :: get_modification_column())
        {
            return $this->get_modification_links($reporting_template_registration);
        }

        return parent :: render_cell($column, $reporting_template_registration);
    }

    /**
     * Gets the action links to display
     *
     * @param $reporting_template_registration ReportingTemplateRegistration The template object for which the links
     *            should be returned
     * @return string A HTML representation of the action links
     */
    private function get_modification_links($reporting_template_registration)
    {

        $toolbar = new Toolbar();

        $toolbar->add_item(
                new ToolbarItem(Translation :: get('View', null, Utilities :: COMMON_LIBRARIES),
                        Theme :: get_common_image_path() . 'action_reporting.png',
                        $this->browser->get_reporting_template_registration_viewing_url(
                                $reporting_template_registration), ToolbarItem :: DISPLAY_ICON));

        $toolbar->add_item(
                new ToolbarItem(Translation :: get('Edit', null, Utilities :: COMMON_LIBRARIES),
                        Theme :: get_common_image_path() . 'action_edit.png',
                        $this->browser->get_reporting_template_registration_editing_url(
                                $reporting_template_registration), ToolbarItem :: DISPLAY_ICON));

        return $toolbar->as_html();
    }
}
?>