<?php
namespace repository\content_object\assessment;

use common\libraries\Display;

use common\libraries\FormValidator;
use common\libraries\EqualityCondition;
use common\libraries\Session;
use common\libraries\Utilities;
use common\libraries\Translation;
use common\libraries\InCondition;
use common\libraries\Request;

use HTML_QuickForm_Controller;

use repository\RepositoryDataManager;
use repository\ComplexContentObjectItem;
use common\libraries\ResourceManager;
use common\libraries\Path;

class AssessmentViewerForm extends FormValidator
{
    const FORM_NAME = 'assessment_viewer_form';
    const PAGE_NUMBER = 'assessment_page_number';
    
    /**
     * @var AssessmentComplexDisplayAssessmentViewerComponent
     */
    private $assessment_viewer;
	private $questions;

    function __construct(AssessmentComplexDisplayAssessmentViewerComponent $assessment_viewer, $method = 'post', $action = null)
    {
        parent :: __construct(self :: FORM_NAME, $method, $action);
        
        $this->assessment_viewer = $assessment_viewer;
        
        $this->add_general();
        $this->add_buttons();
        $this->add_questions();
        $this->add_buttons();
    }

    function get_page_number()
    {
        return $this->assessment_viewer->get_questions_page();
    }

    function get_total_pages()
    {
        return $this->assessment_viewer->get_total_pages();
    }

    function get_assessment_viewer()
    {
        return $this->assessment_viewer;
    }

    function add_general()
    {
        $current_page = self :: PAGE_NUMBER . '-' . $this->get_page_number();
        $this->addElement('hidden', $current_page, $this->get_page_number());
        
        if ($this->get_page_number() == 1)
        {
            $this->add_information_message(null, null, $this->assessment_viewer->get_assessment()->get_description(), true);
        }
        
        $this->addElement('hidden', 'start_time', '', array('id' => 'start_time'));
        $this->addElement('hidden', 'max_time', '', array('id' => 'max_time'));
        $this->addElement('html', ResourceManager :: get_instance()->get_resource_html(Path :: get_repository_content_object_path(true) . '/assessment/resources/javascript/assessment.js'));
        $defaults['start_time'] = ($this->exportValue('start_time')) ? $this->exportValue('start_time') : 0;
        $defaults['max_time'] = ($this->assessment_viewer->get_assessment()->get_maximum_time() * 60);
        $this->setDefaults($defaults);
        
        if ($defaults['max_time'] > 0)
        {
            $this->addElement('html', ' <br /><div class="time_left">' . Translation :: get('TimeLeft') . '<br /><div class="time">' . $defaults['max_time'] . '</div>' . Translation :: get('SecondsShort') . '</div><br /><br />');
        }
    }

    function add_buttons()
    {
        //$progress = round(($this->get_page_number() / $this->get_total_pages()) * 100);
        //Display::get_progress_bar($progress)
        // TODO: Temporary fix
        $this->get_page_number();
        $this->get_total_pages();
        //        $this->addElement('html', '<div style="float: left; padding: 7px; font-weight: bold; line-height: 100%;">' . Translation :: get('PageNumberOfTotal', array(
        //                'CURRENT' => $this->get_page_number(), 'TOTAL' => $this->get_total_pages())) . '</div>');
        

        //Add submit button if there is at least one question
        if (count($this->questions) > 0)
        {
            $submit_button = $this->createElement('style_submit_button', 'submit', Translation :: get('Submit', null, Utilities :: COMMON_LIBRARIES), array(
                    'class' => 'positive submit', 'style' => 'display: none;'));
        }
        
        if ($this->assessment_viewer->get_feedback_per_page())
        {
            //            if (($this->get_page_number() <= $this->assessment_viewer->get_total_pages()))
            //            {
            $buttons[] = $this->createElement('style_submit_button', 'next', Translation :: get('Check', null, Utilities :: COMMON_LIBRARIES), array(
                    'class' => 'normal next'));
        
     //            }
        //            else
        //            {
        //                $buttons[] = $this->createElement('style_submit_button', 'submit', Translation :: get('Finish', null, Utilities :: COMMON_LIBRARIES), array(
        //                        'class' => 'positive finish'));
        //            }
        }
        else
        {
            if ($this->get_page_number() > 1)
            {
                $buttons[] = $this->createElement('style_submit_button', 'back', Translation :: get('Previous', null, Utilities :: COMMON_LIBRARIES), array(
                        'class' => 'previous'));
            }
            
            if ($this->get_page_number() < $this->get_total_pages())
            {
                $buttons[] = $this->createElement('style_submit_button', 'next', Translation :: get('Next', null, Utilities :: COMMON_LIBRARIES), array(
                        'class' => 'next'));
            }
            elseif ($submit_button)
            {
                $submit_button->_attributes['style'] = '';
            }
        }
        
        if ($submit_button)
        {
            $buttons[] = $submit_button;
        }
        
        if (count($buttons) > 0)
        {
            $this->addGroup($buttons, 'buttons', null, '&nbsp;', false);
        }
        
        $renderer = $this->defaultRenderer();
        $renderer->setElementTemplate('<div style="float: right;">{element}</div><br /><br />', 'buttons');
        $renderer->setGroupElementTemplate('{element}', 'buttons');
    }

    function add_questions()
    {
        $i = (($this->get_page_number() - 1) * $this->assessment_viewer->get_assessment()->get_questions_per_page()) + 1;
        
        $this->questions = $this->assessment_viewer->get_questions($this->get_page_number());
        
        foreach ($this->questions as $question)
        {
            $question_display = QuestionDisplay :: factory($this, $question, $i);
            $question_display->display();
            $i ++;
        }
    }
}
?>
