<?php
namespace repository\content_object\assessment;

use repository\ContentObjectResourceRenderer;

use common\libraries\Utilities;
use common\libraries\Theme;
use repository\RepositoryDataManager;

/**
 * $Id: question_display.class.php 200 2009-11-13 12:30:04Z kariboe $
 *
 * @package repository.lib.complex_display.assessment.component.viewer.wizard.inc
 */
abstract class QuestionDisplay
{
    private $complex_content_object_question;
    private $question;
    private $question_nr;
    private $formvalidator;
    private $renderer;

    function __construct($formvalidator, $complex_content_object_question, $question_nr, $question)
    {
        $this->formvalidator = $formvalidator;
        $this->renderer = $formvalidator->defaultRenderer();

        $this->complex_content_object_question = $complex_content_object_question;
        $this->question_nr = $question_nr;
        $this->question = $question;
    }

    function get_attempt()
    {
        return $this->get_formvalidator()->get_assessment_viewer()->get_assessment_question_attempt(
                $this->get_complex_content_object_question()->get_id());
    }

    function get_answers()
    {
        $attempt = $this->get_attempt();
        if (! is_null($attempt))
        {
            return unserialize($attempt->get_answer());
        }
        else
        {
            return false;
        }
    }

    function get_complex_content_object_question()
    {
        return $this->complex_content_object_question;
    }

    function get_question()
    {
        return $this->question;
    }

    function get_renderer()
    {
        return $this->renderer;
    }

    function get_formvalidator()
    {
        return $this->formvalidator;
    }

    function display()
    {
        $formvalidator = $this->formvalidator;
        $this->add_header();
        if ($this->add_borders())
        {
            $header = array();
            $header[] = $this->get_instruction();
            $header[] = '<div class="with_borders">';

            $formvalidator->addElement('html', implode("\n", $header));
        }
        $this->add_question_form();
        if ($this->add_borders())
        {
            $footer = array();
            $footer[] = '<div class="clear"></div>';
            $footer[] = '</div>';
            $formvalidator->addElement('html', implode("\n", $footer));
        }
        $this->add_footer();
    }

    abstract function add_question_form();

    function add_header()
    {
        $formvalidator = $this->formvalidator;
        /*
         * $clo_question = $this->get_clo_question(); $number_of_questions = $formvalidator->get_number_of_questions();
         * $current_question = $this->question_nr;
         */

        $html[] = '<div class="question">';
        $html[] = '<div class="title">';
        $html[] = '<div class="number">';
        $html[] = '<div class="bevel">';
        $html[] = $this->question_nr . '.';
        $html[] = '</div>';
        $html[] = '</div>';
        $html[] = '<div class="text">';
        $html[] = '<div class="bevel">';
        $html[] = $this->get_title();
        $html[] = '</div>';
        $html[] = '</div>';
        $html[] = '<div class="clear"></div>';
        $html[] = '</div>';
        $html[] = '<div class="answer">';
        $html[] = $this->get_description();
        $html[] = '<div class="clear"></div>';

        $header = implode("\n", $html);
        $formvalidator->addElement('html', $header);
    }

    function get_title()
    {
        return $this->question->get_title();
    }

    function get_description()
    {
        $html = array();

        $description = $this->question->get_description();
        if ($this->question->has_description())
        {
            $html[] = '<div class="description">';
            $renderer = new ContentObjectResourceRenderer($this, $description);
            $html[] = $renderer->run();
            $html[] = '<div class="clear">&nbsp;</div>';
            $html[] = '</div>';
        }

        return implode("\n", $html);
    }

    function add_footer($formvalidator)
    {
        $formvalidator = $this->formvalidator;

        $html[] = '</div>';
        $html[] = '</div>';

        $footer = implode("\n", $html);
        $formvalidator->addElement('html', $footer);
    }

    function add_borders()
    {
        return false;
    }

    abstract function get_instruction();

    static function factory($formvalidator, $complex_content_object_question, $question_nr)
    {
        $question = RepositoryDataManager :: get_instance()->retrieve_content_object(
                $complex_content_object_question->get_ref());
        $type = $question->get_type();

        $file = dirname(__FILE__) . '/question_display/' . $type . '.class.php';

        if (! file_exists($file))
        {
            die('file does not exist: ' . $file);
        }

        $class = __NAMESPACE__ . '\\' . Utilities :: underscores_to_camelcase($type) . 'Display';
        $question_display = new $class($formvalidator, $complex_content_object_question, $question_nr, $question);
        return $question_display;
    }

    /**
     *
     * @author Antonio Ognio @source http://www.php.net/manual/en/function.shuffle.php (06-May-2008 04:42)
     */
    function shuffle_with_keys($array)
    {
        /*
         * Auxiliary array to hold the new order
         */
        $aux = array();
        /*
         * We work with an array of the keys
         */
        $keys = array_keys($array);
        /*
         * We shuffle the keys
         */
        shuffle($keys);
        /*
         * We iterate thru' the new order of the keys
         */
        foreach ($keys as $key)
        {
            /*
             * We insert the key, value pair in its new order
             */
            $aux[$key] = $array[$key];
            /*
             * We remove the element from the old array to save memory
             */
        }
        /*
         * The auxiliary array with the new order overwrites the old variable
         */
        return $aux;
    }
}
?>