<?php
namespace repository\content_object\assessment;

use common\libraries\Theme;

use common\libraries\Translation;

use repository\content_object\fill_in_blanks_question\FillInBlanksQuestion;
use repository\content_object\fill_in_blanks_question\FillInBlanksQuestionAnswer;

/**
 * $Id: fill_in_blanks_question_result_display.class.php 200 2009-11-13 12:30:04Z kariboe $
 * @package repository.lib.complex_display.assessment.component.viewer.wizard.inc.question_result_display
 */

class FillInBlanksQuestionResultDisplay extends AssessmentQuestionResultDisplay
{
    /**
     * @var string
     */
    private $parts;
    
    /**
     * @var array
     */
    private $feedback_answer = array();
    
    /**
     * @var boolean
     */
    private $has_feedback;

    function get_question_result()
    {
        $answers = $this->get_answers();
        
        $answer_text = $this->get_question()->get_answer_text();
        $answer_text = nl2br($answer_text);
        $this->parts = preg_split(FillInBlanksQuestionAnswer :: QUESTIONS_REGEX, $answer_text);
        
        $html[] = '<div class="with_borders">';
        $html[] = array_shift($this->parts);
        
        $text = array();
        $index = 0;
        foreach ($this->parts as $i => $part)
        {
            switch ($this->get_question()->is_correct($i, $answers[$i]))
            {
                case FillInBlanksQuestion :: MARK_MAX :
                    $text[] = '<span style="color:green"><b>' . $answers[$i] . '</b></span>';
                    break;
                case FillInBlanksQuestion :: MARK_CORRECT :
                    $text[] = '<span style="color:orange"><b>' . $answers[$i] . '</b></span>';
                    break;
                case FillInBlanksQuestion :: MARK_WRONG :
					$best_answer = $this->get_question()->get_best_answer_for_question($index);
		            $best_answer_text = $best_answer->get_value();
                    $text[] = '<span style="color:green"><b>' . $best_answer_text . '</b></span>';
                    break;
            }
            
            $text[] = $part;
            $index ++;
        }
        
        $html[] = implode('', $text);
        $html[] = '</div>';
        
        $html[] = '<table class="data_table take_assessment">';
        $html[] = '<thead>';
        $html[] = '<tr>';
        $html[] = '<th class="empty"></th>';
        if (count($this->parts) > 1)
        {
            $html[] = '<th class="list">#</th>';
        }
        $html[] = '<th class="list">' . Translation :: get('Answer') . '</th>';
        
        if ($this->get_assessment_result_processor()->get_assessment_viewer()->display_textual_feedback())
        {
            $html[] = '<th class="list">' . Translation :: get('Feedback') . '</th>';
        }
        
        if ($this->get_assessment_result_processor()->get_assessment_viewer()->display_numeric_feedback())
        {
            $html[] = '<th class="list">' . Translation :: get('Score') . '</th>';
        }
        
        $html[] = '</tr>';
        $html[] = '</thead>';
        $html[] = '<tbody>';
        
        foreach ($this->parts as $index => $part)
        {
            $html[] = $this->get_question_feedback($index, $answers[$index], count($this->parts) > 1);
        }
        
        $html[] = '</tbody>';
        $html[] = '</table>';
        
        return implode("\n", $html);
    }

    function get_question_feedback($index, $answer, $multiple_answers)
    {
        
        $question = $this->get_question();
        $correct = $question->is_correct($index, $answer);
        
        $html[] = '<tr class="' . ($index % 2 == 0 ? 'row_even' : 'row_odd') . '">';
        
        if ($multiple_answers)
        {
            $html[] = '<td>' . ($index + 1) . '</td>';
        }
        
        switch ($correct)
        {
            case FillInBlanksQuestion :: MARK_MAX :
                $show_answer = empty($answer) ? '""' : '"' . $answer . '"';
                $html[] = '<td><img src="' . Theme :: get_image_path() . 'answer_correct.png" /></td>';
                $html[] = '<td><span style="color:green"><b>' . $show_answer . '</b></span></td>';
                break;
            case FillInBlanksQuestion :: MARK_CORRECT :
                $show_answer = empty($answer) ? '""' : '"' . $answer . '"';
                $html[] = '<td><img src="' . Theme :: get_image_path() . 'answer_warning.png" /></td>';
                $html[] = '<td><span style="color:orange"><b>' . $show_answer . '</b></span></td>';
                break;
            case FillInBlanksQuestion :: MARK_WRONG :
				$show_answer = empty($answer) ? Translation :: get('NoAnswer') : '"' . $answer . '"';
                $percentage = 0;
                if (! $question->get_best_answer_for_question($index)->check_regex())
                {
                    // always do similarity checks case insensitive.
                    similar_text(mb_strtolower($answer, 'UTF-8'), mb_strtolower($question->get_best_answer_for_question($index)->get_value(), 'UTF-8'), $percentage);
                }
                if ($percentage >= 70)
                {
                    $html[] = '<td><img src="' . Theme :: get_image_path() . 'answer_warning.png" /></td>';
                    $html[] = '<td><span style="color:orange"><b>' . $show_answer . '</b></span></td>';
                }
                else
                {
                    $html[] = '<td><img src="' . Theme :: get_image_path() . 'answer_wrong.png" /></td>';
                    $html[] = '<td><span style="color:red"><b>' . $show_answer . '</b></span></td>';
                }
                break;
        }
        
        if ($this->get_assessment_result_processor()->get_assessment_viewer()->display_textual_feedback())
        {
            // get the comment
            $answer_object = $question->get_answer_object($index, $answer);
            if (isset($answer_object))
            {
                if ($answer_object->has_comment())
                {
                    $comment = $answer_object->get_comment();
                }
            }
            
            $html[] = '<td>';
            switch ($correct)
            {
                case FillInBlanksQuestion :: MARK_MAX :
                    if (isset($comment))
                    {
                        $html[] = $comment;
                    }
                    else
                    {
                        $html[] = '-';
                    }
                    break;
                case FillInBlanksQuestion :: MARK_CORRECT :
                    $html[] = '-';
                case FillInBlanksQuestion :: MARK_WRONG :
                    if (isset($comment))
                    {
                        $html[] = $comment;
                        $html[] = '<br/><br/>';
                    }
                    $best_answer = $question->get_best_answer_for_question($index);
					$number_of_answers = $question->get_answers($index);

                    if ($best_answer->check_regex())
                    {
                        $regex = $best_answer->get_regex_pattern();
                        if ($regex == '^$') // special case for empty answer.
                        {
                            $html[] = Translation :: get(count($number_of_answers) > 1 ? 'BestAnswerWas' : 'AnswerWas', array(
                                    'ANSWER' => '""'));
                        }
                        else
                        {
                            $html[] = Translation :: get('BestAnswerWasRegex', array('ANSWER' => '"' . $regex . '"'));
                        }
                    }
                    else
                    {
                        $html[] = Translation :: get(count($number_of_answers) > 1 ? 'BestAnswerWas' : 'AnswerWas', array(
                                'ANSWER' => '"' . $best_answer->get_value() . '"'));

                    }

                    break;
            }
            $html[] = '</td>';
        }
        
        if ($this->get_assessment_result_processor()->get_assessment_viewer()->display_numeric_feedback())
        {
            $weight = $question->get_weight_from_answer($index, $answer);
            $max_question_weight = $question->get_question_maximum_weight($index);
            $html[] = '<td>' . $weight . ' / ' . $max_question_weight . '</td>';
        }
        
        $html[] = '</tr>';
        
        return implode("\n", $html);
    }

    function get_question_answer($index)
    {
        $result = array();
        $answers = $this->get_question()->get_answers();
        foreach ($answers as $answer)
        {
            if ($answer->get_position() == $index)
            {
                $result[] = $answer;
            }
        }
        
        return $result;
    }

    /**
     * @return boolean
     */
    function has_feedback()
    {
        if (! isset($this->has_feedback))
        {
            $answers = $this->get_answers();
            
            $this->has_feedback = false;
            
            foreach ($this->parts as $index => $part)
            {
                $weight = $this->get_question()->get_weight_from_answer($index, $answers[$index]);
                $max_question_weight = $this->get_question()->get_question_maximum_weight($index);
                
                if ($weight != 0)
                {
                    $as = $this->get_question()->get_answers($index);
                    
                    foreach ($as as $a)
                    {
                        if ($a->get_value() == $answers[$index] && $a->get_position() == $index && $a->has_comment())
                        {
                            $this->has_feedback = true;
                        }
                    }
                }
                else
                {
                    $this->has_feedback = true;
                }
            }
        
        }
        
        return $this->has_feedback;
    }
}