<?php
namespace repository\content_object\assessment;

use common\libraries\Utilities;

/**
 * $Id: score_calculator.class.php 200 2009-11-13 12:30:04Z kariboe $
 *
 * @package repository.lib.complex_display.assessment.component.viewer.wizard.inc
 */
/**
 * Abstract class so each question type can determine the correct score with the given answers
 */
abstract class ScoreCalculator
{
    private $answer;
    private $question;

    function __construct($question, $answer, $weight)
    {
        $this->answer = $answer;
        $this->question = $question;
        $this->weight = $weight;
    }

    abstract function calculate_score();

    function get_answer()
    {
        return $this->answer;
    }

    function get_question()
    {
        return $this->question;
    }

    function get_weight()
    {
        return $this->weight;
    }

    function make_score_relative($score, $total_weight)
    {
        $relative_weight = $this->weight;

        if ($relative_weight == null)
            return $score;

        if ($total_weight == 0)
        {
            return 0;
        }

        $factor = ($total_weight / $relative_weight);

        $new_score = round(($score / $factor) * 100) / 100;

        return $new_score;
    }

    static function factory($question, $answer, $weight)
    {
        $type = $question->get_type();
        $type = str_replace('_question', '', $type);
        $file = dirname(__FILE__) . '/score_calculator/' . $type . '_score_calculator.class.php';

        if (! file_exists($file))
        {
            die('file does not exist: ' . $file);
        }

        $class = __NAMESPACE__ . '\\' . Utilities :: underscores_to_camelcase($type) . 'ScoreCalculator';
        $score_calculator = new $class($question, $answer, $weight);
        return $score_calculator;
    }
}
?>