<?php

namespace repository\content_object\assignment;

use common\libraries\Utilities;
use common\libraries\AttachmentSupport;
use repository\ContentObject;

/**
 * @package repository.content_object.assignment.php
 * 
 * This class represents an assignment
 * 
 * @author Joris Willems <joris.willems@gmail.com>
 * @author Alexander Van Paemel
 */
class Assignment extends ContentObject implements AttachmentSupport
{
    const CLASS_NAME = __CLASS__;
    const PROPERTY_START_TIME = 'start_time';
    const PROPERTY_END_TIME = 'end_time';
    const PROPERTY_VISIBILITY_SUBMISSIONS = 'visibility_submissions';
    const PROPERTY_ALLOW_GROUP_SUBMISSIONS = 'allow_group_submissions';
    const PROPERTY_ALLOW_LATE_SUBMISSIONS = 'allow_late_submissions';
    const PROPERTY_VISIBILTY_FEEDBACK = 'visibility_feedback';
    const PROPERTY_AUTOMATIC_FEEDBACK_TEXT = 'automatic_feedback_text';
    const PROPERTY_AUTOMATIC_FEEDBACK_CO_IDS = 'automatic_feedback_co_ids';
    const PROPERTY_SELECT_ATTACHMENT = 'select_attachment';
    const PROPERTY_ALLOWED_TYPES = 'allowed_types';
    
    const VISIBILITY_FEEDBACK_AFTER_END_TIME = 0;
    const VISIBILITY_FEEDBACK_AFTER_SUBMISSION = 1;

    static function get_type_name()
    {
        return Utilities :: get_classname_from_namespace(self :: CLASS_NAME, true);
    }

    static function get_additional_property_names()
    {
        return array(self :: PROPERTY_START_TIME, self :: PROPERTY_END_TIME, self :: PROPERTY_VISIBILITY_SUBMISSIONS, 
                self :: PROPERTY_ALLOW_GROUP_SUBMISSIONS, self :: PROPERTY_ALLOW_LATE_SUBMISSIONS, 
                self :: PROPERTY_AUTOMATIC_FEEDBACK_TEXT, self :: PROPERTY_VISIBILTY_FEEDBACK, 
                self :: PROPERTY_AUTOMATIC_FEEDBACK_CO_IDS, self :: PROPERTY_ALLOWED_TYPES);
    }

    function get_allow_group_submissions()
    {
        return $this->get_additional_property(self :: PROPERTY_ALLOW_GROUP_SUBMISSIONS);
    }

    function set_allow_group_submissions($allow_group_submissions)
    {
        $this->set_additional_property(self :: PROPERTY_ALLOW_GROUP_SUBMISSIONS, $allow_group_submissions);
    }

    function get_start_time()
    {
        return $this->get_additional_property(self :: PROPERTY_START_TIME);
    }

    function set_start_time($start_time)
    {
        $this->set_additional_property(self :: PROPERTY_START_TIME, $start_time);
    }

    function get_end_time()
    {
        return $this->get_additional_property(self :: PROPERTY_END_TIME);
    }

    function set_end_time($end_time)
    {
        $this->set_additional_property(self :: PROPERTY_END_TIME, $end_time);
    }

    function get_visibility_submissions()
    {
        return $this->get_additional_property(self :: PROPERTY_VISIBILITY_SUBMISSIONS);
    }

    function set_visibility_submissions($visibility_submissions)
    {
        $this->set_additional_property(self :: PROPERTY_VISIBILITY_SUBMISSIONS, $visibility_submissions);
    }

    function get_allow_late_submissions()
    {
        return $this->get_additional_property(self :: PROPERTY_ALLOW_LATE_SUBMISSIONS);
    }

    function set_allow_late_submissions($allow_late_submissions)
    {
        $this->set_additional_property(self :: PROPERTY_ALLOW_LATE_SUBMISSIONS, $allow_late_submissions);
    }

    function get_visibility_feedback()
    {
        return $this->get_additional_property(self :: PROPERTY_VISIBILTY_FEEDBACK);
    }

    function set_visibility_feedback($visibility_feedback)
    {
        $this->set_additional_property(self :: PROPERTY_VISIBILTY_FEEDBACK, $visibility_feedback);
    }

    function get_automatic_feedback_text()
    {
        return $this->get_additional_property(self :: PROPERTY_AUTOMATIC_FEEDBACK_TEXT);
    }

    function set_automatic_feedback_text($automatic_feedback_text)
    {
        $this->set_additional_property(self :: PROPERTY_AUTOMATIC_FEEDBACK_TEXT, $automatic_feedback_text);
    }

    function get_automatic_feedback_co_ids()
    {
        return $this->get_additional_property(self :: PROPERTY_AUTOMATIC_FEEDBACK_CO_IDS);
    }

    function set_automatic_feedback_co_ids($automatic_feedback_co_ids)
    {
        $this->set_additional_property(self :: PROPERTY_AUTOMATIC_FEEDBACK_CO_IDS, $automatic_feedback_co_ids);
    }

    function get_allowed_types()
    {
        return $this->get_additional_property(self :: PROPERTY_ALLOWED_TYPES);
    }

    function set_allowed_types($allowed_types)
    {
        $this->set_additional_property(self :: PROPERTY_ALLOWED_TYPES, $allowed_types);
    }
}

?>