<?php
namespace repository\content_object\calendar_event;

use common\libraries\Session;
use repository\ContentObject;

class IcalImportImplementation extends ImportImplementation
{

    function import()
    {
        $content_object = ContentObject :: factory(CalendarEvent :: get_type_name());
        $content_object->set_owner_id($this->get_controller()->get_parameters()->get_user());
        $content_object->set_parent_id($this->get_controller()->get_parameters()->get_category());
        $component = $this->get_content_object_import_parameters()->get_calendar_component();
        $content_object->set_title($component->summary['value']);
        if (isset($component->description[0]))
        {
            $content_object->set_description($component->description[0]['value']);
        }
        else
        {
            $content_object->set_description('-');
        }
        $content_object->set_start_date(mktime($component->dtstart['value']['hour'], $component->dtstart['value']['min'], $component->dtstart['value']['sec'], $component->dtstart['value']['month'], $component->dtstart['value']['day'], $component->dtstart['value']['year']));
        $content_object->set_end_date(mktime($component->dtend['value']['hour'], $component->dtend['value']['min'], $component->dtend['value']['sec'], $component->dtend['value']['month'], $component->dtend['value']['day'], $component->dtend['value']['year']));
        
        if ($component->rrule[0])
        {
            switch ($component->rrule[0]['value']['FREQ'])
            {
                case 'MONTHLY' :
                    $content_object->set_frequency(CalendarEvent :: FREQ_MONTHLY);
                    break;
                case 'YEARLY' :
                    $content_object->set_frequency(CalendarEvent :: FREQ_YEARLY);
                    break;
                case 'WEEKLY' :
                    $content_object->set_frequency(CalendarEvent :: FREQ_BIWEEK);
                    if ($component->rrule[0]['value']['INTERVAL'] == '2')
                    {
                        $content_object->set_frequency(CalendarEvent :: FREQ_BIWEEK);
                    }
                    else
                    {
                        $content_object->set_frequency(CalendarEvent :: FREQ_WEEKLY);
                    }
                    break;
                case 'DAILY' :
                    $weekdays = array(array('DAY' => 'MO'), array('DAY' => 'TU'), array('DAY' => 'WE'), 
                            array('DAY' => 'TH'), array('DAY' => 'FR'));
                    
                    if ($component->rrule[0]['value']['BYDAY'] == $weekdays)
                    {
                        $content_object->set_frequency(CalendarEvent :: FREQ_WEEK_DAYS);
                    }
                    else
                    {
                        $content_object->set_frequency(CalendarEvent :: FREQ_DAILY);
                    }
                    break;
            }
            
            if ($component->rrule[0]['value']['UNTIL'])
            {
                $content_object->set_until(mktime($component->rrule[0]['value']['UNTIL']['hour'], $component->rrule[0]['value']['UNTIL']['min'], $component->rrule[0]['value']['UNTIL']['sec'], $component->rrule[0]['value']['UNTIL']['month'], $component->rrule[0]['value']['UNTIL']['day'], $component->rrule[0]['value']['UNTIL']['year']));
            }
            if ($component->rrule[0]['value']['COUNT'])
            {
                $content_object->set_frequency_count($component->rrule[0]['value']['COUNT']);
            }
            
            if ($component->rrule[0]['value']['INTERVAL'])
            {
                $content_object->set_frequency_interval($component->rrule[0]['value']['INTERVAL']);
            }
            
            if ($component->rrule[0]['value']['BYMONTHDAY'])
            {
                $content_object->set_bymonthday($component->rrule[0]['value']['BYMONTHDAY']);
            }
            
            if ($component->rrule[0]['value']['BYMONTH'])
            {
                $content_object->set_bymonth($component->rrule[0]['value']['BYMONTH']);
            }
        
        }
        return $content_object;
    }
}
?>