<?php
namespace repository\content_object\calendar_event;
/**
 *
 * @author Magali Gillard
 * @author Hans De Bisschop
 */

use common\libraries\IcalRecurrence;

use common\libraries\Text;

use common\libraries\Utilities;
use common\libraries\Translation;

class Recurrence extends IcalRecurrence
{

    function __construct(CalendarEvent $event, $from_date, $to_date)
    {
        parent :: __construct($event, $from_date, $to_date);
    }

    /**
     *
     * @return the $interval
     */
    public function get_interval()
    {
        if (! isset($this->interval))
        {
            if (! is_null($this->get_event()->get_frequency_interval()))
            {
                $this->interval = $this->get_event()->get_frequency_interval();
            }
            else
            {
                $this->interval = 1;
            }
        }
        return $this->interval;
    }

    /**
     *
     * @return the $count
     */
    public function get_count()
    {
        if (! isset($this->count))
        {
            if (! is_null($this->get_event()->get_frequency_count()))
            {
                $this->count = $this->get_event()->get_frequency_count();
            }
            else
            {
                $this->count = 1000000;
            }
        }
        return $this->count;
    }

    function get_start_date($timestamp = true, $time_midnight = false)
    {
        if (! isset($this->start_date))
        {
            $this->start_date = $this->get_event()->get_start_date();
        }
        if ($timestamp)
        {
            if ($time_midnight)
            {
                return strtotime(date('Ymd', $this->start_date . ' 00:00:00'));
            }
            else
            {
                return $this->start_date;
            }
        }
        else
        {
            return date('Ymd', $this->start_date);
        }
    }

    function get_end_date($timestamp = true)
    {
        $end_date = $this->get_event()->get_end_date();
        return ($timestamp ? $end_date : date('Ymd', $end_date));
    }

    function repeats()
    {
        return $this->get_event()->has_frequency();
    }

    function get_duration()
    {
        return null;
    }

    /**
     *
     * @return the $bymonth
     */
    public function get_bymonth()
    {
        if (! is_null($this->get_event()->get_bymonth()))
        {
            return explode(',', $this->get_event()->get_bymonth());
        }
        else
        {
            return null;
        }
    }

    /**
     *
     * @return the $byweekno
     */
    public function get_byweekno()
    {
        if ($this->get_event()->get_frequency())
        {
            return '';
        }
        else
        {
            return null;
        }
    }

    /**
     *
     * @return the $bymonthday
     */
    public function get_bymonthday()
    {
        if (! is_null($this->get_event()->get_bymonthday()))
        {
            return explode(',', $this->get_event()->get_bymonthday());
        }
        else
        {
            return null;
        }
    }

    /**
     *
     * @return the $freq_type
     */
    public function get_freq_type()
    {
        switch ($this->get_event()->get_frequency())
        {
            case CalendarEvent :: FREQ_DAILY :
                return self :: REPEAT_TYPE_DAY;
                break;
            case CalendarEvent :: FREQ_WEEKLY :
                return self :: REPEAT_TYPE_WEEK;
                break;
            case CalendarEvent :: FREQ_MONTHLY :
                return self :: REPEAT_TYPE_MONTH;
                break;
            case CalendarEvent :: FREQ_YEARLY :
                return self :: REPEAT_TYPE_YEAR;
                break;
            default :
                return self :: NO_REPEAT;
                break;
        }
    }

    /**
     *
     * @return the $except_dates
     */
    public function get_except_dates()
    {
        return null;
    }

    /**
     *
     * @return the $until_unixtime
     */
    public function get_until_unixtime()
    {
        if (! is_null($this->get_event()->get_until()))
        {
            return $this->get_event()->get_until();
        }
    }

    /**
     *
     * @return the $wkst
     */
    public function get_wkst($convert = false, $text = true)
    {
        $wkst = 'MO';
        
        if ($convert)
        {
            return $this->convert_day_name($wkst, $text);
        }
        else
        {
            return $wkst;
        }
    }

    /**
     *
     * @return the $byyearday
     */
    public function get_byyearday()
    {
        return null;
    }

    /**
     *
     * @return the $byday
     */
    public function get_byday()
    {
        if (! is_null($this->get_event()->get_byday()))
        {
            return explode(',', $this->get_event()->get_byday());
        }
        else
        {
            return null;
        }
    }

    public function get_bysetpos()
    {
        return null;
    }
}
?>
