<?php
namespace repository\content_object\document;

use common\libraries\PatternMatchCondition;

use repository\RepositoryDataManager;
use repository\ContentObjectAdvancedFilter;

use common\libraries\AndCondition;
use common\libraries\Session;
use common\libraries\Translation;
use common\libraries\InequalityCondition;

class AdvancedFilter extends ContentObjectAdvancedFilter
{
    const FILTER_COMPARE = 'compare';
    const FILTER_FORMAT = 'format';
    
    const COMPARE_EQUAL = 10;

    function get_conditions()
    {
        $session_filter = Session :: retrieve('advanced_filter');
        $conditions = array();
        if ($this->get_form()->validate() || isset($session_filter))
        {
            if ($this->get_form()->validate())
            {
                $values = $this->get_form()->exportValues();
            }
            else
            {
                $values = unserialize(Session :: retrieve('advanced_filter'));
            }
            
            $filter = serialize($values);
            if ($this->get_form()->validate())
            {
                Session :: register('advanced_filter', $filter);
            }
            
            if ($values[self :: FILTER_COMPARE] && $values[Document :: PROPERTY_FILESIZE] && $values[self :: FILTER_FORMAT])
            {
                $filesize = $values[Document :: PROPERTY_FILESIZE] * pow(1024, $values[self :: FILTER_FORMAT]);
                if ($values[self :: FILTER_COMPARE] == self :: COMPARE_EQUAL)
                {
                    $equality_conditions = array();
                    $equality_conditions[] = new InequalityCondition(Document :: PROPERTY_FILESIZE, InequalityCondition :: GREATER_THAN_OR_EQUAL, $filesize * 0.9, RepositoryDataManager :: get_instance()->get_alias_type_table(), true);
                    $equality_conditions[] = new InequalityCondition(Document :: PROPERTY_FILESIZE, InequalityCondition :: LESS_THAN_OR_EQUAL, $filesize * 1.1, RepositoryDataManager :: get_instance()->get_alias_type_table(), true);
                    $conditions[] = new AndCondition($equality_conditions);
                }
                else
                {
                    $conditions[] = new InequalityCondition(Document :: PROPERTY_FILESIZE, $values[self :: FILTER_COMPARE], $filesize, RepositoryDataManager :: get_instance()->get_alias_type_table(), true);
                }
            }
            
            if ($values[Document :: PROPERTY_EXTENSION])
            {
                $conditions[] = new PatternMatchCondition(Document :: PROPERTY_FILENAME, '*.' . $values[Document :: PROPERTY_EXTENSION], RepositoryDataManager :: get_instance()->get_alias_type_table(), true);
            }
        }
        
        return $conditions;
    }

    function get_parameters()
    {
        $session_filter = Session :: retrieve('advanced_filter');
        $html = array();
        if ($this->get_form()->validate() || isset($session_filter))
        {
            if ($this->get_form()->validate())
            {
                $values = $this->get_form()->exportValues();
            }
            else
            {
                $values = unserialize(Session :: retrieve('advanced_filter'));
            }
            
            if ($values[self :: FILTER_COMPARE] && $values[Document :: PROPERTY_FILESIZE] && $values[self :: FILTER_FORMAT])
            {
                $filesize = $values[Document :: PROPERTY_FILESIZE] * pow(1024, $values[self :: FILTER_FORMAT]);
                
                switch ($values[self :: FILTER_FORMAT])
                {
                    case 1 :
                        $format = Translation :: get('KilobyteShort');
                        break;
                    case 2 :
                        $format = Translation :: get('MegabyteShort');
                        break;
                    case 3 :
                        $format = Translation :: get('GigabyteShort');
                        break;
                }
                
                $filesize_id = 'parameter_' . $this->get_form()->get_type() . '_filesize';
                
                if ($values[self :: FILTER_COMPARE] == self :: COMPARE_EQUAL)
                {
                    $html[] = '<div class="parameter" id="' . $filesize_id . '">' . Translation :: get('FilesizeAbout', array(
                            'SIZE' => $values[Document :: PROPERTY_FILESIZE], 'FORMAT' => $format)) . '</div>';
                }
                else
                {
                    switch ($values[self :: FILTER_COMPARE])
                    {
                        case InequalityCondition :: GREATER_THAN :
                            $html[] = '<div class="parameter" id="' . $filesize_id . '">' . Translation :: get('FilesizeGreaterThanShort', array(
                                    'SIZE' => $values[Document :: PROPERTY_FILESIZE], 'FORMAT' => $format)) . '</div>';
                            break;
                        case InequalityCondition :: LESS_THAN :
                            $html[] = '<div class="parameter" id="' . $filesize_id . '">' . Translation :: get('FilesizeLessThanShort', array(
                                    'SIZE' => $values[Document :: PROPERTY_FILESIZE], 'FORMAT' => $format)) . '</div>';
                            break;
                    }
                }
            }
            
            if ($values[Document :: PROPERTY_EXTENSION])
            {
                $html[] = '<div class="parameter" id="parameter_' . $this->get_form()->get_type() . '_extension">' . $values[Document :: PROPERTY_EXTENSION] . '</div>';
            }
        }
        
        return implode("\n", $html);
    }

    function add_elements()
    {
        $form = $this->get_form();
        $form->addElement('category', Translation :: get('Filesize'));
        $group = array();
        // $group[] = $form->createElement('static', '', '', '<span>' .
        // Translation :: get('Filesize') . '</span>');
        $group[] = $form->createElement('select', self :: FILTER_COMPARE, '', array(
                self :: COMPARE_EQUAL => Translation :: get('EqualsShort'), 
                InequalityCondition :: GREATER_THAN => Translation :: get('GreaterThanShort'), 
                InequalityCondition :: LESS_THAN => Translation :: get('LessThanShort')));
        
        $group[] = $form->createElement('text', Document :: PROPERTY_FILESIZE, null, 'style="width: 50px;"');
        $group[] = $form->createElement('select', self :: FILTER_FORMAT, '', array(
                1 => Translation :: get('KilobyteShort'), 2 => Translation :: get('MegabyteShort'), 
                3 => Translation :: get('GigabyteShort')));
        $form->addGroup($group, Document :: PROPERTY_FILESIZE, null, null, false);
        $form->get_renderer()->setGroupElementTemplate('{element}', Document :: PROPERTY_FILESIZE);
        $form->addElement('category');
        
        $form->addElement('category', Translation :: get('Extension'));
        $form->addElement('text', Document :: PROPERTY_EXTENSION, Translation :: get('Extension'));
        $form->addElement('category');
    }
}
?>