<?php
namespace repository\content_object\external_calendar;

use common\libraries\DatetimeUtilities;
use common\libraries\Theme;
use common\libraries\Utilities;
use common\libraries\Translation;
use common\libraries\Request;

use repository\ContentObject;
use repository\ContentObjectRendition;

use IcalRecurrence;

class HtmlDescriptionRenditionImplementation extends HtmlRenditionImplementation
{

    function render()
    {
        return ContentObjectRendition :: launch($this);
    }

    function get_description()
    {
        $object = $this->get_content_object();
        $event_id = Request :: get(ExternalCalendar :: PARAM_EVENT_ID);
        if (isset($event_id))
        {
            $event = $object->get_event($event_id);
            $ical_recurrence = new Recurrence($event);
            $date_format = Translation :: get('DateTimeFormatLong', null, Utilities :: COMMON_LIBRARIES);
            $html[] = '<div class="content_object" style="background-image: url(' . $object->get_icon_path() . ');">';
            $html[] = '<div class="title">' . $event->summary['value'] . '</div>';
            $html[] = '<div class="calendar_event_range" style="font-weight: bold;">';
            $html[] = Translation :: get('From', null, Utilities :: COMMON_LIBRARIES);
            $html[] = ' ';
            $html[] = DatetimeUtilities :: format_locale_date($date_format, $ical_recurrence->get_start_date());
            $html[] = ' ';
            $html[] = Translation :: get('Until', null, Utilities :: COMMON_LIBRARIES);
            $html[] = ' ';
            $html[] = DatetimeUtilities :: format_locale_date($date_format, $ical_recurrence->get_end_date());
            $html[] = '</div>';
            if ($ical_recurrence->repeats())
            {
                $html[] = $ical_recurrence->get_repeat() . '<br/>';
            }

            if ($event->description)
            {
                $html[] = $event->description[0]['value'];
            }
            $html[] = '</div>';
        }
        else
        {
            $html[] = '<div class="content_object" style="background-image: url(' . $object->get_icon_path() . ');">';
            $html[] = '<div class="title">' . Translation :: get('Description', null, Utilities :: COMMON_LIBRARIES) . '</div>';
            $html[] = '<div class="link_url" style="margin-top: 1em;"><a href="' . htmlentities($object->get_url()) . '">' . htmlentities($object->get_url()) . '</a></div>';

            $number_of_events = $object->count_events();
            $html[] = Translation :: get('EventCount') . ' : ' . $number_of_events;
            $html[] = '</div>';
        }

        return implode("\n", $html);
    }
}
?>