<?php
namespace repository\content_object\external_calendar;

use common\libraries\IcalRecurrence;

use common\libraries\Utilities;
use common\libraries\Translation;

class Recurrence extends IcalRecurrence
{

    function __construct(vevent $event, $from_date, $to_date)
    {
        parent :: __construct($event, $from_date, $to_date);
    }

    /**
     *
     * @return the $interval
     */
    public function get_interval()
    {
        if (! isset($this->interval))
        {
            if (is_array($this->get_event()->rrule) && isset($this->get_event()->rrule[0]['value'][self :: ICAL_INTERVAL]))
            {
                $this->interval = trim($this->get_event()->rrule[0]['value'][self :: ICAL_INTERVAL]);
            }
            else
            {
                $this->interval = 1;
            }
        }
        return $this->interval;
    }

    /**
     *
     * @return the $count
     */
    public function get_count()
    {
        if (! isset($this->count))
        {
            if (is_array($this->get_event()->rrule) && isset($this->get_event()->rrule[0]['value'][self :: ICAL_COUNT]))
            {
                $this->count = trim($this->get_event()->rrule[0]['value'][self :: ICAL_COUNT]);
            }
            else
            {
                $this->count = 1000000;
            }
        }
        return $this->count;
    }

    function get_start_date($timestamp = true, $time_midnight = false)
    {
        if (! isset($this->start_date))
        {
            $start_date = $this->get_event()->dtstart['value'];
            $this->start_date = mktime($start_date['hour'], $start_date['min'], $start_date['sec'], $start_date['month'], $start_date['day'], $start_date['year']);
        }
        if ($timestamp)
        {
            if ($time_midnight)
            {
                return strtotime(date('Ymd', $this->start_date . ' 00:00:00'));
            }
            else
            {
                return $this->start_date;
            }
        }
        else
        {
            return date('Ymd', $this->start_date);
        }
    }

    function get_end_date($timestamp = true)
    {
        $end_date = $this->get_event()->dtend['value'];
        $end_date = mktime($end_date['hour'], $end_date['min'], $end_date['sec'], $end_date['month'], $end_date['day'], $end_date['year']);
        return ($timestamp ? $end_date : date('Ymd', $end_date));
    }

    function repeats()
    {
        if (! empty($this->get_event()->rrule))
        {
            return true;
        }
        return false;
    }

    function get_duration()
    {
        return $this->get_event()->duration;
    }

    /**
     *
     * @return the $bymonth
     */
    public function get_bymonth()
    {
        if (is_array($this->get_event()->rrule) && isset($this->get_event()->rrule[0]['value'][self :: ICAL_MONTH]))
        {
            if (count($this->get_event()->rrule[0]['value'][self :: ICAL_MONTH]) > 1)
            {
                foreach ($this->get_event()->rrule[0]['value'][self :: ICAL_MONTH] as $month)
                {
                    $months[] = trim($month);
                }
            }
            else
            {
                $months[] = trim($this->get_event()->rrule[0]['value'][self :: ICAL_MONTH]);
            }
            return $months;
        }
        else
        {
            return null;
        }
    }

    /**
     *
     * @return the $byweekno
     */
    public function get_byweekno()
    {
        if (is_array($this->get_event()->rrule))
        {
            return trim($this->get_event()->rrule[0]['value'][self :: ICAL_WEEK_NO]);
        }
        else
        {
            
            return null;
        }
    }

    /**
     *
     * @return the $bymonthday
     */
    public function get_bymonthday()
    {
        if (is_array($this->get_event()->rrule) && isset($this->get_event()->rrule[0]['value'][self :: ICAL_MONTHDAYS]))
        {
            if (count($this->get_event()->rrule[0]['value'][self :: ICAL_MONTHDAYS]) > 1)
            {
                foreach ($this->get_event()->rrule[0]['value'][self :: ICAL_MONTHDAYS] as $monthday)
                {
                    $monthdays[] = trim($monthday);
                }
            }
            else
            {
                $monthdays[] = trim($this->get_event()->rrule[0]['value'][self :: ICAL_MONTHDAYS]);
            }
            return $monthdays;
        }
        else
        {
            return null;
        }
    }

    /**
     *
     * @return the $freq_type
     */
    public function get_freq_type()
    {
        if (is_array($this->get_event()->rrule))
        {
            return trim($this->get_event()->rrule[0]['value'][self :: ICAL_FREQUENCY]);
        }
        else
        {
            return self :: NO_REPEAT;
        }
    }

    /**
     *
     * @return the $except_dates
     */
    public function get_except_dates()
    {
        return $this->get_event()->exdate;
    }

    /**
     *
     * @return the $until_unixtime
     */
    public function get_until_unixtime()
    {
        if (is_array($this->get_event()->rrule) && is_array($this->get_event()->rrule[0]['value'][self :: ICAL_UNTIL]))
        {
            $repeat_date = $this->get_event()->rrule[0]['value'][self :: ICAL_UNTIL];
            // Correct repeat date for ical, don't take time into account
            return mktime(23, 59, 59, $repeat_date['month'], $repeat_date['day'], $repeat_date['year']);
        }
    }

    /**
     *
     * @return the $wkst
     */
    public function get_wkst($convert = false, $text = true)
    {
        if (isset($this->get_event()->rrule[0]['value'][self :: ICAL_WEEK_START]))
        {
            $wkst = $this->get_event()->rrule[0]['value'][self :: ICAL_WEEK_START];
        }
        else
        {
            $wkst = 'MO';
        }
        
        if ($convert)
        {
            return $this->convert_day_name($wkst, $text);
        }
        else
        {
            return $wkst;
        }
    }

    /**
     *
     * @return the $byyearday
     */
    public function get_byyearday()
    {
        if (is_array($this->get_event()->rrule))
        {
            return trim($this->get_event()->rrule[0]['value'][self :: ICAL_YEARDAY]);
        }
        else
        {
            return null;
        }
    }

    /**
     *
     * @return the $byday
     */
    public function get_byday()
    {
        if (is_array($this->get_event()->rrule) && isset($this->get_event()->rrule[0]['value'][self :: ICAL_DAYS]))
        {
            if (! isset($this->get_event()->rrule[0]['value'][self :: ICAL_DAYS]['DAY']))
            {
                foreach ($this->get_event()->rrule[0]['value'][self :: ICAL_DAYS] as $day)
                {
                    $days[] = trim($day['0']) . trim($day['DAY']);
                }
            }
            else
            {
                $days[] = trim($this->get_event()->rrule[0]['value'][self :: ICAL_DAYS]['0']) . trim($this->get_event()->rrule[0]['value'][self :: ICAL_DAYS]['DAY']);
            }
            return $days;
        }
        else
        {
            return null;
        }
    }

    public function get_bysetpos()
    {
        if (is_array($this->get_event()->rrule))
        {
            return trim($this->get_event()->rrule[0]['value'][self :: ICAL_SETPOS]);
        }
        else
        {
            return null;
        }
    }
}
?>
