<?php
namespace repository\content_object\feedback;

use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\Versionable;
use common\libraries\AttachmentSupport;
use common\libraries\Theme;

use repository\ContentObject;
use admin\AdminDataManager;

/**
 * $Id: feedback.class.php 200 2009-11-13 12:30:04Z kariboe $
 * @package repository.lib.content_object.feedback
 */
/**
 * A feedback
 */
class Feedback extends ContentObject implements Versionable, AttachmentSupport
{
    const PROPERTY_ICON = 'icon';
    
    const ICON_THUMBS_UP = 1;
    const ICON_THUMBS_DOWN = 2;
    const ICON_WRONG = 3;
    const ICON_RIGHT = 4;
    const ICON_INFORMATIVE = 5;
    
    const CLASS_NAME = __CLASS__;

    static function get_type_name()
    {
        return Utilities :: camelcase_to_underscores(Utilities :: get_classname_from_namespace(self :: CLASS_NAME));
    }

    function get_icon()
    {
        return $this->get_additional_property(self :: PROPERTY_ICON);
    }

    function set_icon($icon)
    {
        return $this->set_additional_property(self :: PROPERTY_ICON, $icon);
    }

    function get_icon_name()
    {
        return self :: icon_name($this->get_icon());
    }

    static function icon_name($icon, $size = Theme :: ICON_SMALL)
    {
        switch ($icon)
        {
            case self :: ICON_THUMBS_UP :
                $icon = 'thumbs_up';
                break;
            case self :: ICON_THUMBS_DOWN :
                $icon = 'thumbs_down';
                break;
            case self :: ICON_RIGHT :
                $icon = 'right';
                break;
            case self :: ICON_WRONG :
                $icon = 'wrong';
                break;
            case self :: ICON_INFORMATIVE :
                $icon = 'informative';
                break;
        }
        
        return $size . '_' . $icon;
    }

    static function get_possible_icons()
    {
        $icons[self :: ICON_THUMBS_UP] = Translation :: get('ThumbsUp');
        $icons[self :: ICON_THUMBS_DOWN] = Translation :: get('ThumbsDown');
        $icons[self :: ICON_WRONG] = Translation :: get('Wrong');
        $icons[self :: ICON_RIGHT] = Translation :: get('Right');
        $icons[self :: ICON_INFORMATIVE] = Translation :: get('Informative');
        return $icons;
    }

    static function get_additional_property_names()
    {
        return array(self :: PROPERTY_ICON);
    }

    function delete()
    {
        //delete feedback-co-links
        $publications_deleted = AdminDataManager :: get_instance()->delete_feedback_publications($this->get_id());
        
        if ($publications_deleted)
        {
            //delete feedback
            return parent :: delete();
        }
        else
        {
            return $publications_deleted;
        }
    }
}
?>