<?php
namespace repository\content_object\fill_in_blanks_question;

use common\libraries\Translation;
use common\libraries\ResourceManager;
use common\libraries\Path;

use repository\ContentObjectForm;
use common\libraries\Utilities;

/**
 * $Id: fill_in_blanks_question_form.class.php 200 2009-11-13 12:30:04Z kariboe $
 * @package repository.lib.question_types.fill_in_blanks_question
 */


class FillInBlanksQuestionForm extends ContentObjectForm
{
    const FIELD_OPTION_VARIATION = 'field_option_variation';
    const FIELD_OPTION_SIZE = 'field_option_size';
    
    const UNIFORM_INPUT_TYPE = 'uniform_input_type';
    const UNIFORM_UNLIMITED_ANSWER = - 1;
    const UNIFORM_LONGEST_ANSWER = 0;
    const UNIFORM_FIXED_ANSWER = 1;
    
    const DEFAULT_FIELD_OPTION_VARIATION = 0;
    const DEFAULT_FIELD_OPTION_SIZE = 15;
    const DEFAULT_UNIFORM_TYPE = self :: UNIFORM_FIXED_ANSWER;

    protected function build_creation_form()
    {
        parent :: build_creation_form();
        $this->build_fill_in_the_blanks_form();
    }

    protected function build_editing_form()
    {
        parent :: build_editing_form();
        $this->build_fill_in_the_blanks_form();
    }

    private function build_fill_in_the_blanks_form()
    {
        // ANSWER TYPE
        $this->addElement('category', Translation :: get('AnswerType'));
        $type_options = array();
        $type_options[] = $this->createElement('radio', FillInBlanksQuestion :: PROPERTY_QUESTION_TYPE, null, Translation :: get('AutoTextField'), FillInBlanksQuestion :: TYPE_SIZED_TEXT, array(
                'class' => 'type_' . FillInBlanksQuestion :: TYPE_SIZED_TEXT . '_option_selector'));
        $type_options[] = $this->createElement('radio', FillInBlanksQuestion :: PROPERTY_QUESTION_TYPE, null, Translation :: get('UniformTextField'), FillInBlanksQuestion :: TYPE_UNIFORM_TEXT, array(
                'class' => 'type_' . FillInBlanksQuestion :: TYPE_UNIFORM_TEXT . '_option_selector'));
        $type_options[] = $this->createElement('radio', FillInBlanksQuestion :: PROPERTY_QUESTION_TYPE, null, Translation :: get('SelectBox'), FillInBlanksQuestion :: TYPE_SELECT, array(
                'class' => 'type_' . FillInBlanksQuestion :: TYPE_SELECT . '_option_selector'));
        $this->addElement('group', null, Translation :: get('UseSelectBox'), $type_options, '<br />', false);
        
        // show inline
        $this->addElement('checkbox', FillInBlanksQuestion :: PROPERTY_SHOW_INLINE, Translation :: get('ShowInputFieldsInline'));
        
        // case sensitive
        $this->addElement('checkbox', FillInBlanksQuestion :: PROPERTY_CASE_SENSITIVE, Translation :: get('CaseSensitive'));
        $this->addElement('category');
        
        // ANSWER OPTIONS
        $this->addElement('category', Translation :: get('AnswerOptions'));
        
        // default scores
        $this->add_textfield(FillInBlanksQuestion :: PROPERTY_DEFAULT_POSITIVE_SCORE, Translation :: get('DefaultPositiveScore'), false, array(
                "size" => "5"));
        $this->add_textfield(FillInBlanksQuestion :: PROPERTY_DEFAULT_NEGATIVE_SCORE, Translation :: get('DefaultNegativeScore'), false, array(
                "size" => "5"));
        
        // auto sized text field
        $this->addElement('html', '<div class="type_' . FillInBlanksQuestion :: TYPE_SIZED_TEXT . '_options_box">');
        $this->add_textfield(self :: FIELD_OPTION_VARIATION, Translation :: get('Variation'), false, array(
                "size" => "5"));
        $this->addElement('html', '</div>');
        
        // uniform sized text field
        $this->addElement('html', '<div class="type_' . FillInBlanksQuestion :: TYPE_UNIFORM_TEXT . '_options_box">');
        $field_size_options = array();
        //$field_size_options[] = $this->createElement('radio', self :: UNIFORM_INPUT_TYPE, null, Translation :: get('Unlimited') . '<br />', self :: UNIFORM_UNLIMITED_ANSWER);
        $field_size_options[] = $this->createElement('radio', self :: UNIFORM_INPUT_TYPE, null, Translation :: get('LongestAnswer') . '<br />', self :: UNIFORM_LONGEST_ANSWER);
        $field_size_options[] = $this->createElement('radio', self :: UNIFORM_INPUT_TYPE, null, null, self :: UNIFORM_FIXED_ANSWER);
        $field_size_options[] = $this->createElement('text', self :: FIELD_OPTION_SIZE, null, null, null);
        $this->addGroup($field_size_options, null, Translation :: get('FieldSize'), '');
        $this->addElement('html', '</div>');
        
        // example
        $this->addElement('category');
        $this->addElement('html', ResourceManager :: get_instance()->get_resource_html(Path :: get(WEB_PATH) . 'common/libraries/resources/javascript/collapse_horizontal.js'));
        $this->addElement('category', '<a href="#">' . Translation :: get('Example', null, Utilities :: COMMON_LIBRARIES) . '</a>', 'content_object_attachments collapsible collapsed');
        $this->addElement('html', '<div>' . Translation :: get('FillInTheBlanksInstructions') . '</div>');
        $this->addElement('category');
        
        // ANSWERS
        $this->addElement('category', Translation :: get('Excercise'));
        
        //$this->addElement('html', '<div class="normal-message">' . Translation :: get('FillInTheblanksInfo') . '</div>');
        $this->addElement('textarea', FillInBlanksQuestion :: PROPERTY_ANSWER_TEXT, Translation :: get('QuestionText'), 'rows="10" class="answer"');
        $this->addRule(FillInBlanksQuestion :: PROPERTY_ANSWER_TEXT, Translation :: get('ThisFieldIsRequired', null, Utilities :: COMMON_LIBRARIES), 'required');
        $this->addElement('html', ResourceManager :: get_instance()->get_resource_html(Path :: get(WEB_PATH) . 'repository/content_object/fill_in_blanks_question/resources/javascript/fill_in_the_blanks.js'));
        $this->add_options($this->get_content_object());
        $this->addElement('category');
    }

    function setDefaults($defaults = array ())
    {
        if (! $this->isSubmitted())
        {
            $object = $this->get_content_object();
            if ($object->get_number_of_questions() != 0)
            {
                //$options = $object->get_answers();
                $defaults[FillInBlanksQuestion :: PROPERTY_ANSWER_TEXT] = $object->get_answer_text();
                $defaults[FillInBlanksQuestion :: PROPERTY_CASE_SENSITIVE] = $object->get_case_sensitive();
                $defaults[FillInBlanksQuestion :: PROPERTY_QUESTION_TYPE] = $object->get_question_type();
                $defaults[FillInBlanksQuestion :: PROPERTY_DEFAULT_POSITIVE_SCORE] = $object->get_default_positive_score();
                $defaults[FillInBlanksQuestion :: PROPERTY_DEFAULT_NEGATIVE_SCORE] = $object->get_default_negative_score();
                $defaults[FillInBlanksQuestion :: PROPERTY_SHOW_INLINE] = $object->get_show_inline();
                
                $option = $object->get_field_option();
                if (isset($option)) // set defaults if we don't have option value, otherwise use value
                {
                    $defaults[self :: FIELD_OPTION_VARIATION] = $option;
                    $defaults[self :: FIELD_OPTION_SIZE] = $option;
                    
                    switch ($option) // filter out -1 and 0, fixed in any other case
                    {
                        case self :: UNIFORM_UNLIMITED_ANSWER :
                            $defaults[self :: UNIFORM_INPUT_TYPE] = self :: UNIFORM_UNLIMITED_ANSWER;
                            break;
                        case self :: UNIFORM_LONGEST_ANSWER :
                            $defaults[self :: UNIFORM_INPUT_TYPE] = self :: UNIFORM_LONGEST_ANSWER;
                            break;
                        default :
                            $defaults[self :: UNIFORM_INPUT_TYPE] = self :: UNIFORM_FIXED_ANSWER;
                            break;
                    }
                }
                else
                {
                    $defaults[self :: FIELD_OPTION_VARIATION] = self :: DEFAULT_FIELD_OPTION_VARIATION;
                    $defaults[self :: FIELD_OPTION_SIZE] = self :: DEFAULT_FIELD_OPTION_SIZE;
                    $defaults[self :: UNIFORM_INPUT_TYPE] = self :: DEFAULT_UNIFORM_TYPE;
                }
            }
            else
            {
                $defaults[FillInBlanksQuestion :: PROPERTY_ANSWER_TEXT] = FillInBlanksQuestion :: DEFAULT_INPUT_ANSWER_TEXT;
                $defaults[FillInBlanksQuestion :: PROPERTY_CASE_SENSITIVE] = FillInBlanksQuestion :: DEFAULT_CASE_SENSITIVE;
                $defaults[FillInBlanksQuestion :: PROPERTY_QUESTION_TYPE] = FillInBlanksQuestion :: DEFAULT_INPUT_TYPE;
                $defaults[FillInBlanksQuestion :: PROPERTY_DEFAULT_POSITIVE_SCORE] = FillInBlanksQuestion :: DEFAULT_POSITIVE_SCORE;
                $defaults[FillInBlanksQuestion :: PROPERTY_DEFAULT_NEGATIVE_SCORE] = FillInBlanksQuestion :: DEFAULT_NEGATIVE_SCORE;
                $defaults[FillInBlanksQuestion :: PROPERTY_SHOW_INLINE] = FillInBlanksQuestion :: DEFAULT_SHOW_INLINE;
                $defaults[self :: UNIFORM_INPUT_TYPE] = self :: DEFAULT_UNIFORM_TYPE;
                $defaults[self :: FIELD_OPTION_VARIATION] = self :: DEFAULT_FIELD_OPTION_VARIATION;
                $defaults[self :: FIELD_OPTION_SIZE] = self :: DEFAULT_FIELD_OPTION_SIZE;
            }
            
            parent :: setDefaults($defaults);
            return;
        }
    }

    function create_content_object()
    {
        $values = $this->exportValues();
        $object = new FillInBlanksQuestion();
        $this->set_content_object($object);
        $object->set_answer_text($values[FillInBlanksQuestion :: PROPERTY_ANSWER_TEXT]);
        $object->set_case_sensitive($values[FillInBlanksQuestion :: PROPERTY_CASE_SENSITIVE]);
        $object->set_default_positive_score($values[FillInBlanksQuestion :: PROPERTY_DEFAULT_POSITIVE_SCORE]);
        $object->set_default_negative_score($values[FillInBlanksQuestion :: PROPERTY_DEFAULT_NEGATIVE_SCORE]);
        $object->set_show_inline($values[FillInBlanksQuestion :: PROPERTY_SHOW_INLINE]);
        $this->set_type_options($object, $values);
        return parent :: create_content_object();
    }

    function update_content_object()
    {
        $values = $this->exportValues();
        $object = $this->get_content_object();
        $object->set_answer_text($values[FillInBlanksQuestion :: PROPERTY_ANSWER_TEXT]);
        $object->set_case_sensitive($values[FillInBlanksQuestion :: PROPERTY_CASE_SENSITIVE]);
        $object->set_default_positive_score($values[FillInBlanksQuestion :: PROPERTY_DEFAULT_POSITIVE_SCORE]);
        $object->set_default_negative_score($values[FillInBlanksQuestion :: PROPERTY_DEFAULT_NEGATIVE_SCORE]);
        $object->set_show_inline($values[FillInBlanksQuestion :: PROPERTY_SHOW_INLINE]);
        $this->set_type_options($object, $values);
        return parent :: update_content_object();
    }

    function set_type_options($object, $values)
    {
        // set type
        $type = $values[FillInBlanksQuestion :: PROPERTY_QUESTION_TYPE];
        $object->set_question_type($type);
        
        // set type specific options
        switch ($type)
        {
            case FillInBlanksQuestion :: TYPE_SIZED_TEXT :
                $object->set_field_option($values[self :: FIELD_OPTION_VARIATION]);
                break;
            case FillInBlanksQuestion :: TYPE_UNIFORM_TEXT :
                if ($values[self :: UNIFORM_INPUT_TYPE] == self :: UNIFORM_FIXED_ANSWER)
                {
                    $object->set_field_option($values[self :: FIELD_OPTION_SIZE]);
                }
                else
                {
                    $object->set_field_option($values[self :: UNIFORM_INPUT_TYPE]);
                }
                break;
            default :
                $object->set_field_option(null);
        }
    }

    function validate()
    {
        if (isset($_POST['add']))
        {
            return false;
        }
        return parent :: validate();
    }

    /**
     * Adds the form-fields to the form to provide the possible options for this
     * multiple choice question
     */
    private function add_options($question)
    {
        $answers = $question->get_answers();
        $default_score = $question->get_default_positive_score();
        if (is_null($default_score))
        {
            $default_score = FillInBlanksQuestion :: DEFAULT_POSITIVE_SCORE;
        }
        
        $style = (count($answers) == 0) ? 'style="display: none;"' : '';
        
        $html = array();
        $html[] = '<div id="answers_table" class="row" ' . $style . '">';
        $html[] = '<div class="label">';
        $html[] = Translation :: get('Answers');
        $html[] = '</div>';
        $html[] = '<div class="formw">';
        $html[] = '<div class="element">';
        $html[] = '<table class="data_table">';
        $html[] = '<thead>';
        $html[] = '<tr>';
        $html[] = '<th>' . Translation :: get('Question') . '</th>';
        $html[] = '<th>' . Translation :: get('Answer') . '</th>';
        $html[] = '<th>' . Translation :: get('Feedback') . '</th>';
        $html[] = '<th>' . Translation :: get('Hint') . '</th>';
        $html[] = '<th class="numeric">' . Translation :: get('NonDefaultScore') . '</th>';
        $html[] = '</tr>';
        $html[] = '</thead>';
        $html[] = '<tbody>';
        
        $position = 0;
        $css_class = 'row_even';
        foreach ($answers as $answer)
        {
            if ($answer->get_position() != $position)
            {
                $position = $answer->get_position();
                $css_class = $css_class == 'row_even' ? 'row_odd' : 'row_even';
            }
            // filter out default scores
            $answer_score = $answer->get_weight();
            if ($answer_score == $default_score)
            {
                $answer_score = '';
            }
            
            // build table
            $html[] = '<tr class="' . $css_class . '">';
            $html[] = '<td>' . ($answer->get_position() + 1) . '</td>';
            $html[] = '<td>' . str_replace("\n", '<br/>', $answer->get_value()) . '</td>';
            $html[] = '<td>' . str_replace("\n", '<br/>', $answer->get_comment()) . ' </td>';
            $html[] = '<td>' . str_replace("\n", '<br/>', $answer->get_hint()) . ' </td>';
            $html[] = '<td>' . $answer_score . '</td>';
            $html[] = '</tr>';
        }
        
        $html[] = '</tbody>';
        $html[] = '</table>';
        $html[] = '</div>';
        $html[] = '<div class="form_feedback"></div></div>';
        $html[] = '<div class="clear">&nbsp;</div>';
        $html[] = '</div>';
        
        $this->addElement('html', implode("\n", $html));
    }

}