<?php
namespace repository\content_object\fill_in_blanks_question;

use common\libraries\Translation;

use repository\ContentObjectRendition;

class HtmlDescriptionRenditionImplementation extends HtmlRenditionImplementation
{

    function render()
    {
        return ContentObjectRendition :: launch($this);
    }

    function get_description()
    {
        $object = $this->get_content_object();
        
        // get answer text
        $answer_text = $object->get_answer_text();
        
        // get the regular text
        $clear_text = preg_split(FillInBlanksQuestionAnswer :: CLOZE_REGEX, $answer_text);
        
        // get the answers
        $answers = $object->get_answers();
        
        // get the number of questions
        $questions = $object->get_number_of_questions();
        
        // position the answers
        $question_answers = array();
        foreach ($answers as $answer)
        {
            $question_answers[$answer->get_position()][] = $answer;
        }
        
        // construct HTML
        $html = array();
        
        // default scores
        $html[] = '<br/><b>' . Translation :: get('DefaultScores') . ':</b><br/>';
        $html[] = $object->get_default_positive_score();
        $html[] = ' / ';
        $html[] = $object->get_default_negative_score();
        $html[] = '<br/><br/>';
        
        // answer text
        $html[] = '<b>' . Translation :: get('Excercise') . ':</b><br/>';
        
        for($i = 0; $i < $questions; $i ++)
        {
            // regular text $i
            $html[] = $clear_text[$i];
            
            // answer $i
            if ($object->get_question_type() == FillInBlanksQuestion :: TYPE_SELECT)
            {
                // combobox
                $answer_select = array();
                $answer_select[] = '<select name="answer">';
                foreach ($question_answers[$i] as $answer)
                {
                    $value = trim($answer->get_value());
                    $answer_select[] = '<option value="' . $value . '">' . $value . '</option>';
                }
                $answer_select[] = '</select>';
                
                $html[] = implode("\n", $answer_select);
            }
            else
            {
                // uniform inputfield
                $size = $object->get_input_field_size($i);
                $best = $object->get_best_answer_for_question($i);
                $html[] = '<input class="' . FillInBlanksQuestion :: TEXT_INPUT_FIELD_CSS_CLASS . '" size="' . $size . '" title="' . Translation :: get('BestAnswer') . '" value="' . $best->get_value() . '" />';
            }
        }
        
        $array_size = count($clear_text);
        while ($array_size > $i)
        {
            $html[] = $clear_text[$i];
            $i ++;
        }
        
        return implode("\n", $html);
    }
}
?>