<?php
namespace repository\content_object\forum;

class Autoloader
{

    /**
     * The array mapping class names to paths
     *
     * @var multitype:string
     */
     private static $map = array(
         'Autoloader' => '/autoloader.class.php',
         'ForumDifference' => '/lib/difference.class.php',
         'ForumDifferenceDisplay' => '/lib/difference_display.class.php',
         'ForumDisplay' => '/lib/display.class.php',
         'ForumBuilder' => '/lib/builder/forum_builder.class.php',
         'ForumBuilderBrowserComponent' => '/lib/builder/component/browser.class.php',
         'ForumBuilderCreatorComponent' => '/lib/builder/component/creator.class.php',
         'ForumBuilderDeleterComponent' => '/lib/builder/component/deleter.class.php',
         'ForumBuilderImportantComponent' => '/lib/builder/component/important.class.php',
         'ForumBuilderMoverComponent' => '/lib/builder/component/mover.class.php',
         'ForumBuilderPreviewComponent' => '/lib/builder/component/preview.class.php',
         'ForumBuilderStickyComponent' => '/lib/builder/component/sticky.class.php',
         'ForumBuilderUpdaterComponent' => '/lib/builder/component/updater.class.php',
         'ForumBuilderViewerComponent' => '/lib/builder/component/viewer.class.php',
         'ForumBrowserTableCellRenderer' => '/lib/builder/component/browser/forum_browser_table_cell_renderer.class.php',
         'ForumBrowserTableColumnModel' => '/lib/builder/component/browser/forum_browser_table_column_model.class.php',
         'ForumPostBrowserTableCellRenderer' => '/lib/builder/component/browser/forum_post_browser_table_cell_renderer.class.php',
         'ForumPostBrowserTableColumnModel' => '/lib/builder/component/browser/forum_post_browser_table_column_model.class.php',
         'ForumComplexDisplay' => '/lib/complex_display/forum_complex_display.class.php',
         'ForumComplexDisplayPreview' => '/lib/complex_display/forum_complex_display_preview.class.php',
         'ForumComplexDisplayAttachmentViewerComponent' => '/lib/complex_display/component/attachment_viewer.class.php',
         'ForumComplexDisplayChangeLockComponent' => '/lib/complex_display/component/change_lock.class.php',
         'ForumComplexDisplayForumPostCreatorComponent' => '/lib/complex_display/component/forum_post_creator.class.php',
         'ForumComplexDisplayForumPostDeleterComponent' => '/lib/complex_display/component/forum_post_deleter.class.php',
         'ForumComplexDisplayForumPostEditorComponent' => '/lib/complex_display/component/forum_post_editor.class.php',
         'ForumComplexDisplayForumPostQuoterComponent' => '/lib/complex_display/component/forum_post_quoter.class.php',
         'ForumComplexDisplayForumSubforumCreatorComponent' => '/lib/complex_display/component/forum_subforum_creator.class.php',
         'ForumComplexDisplayForumSubforumDeleterComponent' => '/lib/complex_display/component/forum_subforum_deleter.class.php',
         'ForumComplexDisplayForumSubforumEditorComponent' => '/lib/complex_display/component/forum_subforum_editor.class.php',
         'ForumComplexDisplayForumSubscribeComponent' => '/lib/complex_display/component/forum_subscribe.class.php',
         'ForumComplexDisplayForumTopicCreatorComponent' => '/lib/complex_display/component/forum_topic_creator.class.php',
         'ForumComplexDisplayForumTopicDeleterComponent' => '/lib/complex_display/component/forum_topic_deleter.class.php',
         'ForumComplexDisplayForumUnsubscribeComponent' => '/lib/complex_display/component/forum_unsubscribe.class.php',
         'ForumComplexDisplayForumViewerComponent' => '/lib/complex_display/component/forum_viewer.class.php',
         'ForumComplexDisplayImportantComponent' => '/lib/complex_display/component/important.class.php',
         'ForumComplexDisplayStickyComponent' => '/lib/complex_display/component/sticky.class.php',
         'ForumComplexDisplayTopicPreviewerComponent' => '/lib/complex_display/component/topic_previewer.class.php',
         'ForumComplexDisplayTopicSubscribeComponent' => '/lib/complex_display/component/topic_subscribe.class.php',
         'ForumComplexDisplayTopicUnsubscribeComponent' => '/lib/complex_display/component/topic_unsubscribe.class.php',
         'ForumComplexDisplayTopicViewerComponent' => '/lib/complex_display/component/topic_viewer.class.php',
         'ForumPostFormAction' => '/lib/complex_display/component/forum_post_form_action/forum_post_form_action.class.php',
         'ForumPostFormActionCreate' => '/lib/complex_display/component/forum_post_form_action/forum_post_form_action_create.class.php',
         'ComplexForum' => '/lib/data_class/complex_content_object_item.class.php',
         'Forum' => '/lib/data_class/content_object.class.php',
         'ForumSubscribe' => '/lib/data_class/forum_subscribe.class.php',
         'ForumDataManager' => '/lib/data_manager/forum_data_manager.class.php',
         'ForumDataManagerInterface' => '/lib/data_manager/forum_data_manager_interface.class.php',
         'Mdb2ForumDataManager' => '/lib/data_manager/implementation/mdb2.class.php',
         'EmailNotificator' => '/lib/email_notification/email_notificator.class.php',
         'PostEmailNotificator' => '/lib/email_notification/post_email_notificator.class.php',
         'SubforumEmailNotificator' => '/lib/email_notification/subforum_email_notificator.class.php',
         'TopicEmailNotificator' => '/lib/email_notification/topic_email_notificator.class.php',
         'ComplexForumForm' => '/lib/form/complex_content_object_item.class.php',
         'ForumForm' => '/lib/form/content_object.class.php',
         'ForumComplexDisplaySupport' => '/lib/interfaces/forum_complex_display_support.class.php',
         'Activator' => '/package/activate/activator.class.php',
         'Deactivator' => '/package/deactivate/deactivator.class.php',
         'Installer' => '/package/install/forum_installer.class.php'
    );

    /**
     * Try to load the class
     *
     * @param $classname string
     * @return boolean
     */
    static function load($classname)
    {
        if (isset(self :: $map[$classname]))
        {
            require_once __DIR__ . self :: $map[$classname];
            return true;
        }

        return false;
    }

    /**
     * Synchronize the autoloader
     *
     * @param $update boolean
     * @return multitype:string
     */
    static function synch($update)
    {
        return \common\libraries\AutoloaderUtilities :: synch(__DIR__, __DIR__, $update);
    }

}
?>