<?php
namespace repository\content_object\forum;

use common\libraries\DelegateComponent;

use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Utilities;
use common\libraries\EqualityCondition;

use common\extensions\repo_viewer\RepoViewer;
use common\extensions\repo_viewer\RepoViewerInterface;

use repository\ContentObjectTypeSelector;
use repository\RepositoryDataManager;
use repository\ComplexBuilder;
use repository\ComplexContentObjectItem;

/**
 * $Id: creator.class.php 200 2009-11-13 12:30:04Z kariboe $
 * 
 * @package repository.lib.complex_builder.forum.component
 */
class ForumBuilderCreatorComponent extends ForumBuilder implements RepoViewerInterface, DelegateComponent
{
    
    private $repository_data_manager;
    private $type;

    function run()
    {
        $trail = BreadcrumbTrail :: get_instance();
        $menu_trail = $this->get_complex_content_object_breadcrumbs();
        $trail->add_help('repository forum builder');
        
        $complex_content_object_item_id = Request :: get(ComplexBuilder :: PARAM_COMPLEX_CONTENT_OBJECT_ITEM_ID);
        $this->type = $rtype = Request :: get(ComplexBuilder :: PARAM_TYPE);
        
        $parameters = array(ComplexBuilder :: PARAM_COMPLEX_CONTENT_OBJECT_ITEM_ID => $complex_content_object_item_id, 
                ComplexBuilder :: PARAM_TYPE => $type);
        
        // $trail->add(new Breadcrumb($this->get_url($parameters), Translation
        // :: get('Add' . Utilities :: underscores_to_camelcase($type))));
        
        $this->repository_data_manager = RepositoryDataManager :: get_instance();
        $parent = $this->get_root_content_object_id();
        if ($complex_content_object_item_id)
        {
            $parent_complex_content_object_item = $this->repository_data_manager->retrieve_complex_content_object_item($complex_content_object_item_id);
            $parent = $parent_complex_content_object_item->get_ref();
        }
        if ($this->get_complex_content_object_item())
        {
            $content_object = $this->repository_data_manager->retrieve_content_object($this->get_complex_content_object_item()->get_ref());
        }
        else
        {
            $content_object = $this->get_root_content_object();
        }
        
        $exclude = $this->retrieve_used_items($this->get_root_content_object()->get_id());
        $exclude[] = $this->get_root_content_object()->get_id();
        
        if (! $this->type)
        {
            $this->type = $rtype = Request :: post(ContentObjectTypeSelector :: PARAM_CONTENT_OBJECT_TYPE);
            if (! $this->type)
            {
                $this->type = $content_object->get_allowed_types();
            }
        }
        if (! RepoViewer :: is_ready_to_be_published())
        {
            $pub = RepoViewer :: construct($this);
            if ($rtype)
            {
                $pub->set_parameter(ComplexBuilder :: PARAM_TYPE, $rtype);
            }
            $pub->set_maximum_select(RepoViewer :: SELECT_SINGLE);
            $pub->set_parameter(ComplexBuilder :: PARAM_COMPLEX_CONTENT_OBJECT_ITEM_ID, $complex_content_object_item_id);
            $pub->set_excluded_objects($exclude);
            $t = is_array($this->type) ? implode(',', $this->type) : $this->type;
            // $p =
            // $this->repository_data_manager->retrieve_content_object($parent);
            // $html[] = '<h4>' . sprintf(Translation ::
            // get('AddOrCreateNewTo'), $t, $p->get_type(), $p->get_title()) .
            // '</h4><br />';
            $pub->run();
        }
        else
        {
            $object = RepoViewer :: get_selected_objects();
            if (! is_array($object))
            {
                $object = array($object);
            }
            
            $repository_data_manager = $this->repository_data_manager;
            
            $failures = 0;
            foreach ($object as $obj)
            {
                $type = $repository_data_manager->determine_content_object_type($obj);
                
                $complex_content_object_item = ComplexContentObjectItem :: factory($type);
                $complex_content_object_item->set_ref($obj);
                $complex_content_object_item->set_parent($parent);
                
                if ($type == Forum :: get_type_name())
                {
                    $complex_content_object_item->set_display_order($repository_data_manager->select_next_display_order_forum($parent));
                }
                $complex_content_object_item->set_user_id($this->get_user_id());
                
                if (! $complex_content_object_item->create())
                {
                    $failures ++;
                }
            }
            
            $success = ($failures == 0);
            
            if (count($subforums) > 1)
            {
                $message = htmlentities(Translation :: get(($success ? 'ObjectsCreated' : 'ObjectsNotCreated'), array(
                        'OBJECT' => Translation :: get('Forum')), Utilities :: COMMON_LIBRARIES));
            }
            else
            {
                $message = htmlentities(Translation :: get(($success ? 'ObjectCreated' : 'ObjectNotCreated'), array(
                        'OBJECT' => Translation :: get('Forum')), Utilities :: COMMON_LIBRARIES));
            }
            
            $this->redirect($message, ($success ? false : true), array(
                    ComplexBuilder :: PARAM_BUILDER_ACTION => ComplexBuilder :: ACTION_BROWSE, 
                    ComplexBuilder :: PARAM_COMPLEX_CONTENT_OBJECT_ITEM_ID => $complex_content_object_item_id));
        }
    }

    private function retrieve_used_items($object)
    {
        $items = array();
        $rdm = RepositoryDataManager :: get_instance();
        $items = array_merge($items, $this->retrieve_used_items_parents($object));
        $complex_content_object_items = $rdm->retrieve_complex_content_object_items(new EqualityCondition(ComplexContentObjectItem :: PROPERTY_PARENT, $object, ComplexContentObjectItem :: get_table_name()));
        while ($complex_content_object_item = $complex_content_object_items->next_result())
        {
            
            if ($complex_content_object_item->is_complex())
            {
                
                $items[] = $complex_content_object_item->get_ref();
                $items = array_merge($items, $this->retrieve_used_items($complex_content_object_item->get_ref()));
            
            }
        }
        return $items;
    
    }

    private function retrieve_used_items_parents($object_id)
    {
        $items = array();
        $rdm = RepositoryDataManager :: get_instance();
        $items[] = $object_id;
        $complex_content_object_items_parent = $rdm->retrieve_complex_content_object_items(new EqualityCondition(ComplexContentObjectItem :: PROPERTY_REF, $object_id));
        while ($complex_content_object_item_parent = $complex_content_object_items_parent->next_result())
        {
            if ($complex_content_object_item_parent->is_complex())
            {
                
                $items = array_merge($items, $this->retrieve_used_items_parents($complex_content_object_item_parent->get_parent()));
            
            }
        }
        return $items;
    }

    function get_allowed_content_object_types()
    {
        return array($this->type);
    }

    function get_additional_parameters()
    {
        return array(self :: PARAM_TYPE);
    }
}
?>