<?php
namespace repository\content_object\forum;

use common\libraries\Display;
use common\libraries\Translation;
use common\libraries\Request;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Utilities;
use common\libraries\ParameterNotDefinedException;
use common\libraries\NotAllowedException;

use repository\ContentObjectRenditionImplementation;
use repository\ContentObjectRendition;
use repository\RepositoryDataManager;

use repository\content_object\forum_topic\ForumTopicDataManager;
/**
 * Attachment Viewer used for the Forum Posts.
 *
 * @author Maarten Volckaert - Hogeschool Gent
 */
class ForumComplexDisplayAttachmentViewerComponent extends ForumComplexDisplay
{
    function run()
    {
        /*
         * Retrieve data and check if it is a valid attachment
         */
        $post_id = Request :: get(ForumComplexDisplay :: PARAM_SELECTED_FORUM_POST);
        $attachment_id = Request :: get(ForumComplexDisplay :: PARAM_ATTACHMENT_ID);   
        $topic_id = Request :: get(ForumComplexDisplay :: PARAM_FORUM_TOPIC_ID);
        
        if(is_null($attachment_id))
        {
            throw new ParameterNotDefinedException(ForumComplexDisplay :: PARAM_ATTACHMENT_ID);
        }    
        
        /*
         * Test if a attachment is attached to a post.
         */
        $found_post = ForumTopicDataManager :: retrieve_attachment_of_post($post_id,$attachment_id);
        
        if($found_post == null)
        {
            throw new NotAllowedException();
        }

        /*
         * Test if a post is part of a topic
         */
        $post_in_topic = ForumTopicDataManager :: retrieve_forum_post_of_topic($topic_id, $post_id);
        
        if($post_in_topic == null)
        {
            throw new NotAllowedException();
        }
        
        /*
         * Render the attachment
         */
        $attachment = RepositoryDataManager :: get_instance()->retrieve_content_object($attachment_id);
        $trail = BreadcrumbTrail :: get_instance();
        $trail->add(new Breadcrumb($this->get_url(array(ForumComplexDisplay :: PARAM_ATTACHMENT_ID => $attachment_id)), Translation :: get('ViewAttachment')));
        Display :: small_header();

        echo '<a href="javascript:history.go(-1)">' . Translation :: get('Back', null, Utilities :: COMMON_LIBRARIES) 
                . '</a><br /><br />';
        
        echo ContentObjectRenditionImplementation :: launch($attachment, ContentObjectRendition :: FORMAT_HTML, 
                ContentObjectRendition :: VIEW_FULL, $this);

        Display :: small_footer();
        
        // END EDITING
    }
    
}

?>
