<?php
namespace repository\content_object\forum;

use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\extensions\repo_viewer\RepoViewerInterface;
use common\extensions\repo_viewer\RepoViewer;
use common\libraries\Request;

use repository\RepositoryDataManager;
use repository\content_object\forum_topic\ForumPost;
use repository\ComplexDisplay;
use repository\ContentObject;
use repository\ComplexContentObjectItem;
use repository\content_object\forum_topic\ForumPostForm;
use repository\content_object\forum_topic\ForumTopicDataManager;
use repository\content_object\forum\ForumPostCR;

/**
 *
 * @author Mattias De Pauw - Hogeschool Gent
 * @author Maarten Volckaert - Hogeschool Gent
 */

class ForumComplexDisplayForumPostCreatorComponent extends ForumPostFormActionCreate
{
    protected $forumpost;
    protected $form;

    /**
     * Makes a new creator form and if its validate makes a new post
     */
    function run()
    {
        $this->forumpost = new ForumPost();
        $first_post = ForumTopicDataManager :: retrieve_first_post($this->get_complex_content_object_item()->get_ref())->as_array();
        $post_id = Request :: get(self :: PARAM_SELECTED_FORUM_POST);
        
        if ($post_id != null)
        {
            $selected_post = ForumTopicDataManager :: retrieve_forum_post_of_topic($this->get_complex_content_object_item()->get_ref(), $post_id);
            $this->forumpost->set_title($selected_post->get_title());
        }
        else
        {
            $this->forumpost->set_title($first_post[0]->get_title());
        }
        
        $this->form = new ForumPostForm(ForumPostForm :: TYPE_CREATE, $this->get_url(array(
                self :: PARAM_COMPLEX_CONTENT_OBJECT_ITEM_ID => $this->get_complex_content_object_item_id())), $this->forumpost, $post_id);
        
        if ($this->form->validate())
        {
            $success = parent :: create_forum_post(ForumPostForm :: TYPE_CREATE);
            
            $this->my_redirect($success);
        }
        else
        {
            $this->add_common_breadcrumbtrails();
            $this->display_header();
            $this->form->display();
            echo ('<iframe style="width:100%; height:350px; border:1px solid #EBEBEB;" src="' . $this->get_url(array(
                    ForumComplexDisplay :: PARAM_DISPLAY_ACTION => ForumComplexDisplay :: ACTION_PREVIEW_TOPIC)) . '"></iframe>');
            $this->display_footer();
        }
    }

    /**
     * redirect
     *
     * @param $success type           
     */
    private function my_redirect($success)
    {
        $message = htmlentities(Translation :: get(($success ? 'ObjectCreated' : 'ObjectNotCreated'), array(
                'OBJECT' => Translation :: get('ForumPost')), Utilities :: COMMON_LIBRARIES));
        
        $params = array();
        $params[ComplexDisplay :: PARAM_DISPLAY_ACTION] = ForumComplexDisplay :: ACTION_VIEW_TOPIC;
        $params[ComplexDisplay :: PARAM_COMPLEX_CONTENT_OBJECT_ITEM_ID] = $this->get_complex_content_object_item_id();
        $this->redirect($message, ($success ? false : true), $params);
    }
    
    /*
     * Adding breadcrumbtrail
     */
    public function add_common_breadcrumbtrails()
    {
        $trail = parent :: add_common_breadcrumbtrails();
        $trail->add(new Breadcrumb($this->get_url(), Translation :: get('ReplyOnTopic', null, 'repository\content_object\forum_topic')));
    }
}

?>