<?php
namespace repository\content_object\forum;

use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Display;
use common\libraries\Request;

use repository\RepositoryDataManager;
use repository\ComplexDisplay;
use repository\content_object\forum\PostEmailNotificator;
use repository\content_object\forum_topic\Mdb2ForumTopicDataManager;
use repository\content_object\forum_topic\ForumTopicDataManager;
use repository\ContentObjectForm;
use repository\content_object\forum_topic\ForumPostForm;
use repository\content_object\forum_topic\ForumPost;
use repository\ContentObject;
use repository\RepositoryRights;

/**
 * @author Mattias De Pauw - Hogeschool Gent
 * @author Maarten Volckaert - Hogeschool Gent
 */
class ForumComplexDisplayForumPostEditorComponent extends ForumPostFormAction
{
    private $forumpost;
    private $selected_forum_post_id;
     /**
     * Makes a new editing form and if its validate edits the post. 
     */  
    function run()
    {
        $datamanager = ForumTopicDataManager :: get_instance();
        $this->selected_forum_post_id = Request :: get(self :: PARAM_SELECTED_FORUM_POST);
        $this->forumpost = $datamanager->retrieve_forum_post($this->selected_forum_post_id);
        
         if ($this->forumpost->get_user_id() == $this->get_user_id() || $this->get_parent()->is_allowed(RepositoryRights :: EDIT_RIGHT))
         {     
            $form = new ForumPostForm(ForumPostForm :: TYPE_EDIT,$this->get_url(array(self :: PARAM_COMPLEX_CONTENT_OBJECT_ITEM_ID => $this->get_complex_content_object_item_id(),self :: PARAM_SELECTED_FORUM_POST => $this->selected_forum_post_id)),
            $this->forumpost, $this->selected_forum_post_id);
            
           

            if($form->validate())
            {
                
                $values = $form->exportValues();
                $this->forumpost->set_title($values[ForumPost :: PROPERTY_TITLE]);
                $this->forumpost->set_content($values[ForumPost :: PROPERTY_CONTENT]);
          
                $success = $this->forumpost->update();
                
                if($success)
                {

                    
                // Process attachments
                // Add the new attachments after the edit.      
                foreach($values['attachments']['lo'] as $value)
                {
                    $help = $value;
                    if(ForumTopicDataManager :: get_instance()->retrieve_attached_object($this->selected_forum_post_id, $help) == null)
                    {
                        $this->forumpost->attach_content_object($value, ContentObject :: ATTACHMENT_NORMAL);
                    }
                }
                
                }
               
                // Remove the attachments that were removed during the edit.
                foreach( $this->forumpost->get_attached_content_objects() as $object)
                {
                    $counter = 0;
                    $found = false;
                    $new_list_counter = count($values['attachments']['lo']);
                    while($counter < $new_list_counter)
                    {
                        if( $object->get_id() == $values['attachments']['lo'][$counter])
                        {
                            $found = true;
                            break;
                        }
                        else
                        {    
                            $counter++;
                        }
                    }
                    if(!$found)
                    {
                        ForumTopicDataManager :: detach_content_object($this->forumpost, $object->get_id());
                    }
                }
    
                $this->my_redirect($success);
            }
            else
            {
                $this->add_common_breadcrumbtrails();
                $this->display_header();
                $form->display();
                $this->display_footer();
            }      
         }
         else
         {
             Display :: not_allowed();
             $this->add_common_breadcrumbtrails();
             $this->display_header();
             $form->display();
             $this->display_footer();
         }
    }
    
     /**
     * redirect
     * 
     * @param type $success 
     */
    private function my_redirect($success)
    {
        $message = htmlentities(Translation :: get(($success ? 'ObjectUpdated' : 'ObjectNotUpdated'), array(
                'OBJECT' => Translation :: get('ForumPost')), Utilities :: COMMON_LIBRARIES));
        $params = array();
        $params[ComplexDisplay :: PARAM_DISPLAY_ACTION] = ForumComplexDisplay :: ACTION_VIEW_TOPIC;
        $params[ComplexDisplay :: PARAM_COMPLEX_CONTENT_OBJECT_ITEM_ID] = $this->get_complex_content_object_item_id();
        $this->redirect($message, ($success ? false : true), $params);
    }
    
    /**
     * add breadcrumbtrails 
     */
    public function add_common_breadcrumbtrails()
    {
            $trail = parent :: add_common_breadcrumbtrails();
            $trail->add(new Breadcrumb($this->get_url(array(self :: PARAM_SELECTED_FORUM_POST => $this->selected_forum_post_id)), Translation :: get('EditPost', null, 'repository\content_object\forum_topic')));
    }
}
?>
