<?php

namespace repository\content_object\forum;

use common\libraries\Request;
use common\libraries\DataClass;
use common\libraries\Utilities;
use common\libraries\Translation;
use common\libraries\InCondition;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use common\libraries\AttachmentSupport;

use repository\RepositoryDataManager;
use repository\ContentObject;
use repository\ContentObjectAttachment;

/**
 * Dataclass ForumSubscribe dataclass for the users who subscribe to a forum
 * 
 * @author Mattias De Pauw - Hogeschool Gent
 * @author Maarten Volckaert - Hogeschool Gent
 */
class ForumSubscribe extends Dataclass
{
    /****************************************************************************************************************
    * Constants											                    *
    ****************************************************************************************************************/
    
    /**
     *Constant used for Autoloader class. 
     */
    const CLASS_NAME = __CLASS__;
    
    /**
     *Represents the id of the forum which is subscribed. 
     */
    const PROPERTY_FORUM_ID = 'forum_id';
    
    /**
     *Represents the id of the user who is subscribing. 
     */
    const PROPERTY_USER_ID = 'user_id';
    
   /****************************************************************************************************************
    * Getters												            *
    ****************************************************************************************************************/
         
    /**
     * Returns the type name of this class. 
     * 
     * @return ForumSubscribe 
     * 
     */
    static function get_type_name()
    {
        return Utilities :: camelcase_to_underscores(Utilities :: get_classname_from_namespace(self :: CLASS_NAME));
    }
     
    /**
     * Inherited
     * 
     * Returns an instance of the ForumDataManager.
     * 
     * @return ForumDataManager An instance of the ForumDataManager.
     * 
     */
    function get_data_manager()
    {
        return ForumDataManager :: get_instance();
    }

    /**
     * Inherited
     * 
     * Returns the table name in the database of this dataclass.
     * 
     * @return string String version of the table name in the database.
     *  
     */
    static function get_table_name()
    {
        return Utilities :: get_classname_from_namespace(self :: CLASS_NAME, true);
   
    }
    /**
     * Returns the id of the forum that is subscribed.
     * 
     * @return int Returns the id of the forum that is subscribed.
     * 
     */
    function get_forum_id()
    {
        return $this->get_default_property(self :: PROPERTY_FORUM_ID);
        
    }
    
    /**
     * Returns the id of the user that is subscribing.
     * 
     * @return int Returns the id of the user that is subscribing.
     * 
     */
    function get_user_id()
    {
        return $this->get_default_property(self :: PROPERTY_USER_ID);
    }
    
     /**
     * Returns the default properties of this dataclass
     *
     * @return String[] - The property names.
     * 
     */
    static function get_default_property_names($extended_property_names = array())
    {
        return parent :: get_default_property_names(array(self :: PROPERTY_USER_ID, self :: PROPERTY_FORUM_ID));
    }
    
    /**
     * Returns a user object of this subscribe
     * 
     * @return User
     * 
     */
    function get_user()
    {
        if (! isset($this->user))
        {
            $this->user = UserDataManager :: get_instance()->retrieve_user($this->get_user_id());
        }
        return $this->user;
    }
    
    /****************************************************************************************************************
    * Setters												            *
    ****************************************************************************************************************/
    
    /**
     * Sets the ID of this object's forum.
     *
     * @param int $forum_id The forum id.
     * 
     */
    function set_forum_id($forum_id)
    {
        $this->set_default_property(self :: PROPERTY_FORUM_ID, $forum_id);
    }
    
    /**
     * Sets the ID of this object's user.
     *
     * @param int $user_id The user id.
     * 
     */ 
    function set_user_id($user_id)
    {
        $this->set_default_property(self :: PROPERTY_USER_ID, $user_id);
    }
}

?>
