<?php
namespace repository\content_object\forum;

use common\libraries\Path;
use common\libraries\EqualityCondition;
use common\libraries\DataClass;
use common\libraries\Utilities;
use common\libraries\AndCondition;
use common\libraries\InCondition;
use common\libraries\Mdb2Database;
use common\libraries\Translation;
use common\libraries\ObjectTableOrder;

use repository\content_object\forum\ForumDataManagerInterface;
use repository\ContentObject;
use repository\RepositoryDataManager;
use repository\ComplexContentObjectItem;    
use repository\content_object\forum\ForumUserViewed;
use repository\content_object\forum\ForumSubscribe;
use repository\content_object\forum_topic\ForumPost;
use repository\content_object\forum_topic\ForumTopic;

use user\UserDataManager;
use user\User;

use MDB2;
use MDB2_Error;
use Exception;
     
/*
 * This class does all the necessary communication with the database layer.
 * 
 * @author Mattias De Pauw - Hogeschool Gent
 * @author Maarten Volckaert - Hogeschool Gent
 */
class Mdb2ForumDataManager extends Mdb2Database implements \repository\content_object\forum\ForumDataManagerInterface
{
    /**
     *  Inherited.
     *  Sets the right prefix for this mdb2 class.
     */
    function initialize()
    {
        parent :: initialize();
        $this->set_prefix('repository_');
    }
    
     /**
     * This function is used to retrieve a single subscribe based on its subscribe id.
     * 
     * @param int $subscribe_id The id of the forum topic.
     * 
     * @return ForumSubscribe 
     */
    function retrieve_subscribe($subscribe_id, $condition = null)
    {
        if(!$condition)
            $condition = new EqualityCondition(ForumSubscribe :: PROPERTY_ID, $subscribe_id);
        
        return $this->retrieve_object(ForumSubscribe :: get_table_name(), $condition, array(), ForumSubscribe :: CLASS_NAME);
    }
    
    /**
     * This function is used to retrieve a single subscribe based on its id .
     * 
     * @param int $id The id of the forum subscribe.
     * 
     * 
     * @return ForumSubscribe 
     */
    function retrieves_forum_subscribe($idforumsubscribe)
    {
        $condition = new EqualityCondition(ForumSubscribe :: PROPERTY_ID, $idforumsubscribe);
        
        return $this->retrieve_object(ForumSubscribe :: get_table_name(), $condition, array(), ForumSubscribe :: CLASS_NAME);
    }
    
    /**
     *
     * @param type $condition
     * 
     * @return type 
     * 
     */
    function retrieve_forum_subscribers($condition)
    {
         return $this->retrieve_objects(ForumSubscribe :: get_table_name(), $condition, array(), ForumSubscribe :: CLASS_NAME);
    }
    
    function retrieve_last_post_forum_topics($forum_id)
    {
        $complex_item_alias = $this->get_alias(ComplexContentObjectItem :: get_table_name());
        $forum_post_alias = $this->get_alias(ForumPost :: get_table_name());
        $forum_alias = $this->get_alias(Forum :: get_table_name());
        $forum_topic_alias = $this->get_alias(ForumTopic :: get_table_name());
       
                $condition = new EqualityCondition(ComplexContentObjectItem :: PROPERTY_PARENT, $forum_id, $complex_item_alias, true );
        
        $order_by = array();
        $order_by[] = new ObjectTableOrder(ForumPost :: PROPERTY_CREATION_DATE , SORT_DESC, $forum_post_alias);
        
        $query = 'SELECT *';
        
        $query .= ' FROM ' . $this->escape_table_name(ComplexContentObjectItem :: get_table_name()) . 
                ' AS ' . $complex_item_alias;
        
        $query .= ' JOIN ' . $this->escape_table_name(Forum :: get_table_name()) . ' AS ' . $forum_alias . 
                ' ON ' . $this->escape_column_name(ComplexContentObjectItem :: PROPERTY_PARENT, $complex_item_alias) . ' = '
                . $this->escape_column_name(Forum :: PROPERTY_ID, $forum_alias);
        
        $query .= ' JOIN ' . $this->escape_table_name(ForumTopic :: get_table_name()) . ' AS ' . $forum_topic_alias . ' ON '
                . $this->escape_column_name(ComplexContentObjectItem :: PROPERTY_REF, $complex_item_alias) . ' = ' 
                . $this->escape_column_name(ForumTopic :: PROPERTY_ID, $forum_topic_alias);
        
        $query .= ' JOIN ' . $this->escape_table_name(ForumPost :: get_table_name()) . ' AS ' . $forum_post_alias . ' ON ' 
                . $this->escape_column_name(ForumTopic :: PROPERTY_ID  , $forum_topic_alias) . ' = ' . $this->escape_column_name(ForumPost :: PROPERTY_FORUM_TOPIC_ID, $forum_post_alias);
       
        
        return $this->retrieve_object_set($query , ForumPost :: get_table_name() , $condition , 0 , 1 , $order_by , ForumPost :: CLASS_NAME);
    }
    
    /**
     * get the last post of a (sub)forum his subforum(s)
     * 
     * @param int $forum_id
     * 
     * @return Forum 
     */
    function retrieve_forum_last_post_forum_subforums($forum_id)
    {
        $complex_item_alias = $this->get_alias(ComplexContentObjectItem :: get_table_name());
        $forum_post_alias = $this->get_alias(ForumPost :: get_table_name());
        $forum_alias = $this->get_alias(Forum :: get_table_name());
        
        $help_table_repo_forum = 'forum';
        
        $forum_alias_bis = $this->get_alias($help_table_repo_forum);
        
        $condition = new EqualityCondition(ComplexContentObjectItem :: PROPERTY_PARENT, $forum_id, $complex_item_alias, true);
        
        $order_by = array();
        $order_by[] = new ObjectTableOrder(ForumPost :: PROPERTY_CREATION_DATE, SORT_DESC, $forum_post_alias);
        
       
        $query = 'SELECT *';
        
        $query .= ' FROM ' . $this->escape_table_name(ComplexContentObjectItem :: get_table_name()) . ' AS ' . 
                $complex_item_alias;
        
        $query .= ' JOIN ' . $this->escape_table_name(Forum :: get_table_name()) . ' AS ' . $forum_alias . ' ON ' . 
                $this->escape_column_name(ComplexContentObjectItem :: PROPERTY_PARENT, $complex_item_alias) . ' = ' .
                $this->escape_column_name(Forum :: PROPERTY_ID, $forum_alias);
        
        $query .= ' JOIN ' . $this->escape_table_name($help_table_repo_forum) . ' AS ' . $forum_alias_bis. ' ON ' .
                $this->escape_column_name(ComplexContentObjectItem :: PROPERTY_REF, $complex_item_alias) . ' = ' . 
                $this->escape_column_name(Forum :: PROPERTY_ID, $forum_alias_bis);
        
        $query .= ' JOIN ' . $this->escape_table_name(ForumPost :: get_table_name()) . ' AS ' . $forum_post_alias . 
                ' ON ' . $this->escape_column_name(Forum :: PROPERTY_LAST_POST  , $forum_alias_bis) . ' = ' . 
                $this->escape_column_name(ForumPost :: PROPERTY_ID, $forum_post_alias);
       
        
       
        return $this->retrieve_object_set($query , Forum :: get_table_name() , $condition , 0 ,1 , $order_by , Forum :: CLASS_NAME);
        
        
    }
}

?>
