<?php
namespace repository\content_object\forum_topic;

use common\libraries\Utilities;
use common\libraries\DataClass;

/**
 * Dataclass that describes a Forum Topic Subsribe.
 *
 * @author Maarten Volckaert - Hogeschool Gent
 */
class ForumTopicSubscribe extends DataClass
{
    /****************************************************************************************************************
    * Constants											                    *
    ****************************************************************************************************************/
    const CLASS_NAME = __CLASS__;
    
    /**
     * Represents the id of the user who is subscribing. 
     */
    const PROPERTY_USER_ID = 'user_id';
    /*
     * Represents the id of the forum topic which is subscribed. 
     */
    const PROPERTY_FORUM_TOPIC_ID = 'forum_topic_id';
    
    
    /****************************************************************************************************************
    * Getters												            *
    ****************************************************************************************************************/
    
     /**
     * Returns the type name of this class. 
     * 
     * @return ForumTopicSubscribe 
     * 
     */
    static function get_type_name()
    {
        return Utilities :: camelcase_to_underscores(Utilities :: get_classname_from_namespace(self :: CLASS_NAME));
    }
    
    /**
     * Gets a string version of the table name in the database.
     * 
     * @return string String version of the table name in the database.
     */
    static function get_table_name()
    {
        return Utilities :: get_classname_from_namespace(self :: CLASS_NAME, true);
    }

    /**
     * Get the default properties of all content object attachments.
     * 
     * @return array The property names.
     */
    static function get_default_property_names($extended_property_names = array())
    {
        return parent :: get_default_property_names(array(self :: PROPERTY_FORUM_TOPIC_ID, self :: PROPERTY_USER_ID));
    }
    
    /**
     * Gets the data manager of the forum topic subscribe object.
     * 
     * @return ForumTopicDataManager Returns a data manager object for database communication
     * 
     */
    function get_data_manager()
    {
        return ForumTopicDataManager :: get_instance();
    }
    
    /**
     * Gets the id of the forum topic.
     * 
     * @return int The id of the forum topic
     * 
     */
    function get_forum_topic_id()
    {
        return $this->get_default_property(self:: PROPERTY_FORUM_TOPIC_ID);
    }

     /**
     * Gets the id of the user that is subscribing.
     * 
     * @return int Returns the id of the user that is subscribing.
     * 
     */
    function get_user_id()
    {
        return $this->get_default_property(self :: PROPERTY_USER_ID);
    }
    
    /**
     * Returns a user object of this subscribe
     * 
     * @return User
     */
    function get_user()
    {
        if (! isset($this->user))
        {
            $this->user = UserDataManager :: get_instance()->retrieve_user($this->get_user_id());
        }
        return $this->user;
    }
    
    /****************************************************************************************************************
    * Setters												            *
    ****************************************************************************************************************/
   /**
     * Sets the ID of this object's forum topic.
     *
     * @param int $forum_topic_id The forum topic id.
     * 
     */
    function set_forum_topic_id($forum_topic_id)
    {
        $this->set_default_property(self :: PROPERTY_FORUM_TOPIC_ID, $forum_topic_id);
    }
    
    /**
     * Sets the ID of this object's user.
     *
     * @param int $user_id The user id.
     * 
     */ 
    function set_user_id($user_id)
    {
        $this->set_default_property(self :: PROPERTY_USER_ID, $user_id);
    }        
}

?>
