<?php
namespace repository\content_object\forum_topic;

/**
 * Interface class that contains all methods of the datamanager.
 * 
 * @author Mattias De Pauw - Hogeschool Gent
 * @author Maarten Volckaert - Hogeschool Gent 
 */
interface ForumTopicDataManagerInterface
{
    /****************************************************************************************************************
    * Posts         											            *
    ****************************************************************************************************************/
        
    /*
     * This function is used for retrieving a particular forum post based on its id.
     * 
     * @param int $forum_post_id  The id of the forum post that needs to be retrieved
     * 
     * @return ForumPost
     * 
     */
    function retrieve_forum_post($forum_post_id);
     
      /*
      * This function is used for retrieving a particular forum topic based on its id.
      * 
      * @param int $forum_topic_id  The id of the forum topic that needs to be retrieved
      * 
      * @return ForumTopic
      * 
      */
     function retrieve_forum_topic($forum_topic_id);
     
     /*
      * This function counts the forum posts of a forum topic
      * 
      * @param int $forum_topic_id The id of a forum topic of which the posts will be counted
      * 
      * @return int The number of posts of the topic
      * 
      */
     function count_forum_posts($condition);
     
     /*
      * This function returns a resultset of forumpost objects of a forum topic.
      * 
      * @param int $forum_topic_id  The id of a forum topic of which a resultset of posts will be returned
      * 
      * @return ResultSet A resultset of forum_topic_posts
      * 
      */
     function retrieve_forum_posts($forum_topic_id,$offset,$max_objects,$order_by);  
 
    /****************************************************************************************************************
    * Attachments											            *
    ****************************************************************************************************************/ 
     
    /*
     * This function returns a ContentObject that is attached to a forum post.
     * 
     * @param int $forum_post_id  The id of a forum post that has an attached ContentObject.
     * @param int $attachment_id  The id of a ContentObject that is attached to a forum post.
     * 
     * @return ContentObject
     * 
     */
     function retrieve_attached_object($forum_post_id, $attachment_id);
     
    /*
     * This method returns all attachment objects of a particular forum post.
     * 
     * @param Condition $condition
     *
     * @return ResultSet
     * 
     */
     function retrieve_attached_objects($condition);
     
     /*
      * This method retrieves an array of the attached content objects of a particular post.
      * 
      * @param int $forum_post_id  The id of a forum post that has attached ContentObjects
      * @param int $offset
      * @param int $max_objects
      * @param int $order_by  The ordering of the ResultSet.
      * 
      * @return ResultSet
      *  
      */
     function retrieve_attached_object_from_forum_post($forum_post_id, $offset, $max_objects, $order_by);
  
}
?>
