<?php
namespace repository\content_object\glossary;

use common\extensions\repo_viewer\RepoViewer;
use common\extensions\repo_viewer\RepoViewerInterface;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\DelegateComponent;
use common\libraries\Translation;
use common\libraries\Utilities;

use repository\content_object\glossary_item\GlossaryItem;
use repository\ComplexContentObjectItem;
use repository\RepositoryDataManager;

/**
 * Description of glossary_item_creator
 *
 * @author Anthony Hurst (Hogeschool Gent)
 */
class GlossaryComplexDisplayGlossaryItemCreatorComponent extends GlossaryComplexDisplay implements RepoViewerInterface, DelegateComponent
{
    function run()
    {
        if(!RepoViewer :: is_ready_to_be_published())
        {
            BreadcrumbTrail :: get_instance()->add(new Breadcrumb($this->get_url(array(
                self :: PARAM_DISPLAY_ACTION => self :: ACTION_VIEW_COMPLEX_CONTENT_OBJECT,
                self :: PARAM_COMPLEX_CONTENT_OBJECT_ITEM_ID => null)), $this->get_root_content_object()->get_title()));
            
            $repo_viewer = RepoViewer :: construct($this);
            $repo_viewer->set_parameter(self :: PARAM_DISPLAY_ACTION, self :: ACTION_CREATE_GLOSSARY_ITEM);
            $repo_viewer->set_parameter(self :: PARAM_COMPLEX_CONTENT_OBJECT_ITEM_ID, $this->get_complex_content_object_item_id());
            $repo_viewer->run();
        }
        else
        {
            $object_ids = RepoViewer :: get_selected_objects();
            if(!is_array($object_ids))
            {
                $object_ids = array($object_ids);
            }
            
            $failures = 0;
            foreach($object_ids as $object_id)
            {
                $ccoi = ComplexContentObjectItem :: factory(GlossaryItem :: get_type_name());
                $ccoi->set_parent($this->get_root_content_object_id());
                $ccoi->set_ref($object_id);
                $ccoi->set_user_id($this->get_user_id());
                $ccoi->set_display_order(RepositoryDataManager :: get_instance()->select_next_display_order($ccoi->get_parent()));
                if(!$ccoi->create())
                {
                    $failures++;
                }
            }
            
            $this->my_redirect($failures == 0);
        }
    }
    
    private function my_redirect($success)
    {
        $message = htmlentities(Translation :: get(($success ? 'ObjectCreated' : 'ObjectNotCreated'), array(
                'OBJECT' => Translation :: get('GlossaryItem')), Utilities :: COMMON_LIBRARIES));
        
        $parameters = array();
        $parameters[self :: PARAM_DISPLAY_ACTION] = self :: ACTION_VIEW_COMPLEX_CONTENT_OBJECT;
        $parameters[self :: PARAM_COMPLEX_CONTENT_OBJECT_ITEM_ID] = $this->get_complex_content_object_item_id();
        
        $this->redirect($message, !$success, $parameters);
    }
    
    function get_allowed_content_object_types()
    {
        return array(GlossaryItem :: get_type_name());
    }
}

?>
