<?php
namespace repository\content_object\hotspot_question;

use common\libraries\Utilities;
use common\libraries\Versionable;

use repository\ContentObject;
use repository\RepositoryDataManager;

/**
 * $Id: hotspot_question.class.php 200 2009-11-13 12:30:04Z kariboe $
 * @package repository.lib.content_object.hotspot_question
 */
/**
 * This class represents a hotspot question
 */
class HotspotQuestion extends ContentObject implements Versionable
{
    const PROPERTY_ANSWERS = 'answers';
    const PROPERTY_IMAGE = 'image';
    
    const CLASS_NAME = __CLASS__;

    static function get_type_name()
    {
        return Utilities :: camelcase_to_underscores(Utilities :: get_classname_from_namespace(self :: CLASS_NAME));
    }

    public function add_answer($answer)
    {
        $answers = $this->get_answers();
        $answers[] = $answer;
        return $this->set_additional_property(self :: PROPERTY_ANSWERS, serialize($answers));
    }

    public function set_answers($answers)
    {
        return $this->set_additional_property(self :: PROPERTY_ANSWERS, serialize($answers));
    }

    public function get_answers()
    {
        if ($result = unserialize($this->get_additional_property(self :: PROPERTY_ANSWERS)))
        {
            return $result;
        }
        return array();
    }

    public function get_number_of_answers()
    {
        return count($this->get_answers());
    }

    public function get_image()
    {
        return $this->get_additional_property(self :: PROPERTY_IMAGE);
    }

    public function set_image($image)
    {
        $this->set_additional_property(self :: PROPERTY_IMAGE, $image);
    }

    static function get_additional_property_names()
    {
        return array(self :: PROPERTY_ANSWERS, self :: PROPERTY_IMAGE);
    }

    function get_image_object()
    {
        $image = $this->get_image();
        
        if (isset($image) && $image != 0)
        {
            return RepositoryDataManager :: get_instance()->retrieve_content_object($image);
        }
        else
        {
            return null;
        }
    }

    /**
     * Returns the maximum weight/score a user can receive.
     */
    public function get_maximum_score()
    {
        $max = 0;
        $answers = $this->get_answers();
        foreach ($answers as $answer)
        {
            $max = max($answer->get_weight(), $max);
        }
        return $max;
    }

    //TODO: should be moved to an additional parent layer "question" which offers a default implementation.
    function get_default_weight()
    {
        return $this->get_maximum_score();
    }
}
?>