<?php
namespace repository\content_object\learning_path;

use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\EqualityCondition;
use common\libraries\ToolbarItem;
use common\libraries\Toolbar;
use common\libraries\Theme;
use common\libraries\Application;
use common\libraries\NotCondition;
use common\libraries\AndCondition;
use common\libraries\ComplexContentObjectSupport;
use common\libraries\Path;
use common\libraries\SubselectCondition;
use repository\content_object\learning_path_item\LearningPathItem;
use repository\content_object\assessment\Assessment;
use repository\ComplexBrowserTableCellRenderer;
use repository\ContentObject;
use repository\ComplexBuilder;
use repository\ComplexContentObjectItem;
use repository\RepositoryDataManager;
use repository\RepositoryManager;
use repository\ComplexBrowserTableColumnModel;

/**
 * $Id: learning_path_browser_table_cell_renderer.class.php 200 2009-11-13 12:30:04Z kariboe $
 * @package repository.lib.complex_builder.learning_path.component.browser
 */
/**
 * Cell rendere for the learning object browser table
 */
class LearningPathBrowserTableCellRenderer extends ComplexBrowserTableCellRenderer
{
    private $count;

    /**
     * Constructor
     * @param RepositoryManagerBrowserComponent $browser
     */
    function __construct($browser, $condition)
    {
        if ($condition)
        {
            $count_conditions[] = $condition;
        }
        
        $subselect_condition = new NotCondition(new EqualityCondition(ContentObject :: PROPERTY_TYPE, LearningPath :: get_type_name()));
        $count_conditions[] = new SubselectCondition(ComplexContentObjectItem :: PROPERTY_REF, ContentObject :: PROPERTY_ID, 'content_object', $subselect_condition);
        $count_condition = new AndCondition($count_conditions);
        
        $this->count = RepositoryDataManager :: get_instance()->count_complex_content_object_items($count_condition);
        parent :: __construct($browser, $condition);
    }
    
    private $lpi_ref_object;

    // Inherited
    function render_cell($column, $complex_content_object_item)
    {      
        $content_object = $this->retrieve_content_object($complex_content_object_item->get_ref());
        $ref_lo = $content_object;
        if ($content_object->get_type() == LearningPathItem :: get_type_name())
        {
            if (! $this->lpi_ref_object || $this->lpi_ref_object->get_id() != $content_object->get_reference())
            {
                $content_object = RepositoryDataManager :: get_instance()->retrieve_content_object($content_object->get_reference());
                $this->lpi_ref_object = $content_object;
            }
            else
            {
                $content_object = $this->lpi_ref_object;
            }
        }
        
        if ($column === ComplexBrowserTableColumnModel :: get_modification_column())
        {
            return $this->get_modification_links($complex_content_object_item, $ref_lo);
        }
        
        switch ($column->get_name())
        {
            case ContentObject :: PROPERTY_TITLE :
                $title = htmlspecialchars($content_object->get_title());
                $title_short = $title;
                
                $title_short = Utilities :: truncate_string($title_short, 53, false);
                
                if ($content_object->get_type() == LearningPath :: get_type_name())
                {
                    $title_short = '<a href="' . $this->browser->get_url(array(
                            ComplexBuilder :: PARAM_COMPLEX_CONTENT_OBJECT_ITEM_ID => $complex_content_object_item->get_id())) . '">' . $title_short . '</a>';
                }
                else
                {
                    if ($content_object instanceof ComplexContentObjectSupport)
                    {
                        $url = Path :: get_launcher_application_path(true) . 'index.php?' . Application :: PARAM_APPLICATION . '=complex_builder&' . RepositoryManager :: PARAM_CONTENT_OBJECT_ID . '=' . $content_object->get_id();
                        $title_short = '<a href="#" onclick="javascript:openPopup(\'' . $url . '\'); return false">' . $title_short . '</a>';
                    }
                    else
                    {
                        $object_url = $this->browser->get_complex_content_object_item_view_url($complex_content_object_item->get_id());
                        $title_short = '<a onclick="javascript:openPopup(\'' . $object_url . '\'); return false;" href="#" >' . $title_short . '</a>';                    
                    }
                }
                
                return $title_short;
        }
        
        return parent :: render_cell($column, $complex_content_object_item, $content_object);
    }

    protected function get_modification_links($complex_content_object_item)
    {
        $content_object = $this->retrieve_content_object($complex_content_object_item->get_ref());
        $toolbar = new Toolbar();
        $parent = RepositoryDataManager :: get_instance()->retrieve_content_object($complex_content_object_item->get_parent());
        
        if ($content_object->get_type() == LearningPathItem :: get_type_name())
        {
            if ($parent->get_version() == 'chamilo' && $this->count > 1)
            {
                $prerequisites = $complex_content_object_item->get_prerequisites();
                if (! empty($prerequisites))
                {
                    $toolbar->add_item(new ToolbarItem(Translation :: get('EditPrerequisites'), Theme :: get_common_image_path() . 'action_edit_prerequisites.png', $this->browser->get_prerequisites_url($complex_content_object_item->get_id()), ToolbarItem :: DISPLAY_ICON));
                }
                else
                {
                    $toolbar->add_item(new ToolbarItem(Translation :: get('BuildPrerequisites'), Theme :: get_common_image_path() . 'action_build_prerequisites.png', $this->browser->get_prerequisites_url($complex_content_object_item->get_id()), ToolbarItem :: DISPLAY_ICON));
                }
            }
            
            if ($this->lpi_ref_object->get_type() == Assessment :: get_type_name())
            {
                $toolbar->add_item(new ToolbarItem(Translation :: get('SetMasteryScore'), Theme :: get_common_image_path() . 'action_quota.png', $this->browser->get_mastery_score_url($complex_content_object_item->get_id()), ToolbarItem :: DISPLAY_ICON));
            }
        }
        
        $toolbar->add_item(new ToolbarItem(Translation :: get('Edit', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_edit.png', $this->browser->get_complex_content_object_item_edit_url($complex_content_object_item->get_id()), ToolbarItem :: DISPLAY_ICON));
        
        if ($parent->get_version() == 'chamilo')
        {
            
            $delete_url = $this->browser->get_complex_content_object_item_delete_url($complex_content_object_item->get_id());
            $moveup_url = $this->browser->get_complex_content_object_item_move_url($complex_content_object_item->get_id(), RepositoryManager :: PARAM_DIRECTION_UP);
            $movedown_url = $this->browser->get_complex_content_object_item_move_url($complex_content_object_item->get_id(), RepositoryManager :: PARAM_DIRECTION_DOWN);
            $change_parent_url = $this->browser->get_complex_content_object_parent_changer_url($complex_content_object_item->get_id());
            
            $toolbar->add_item(new ToolbarItem(Translation :: get('Delete', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_delete.png', $delete_url, ToolbarItem :: DISPLAY_ICON, true));
            $toolbar->add_item(new ToolbarItem(Translation :: get('Move', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_move.png', $change_parent_url, ToolbarItem :: DISPLAY_ICON));
            
            $allowed = $this->check_move_allowed($complex_content_object_item);
            
            if ($allowed["moveup"])
            {
                $toolbar->add_item(new ToolbarItem(Translation :: get('MoveUp', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_up.png', $moveup_url, ToolbarItem :: DISPLAY_ICON));
            }
            else
            {
                $toolbar->add_item(new ToolbarItem(Translation :: get('MoveUpNA', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_up_na.png', null, ToolbarItem :: DISPLAY_ICON));
            
            }
            
            if ($allowed["movedown"])
            {
                $toolbar->add_item(new ToolbarItem(Translation :: get('MoveDown', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_down.png', $movedown_url, ToolbarItem :: DISPLAY_ICON));
            }
            else
            {
                $toolbar->add_item(new ToolbarItem(Translation :: get('MoveDownNA', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_down_na.png', null, ToolbarItem :: DISPLAY_ICON));
            
            }
        }
        
        return $toolbar->as_html();
    
     //return parent :: get_modification_links($complex_content_object_item, $additional_items);
    }
}
?>