<?php

namespace repository\content_object\learning_path;

use common\libraries\FormValidator;
use common\libraries\Translation;
use common\libraries\EqualityCondition;
use common\libraries\Theme;
use common\libraries\NotCondition;
use common\libraries\AndCondition;
use common\libraries\Path;
use common\libraries\Text;
use repository\content_object\learning_path_item\LearningPathItem;
use repository\ComplexContentObjectItem;
use repository\RepositoryDataManager;
use common\libraries\Utilities;

/**
 * $Id: prerequisites_builder_form.class.php 200 2009-11-13 12:30:04Z kariboe $
 * @package repository.lib.complex_builder.learning_path.component.prerequisites_builder
 */
class PrerequisitesBuilderForm extends FormValidator
{
    
    private $parent;
    private $user;
    private $clo_item;
    private $form_type;
    private $clpi_id;
    
    const FORM_TYPE_ADVANCED = 'advanced';
    const FORM_TYPE_BASIC = 'basic';
    const IDENTIFER = 'clpi_';

    /**
     * Creates a new AccountForm
     */
    function __construct($user, $clo_item, $action)
    {
        parent :: __construct('prerequisites', 'post', $action);
        
        $this->user = $user;
        $this->clo_item = $clo_item;
        $this->clpi_id = $this->clo_item->get_id();
        
        $this->setDefaults();
        $this->handle_session_values();
        
        switch ($this->form_type)
        {
            case self :: FORM_TYPE_ADVANCED :
                $this->build_advanced_form();
                break;
            case self :: FORM_TYPE_BASIC :
                $this->build_basic_form();
                break;
        }
    }

    function set_form_type($form_type)
    {
        $_SESSION[self :: IDENTIFER . $this->clpi_id]['form_type'] = $form_type;
    }

    function handle_session_values()
    {
        
        $clpi_id = $this->clpi_id;
        
        if (! $this->isSubmitted())
        {
            unset($_SESSION[self :: IDENTIFER . $clpi_id]['number_of_groups']);
            unset($_SESSION[self :: IDENTIFER . $clpi_id]['number_of_items']);
            unset($_SESSION[self :: IDENTIFER . $clpi_id]['skip_items']);
            unset($_SESSION[self :: IDENTIFER . $clpi_id]['skip_groups']);
        }
        
        if (isset($_POST['go_basic']))
        {
            $_SESSION[self :: IDENTIFER . $clpi_id]['form_type'] = self :: FORM_TYPE_BASIC;
        }
        else 
            if (isset($_POST['go_advanced']))
            {
                $_SESSION[self :: IDENTIFER . $clpi_id]['form_type'] = self :: FORM_TYPE_ADVANCED;
            }
        
        if (isset($_POST['add_group']))
        {
            $_SESSION[self :: IDENTIFER . $clpi_id]['number_of_groups'] = $_SESSION[self :: IDENTIFER . $clpi_id]['number_of_groups'] + 1;
            
            $group_number = $_SESSION[self :: IDENTIFER . $clpi_id]['number_of_groups'] - 1;
            
            $_SESSION[self :: IDENTIFER . $clpi_id]['number_of_items'][$group_number] = 2;
            
            $_SESSION[self :: IDENTIFER . $clpi_id]['skip_items'][$group_number] = array();
        }
        
        if (isset($_POST['remove_group']))
        {
            $indexes = array_keys($_POST['remove_group']);
            
            $_SESSION[self :: IDENTIFER . $clpi_id]['skip_groups'][] = $indexes[0];
            unset($_SESSION[self :: IDENTIFER . $clpi_id]['number_of_items'][$indexes[0]]);
        }
        
        if (isset($_POST['add_item']))
        {
            $indexes = array_keys($_POST['add_item']);
            $_SESSION[self :: IDENTIFER . $clpi_id]['number_of_items'][$indexes[0]] ++;
        }
        
        if (isset($_POST['remove_item']))
        {
            foreach ($_POST['remove_item'] as $group_number => $item)
            {
                $indexes = array_keys($item);
                $_SESSION[self :: IDENTIFER . $clpi_id]['skip_items'][$group_number][] = $indexes[0];
            }
        }
        
        if (isset($_POST['submit_basic']))
        {
            $this->form_type = self :: FORM_TYPE_BASIC;
        }
        
        if ($this->number_of_groups)
        {
            $_SESSION[self :: IDENTIFER . $clpi_id]['number_of_groups'] = $this->number_of_groups;
        }
        
        if ($this->number_of_items)
        {
            $_SESSION[self :: IDENTIFER . $clpi_id]['number_of_items'] = $this->number_of_items;
        }
        
        if (! isset($_SESSION[self :: IDENTIFER . $clpi_id]['number_of_groups']))
        {
            $_SESSION[self :: IDENTIFER . $clpi_id]['number_of_groups'] = 1;
            $_SESSION[self :: IDENTIFER . $clpi_id]['number_of_items'][0] = 2;
        }
        
        if (! isset($_SESSION[self :: IDENTIFER . $clpi_id]['skip_groups']))
        {
            $_SESSION[self :: IDENTIFER . $clpi_id]['skip_groups'] = array();
            $_SESSION[self :: IDENTIFER . $clpi_id]['skip_items'][] = array();
        }
        
        $this->form_type = $_SESSION[self :: IDENTIFER . $clpi_id]['form_type'];
    }

    /*
     * This method shows basic prerequisites builder
     */
    
    function build_basic_form()
    {
        
        $siblings = $this->retrieve_siblings();
        $prerequisite = 'basic_prerequisite';
        $choices = array();
        
        $items_ids = array();
        $items_ids = array_keys($siblings);
        
        for($i; $i < sizeof($siblings); $i ++)
        {
            
            if ($items_ids[$i])
            {
                $choices[] = $this->createElement('radio', $prerequisite, '', Translation :: get($siblings[$items_ids[$i]]), $items_ids[$i]);
            }
        }
        
        $this->addGroup($choices, $prerequisite, Translation :: get('Steps'), '<br />', false);
        $form_buttons = array();
        $form_buttons[] = $this->createElement('style_reset_button', 'reset', Translation :: get('Reset', null, Utilities :: COMMON_LIBRARIES), array(
                'class' => 'normal empty'));
        $form_buttons[] = $this->createElement('style_submit_button', 'submit_basic', Translation :: get('SavePrerequisites'), array(
                'class' => 'positive save'));
        $form_buttons[] = $this->createElement('style_submit_button', 'go_advanced', Translation :: get('AdvancedPrerequisites'), array(
                'class' => 'normal next'));
		
        $this->addGroup($form_buttons, 'option_buttons', null, '&nbsp;', false);
    }

    function build_advanced_form()
    {
        $clpi_id = $this->clpi_id;
        
        $renderer = &$this->defaultRenderer();
        //        $renderer->setElementTemplate('<div style="margin: 10px 0px;">{element}<div class="clear"></div></div>', 'option_buttons');
        //        $renderer->setGroupElementTemplate('<div style="text-align: center; margin-right: 10px;">{element}</div>', 'option_buttons');
        //        $gbuttons = array();
        //        $gbuttons[] = $this->createElement('style_button', 'add_group[]', Translation :: get('AddPrerequisiteGroup'), array('class' => 'normal add', 'id' => 'add_group'));
        //        $this->addGroup($gbuttons, 'option_buttons', null, '', false);
        

        $operator = array('' => Translation :: get('Operator'), 
                '&' => Translation :: get('And', null, Utilities :: COMMON_LIBRARIES), 
                '|' => Translation :: get('Or', null, Utilities :: COMMON_LIBRARIES));
        $goperator = array('&' => Translation :: get('And', null, Utilities :: COMMON_LIBRARIES), 
                '|' => Translation :: get('Or', null, Utilities :: COMMON_LIBRARIES));
        //$goperator = array('' => Translation :: get('GroupOperator'), '&' => Translation :: get('And'), '|' => Translation :: get('Or'));
        

        $not = array('' => '', '~' => Translation :: get('Not', null, Utilities :: COMMON_LIBRARIES));
        $siblings = $this->retrieve_siblings();
        
        $number_of_groups = $_SESSION[self :: IDENTIFER . $clpi_id]['number_of_groups'];
        $gcounter = 0;
        for($group_number = 0; $group_number < $number_of_groups; $group_number ++)
        {
            if (! in_array($group_number, $_SESSION[self :: IDENTIFER . $clpi_id]['skip_groups']))
            {
                
                $category_html = array();
                $category_html[] = '<div class="prerequisite_group">';
                $category_html[] = '<div class="header">';
                $category_html[] = '<div class="operator">';
                $this->addElement('html', implode("\n", $category_html));
                
                if ($gcounter > 0 && $group_number != 0)
                {
                    $renderer->setElementTemplate('{element}', 'group_operator[' . $group_number . ']');
                    $this->addElement('select', 'group_operator[' . $group_number . ']', '', $goperator);
                }
                
                $category_html = array();
                $category_html[] = '</div>';
                $category_html[] = '<div class="title">' . Translation :: get('PrerequisiteGroup') . ' ' . ($gcounter + 1) . '</div>';
                $category_html[] = '<div class="actions">';
                $this->addElement('html', implode("\n", $category_html));
                
                if ($_SESSION[self :: IDENTIFER . $clpi_id]['number_of_groups'] - count($_SESSION[self :: IDENTIFER . $clpi_id]['skip_groups']) > 1)
                {
                    
                    $renderer->setElementTemplate('{element}', 'remove_group[' . $group_number . ']');
                    $group[] = $this->addElement('image', 'remove_group[' . $group_number . ']', Theme :: get_common_image_path() . 'action_delete.png', array(
                            'title' => Translation :: get('RemoveGroup'), 'class' => 'remove_group', 
                            'id' => $group_number));
                }
                
                $category_html = array();
                $category_html[] = '</div>';
                $category_html[] = '</div>';
                $category_html[] = '<div class="body">';
                $this->addElement('html', implode("\n", $category_html));
                //$this->addElement('category', Translation :: get('PrerequisiteGroup') . ' ' . ($gcounter + 1));
                

                $number_of_items = intval($_SESSION[self :: IDENTIFER . $clpi_id]['number_of_items'][$group_number]);
                
                $counter = 0;
                for($item_number = 0; $item_number < $number_of_items; $item_number ++)
                {
                    if (! in_array($item_number, $_SESSION[self :: IDENTIFER . $clpi_id]['skip_items'][$group_number]))
                    {
                        $identifier = '[' . $group_number . '][' . $item_number . ']';
                        $group = array();
                        
                        if ($counter > 0)
                        {
                            $group[] = $this->createElement('select', 'operator' . $identifier, '', $operator);
                        }
                        else
                        {
                            $element = $this->createElement('select', 'operator' . $identifier, '', $operator, array(
                                    'disabled'));
                            $group[] = $element;
                        }
                        
                        $group[] = $this->createElement('select', 'not' . $identifier, '', $not);
                        $group[] = $this->createElement('select', 'prerequisite' . $identifier, '', $siblings);
                        
                        if ($_SESSION[self :: IDENTIFER . $clpi_id]['number_of_items'][$group_number] - count($_SESSION[self :: IDENTIFER . $clpi_id]['skip_items'][$group_number]) > 1)
                        {
                            
                            $group[] = & $this->createElement('image', 'remove_item[' . $group_number . '][' . $item_number . ']', Theme :: get_common_image_path() . 'action_delete.png', array(
                                    'title' => Translation :: get('RemoveItem'), 'class' => 'remove_item', 
                                    'id' => $group_number . '_' . $item_number));
                        }
                        
                        $this->addGroup($group, 'item_' . $group_number . '_' . $item_number, null, '', false);
                        $renderer->setGroupElementTemplate('{element} &nbsp; ', 'item_' . $group_number . '_' . $item_number);
                        
                        $counter ++;
                    }
                }
                
                $gcounter ++;
                
                //                $group = array();
                //$group[] = &$this->createElement('image', 'create_item[' . $group_number . ']', Theme :: get_common_image_path() . 'action_add.png', array('title' => Translation :: get('AddItem'), 'class' => 'create_item', 'id' => $group_number));
                

                $renderer->setElementTemplate('{element}', 'add_item[' . $group_number . ']');
                $this->addElement('html', '<div style="border-top: 1px dotted #cecece; padding: 10px;">');
                $this->addElement('image', 'add_item[' . $group_number . ']', Theme :: get_common_image_path() . 'action_add.png', array(
                        'title' => Translation :: get('Add', null, Utilities :: COMMON_LIBRARIES), 'class' => 'add_item', 
                        'id' => $group_number));
                $this->addElement('html', '</div>');
                
                //                if ($_SESSION['number_of_groups'] - count($_SESSION['skip_groups']) > 1)
                //                {
                //                    $group[] = &$this->createElement('image', 'remove_group[' . $group_number . ']', Theme :: get_common_image_path() . 'action_delete.png', array('title' => Translation :: get('RemoveGroup'), 'class' => 'remove_group', 'id' => $group_number));
                //                }
                //                $this->addGroup($group, 'group_' . $group_number, null, '', false);
                //                $renderer->setElementTemplate('<div style="float: right; margin: 10px 0px 10px 0px;">{element}<div class="clear"></div></div>', 'group_' . $group_number);
                

                $category_html = array();
                $category_html[] = '<div style="clear: both;"></div>';
                $category_html[] = '</div>';
                $category_html[] = '<div style="clear: both;"></div>';
                $category_html[] = '</div>';
                $this->addElement('html', implode("\n", $category_html));
            }
        }
        
        $form_buttons = array();
        
        //check if the item has already the prerequisites
        

        $prerequisites = $this->clo_item->get_prerequisites();
        $form_buttons[] = $this->createElement('style_submit_button', 'go_basic', Translation :: get('BasicPrerequisites'), array(
                'class' => 'normal previous'));
        $form_buttons[] = $this->createElement('style_button', 'add_group[]', Translation :: get('AddPrerequisiteGroup'), array(
                'class' => 'normal add', 'id' => 'add_group'));
        $form_buttons[] = $this->createElement('style_submit_button', 'submit', Translation :: get('SavePrerequisites'), array(
                'class' => 'positive save'));
        $this->addGroup($form_buttons, 'option_buttons', null, '&nbsp;', false);
    }
    
    private $siblings;

    function retrieve_siblings()
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(ComplexContentObjectItem :: PROPERTY_PARENT, $this->clo_item->get_parent(), ComplexContentObjectItem :: get_table_name());
        $conditions[] = new NotCondition(new EqualityCondition(ComplexContentObjectItem :: PROPERTY_ID, $this->clo_item->get_id(), ComplexContentObjectItem :: get_table_name()));
        $condition = new AndCondition($conditions);
        
        $rdm = RepositoryDataManager :: get_instance();
        $siblings[- 1] = ''; //add an empty box
        $siblings_list = $rdm->retrieve_complex_content_object_items($condition);
        while ($sibbling = $siblings_list->next_result())
        {
            $content_object = $rdm->retrieve_content_object($sibbling->get_ref());
            
            if ($content_object->get_type() == LearningPath :: get_type_name())
            {
                continue;
            }
            
            if ($content_object->get_type() == LearningPathItem :: get_type_name())
            {
                $content_object = $rdm->retrieve_content_object($content_object->get_reference());
            }
            
            $siblings[$sibbling->get_id()] = $content_object->get_title();
        }
        
        return $siblings;
    }

    function validate()
    {
        if (isset($_POST['submit']) || isset($_POST['submit_basic']))
        {
            return parent :: validate();
        }
        
        return false;
    }
    
    private $number_of_groups;
    private $number_of_items;

    function setDefaults($defaults = array())
    {
        $prerequisites = $this->clo_item->get_prerequisites();
        $defaults_basic = '';
        
        //When the form is accessed for the first time and there are no prerequisites set
        if (sizeof($_POST) == 0)
        {
            if (! $prerequisites)
            {
                $this->set_form_type(self :: FORM_TYPE_BASIC);
            }
        }
        
        if (($prerequisites && ! $this->isSubmitted()) || ($prerequisites && isset($_POST['go_advanced'])) || ($prerequisites && isset($_POST['go_basic'])))
        {
            
            $pattern = '/\([^\)]*\)/';
            $matches = array();
            preg_match_all($pattern, $prerequisites, $matches);
            $groups = $matches[0];
            
            foreach ($groups as $i => $group)
            {
                $prerequisites = str_replace($group, '_', $prerequisites);
                $group = str_replace('(', '', $group);
                $group = str_replace(')', '', $group);
                
                $or_values = explode('|', $group);
                
                $item_counter = 0;
                foreach ($or_values as $or_value)
                {
                    if (strpos($or_value, '&') === false)
                    {
                        if (Text :: char_at($or_value, 0) == '~')
                        {
                            $or_value = substr($or_value, 1);
                            $defaults['not'][$i][$item_counter] = '~';
                        }
                        
                        $defaults['prerequisite'][$i][$item_counter] = $or_value;
                        if ($item_counter > 0)
                            $defaults['operator'][$i][$item_counter] = '|';
                        
                        $item_counter ++;
                        continue;
                    }
                    
                    $and_values = explode('&', $or_value);
                    foreach ($and_values as $and_value)
                    {
                        if (Text :: char_at($and_value, 0) == '~')
                        {
                            $and_value = substr($and_value, 1);
                            $defaults['not'][$i][$item_counter] = '~';
                        }
                        $defaults['prerequisite'][$i][$item_counter] = $and_value;
                        $defaults_basic = $and_value;
                        if ($item_counter > 0)
                            $defaults['operator'][$i][$item_counter] = '&';
                        $item_counter ++;
                    }
                }
                
                $this->number_of_items[$i] = $item_counter;
            }
            
            $this->number_of_groups = count($groups);
            
            $operators = explode('_', $prerequisites);
            
            $defaults['group_operator'] = $operators;
            
            if ($this->number_of_groups == 0 && is_numeric($prerequisites))
            {
                $this->number_of_groups = 1;
                $this->number_of_items[0] = 1;
                $defaults['prerequisite'][0][0] = $prerequisites;
            }
            
            if ($this->number_of_groups > 1 || $item_counter > 2)
            {
                $this->set_form_type(self :: FORM_TYPE_ADVANCED);
            }
            else
                $this->set_form_type(self :: FORM_TYPE_BASIC);
        }
        
        $defaults['basic_prerequisite'] = $defaults_basic;
        parent :: setDefaults($defaults);
    }

    function build_basic_prerequisites()
    {
        
        $values = $this->exportValues();
        $prereq_formula = '';
        $prerequisites_string = '';
        if ($values['basic_prerequisite'] == - 1)
        {
            $prereq_formula = '';
        }
        else
        {
            $prerequisites_string .= '&' . $values['basic_prerequisite'];
            if ($prerequisites_string != '')
            {
                $prereq_formula .= '(';
                $prereq_formula .= $prerequisites_string;
                $prereq_formula .= ')';
            }
        }
        $this->clo_item->set_prerequisites($prereq_formula);
    }

    function build_prerequisites()
    {
        if ($this->form_type == self :: FORM_TYPE_BASIC)
        {
            $this->build_basic_prerequisites();
        }
        else
        {
            $values = $this->exportValues();
            $prereq_formula = '';
            
            foreach ($values['prerequisite'] as $group_number => $items)
            {
                $prerequisites_string = '';
                foreach ($items as $item_number => $item)
                {
                    if ($item == - 1)
                    {
                        continue;
                    }
                    $prerequisites_string .= $values['operator'][$group_number][$item_number] . $values['not'][$group_number][$item_number] . $item;
                }
                if (strlen($prerequisites_string) > 1)
                {
                    $prereq_formula .= $values['group_operator'][$group_number] . '(';
                    $prereq_formula .= $prerequisites_string;
                    $prereq_formula .= ')';
                }
            }
            $this->clo_item->set_prerequisites($prereq_formula);
        }
        unset($_SESSION[self :: IDENTIFER . $this->clpi_id]);
        return $this->clo_item->update();
    }

}

?>