<?php
namespace repository\content_object\mediamosa;

use common\extensions\external_repository_manager\implementation\mediamosa\ExternalObject;

use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Path;
use common\libraries\Utilities;
use common\libraries\Filesystem;

use repository\ContentObjectRendition;
use repository\RepositoryManager;

class HtmlDescriptionRenditionImplementation extends HtmlRenditionImplementation
{

    const PARAM_MEDIAFILE = 'mediafile_id';

    function render()
    {
        return ContentObjectRendition :: launch($this);
    }

    function get_description()
    {
        $this->set_mediamosa_object();

        if (! $this->is_connection_lost())
        {
            $video_element = $this->get_video_player();
            $additional_properties = $this->get_additional_properties();

            return '<div class="link_url" style="margin-top: 1em;">' . $video_element . '<br/>' . $additional_properties . '</div>';
        }
        else
        {
            return '<div>' . Translation :: get('ConnectionLost') . '</div>';
        }
    }

    function get_video_player()
    {
        $this->set_mediamosa_object();

        if ($this->get_mediamosa_object()->get_status() == ExternalObject :: STATUS_AVAILABLE)
        {
            // see which mediafile to play
            if (Request :: get(self :: PARAM_MEDIAFILE))
            {
                $mediafile_id = Request :: get(self :: PARAM_MEDIAFILE);
            }
            else
            {
                $mediafile_id = $this->get_mediamosa_object()->get_default_mediafile();
            }

            if ($mediafile_id)
            {
                // get player
                $output = $this->get_mediamosa_external_repository_manager_connector()->mediamosa_play_proxy_request(
                        $this->get_mediamosa_object()->get_id(), $mediafile_id);
            }
            else
            {
                $output = '';
            }
        }
        else
        {
            $output = Translation :: get('VideoNotAvailable');
        }
        return $output;
    }

    function get_additional_properties()
    {
        // get different mediafiles (+status)
        $mediafiles = $this->get_mediamosa_object()->get_mediafiles();

        $html = array();
        $i = 1;
        $html[] = '<tr><td class="header">' . Translation :: get('Versions') . '</td></tr>';

        if (is_array($mediafiles))
        {
            foreach ($mediafiles as $mediafile)
            {
                $object = $this->get_content_object();
                $url = $this->get_content_object_url($object);
                $html[] = '<tr><td><a href="' . $url . '&' . self :: PARAM_MEDIAFILE . '=' . $mediafile->get_id() . '">' . $mediafile->get_title() . '</a></td></tr>';

                $i ++;
            }
            $html2 = array();

            $html2[] = Translation :: get('PublishedBy') . ' : ' . $this->get_mediamosa_object()->get_publisher() . '<br />';

            if ($this->get_mediamosa_object()->get_creator())
            {
                $html2[] = Translation :: get('CreatedBy') . ' : ' . $this->get_mediamosa_object()->get_creator();
            }

            return '<table class="data_table data_table_no_header">' . implode("\n", $html) . '</table>' . implode("\n",
                    $html2);
        }
    }
}
?>