<?php
namespace repository\content_object\ordering_question;

use common\libraries\Utilities;
use common\libraries\Versionable;
use repository\ContentObject;
use common\libraries\StringUtilities;

/**
 * $Id: ordering_question.class.php 200 2009-11-13 12:30:04Z kariboe $
 *
 * @package repository.lib.content_object.ordering_question
 */
class OrderingQuestion extends ContentObject implements Versionable
{
    const PROPERTY_OPTIONS = 'options';
    const PROPERTY_HINT = 'hint';
    const CLASS_NAME = __CLASS__;

    static function get_type_name()
    {
        return Utilities :: get_classname_from_namespace(self :: CLASS_NAME, true);
    }

    public function add_option($option)
    {
        $options = $this->get_options();
        $options[] = $option;
        return $this->set_additional_property(self :: PROPERTY_OPTIONS, serialize($options));
    }

    public function set_options($options)
    {
        return $this->set_additional_property(self :: PROPERTY_OPTIONS, serialize($options));
    }

    public function get_options()
    {
        if ($result = unserialize($this->get_additional_property(self :: PROPERTY_OPTIONS)))
        {
            return $result;
        }
        return array();
    }

    public function set_hint($hint)
    {
        return $this->set_additional_property(self :: PROPERTY_HINT, $hint);
    }

    public function get_hint()
    {
        return $this->get_additional_property(self :: PROPERTY_HINT);
    }

    function has_hint()
    {
        return StringUtilities :: has_value($this->get_hint(), true);
    }

    public function get_number_of_options()
    {
        return count($this->get_options());
    }

    static function get_additional_property_names()
    {
        return array(self :: PROPERTY_OPTIONS, self :: PROPERTY_HINT);
    }

    /**
     * Returns the maximum weight/score a user can receive.
     */
    public function get_maximum_score()
    {
        // for each option 1 point ? -> the assessment score calculator sugests this...
        $options = $this->get_options();
        if ($options)
        {
            return count($options);
        }
        return 1;
    }

    // TODO: should be moved to an additional parent layer "question" which offers a default implementation.
    function get_default_weight()
    {
        return $this->get_maximum_score();
    }

    /**
     * Returns the names of the properties which are UI-wise filled by the integrated html editor
     *
     * @return multitype:string
     */
    static function get_html_editors($html_editors = array())
    {
        return parent :: get_html_editors(array(self :: PROPERTY_HINT));
    }
}
?>