<?php
namespace repository\content_object\rss_feed;

use repository\ContentObjectBlock;

use common\libraries\Translation;
use common\libraries\Theme;
use common\libraries\StringUtilities;

/**
 * $Id: feeder.class.php 200 2009-11-13 12:30:04Z kariboe $
 *
 * @package repository.block
 */
/**
 * Display a RSS Feed.
 */
class RssFeedFeeder extends ContentObjectBlock
{

    /**
     * Returns the list of type names that this block can map to.
     *
     * @return array
     */
    static function get_supported_types()
    {
        $result = array();
        $result[] = RssFeed :: get_type_name();
        return $result;
    }

    function __construct($parent, $block_info, $configuration)
    {
        parent :: __construct($parent, $block_info, $configuration);
        $this->default_title = Translation :: get('Newsfeed');
    }

    function is_visible()
    {
        return true; // i.e.display on homepage when anonymous
    }

    /**
     * Returns the html to display when the block is configured.
     *
     * @return string
     */
    function display_content()
    {
        $content_object = $this->get_object();
        
        $html = array();
        $feed = RenditionImplementation :: parse_file($content_object->get_url());
        if ($feed)
        {
            $target = $this->get_link_target();
            $target = $target ? 'target="' . $target . '"' : 'target="_blank"';
            $icon = Theme :: get_image_path() . 'logo/' . Theme :: ICON_MINI . '.png';
            $html[] = '<div class="tool_menu">';
            $html[] = '<ul>';
            
            $count_valid = 0;
            
            foreach ($feed['items'] as $item)
            {
                if (! $item['link'] || ! $item['title'])
                {
                    continue;
                }
                
                $count_valid ++;
                
                $html[] = '<li class="tool_list_menu" style="background-image: url(' . $icon . ')"><a href="' . htmlentities($item['link']) . '" ' . $target . '>' . $item['title'] . '</a></li>';
            }
            
            $html[] = '</ul>';
            $html[] = '<div class="clear"></div>';
            $html[] = '</div>';
        }
        
        if (! $feed || $count_valid == 0)
        {
            $html[] = '<span style="font-weight: bold;">' . Translation :: get('NoFeedsFound') . '</span>';
        }
        
        return '<div style="height: 4px;"></div>' . implode(StringUtilities :: NEW_LINE, $html);
    }

}
?>