<?php
namespace repository\content_object\task;

use user\UserDataManager;
use common\libraries\Path;
use vtodo;

require_once Path :: get_plugin_path() . 'icalcreator/iCalcreator.class.php';

class IcalDefaultExportImplementation extends IcalExportImplementation
{

    function render()
    {
        $content_object = $this->get_content_object();
        $vevent = new vtodo();
        $vevent->setProperty('summary', $content_object->get_title());

        $vevent->setProperty('dtstart', $this->get_date_in_ical_format($content_object->get_start_date()));
        $vevent->setProperty('due', $this->get_date_in_ical_format($content_object->get_end_date()));

        $vevent->setProperty('description',
                str_replace(array("\n", "\r", "\r\n"), '', $content_object->get_description()));
        $vevent->setProperty('created', $this->get_date_in_ical_format($content_object->get_creation_date()));
        $vevent->setProperty('last-mod', $this->get_date_in_ical_format($content_object->get_modification_date()));
        $owner = UserDataManager :: get_instance()->retrieve_user($content_object->get_owner_id());

        $vevent->setProperty('organizer', $owner->get_email());

        if ($content_object->has_frequency())
        {
            $vevent->setProperty('rrule', $this->get_rrule());
        }

        $vevent->setProperty('priority', $content_object->get_task_priority());
        $vevent->setProperty('categories', $content_object->get_task_type_as_string(), array('LANGUAGE' => 'en'));

        $ical = $this->get_context()->get_ical();
        $ical->setComponent($vevent);
    }

    function get_rrule()
    {
        $rrule = array();

        $content_object = $this->get_content_object();
     $frequency = $content_object->get_frequency();
        switch ($frequency)
        {
            case Task :: FREQ_DAILY :
                $rrule['FREQ'] = 'DAILY';
                break;
            case Task :: FREQ_WEEKLY :
                $rrule['FREQ'] = 'WEEKLY';
                
                break;
            case Task :: FREQ_MONTHLY :
                $rrule['FREQ'] = 'MONTHLY';
                break;
            case Task :: FREQ_YEARLY :
                $rrule['FREQ'] = 'YEARLY';
                break;
            case Task :: FREQ_BIWEEK :
                $rrule['FREQ'] = 'WEEKLY';
                $rrule['INTERVAL'] = '2';
                break;
            case Task :: FREQ_WEEK_DAYS :
                $rrule['FREQ'] = 'DAILY';
                $rrule['BYDAY'] = array(array('DAY' => 'MO'), array('DAY' => 'TU'), array('DAY' => 'WE'), 
                        array('DAY' => 'TH'), array('DAY' => 'FR'));
                break;
        }
        
        if (! $content_object->frequency_is_indefinately())
        {
            $rrule['UNTIL'] = $this->get_date_in_ical_format($content_object->get_until());
        }
        
        if ($content_object->get_frequency_count() > 0)
        {
            $rrule['COUNT'] = $content_object->get_frequency_count();
        }
        
        if ($content_object->get_frequency_interval() > 0)
        {
            $rrule['INTERVAL'] = $content_object->get_frequency_interval();
        }
     
        if ($content_object->get_byday())
        {
            $rrule['BYDAY'] = Task::get_byday_parts($content_object->get_byday());
        }
       
        if ($content_object->get_bymonthday())
        {
            $rrule['BYMONTHDAY'] = $content_object->get_bymonthday();
        }
        
        if ($content_object->get_bymonth())
        {
            $rrule['BYMONTH'] = $content_object->get_bymonth();
        }
        

        return $rrule;
    }

    function get_date_in_ical_format($date)
    {
        $y = date('Y', $date);
        $m = date('m', $date);
        $d = date('d', $date);
        $h = date('H', $date);
        $M = date('i', $date);
        $s = date('s', $date);

        return $y . $m . $d . 'T' . $h . $M . $s;
    }
}
?>