<?php
namespace repository\content_object\twitter_search;

use common\libraries\PlatformSetting;

use admin\AdminDataManager;

use common\libraries\SimpleTemplate;
use common\libraries\ResourceManager;
use common\libraries\Path;
use common\libraries\Translation;
use common\libraries\Theme;

use repository\ContentObjectRendition;
use repository\ContentObject;

use LastRss;

class HtmlDescriptionRenditionImplementation extends HtmlRenditionImplementation
{

    static $intialized = false;

    function render()
    {
        $object = $this->get_content_object();

        $html = array();
        $html[] = '<div class="content_object" style="background-image: url({$ICON});">';
        $html[] = '<div class="title">{$TITLE}</div>';
        $html[] = '<div class="description">{$DESCRIPTION}</div>';
        $html[] = '{$WIDGET}';
        $html[] = '</div>';

        $template_variables = array();
        $template_variables['ICON'] = $object->get_icon_path();
        $template_variables['TITLE'] = $object->get_title();
        $template_variables['DESCRIPTION'] = ContentObjectRendition :: factory($this)->get_description();
        $template_variables['WIDGET'] = $this->get_widget();

        return SimpleTemplate :: ex($html, $template_variables);
    }

    function get_widget($scrollbar = false, $loop = true, $live = true, $hashtags = true, $timestamp = true, $avatars = true, $toptweets = true)
    {
        $object = $this->get_content_object();
        $query = $object->get_query();
        $pattern = '/\@[a-zA-Z_][a-zA-Z0-9_]*/';

        if (preg_match($pattern, $query))
        {
            // i.e. query is @username
            return $this->get_profile($scrollbar, $loop, $live, $hashtags, $timestamp, $avatars, $toptweets);
        }
        else
        {
            return $this->get_search($scrollbar, $loop, $live, $hashtags, $timestamp, $avatars, $toptweets);
        }
    }

    function get_profile($scrollbar = false, $loop = true, $live = true, $hashtags = true, $timestamp = true, $avatars = true, $toptweets = true)
    {
        $object = $this->get_content_object();

        $bloc_id = 'twtr-widget-' . $object->get_id();
        $user = $object->get_query();
        $user = trim($user, '@');
        $scrollbar = $scrollbar ? 'true' : 'false';
        $loop = $loop ? 'true' : 'false';
        $live = $live ? 'true' : 'false';
        $hashtags = $hashtags ? 'true' : 'false';
        $timestamp = $timestamp ? 'true' : 'false';
        $avatars = $avatars ? 'true' : 'false';
        $toptweets = $toptweets ? 'true' : 'false';
        $footer = Translation :: get('Go');
        $resources = self :: get_resource_html();

        $content = <<<EOT

$resources
<script src="http://widgets.twimg.com/j/2/widget.js"></script>
<div id="tbox"></div>
<div class="action_bar" ><div class="twtr-container"><div class="twtr-widget" id="$bloc_id"></div></div></div>
<script>
new TWTR.Widget({
  version: 2,
  type: 'profile',
  rpp: 5,
  interval: 6000,
  width: 'auto',
  height: 300,
  footer: '$footer',
  id: '$bloc_id',
  theme: {
    shell: {
      background: 'transparent',
      color: 'inherit'
    },
    tweets: {
      background: 'none',
      color: 'none',
      links: 'none'
    }
  },
  features: {
    scrollbar: $scrollbar,
    loop: $loop,
    live: $live,
    hashtags: $hashtags,
    timestamp: $timestamp,
    avatars: $avatars,
    toptweets: $toptweets,
    behavior: 'all'
  }
}).render().setUser('$user').start();
</script>
EOT;
        return $content;
    }

    function get_search($scrollbar = false, $loop = true, $live = true, $hashtags = true, $timestamp = true, $avatars = true, $toptweets = true)
    {
        $object = $this->get_content_object();

        $bloc_id = 'twtr-widget-' . $object->get_id();
        $query = $object->get_query();
        $subject = $object->get_title();
        $title = '';
        $scrollbar = $scrollbar ? 'true' : 'false';
        $loop = $loop ? 'true' : 'false';
        $live = $live ? 'true' : 'false';
        $hashtags = $hashtags ? 'true' : 'false';
        $timestamp = $timestamp ? 'true' : 'false';
        $avatars = $avatars ? 'true' : 'false';
        $toptweets = $toptweets ? 'true' : 'false';
        $footer = Translation :: get('Go');
        $resources = self :: get_resource_html();

        $content = <<<EOT

$resources
<script src="http://widgets.twimg.com/j/2/widget.js"></script>
<div class="action_bar" ><div class="twtr-container"><div class="twtr-widget" id="$bloc_id"></div></div></div>
<script>
new TWTR.Widget({
  version: 2,
  type: 'search',
  search: '$query',
  interval: 6000,
  title: '$title',
  subject: '$subject',
  width: 'auto',
  height: 300,
  footer: '$footer',
  id: '$bloc_id',
  theme: {
    shell: {
      background: 'transparent',
      color: 'inherit'
    },
    tweets: {
      background: 'none',
      color: 'none',
      links: 'none'
    }
  },
  features: {
    scrollbar: $scrollbar,
    loop: $loop,
    live: $live,
    hashtags: $hashtags,
    timestamp: $timestamp,
    avatars: $avatars,
    toptweets: $toptweets,
    behavior: 'default'
  }
}).render().start();
</script>

EOT;
        return $content;
    }

    /**
     * This function returns the javascript needed for Twitter @anywere to work. Returns resources only once as those
     * should not be included more than once which is possible with different blocks.
     */
    static function get_resource_html()
    {
        if (self :: $intialized)
        {
            return '';
        }

        $key = PlatformSetting :: get('twitter_api_key', __NAMESPACE__);
        if (empty($key))
        {
            // @todo: remove that when the UI works. This is a hack!!
            $key = file_get_contents(dirname(__FILE__) . '/../../../resources/key.txt');
        }

        $result = array();
        $result[] = '<script src="http://platform.twitter.com/anywhere.js?id=' . $key . '&amp;v=1" type="text/javascript"></script>';
        $result[] = ResourceManager :: get_instance()->get_resource_html(Path :: get_repository_content_object_path(true) . 'twitter_search/resources/javascript/twitter.js');
        $result = implode("\n", $result);
        self :: $intialized = true;
        return $result;
    }
}
?>