<?php
namespace repository\content_object\wiki;

use common\libraries\DelegateComponent;

use repository\ContentObject;

use common\libraries\Path;
use common\libraries\BreadcrumbTrail;
use common\libraries\OrCondition;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use common\libraries\PatternMatchCondition;
use repository\ComplexContentObjectItem;

/**
 * $Id: wiki_viewer.class.php 200 2009-11-13 12:30:04Z kariboe $
 *
 * @package repository.lib.complex_display.wiki.component
 */
/*
 * This is the compenent that allows the user to view all pages of a wiki. If no homepage is set all available pages
 * will be shown, otherwise the homepage will be shown. Author: Stefan Billiet Author: Nick De Feyter
 */

require_once Path :: get_plugin_path() . 'wiki/mediawiki_parser.class.php';

class WikiComplexDisplayWikiBrowserComponent extends WikiComplexDisplay implements DelegateComponent
{
    private $owner;

    function run()
    {
        $this->owner = $this->get_root_content_object()->get_id();
        
        if ($this->get_root_content_object() != null)
        {
            $this->display_header();
            
            $table = new WikiPageTable($this, $this->get_condition());
            echo $table->as_html();
            
            $this->display_footer();
        }
    }

    function get_condition()
    {
        // search condition
        $condition = $this->get_search_condition();
        
        // append with extra conditions
        $owner_condition = new EqualityCondition(ComplexContentObjectItem :: PROPERTY_PARENT, $this->owner, ComplexContentObjectItem :: get_table_name());
        if ($condition)
        {
            $conditions = array();
            $conditions[] = $condition;
            $conditions[] = $owner_condition;
            $condition = new AndCondition($conditions);
        }
        else
        {
            $condition = $owner_condition;
        }
        
        return $condition;
    }

    function get_search_condition()
    {
        $query = $this->get_search_form()->get_query();
        if (isset($query) && $query != '')
        {
            $conditions[] = new PatternMatchCondition(ContentObject :: PROPERTY_TITLE, '*' . $query . '*', ContentObject :: get_table_name());
            $conditions[] = new PatternMatchCondition(ContentObject :: PROPERTY_DESCRIPTION, '*' . $query . '*', ContentObject :: get_table_name());
            return new OrCondition($conditions);
        }
        return null;
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail = $this->get_breadcrumbtrail();
    }
}
?>