<?php
namespace repository\content_object\wiki;

use common\libraries\DelegateComponent;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\Path;
use common\libraries\BreadcrumbTrail;
use common\libraries\Breadcrumb;

use repository\ComplexDisplay;
use repository\RepositoryDataManager;

use MediawikiParser;
use MediawikiParserContext;

/**
 * $Id: wiki_item_viewer.class.php 200 2009-11-13 12:30:04Z kariboe $
 *
 * @package repository.lib.complex_display.wiki.component
 */
/*
 * This viewer will show the selected wiki_page. You'll be redirected here from
 * the wiki_viewer page by clicking on the name of a wiki_page Author: Stefan
 * Billiet Author: Nick De Feyter
 */

require_once Path :: get_plugin_path() . 'wiki/mediawiki_parser.class.php';
require_once Path :: get_plugin_path() . 'wiki/mediawiki_parser_context.class.php';

class WikiComplexDisplayWikiItemViewerComponent extends WikiComplexDisplay implements DelegateComponent
{

    function run()
    {
        BreadcrumbTrail :: get_instance()->add(new Breadcrumb(null, $this->get_root_content_object()->get_title()));
        $complex_wiki_page_id = Request :: get(ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID);
        
        if ($complex_wiki_page_id)
        {
            $version_object_id = Request :: get(self :: PARAM_WIKI_VERSION_ID);
            $complex_wiki_page = RepositoryDataManager :: get_instance()->retrieve_complex_content_object_item($complex_wiki_page_id);
            $wiki_page = $complex_wiki_page->get_ref_object();
            BreadcrumbTrail :: get_instance()->add(new Breadcrumb(null, $wiki_page->get_title()));
            if ($version_object_id)
            {
                $version_object = RepositoryDataManager :: get_instance()->retrieve_content_object($version_object_id);
                if ($version_object && $version_object->get_object_number() == $wiki_page->get_object_number())
                {
                    $display_wiki_page = $version_object;
                }
                else
                {
                    $display_wiki_page = $wiki_page;
                }
                
                if ($wiki_page->get_id() == $version_object_id)
                {
                    Request :: set_get(self :: PARAM_WIKI_VERSION_ID, null);
                }
            }
            else
            {
                $display_wiki_page = $wiki_page;
            }
            
            $this->display_header($complex_wiki_page);
            
            $html[] = '<div class="wiki-pane-content-title">' . $display_wiki_page->get_title() . '</div>';
            $html[] = '<div class="wiki-pane-content-subtitle">' . Translation :: get('From', null, Utilities :: COMMON_LIBRARIES) . ' ' . $this->get_root_content_object()->get_title() . '</div>';
            
            if ($version_object_id && $wiki_page->get_id() != $version_object_id)
            {
                $html[] = '<div class="wiki-pane-content-version">' . Translation :: get('WikiOldVersion') . '</div>';
            }
            
            $parser = new MediawikiParser(new MediawikiParserContext($this->get_root_content_object(), $display_wiki_page->get_title(), $display_wiki_page->get_description(), $this->get_parameters()));
            
            $html[] = '<div class="wiki-pane-content-body">';
            $html[] = $parser->parse();
            $html[] = '<div class="clear"></div>';
            $html[] = '</div>';
            
            echo implode("\n", $html);
            
            $this->display_footer();
        }
        else
        {
            $this->redirect(null, false, array(
                    Complexdisplay :: PARAM_DISPLAY_ACTION => WikiComplexDisplay :: ACTION_VIEW_WIKI));
        }
    }
}

?>