<?php
namespace repository\content_object\wiki;

use repository\ContentObjectResourceRenderer;
use application\wiki\WikiDataManager;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\Path;
use common\libraries\BreadcrumbTrail;
use common\libraries\Breadcrumb;
use common\libraries\ActionBarSearchForm;
use common\libraries\ToolbarItem;
use common\libraries\Toolbar;
use common\libraries\Theme;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use repository\ComplexDisplay;
use repository\content_object\wiki_page\ComplexWikiPage;
use repository\RepositoryDataManager;
use common\extensions\repo_viewer\RepoViewer;
use MediawikiParser;
use MediawikiParserContext;

require_once Path :: get_plugin_path() . 'wiki/mediawiki_parser.class.php';
require_once Path :: get_plugin_path() . 'wiki/mediawiki_parser_context.class.php';

/**
 * This tool allows a user to publish wikis.
 */
class WikiComplexDisplay extends ComplexDisplay
{
    const PARAM_WIKI_ID = 'wiki_id';
    const PARAM_WIKI_PAGE_ID = 'wiki_page_id';
    const PARAM_WIKI_VERSION_ID = 'wiki_version_id';
    const ACTION_BROWSE_WIKI = 'wiki_browser';
    const ACTION_VIEW_WIKI = 'viewer';
    const ACTION_VIEW_WIKI_PAGE = 'wiki_item_viewer';
    const ACTION_CREATE_PAGE = 'wiki_page_creator';
    const ACTION_SET_AS_HOMEPAGE = 'wiki_homepage_setter';
    const ACTION_DISCUSS = 'wiki_discuss';
    const ACTION_HISTORY = 'wiki_history';
    const ACTION_PAGE_STATISTICS = 'reporting_template_viewer';
    const ACTION_COMPARE = 'comparer';
    const ACTION_ACCESS_DETAILS = 'reporting_template_viewer';
    const ACTION_VERSION_REVERT = 'version_reverter';
    const ACTION_VERSION_DELETE = 'version_deleter';
    const DEFAULT_ACTION = self :: ACTION_VIEW_WIKI;

    private $search_form;

    function __construct($parent)
    {
        parent :: __construct($parent);

        $this->search_form = new ActionBarSearchForm($this->get_url());
    }

    static function is_wiki_locked($wiki_id)
    {
        $wiki = RepositoryDataManager :: get_instance()->retrieve_content_object($wiki_id);
        return $wiki->get_locked() == 1;
    }

    static function get_wiki_homepage($wiki_id)
    {
        $conditions[] = new EqualityCondition(ComplexWikiPage :: PROPERTY_PARENT, $wiki_id);
        $conditions[] = new EqualityCondition(ComplexWikiPage :: PROPERTY_IS_HOMEPAGE, 1, 'complex_wiki_page');
        $complex_wiki_homepage = RepositoryDataManager :: get_instance()->retrieve_complex_content_object_items(
                new AndCondition($conditions), array(), 0, 1, 'complex_wiki_page');
        return $complex_wiki_homepage->next_result();
    }

    static function get_current_page_complex_id()
    {
        $selected_page = Request :: get(self :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID);

        if (! $selected_page)
        {
            $selected_page = $this->get_wiki_homepage($this->get_root_content_object_id())->get_id();
        }

        return $selected_page;
    }

    function get_breadcrumbtrail()
    {
        $trail = BreadcrumbTrail :: get_instance();
        $trail->add(
                new Breadcrumb(
                        $this->get_url(
                                array(
                                        ComplexDisplay :: PARAM_DISPLAY_ACTION => ComplexDisplay :: ACTION_VIEW_COMPLEX_CONTENT_OBJECT)),
                        $this->get_root_content_object()->get_title()));
        switch (Request :: get(ComplexDisplay :: PARAM_DISPLAY_ACTION))
        {
            case ComplexDisplay :: ACTION_VIEW_COMPLEX_CONTENT_OBJECT :
                break;
            case self :: ACTION_CREATE_PAGE :
                $trail->add(
                        new Breadcrumb(
                                $this->get_url(
                                        array(ComplexDisplay :: PARAM_DISPLAY_ACTION => self :: ACTION_CREATE_PAGE)),
                                Translation :: get('CreateWikiPage')));
                break;
            case self :: ACTION_UPDATE_CONTENT_OBJECT :
                $trail->add(
                        new Breadcrumb(
                                $this->get_url(
                                        array(
                                                ComplexDisplay :: PARAM_DISPLAY_ACTION => self :: ACTION_UPDATE_CONTENT_OBJECT)),
                                Translation :: get('Edit', null, Utilities :: COMMON_LIBRARIES)));
                break;
            case self :: ACTION_PAGE_STATISTICS :
                $complex_wiki_page_id = Request :: get(ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID);
                $complex_wiki_page = RepositoryDataManager :: get_instance()->retrieve_complex_content_object_item(
                        $complex_wiki_page_id);
                $wiki_page = $complex_wiki_page->get_ref_object();
                $trail->add(new Breadcrumb(null, $wiki_page->get_title()));
                $trail->add(
                        new Breadcrumb(
                                $this->get_url(
                                        array(ComplexDisplay :: PARAM_DISPLAY_ACTION => self :: ACTION_PAGE_STATISTICS,
                                                ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID => Request :: get(
                                                        ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID))),
                                Translation :: get('Reporting')));
                break;
            case self :: ACTION_ACCESS_DETAILS :
                $trail->add(
                        new Breadcrumb(
                                $this->get_url(
                                        array(ComplexDisplay :: PARAM_DISPLAY_ACTION => self :: ACTION_ACCESS_DETAILS,
                                                ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID => Request :: get(
                                                        ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID))),
                                Translation :: get('Reporting')));
                break;
            case self :: ACTION_VIEW_WIKI_PAGE :
                $trail->add(
                        new Breadcrumb(
                                $this->get_url(
                                        array(ComplexDisplay :: PARAM_DISPLAY_ACTION => self :: ACTION_VIEW_WIKI_PAGE,
                                                ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID => Request :: get(
                                                        ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID))),
                                $this->get_content_object_from_complex_id(
                                        Request :: get(ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID))->get_title()));
                break;
            case self :: ACTION_UPDATE_COMPLEX_CONTENT_OBJECT_ITEM :
                $trail->add(
                        new Breadcrumb(
                                $this->get_url(
                                        array(ComplexDisplay :: PARAM_DISPLAY_ACTION => self :: ACTION_VIEW_WIKI_PAGE,
                                                ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID => Request :: get(
                                                        ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID))),
                                $this->get_content_object_from_complex_id(
                                        Request :: get(ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID))->get_title()));
                break;
            case self :: ACTION_DISCUSS :
                $trail->add(
                        new Breadcrumb(
                                $this->get_url(
                                        array(ComplexDisplay :: PARAM_DISPLAY_ACTION => self :: ACTION_VIEW_WIKI_PAGE,
                                                ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID => Request :: get(
                                                        ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID))),
                                $this->get_content_object_from_complex_id(
                                        Request :: get(ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID))->get_title()));
                $trail->add(
                        new Breadcrumb(
                                $this->get_url(
                                        array(
                                                ComplexDisplay :: PARAM_DISPLAY_ACTION => Request :: get(
                                                        ComplexDisplay :: PARAM_DISPLAY_ACTION),
                                                ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID => Request :: get(
                                                        ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID))),
                                Translation :: get('WikiDiscuss')));
                break;
            case self :: ACTION_HISTORY :
                $trail->add(
                        new Breadcrumb(
                                $this->get_url(
                                        array(ComplexDisplay :: PARAM_DISPLAY_ACTION => self :: ACTION_VIEW_WIKI_PAGE,
                                                ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID => Request :: get(
                                                        ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID))),
                                $this->get_content_object_from_complex_id(
                                        Request :: get(ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID))->get_title()));

                break;
        }
        return $trail;
    }

    private function get_content_object_from_complex_id($complex_id)
    {
        $complex_content_object_item = RepositoryDataManager :: get_instance()->retrieve_complex_content_object_item(
                $complex_id);
        return RepositoryDataManager :: get_instance()->retrieve_content_object($complex_content_object_item->get_ref());
    }

    function get_application_component_path()
    {
        return dirname(__FILE__) . '/component/';
    }

    function get_publication()
    {
        return $this->get_parent()->get_publication();
    }

    function display_header(ComplexWikiPage $complex_wiki_page = null)
    {
        parent :: display_header(null, false);

        $html = array();

        // The general menu
        $html[] = '<div class="wiki-menu">';

        $html[] = '<div class="wiki-menu-section">';
        $toolbar = new Toolbar(Toolbar :: TYPE_VERTICAL);
        $toolbar->add_item(
                new ToolbarItem(Translation :: get('MainPage'), Theme :: get_common_image_path() . 'action_home.png',
                        $this->get_url(
                                array(self :: PARAM_DISPLAY_ACTION => self :: ACTION_VIEW_WIKI,
                                        ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID => null)),
                        ToolbarItem :: DISPLAY_ICON_AND_LABEL));
        $toolbar->add_item(
                new ToolbarItem(Translation :: get('Contents'), Theme :: get_common_image_path() . 'action_browser.png',
                        $this->get_url(
                                array(self :: PARAM_DISPLAY_ACTION => self :: ACTION_BROWSE_WIKI)),
                        ToolbarItem :: DISPLAY_ICON_AND_LABEL));
        $html[] = $toolbar->as_html();
        $html[] = '<div class="clear"></div>';
        $html[] = '</div>';

        $links = $this->get_root_content_object()->get_links();

        if (! empty($links))
        {
            $object_renderer = new ContentObjectResourceRenderer($this, $links);
            $links = $object_renderer->run();
            $parser = new MediawikiParser(
                    new MediawikiParserContext($this->get_root_content_object(), '', $links, $this->get_parameters()));

            $html[] = '<div class="wiki-menu-section">';
            $html[] = $parser->parse();
            $html[] = '<div class="clear"></div>';
            $html[] = '</div>';
        }

        $html[] = '<div class="wiki-menu-section">';
        $toolbar = new Toolbar(Toolbar :: TYPE_VERTICAL);
        $toolbar->add_item(
                new ToolbarItem(Translation :: get('AddWikiPage'),
                        Theme :: get_common_image_path() . 'action_create.png',
                        $this->get_url(
                                array(self :: PARAM_DISPLAY_ACTION => self :: ACTION_CREATE_PAGE)),
                        ToolbarItem :: DISPLAY_ICON_AND_LABEL));
        $html[] = $toolbar->as_html();
        $html[] = '<div class="clear"></div>';
        $html[] = '</div>';

        $html[] = '</div>';

        // The main content pane
        $html[] = '<div class="wiki-pane">';
        $html[] = '<div class="wiki-pane-actions-bar">';

        $display_action = $this->get_action();

        if ($display_action != self :: ACTION_CREATE_PAGE)
        {
            $html[] = '<ul class="wiki-pane-actions wiki-pane-actions-left">';
            if ($complex_wiki_page)
            {
                $read_url = $this->get_url(
                        array(ComplexDisplay :: PARAM_DISPLAY_ACTION => self :: ACTION_VIEW_WIKI_PAGE,
                                ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID => $complex_wiki_page->get_id()));
                $discuss_url = $this->get_url(
                        array(self :: PARAM_DISPLAY_ACTION => self :: ACTION_DISCUSS,
                                'wiki_publication' => Request :: get('wiki_publication'),
                                ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID => $complex_wiki_page->get_id()));
                $statistics_url = $this->get_url(
                        array(self :: PARAM_DISPLAY_ACTION => self :: ACTION_PAGE_STATISTICS,
                                ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID => $complex_wiki_page->get_id()));

                $html[] = '<li><a' . ($this->get_action() != self :: ACTION_DISCUSS && $this->get_action() != self :: ACTION_PAGE_STATISTICS ? ' class="current"' : '') . ' href="' . $read_url . '">' . Translation :: get(
                        'WikiArticle') . '</a></li>';
                $html[] = '<li><a' . ($this->get_action() == self :: ACTION_DISCUSS ? ' class="current"' : '') . ' href="' . $discuss_url . '">' . Translation :: get(
                        'WikiDiscuss') . '</a></li>';
                $html[] = '<li><a' . ($this->get_action() == self :: ACTION_PAGE_STATISTICS ? ' class="current"' : '') . ' href="' . $statistics_url . '">' . Translation :: get(
                        'WikiStatistics') . '</a></li>';
            }
            else
            {
                $html[] = '<li><a class="current" href="#">' . Translation :: get('WikiArticle') . '</a></li>';
            }

            $html[] = '</ul>';

            $html[] = '<div class="wiki-pane-actions wiki-pane-actions-right wiki-pane-search">';
            $html[] = $this->search_form->as_html();
            $html[] = '<div class="clear"></div>';
            $html[] = '</div>';

            $html[] = '<ul class="wiki-pane-actions wiki-pane-actions-right">';

            if ($complex_wiki_page)
            {
                $delete_url = $this->get_url(
                        array(
                                ComplexDisplay :: PARAM_DISPLAY_ACTION => ComplexDisplay :: ACTION_DELETE_COMPLEX_CONTENT_OBJECT_ITEM,
                                ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID => $complex_wiki_page->get_id()));
                $history_url = $this->get_url(
                        array(self :: PARAM_DISPLAY_ACTION => self :: ACTION_HISTORY,
                                ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID => $complex_wiki_page->get_id()));
                $edit_url = $this->get_url(
                        array(
                                ComplexDisplay :: PARAM_DISPLAY_ACTION => ComplexDisplay :: ACTION_UPDATE_COMPLEX_CONTENT_OBJECT_ITEM,
                                ComplexDisplay :: PARAM_SELECTED_COMPLEX_CONTENT_OBJECT_ITEM_ID => $complex_wiki_page->get_id()));

                $complex_wiki_page_properties = $complex_wiki_page->get_ref_object()->get_properties();

                $html[] = '<li><a' . (in_array($this->get_action(),
                        array(self :: ACTION_VIEW_WIKI, self :: ACTION_VIEW_WIKI_PAGE)) && ! Request :: get(
                        self :: PARAM_WIKI_VERSION_ID) ? ' class="current"' : '') . ' href="' . $read_url . '">' . Translation :: get(
                        'WikiRead') . '</a></li>';
                $html[] = '<li><a' . ($this->get_action() == self :: ACTION_UPDATE_COMPLEX_CONTENT_OBJECT_ITEM ? ' class="current"' : '') . ' href="' . $edit_url . '">' . Translation :: get(
                        'WikiEdit') . '</a></li>';
                $html[] = '<li><a' . (($this->get_action() == self :: ACTION_HISTORY) || ($this->get_action() == self :: ACTION_VIEW_WIKI_PAGE && Request :: get(
                        self :: PARAM_WIKI_VERSION_ID)) ? ' class="current"' : '') . ' href="' . $history_url . '">' . Translation :: get(
                        'WikiHistory') . '</a></li>';
                $html[] = '<li><a' . ($this->get_action() == self :: ACTION_DELETE_COMPLEX_CONTENT_OBJECT_ITEM ? ' class="current"' : '') . ' href="' . $delete_url . '" onClick="return confirm(\'' . Translation :: get(
                        'WikiDeleteConfirm',
                        array('WIKIPAGENAME' => $complex_wiki_page_properties['default_properties']['title'],
                                'WIKINAME' => $this->get_root_content_object()->get_title()), __NAMESPACE__) . '\')">' . Translation :: get(
                        'WikiDelete') . '</a></li>';
            }
            else
            {
                $html[] = '<li><a class="current" href="#">' . Translation :: get('WikiRead') . '</a></li>';
            }

            $html[] = '</ul>';
        }
        else
        {
            $html[] = '<ul class="wiki-pane-actions wiki-pane-actions-left">';
            $html[] = '<li><a class="current" href="#">' . Translation :: get('AddWikiPage') . '</a></li>';
            $html[] = '</ul>';

            $html[] = '<ul class="wiki-pane-actions wiki-pane-actions-right">';

            $repo_viewer_action = Request :: get(RepoViewer :: PARAM_ACTION);
            $creator_url = $this->get_url(array(RepoViewer :: PARAM_ACTION => RepoViewer :: ACTION_CREATOR));
            $browser_url = $this->get_url(array(RepoViewer :: PARAM_ACTION => RepoViewer :: ACTION_BROWSER));
            $html[] = '<li><a' . (($repo_viewer_action == RepoViewer :: ACTION_CREATOR || is_null($repo_viewer_action)) ? ' class="current"' : '') . ' href="' . $creator_url . '">' . Translation :: get(
                    'WikiPageNew') . '</a></li>';
            $html[] = '<li><a' . ($repo_viewer_action == RepoViewer :: ACTION_BROWSER ? ' class="current"' : '') . ' href="' . $browser_url . '">' . Translation :: get(
                    'WikiPageSelect') . '</a></li>';

            if ($repo_viewer_action == RepoViewer :: ACTION_VIEWER)
            {
                $html[] = '<li><a class="current" href="#">' . Translation :: get('WikiPagePreview') . '</a></li>';
            }

            $html[] = '</ul>';
        }

        $html[] = '<div class="clear"></div>';
        $html[] = '</div>';

        $html[] = '<div class="wiki-pane-content">';

        echo implode("\n", $html);
    }

    function display_footer()
    {
        $html = array();

        $html[] = '<div class="clear"></div>';
        $html[] = '<div class="wiki-pane-top"><a href=#top>' . Theme :: get_common_image('action_ajax_add', 'png',
                Translation :: get('BackToTop')) . '</a></div>';
        $html[] = '<div class="clear"></div>';
        $html[] = '</div>';
        $html[] = '<div class="clear"></div>';
        $html[] = '</div>';

        echo implode("\n", $html);

        parent :: display_footer();
    }

    function get_search_form()
    {
        return $this->search_form;
    }

    /**
     * Helper function for the SubManager class, pending access to class constants via variables in PHP 5.3 e.g. $name =
     * $class :: DEFAULT_ACTION DO NOT USE IN THIS SUBMANAGER'S CONTEXT Instead use: - self :: DEFAULT_ACTION in the
     * context of this class - YourSubManager :: DEFAULT_ACTION in all other application classes
     */
    static function get_default_action()
    {
        return self :: DEFAULT_ACTION;
    }

    /**
     * Helper function for the SubManager class, pending access to class constants via variables in PHP 5.3 e.g. $name =
     * $class :: PARAM_ACTION DO NOT USE IN THIS SUBMANAGER'S CONTEXT Instead use: - self :: PARAM_ACTION in the context
     * of this class - YourSubManager :: PARAM_ACTION in all other application classes
     */
    static function get_action_parameter()
    {
        return self :: PARAM_DISPLAY_ACTION;
    }
}
?>