<?php

namespace repository;

use common\libraries\Translation;
use common\libraries\Path;
use common\libraries\Theme;

/**
 * Description of bookmarklet
 *
 * @copyright (c) 2011 University of Geneva
 * @license GNU General Public License - http://www.gnu.org/copyleft/gpl.html
 * @author lopprecht
 */
class RepositoryBookmarklet
{
    
    private $base_path = '';
    private $name = '';
    private $features = array();

    public function __construct($name = '', $width = '', $height = '', $base_path = '')
    {
        $this->name = $name;
        $this->base_path = $base_path;
        
        $this->set_feature('width', $width);
        $this->set_feature('height', $height);
    }

    public function get_name()
    {
        return $this->name;
    }

    public function set_name($value)
    {
        $this->name = $value;
    }

    public function get_base_path()
    {
        return $this->base_path;
    }

    public function set_base_path($value)
    {
        $this->base_path = $value;
    }

    public function get_feature($name, $default = '')
    {
        $features = $this->features;
        return isset($features[$name]) ? $features[$name] : $default;
    }

    public function set_feature($name, $value)
    {
        $this->features[$name] = $value;
    }

    public function get_width()
    {
        return $this->get_feature('width');
    }

    public function set_width($value)
    {
        return $this->set_feature('width', $value);
    }

    public function get_height()
    {
        return $this->get_feature('height');
    }

    public function set_height($value)
    {
        return $this->set_feature('height', $value);
    }

    public function get_favicon_path()
    {
        return Theme :: get_common_image_path() . 'favicon.ico';
    }

    public function display()
    {
        $BASE = Path :: get(WEB_PATH) . 'core.php?application=repository&go=resource_adder';
        $NAME = Translation :: get('AddToChamilo');
        
        $javascript = $this->get_bookmarklet_javascript();
        ;
        $result = <<<EOT
    <a href="javascript:$javascript">$NAME</a>
EOT;
        return $result;
    }

    public function get_bookmarklet_javascript()
    {
        $me = $_SERVER['SERVER_NAME'];
        $me = explode('?', $me);
        $me = reset($me);
        
        $FAVICON = htmlentities($this->get_favicon());
        $ACTION = $this->get_action();
        $result = "(function(){if(window.location.href.indexOf('$me')>0){return '$FAVICON';}else{{$ACTION}}})();";
        return $result;
    }

    /**
     * The javascript file to add to the web page.
     * @return string
     */
    protected function get_resource_javascript()
    {
        return '';
    }

    /**
     * The name of the function.
     *
     * @return string
     */
    protected function get_main_javascript()
    {
        return 'chamilo_execute';
    }

    /**
     * Returns the action done by the bookmarklet
     * @return string
     */
    protected function get_action()
    {
        $WINDOW = $this->get_open_window();
        $JAVASCRIPT = htmlspecialchars($this->get_resource_javascript());
        $MAIN = $this->get_main_javascript();
        $URL = htmlspecialchars($this->get_base_path());
        
        $result = <<<EOT
var d=document,w=window,o=false,c=null,h=null;
c=function(){ $MAIN('$URL'); };
if(w.chamilo===undefined)
{
 o=d.createElement('script');
 o.src='$JAVASCRIPT';
 o.type='text/javascript';
 h=d.getElementsByTagName('head')[0];
 w.chamilo=true;
 var d = false;
 o.onload = o.onreadystatechange = function()
 {
  if(!d && (!this.readyState || this.readyState == 'loaded' || this.readyState == 'complete'))
  {
   c();
   o.onload = o.onreadystatechange = null;
   d = true;
  }
 };
 h.appendChild(o);
}
else
{
 c();
}
EOT;
        return $result;
    }

    protected function get_favicon()
    {
        $FAVICON_URL = $this->get_favicon_path();
        $NAME = $this->get_name();
        $result = <<<EOS
<!DOCTYPE html><html><head><title>$NAME</title><link rel="icon" type="image/png" href="$FAVICON_URL" /></head><body>$NAME</body></html>
EOS;
        return $result;
    }

    /**
     * Utility function. Returns the javascript open windows function.
     *
     * status       The status bar at the bottom of the window.
     * toolbar      The standard browser toolbar, with buttons such as Back and Forward.
     * location     The Location entry field where you enter the URL.
     * menubar      The menu bar of the window$
     * directories  The standard browser directory buttons, such as What’s New and What’s Cool
     * resizable    Allow/Disallow the user to resize the window.
     * scrollbars   Enable the scrollbars if the document is bigger than the window
     * height       Specifies the height of the window in pixels. (example: height=’350′)
     * width        Specifies the width of the window in pixels.
     */
    protected function get_open_window($url = 'uri', $title = 'title', $description = 'description', $html = 'html')
    {
        $name = $name ? $name : $this->get_name();
        $r = array();
        $features = $this->features;
        foreach ($features as $key => $value)
        {
            $r[] = "$key=$value";
        }
        $r = implode(',', $r);
        
        $action = $this->get_base_path();
        
        $result = <<<EOT
var sData;
sData='<html><body><form name="submitform" id="submitform" action="$action" method="post">';
sData+='<input type="hidden" id="title" name="title" value="'+$title+'" />';
sData+='<input type="hidden" id="url" name="url" value="'+$url+'" />';
sData+='<input type="hidden" id="description" name="description" value="'+$description+'" />';
sData+='<input type="hidden" id="html" name="html" value="'+$html+'" />';
sData+='<input type="hidden" id="init" name="init" value="true" />';
sData+='<input type="submit" name="go" id="go" value="Go" style="display:none"/>';
sData+='</form>';
sData+='<script type="text/javascript">';
sData+='document.submitform.submit();';
sData+='</script></body></html>';
var OpenWindow=window.open('', 'na', '$r');
OpenWindow.document.write(sData);
OpenWindow.document.close();
EOT;
        $result = str_replace("\n", '', $result);
        $result = str_replace('"', '\\\'', $result);
        return $result;
    
     //return "window.open($url, '$title','$r');";
    }

}

?>
