<?php

namespace repository;

use common\libraries\NewObjectTableCellRenderer;
use common\libraries\NewObjectTableCellRendererActionsColumnSupport;
use common\libraries\ToolbarItem;
use common\libraries\Toolbar;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\Theme;

/**
 * Description of impact_view_cell_renderer
 *
 * @author Pieterjan Broekaert
 */
class ImpactViewTableCellRenderer extends NewObjectTableCellRenderer implements
NewObjectTableCellRendererActionsColumnSupport
{

    function render_cell($column, $content_object)
    {
        switch ($column->get_name())
        {
            case ContentObject :: PROPERTY_TITLE :
                return $content_object->get_title();
            case ContentObject :: PROPERTY_ID :
                return $content_object->get_id();
            case ImpactViewTableColumnModel :: COLUMN_CATEGORY :
                $repository_data_manager = RepositoryDataManager :: get_instance();
                $category = $repository_data_manager->retrieve_category($content_object->get_parent_id());
                return $category->get_name();
            case ImpactViewTableColumnModel :: COLUMN_SAFE_DELETE:
                return $this->render_is_linked_column($content_object);
        }

        return parent :: render_cell($column, $content_object);
    }

    public function get_object_actions($object)
    {
        $toolbar = new Toolbar();
        $toolbar->add_item(
                new ToolbarItem(
                    Translation :: get('Preview', null, Utilities :: COMMON_LIBRARIES), 
                    Theme :: get_common_image_path() . 'action_preview.png', 
                    'javascript:openPopup(\'' 
                        . $this->get_object_table()->get_component()->get_content_object_preview_url($object) . 
                    '\');void(0);', 
                    ToolbarItem :: DISPLAY_ICON
                    )
                );
        return $toolbar->as_html();
    }
    

    private function render_is_linked_column($content_object)
    {
        if(!RepositoryDataManager :: content_object_deletion_allowed($content_object))
        {            
            return '<img src="' . Theme :: get_common_image_path() . 'status_warning_mini.png' . '" alt="' . $status . '" />';
        }
        else
        {
            return '<img src="' . Theme :: get_common_image_path() . 'status_ok_mini.png' . '" alt="' . $status . '" />';
        }
    }

}

?>
