<?php
namespace repository;

use common\libraries\Request;
use common\libraries\Path;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Utilities;
use common\libraries\EqualityCondition;
use common\libraries\Application;
use common\libraries\ComplexContentObjectSupport;
use common\libraries\OptionsMenuRenderer;
use common\libraries\TreeMenuRenderer;
use HTML_Menu;
use HTML_Menu_ArrayRenderer;

/**
 * $Id: complex_menu.class.php 200 2009-11-13 12:30:04Z kariboe $
 * 
 * @package repository.lib.complex_builder
 */
/**
 * This class provides a navigation menu to allow a user to browse through his
 * categories of objects.
 * 
 * @author Sven Vanpoucke
 */
class ComplexMenu extends HTML_Menu
{
    const TREE_NAME = __CLASS__;
    
    private $cloi;
    private $root;
    /**
     * The string passed to sprintf() to format category URLs
     */
    private $urlFmt;
    /**
     * The array renderer used to determine the breadcrumbs.
     */
    private $array_renderer;
    
    /**
     * Boolean to determine wheter the nodes of the tree which are not complex
     * are shown in the tree or not
     */
    private $view_entire_structure;
    
    /*
     * Boolean to determine wheter the url should be added or not @var Bool
     */
    private $show_url;
    
    /**
     * The datamanger that is used
     * 
     * @var RepositoryDataManager
     */
    private $dm;

    /**
     * Creates a new category navigation menu.
     * 
     * @param $owner int
     *            The ID of the owner of the categories to provide in
     *            this menu.
     * @param $current_category int
     *            The ID of the current category in the menu.
     * @param $url_format string
     *            The format to use for the URL of a category.
     *            Passed to sprintf(). Defaults to the string
     *            "?category=%s".
     * @param $extra_items array
     *            An array of extra tree items, added to the
     *            root.
     */
    function __construct($root, $cloi, $url_format = '?application=repository&go=build_complex&builder_action=browse', $view_entire_structure = false, $show_url = true)
    {
        $url_format .= '&cloi=%s';
        $this->view_entire_structure = $view_entire_structure;
        $extra = array('publish');
        
        foreach ($extra as $item)
        {
            if (Request :: get($item))
                $url_format .= '&' . $item . '=' . Request :: get($item);
        }
        
        $this->show_url = $show_url;
        $this->cloi = $cloi;
        $this->root = $root;
        $this->urlFmt = $url_format;
        $this->dm = RepositoryDataManager :: get_instance();
        
        $menu = $this->get_menu($root);
        parent :: __construct($menu);
        $this->array_renderer = new HTML_Menu_ArrayRenderer();
        $this->forceCurrentUrl($this->get_cloi_url($cloi));
    }

    function get_menu($root)
    {
        $menu = array();
        $lo = $root;
        $menu_item = array();
        $menu_item['title'] = $lo->get_title();
        
        if ($this->show_url)
            $menu_item['url'] = $this->get_cloi_url();
        
        $sub_menu_items = $this->get_menu_items($root->get_id());
        if (count($sub_menu_items) > 0)
        {
            $menu_item['sub'] = $sub_menu_items;
        }
        
        $menu_item['class'] = 'type_' . $lo->get_type();
        // $menu_item['class'] = 'type_category';
        $menu_item[OptionsMenuRenderer :: KEY_ID] = 0;
        $menu[0] = $menu_item;
        return $menu;
    }

    /**
     * Returns the menu items.
     * 
     * @param $extra_items array
     *            An array of extra tree items, added to the
     *            root.
     * @return array An array with all menu items. The structure of this array
     *         is the structure needed by PEAR::HTML_Menu, on which this
     *         class is based.
     */
    private function get_menu_items($parent_id)
    {
        $condition = new EqualityCondition(ComplexContentObjectItem :: PROPERTY_PARENT, $parent_id, ComplexContentObjectItem :: get_table_name());
        $datamanager = $this->dm;
        $clois = $datamanager->retrieve_complex_content_object_items($condition);
        
        while ($cloi = $clois->next_result())
        {
            $lo = $datamanager->retrieve_content_object($cloi->get_ref());
            $url = null;
            
            if (in_array($lo->get_type(), RepositoryDataManager :: get_active_helper_types()))
            {
                $lo = $datamanager->retrieve_content_object($lo->get_reference());
                $url = $this->get_build_complex_url($lo);
            }
            
            if ($lo instanceof ComplexContentObjectSupport || $this->view_entire_structure)
            {
                $menu_item = array();
                $menu_item['title'] = $lo->get_title();
                
                if ($this->show_url)
                {
                    if ($url)
                    {
                        $menu_item['onclick'] = 'javascript:openPopup(\'' . $url . '\'); return false;';
                    }
                    else
                    {
                        $menu_item['url'] = $this->get_cloi_url($cloi);
                    }
                }
                
                $sub_menu_items = $this->get_menu_items($cloi->get_ref());
                if (count($sub_menu_items) > 0)
                {
                    $menu_item['sub'] = $sub_menu_items;
                }
                
                $menu_item['class'] = 'type_' . $lo->get_type();
                // $menu_item['class'] = 'type_category';
                $menu_item[OptionsMenuRenderer :: KEY_ID] = $cloi->get_id();
                $menu[$cloi->get_id()] = $menu_item;
            }
        }
        
        return $menu;
    }

    private function get_cloi_url($cloi)
    {
        if ($cloi == null || $cloi->get_ref() == $this->root)
        {
            $new = str_replace('&cloi=%s', '', $this->urlFmt);
            return sprintf($new, $this->root->get_id());
        }
        return sprintf($this->urlFmt, $cloi->get_id(), $this->root->get_id());
    
    }

    private function get_build_complex_url($object)
    {
        return Path :: get_launcher_application_path(true) . 'index.php?' . Application :: PARAM_APPLICATION . '=complex_builder&' . RepositoryManager :: PARAM_CONTENT_OBJECT_ID . '=' . $object->get_id();
    }

    /**
     * Get the breadcrumbs which lead to the current category.
     * 
     * @return array The breadcrumbs.
     */
    function get_breadcrumbs()
    {
        $this->render($this->array_renderer, 'urhere');
        $breadcrumbs = $this->array_renderer->toArray();
        array_shift($breadcrumbs);
        $trail = BreadcrumbTrail :: get_instance();
        foreach ($breadcrumbs as $crumb)
        {
            $trail->add(new Breadcrumb($crumb['url'], $crumb['title']));
        }
        return $trail;
    }

    /**
     * Renders the menu as a tree
     * 
     * @return string The HTML formatted tree
     */
    function render_as_tree()
    {
        $renderer = new TreeMenuRenderer($this->get_tree_name());
        $this->render($renderer, 'sitemap');
        return $renderer->toHTML();
    }

    static function get_tree_name()
    {
        return Utilities :: get_classname_from_namespace(self :: TREE_NAME, true);
    }
}
?>