<?php
namespace repository;

class ComplexContentObjectPathNode
{
    
    /**
     * @var ComplexContentObjectPath
     */
    private $tree;
    
    /**
     * @var int
     */
    private $id;
    
    /**
     * @var int
     */
    private $parent_id;
    
    /**
     * @var ComplexContentObjectItem
     */
    private $complex_content_object_item;
    
    /**
     * @var ContentObject
     */
    private $content_object;
    
    /**
     * @var array
     */
    private $children;
    
    /**
     * @var array
     */
    private $parents;

    /**
     * @param ComplexContentObjectPath $tree
     * @param int $id
     * @param int $parent
     * @param ComplexContentObjectItem $complex_content_object_item
     * @param ContentObject $content_object
     */
    function __construct($tree, $id, $parent_id, ComplexContentObjectItem $complex_content_object_item, ContentObject $content_object)
    {
        $this->tree = $tree;
        $this->id = $id;
        $this->parent_id = $parent_id;
        $this->complex_content_object_item = $complex_content_object_item;
        $this->content_object = $content_object;
    }

    /**
     * @return ComplexContentObjectPath
     */
    function get_tree()
    {
        return $this->tree;
    }

    /**
     * @return int
     */
    function get_id()
    {
        return $this->id;
    }

    /**
     * @return int
     */
    function get_parent_id()
    {
        return $this->parent_id;
    }

    /**
     * @return ComplexContentObjectItem
     */
    function get_complex_content_object_item()
    {
        return $this->complex_content_object_item;
    }

    /**
     * @return ContentObject
     */
    function get_content_object()
    {
        return $this->content_object;
    }

    /**
     * @param int $id
     */
    function set_id($id)
    {
        $this->id = $id;
    }

    /**
     * @param int $parent
     */
    function set_parent_id($parent_id)
    {
        $this->parent_id = $parent_id;
    }

    /**
     * @param ComplexContentObjectItem $complex_content_object_item
     */
    function set_complex_content_object_item(ComplexContentObjectItem $complex_content_object_item)
    {
        $this->complex_content_object_item = $complex_content_object_item;
    }

    /**
     * @param ContentObject $content_object
     */
    function set_content_object(ContentObject $content_object)
    {
        $this->content_object = $content_object;
    }

    /**
     * @return boolean
     */
    function is_root()
    {
        return $this->get_parent_id() == 0;
    }

    function get_parent()
    {
        if ($this->is_root())
        {
            return null;
        }
        else
        {
            return $this->get_tree()->get_node($this->get_parent_id());
        }
    }

    /**
     * @param int $node_id
     * @param boolean $include_self
     * @return array<ComplexContentObjectPathNode>
     */
    function get_parents($include_self = false, $reverse = false)
    {
        if (! isset($this->parents[$include_self][$reverse]))
        {
            $this->parents[$include_self][$reverse] = self :: get_node_parents($this, $include_self, $reverse);
        }
        
        return $this->parents[$include_self][$reverse];
    }

    function get_children()
    {
        if (! isset($this->children))
        {
            $this->children = self :: get_node_children($this);
        }
        
        return $this->children;
    }

    function has_children()
    {
        return count($this->get_children()) > 0;
    }

    /**
     * @return NULL|ComplexContentObjectPathNode
     */
    function get_next()
    {
        if ($this->get_id() >= $this->get_tree()->count_nodes())
        {
            return null;
        }
        else
        {
            return $this->get_tree()->get_node($this->get_id() + 1);
        }
    }

    /**
     * @return NULL|ComplexContentObjectPathNode
     */
    function get_previous()
    {
        if ($this->get_id() <= 1)
        {
            return null;
        }
        else
        {
            return $this->get_tree()->get_node($this->get_id() - 1);
        }
    }

    static function get_node_parents(ComplexContentObjectPathNode $node, $include_self = false, $reverse = false)
    {
        $parents = array();
        
        if ($include_self)
        {
            $parents[] = $node;
        }
        
        while ($node->get_parent_id() !== 0)
        {
            $node = $node->get_tree()->get_node($node->get_parent_id());
            $parents[] = $node;
        }
        
        if ($reverse)
        {
            krsort($parents);
        }
        
        return $parents;
    }

    static function get_node_children(ComplexContentObjectPathNode $parent)
    {
        $children = array();
        
        foreach ($parent->get_tree()->get_nodes() as $node)
        {
            if ($node->get_parent_id() == $parent->get_id())
            {
                $children[] = $node;
            }
        }
        
        return $children;
    }
}
?>