<?php
namespace repository;

use common\libraries\Utilities;
use common\libraries\Path;
use common\libraries\SubManager;
use common\libraries\Display;
use common\libraries\Translation;
use Exception;

abstract class ComplexDisplayPreview extends SubManager implements ComplexDisplaySupport
{

    /**
     *
     * @param Application|SubManager $parent
     */
    function __construct($parent)
    {
        parent :: __construct($parent);
    }

    /**
     * Pseudo-submanager without components, so get_application_component_path has an empty implementation.
     */
    function get_application_component_path()
    {
    }

    /**
     *
     * @param string $type
     * @param Application $application
     */
    static function launch($type, $application)
    {
        $class = ContentObject :: get_content_object_type_namespace($type) . '\\' . Utilities :: underscores_to_camelcase(
                $type) . 'ComplexDisplayPreview';

        if (! class_exists($class))
        {
            throw new Exception(
                    Translation :: get('ComplexDisplayPreviewTypeDoesNotExist',
                            array('type' => $type)));
        }

        $preview = new $class($application);
        $preview->run();
    }

    /**
     * Abstract method implementened by every extension. Displays the actual complex display.
     */
    abstract function run();

    /**
     * Method always has to be implemented for a class implementing the ComplexDisplay
     *
     * @return ContentObject
     */
    function get_root_content_object()
    {
        return $this->get_parent()->get_root_content_object();
    }

    /**
     * Inform the user that the requested functionality is not available in preview mode
     *
     * @param string $message
     */
    function not_available($message)
    {
        $this->display_header();
        Display :: normal_message($message);
        $this->display_footer();
        exit();
    }

    public function is_allowed($right)
    {
        return true;
    }

    public function is_allowed_to_add_child()
    {
        return true;
    }

    public function is_allowed_to_delete_child()
    {
        return true;
    }

    public function is_allowed_to_delete_feedback()
    {
        return true;
    }

    public function is_allowed_to_edit_content_object()
    {
        return true;
    }

    public function is_allowed_to_edit_feedback()
    {
        return true;
    }

    public function is_allowed_to_view_content_object()
    {
        return true;
    }
}
?>