<?php
namespace repository;

use common\libraries\Utilities;

/**
 *
 * @package repository.lib
 *         
 *          A class to export a ContentObject.
 */
abstract class ContentObjectExport
{
    const FORMAT_CPO = 'cpo';
    const FORMAT_ICAL = 'ical';
    const FORMAT_ZIP = 'zip';
    const FORMAT_HTML = 'html';
    const FORMAT_QTI = 'qti';
    
    const TYPE_DEFAULT = 'default';
    
    private $export_implementation;

    function __construct($export_implementation)
    {
        $this->export_implementation = $export_implementation;
    }

    /**
     *
     * @return ContentObjectExport
     */
    public function get_export_implementation()
    {
        return $this->export_implementation;
    }

    /**
     *
     * @param $export_implementation the
     *            $export_implementation to set
     */
    public function set_export_implementation($export_implementation)
    {
        $this->export_implementation = $export_implementation;
    }

    /**
     *
     * @return ContentObjectExportController
     */
    public function get_context()
    {
        return $this->export_implementation->get_context();
    }

    /**
     *
     * @param $context the
     *            $context to set
     */
    public function set_context($context)
    {
        $this->export_implementation->set_context($context);
    }

    /**
     *
     * @return ContentObject
     */
    public function get_content_object()
    {
        return $this->export_implementation->get_content_object();
    }

    /**
     *
     * @param $content_object the
     *            $content_object to set
     */
    public function set_content_object($content_object)
    {
        $this->export_implementation->set_content_object($content_object);
    }

    static function launch($export_implementation)
    {
        return self :: factory($export_implementation)->render();
    }

    static function factory($export_implementation)
    {
        $class_name = Utilities :: get_classname_from_object($export_implementation, true);
        $class_name_parts = explode('_', $class_name);
        
        $class = __NAMESPACE__ . '\\' . Utilities :: underscores_to_camelcase($class_name_parts[0]) . Utilities :: underscores_to_camelcase($class_name_parts[1]) . 'ContentObjectExport';
        
        return new $class($export_implementation);
    }

    static function get_types()
    {
        return array(self :: FORMAT_CPO, self :: FORMAT_ICAL, self :: FORMAT_ZIP, self :: FORMAT_HTML, self :: FORMAT_QTI);
    }
}
?>