<?php
namespace repository;

use common\libraries\Utilities;

use common\libraries\Filecompression;
use common\libraries\Filesystem;
use common\libraries\Session;
use common\libraries\Path;
use common\libraries\InCondition;

class ZipContentObjectExportController extends ContentObjectExportController
{
    
    /**
     *
     * @var string
     */
    private $temporary_directory;

    function __construct(ExportParameters $parameters)
    {
        parent :: __construct($parameters);
        
        $this->prepare_file_system();
    }

    function run()
    {
        $content_object_ids = $this->get_parameters()->get_content_object_ids();
        if (count($content_object_ids) > 0)
        {
            $condition = new InCondition(ContentObject :: PROPERTY_ID, $content_object_ids, ContentObject :: get_table_name());
        }
        else
        {
            $condition = null;
        }
        
        $content_objects = RepositoryDataManager :: get_instance()->retrieve_content_objects($condition);
        
        while ($content_object = $content_objects->next_result())
        {
            $this->process($content_object);
        }
        return $this->zip();
    }

    function process($content_object)
    {
        $export_types = ContentObjectExportImplementation :: get_types_for_object(Utilities :: get_namespace_from_object($content_object));

        if (in_array(ContentObjectExport :: FORMAT_ZIP, $export_types))
        {
            ContentObjectExportImplementation :: launch($this, $content_object, ContentObjectExport :: FORMAT_ZIP, $this->get_parameters()->get_type());
        }
    }

    function get_filename()
    {
        return 'content_objects.zip';
    }

    function prepare_file_system()
    {
        $user_id = Session :: get_user_id();
        
        $this->temporary_directory = Path :: get(SYS_TEMP_PATH) . $user_id . '/export_content_objects/';
        if (! is_dir($this->temporary_directory))
        {
            mkdir($this->temporary_directory, 0777, true);
        }
    
    }

    /**
     *
     * @param $source string           
     * @param $destination string           
     */
    function add_files($source, $destination)
    {
        Filesystem :: recurse_copy($source, $this->temporary_directory . $destination, true);
    }

    function zip()
    {
        $zip = Filecompression :: factory();
        $zip_path = $zip->create_archive($this->temporary_directory);
        Filesystem :: remove($this->temporary_directory);
        return $zip_path;
    }

    function get_temporary_directory()
    {
        return $this->temporary_directory;
    }
}
?>