<?php
namespace repository;

use common\libraries\Utilities;

/**
 *
 * @package repository.lib A class to import a ContentObject.
 */
abstract class ContentObjectImport
{
    const FORMAT_CPO = 'cpo';
    const FORMAT_ICAL = 'ical';
    const FORMAT_QTI = 'qti';
    const FORMAT_DOCUMENT = 'document';
    const FORMAT_ZIP = 'zip';
    const FORMAT_YOUTUBE = 'youtube';
    const FORMAT_VIMEO = 'vimeo';
    const FORMAT_HOTPOTATOES = 'hotpotatoes';
    const FORMAT_SCORM = 'scorm';

    const TYPE_DEFAULT = 'default';

    private $import_implementation;

    function __construct($import_implementation)
    {
        $this->import_implementation = $import_implementation;
    }

    /**
     *
     * @return AbstractContentObjectImportImplementation
     */
    public function get_import_implementation()
    {
        return $this->import_implementation;
    }

    /**
     *
     * @param $import_implementation the $import_implementation to set
     */
    public function set_import_implementation($import_implementation)
    {
        $this->import_implementation = $import_implementation;
    }

    /**
     *
     * @return ContentObjectImportController
     */
    public function get_context()
    {
        return $this->import_implementation->get_context();
    }

    /**
     *
     * @param $context the $context to set
     */
    public function set_context($context)
    {
        $this->import_implementation->set_context($context);
    }

    /**
     *
     * @return ContentObject
     */
    public function get_content_object()
    {
        return $this->import_implementation->get_content_object();
    }

    /**
     *
     * @param $content_object the $content_object to set
     */
    public function set_content_object($content_object)
    {
        $this->import_implementation->set_content_object($content_object);
    }

    static function launch($import_implementation)
    {
        return self :: factory($import_implementation)->import();
    }

    static function post_process($import_implementation, $content_object)
    {
        return self :: factory($import_implementation)->post_import($content_object);
    }

    static function factory($import_implementation)
    {
        $class_name = Utilities :: get_classname_from_object($import_implementation, true);
        $class_name_parts = explode('_', $class_name);
        $class = __NAMESPACE__ . '\\' . Utilities :: underscores_to_camelcase($class_name_parts[0]) . 'ContentObjectImport';
        return new $class($import_implementation);
    }
}
?>