<?php
namespace repository;

use common\libraries\AndCondition;
use common\libraries\Path;
use common\libraries\Filecompression;
use common\libraries\Session;
use common\libraries\Translation;
use common\libraries\EqualityCondition;
use DOMDocument;
use DOMXPath;

class CpoContentObjectImportController extends ContentObjectImportController
{
    const NODE_TYPE_SUB_ITEMS = 'sub_items';
    const NODE_TYPE_ATTACHMENTS = 'attachments';
    const NODE_TYPE_INCLUDES = 'includes';
    const FORMAT = 'cpo';

    /**
     *
     * @var DOMDocument
     */
    private $dom_document;

    /**
     *
     * @var DOMXPath
     */
    private $dom_xpath;

    /**
     *
     * @var string
     */
    private $temporary_directory;

    /**
     *
     * @var multitype:multitype
     */
    private $id_cache;

    /**
     *
     * @var multitype:boolean
     */
    private $object_number_created;

    /**
     *
     * @var multitype:multitype
     */
    private $version;

    /**
     *
     * @param $content_object_ids multitype:integer
     */
    function __construct($parameters)
    {
        parent :: __construct($parameters);

        $this->dom_document = new DOMDocument('1.0', 'UTF-8');
        $this->prepare_file_system();
    }

    /**
     *
     * @return DOMDocument
     */
    function get_dom_document()
    {
        return $this->dom_document;
    }

    /**
     *
     * @param $dom_document DOMDocument
     */
    function set_dom_document($dom_document)
    {
        $this->dom_document = $dom_document;
    }

    /**
     *
     * @return DOMXPath
     */
    function get_dom_xpath()
    {
        return $this->dom_xpath;
    }

    /**
     *
     * @param $dom_xpath DOMXPath
     */
    function set_dom_xpath($dom_xpath)
    {
        $this->dom_xpath = $dom_xpath;
    }

    function prepare_file_system()
    {
        $user_id = Session :: get_user_id();

        $this->temporary_directory = Path :: get(SYS_TEMP_PATH) . $user_id . '/import_content_objects/';
        if (! is_dir($this->temporary_directory))
        {
            mkdir($this->temporary_directory, 0777, true);
        }
    }

    function set_cache_id($classname, $property, $old_id, $new_id)
    {
        $this->id_cache[$classname][$property][$old_id] = $new_id;
    }

    function set_content_object_id_cache_id($old_id, $new_id)
    {
        $this->set_cache_id(ContentObject :: CLASS_NAME, ContentObject :: PROPERTY_ID, $old_id, $new_id);
    }

    function set_category_id_cache_id($old_id, $new_id)
    {
        $this->set_cache_id(RepositoryCategory :: CLASS_NAME, RepositoryCategory :: PROPERTY_ID, $old_id, $new_id);
    }

    function set_content_object_object_number_cache_id($old_object_number, $new_object_number)
    {
        $this->set_cache_id(ContentObject :: CLASS_NAME, ContentObject :: PROPERTY_OBJECT_NUMBER, $old_object_number, $new_object_number);
    }

    function set_complex_content_object_item_id_cache_id($old_item_id, $new_item_id)
    {
        $this->set_cache_id(ComplexContentObjectItem :: CLASS_NAME, ComplexContentObjectItem :: PROPERTY_ID, $old_item_id, $new_item_id);
    }

    function set_external_instance_id_cache_id($old_external_instance_id, $new_external_instance_id)
    {
        $this->set_cache_id(ExternalInstance :: CLASS_NAME, ExternalInstance :: PROPERTY_ID, $old_external_instance_id, $new_external_instance_id);
    }

    function get_cache_id($classname, $property, $old_id)
    {
        return $this->id_cache[$classname][$property][$old_id];
    }

    function get_cache()
    {
        return $this->id_cache;
    }

    function get_cache_ids($classname, $property)
    {
        return $this->id_cache[$classname][$property];
    }

    function get_content_object_id_cache_id($old_id)
    {
        return $this->get_cache_id(ContentObject :: CLASS_NAME, ContentObject :: PROPERTY_ID, $old_id);
    }

    function get_category_id_cache_id($old_id)
    {
        return $this->get_cache_id(RepositoryCategory :: CLASS_NAME, RepositoryCategory :: PROPERTY_ID, $old_id);
    }

    function get_content_object_object_number_cache_id($old_object_number)
    {
        return $this->get_cache_id(ContentObject :: CLASS_NAME, ContentObject :: PROPERTY_OBJECT_NUMBER, $old_object_number);
    }

    function get_complex_content_object_item_id_cache_id($old_item_id)
    {
        return $this->get_cache_id(ComplexContentObjectItem :: CLASS_NAME, ComplexContentObjectItem :: PROPERTY_ID, $old_item_id);
    }

    function get_external_instance_id_cache_id($old_external_instance_id)
    {
        return $this->get_cache_id(ExternalInstance :: CLASS_NAME, ExternalInstance :: PROPERTY_ID, $old_external_instance_id);
    }

    function get_object_number_created($id)
    {
        return $this->object_number_created[$id];
    }

    function set_object_number_created($id)
    {
        $this->object_number_created[$id] = true;
    }

    function get_version($id)
    {
        return $this->version[$id];
    }

    function set_version($object_number, $creation_date)
    {
        $this->version[$object_number] = $creation_date;
    }

    function run()
    {
        if (in_array($this->get_parameters()->get_file()->get_extension(), self :: get_allowed_extensions()))
        {
            $this->temporary_directory = $this->unzip();
            $xml_path = $this->temporary_directory . '/content_object.xml';
            if (file_exists($xml_path))
            {
                $this->dom_document->load($xml_path);
                $this->dom_xpath = new DOMXPath($this->dom_document);
                $this->process_categories();
                $content_object_list = $this->dom_xpath->query('/export/content_objects/content_object');
                foreach ($content_object_list as $content_object_node)
                {
                    if (! $this->get_content_object_id_cache_id($content_object_node->getAttribute('id')))
                    {
                        $this->process_content_object($content_object_node);
                    }
                }
                $this->add_message(Translation :: get('ObjectImported'), self :: TYPE_CONFIRM);
            }
            else
            {
                $this->add_message(Translation :: get('NoCpoFile'), self :: TYPE_WARNING);
            }
        }
        else
        {
            $this->add_message(Translation :: get('UnsupportedFileFormat', array(
                    'TYPES' => implode(', ', self :: get_allowed_extensions()))), self :: TYPE_ERROR);
        }

        return $this->get_cache_ids(ContentObject :: CLASS_NAME, ContentObject :: PROPERTY_ID);
    }

    function process_categories()
    {
        $root_categories = $this->dom_xpath->query('//category[parent_id=0]');
        foreach($root_categories as $root_category)
        {
            $this->process_category($root_category, $this->get_parameters()->get_category());
        }
    }

    function process_category($node, $parent_id)
    {
        $category = new RepositoryCategory();
        $base_name = $this->dom_xpath->query('name', $node)->item(0)->nodeValue;
        $category->set_name(RepositoryDataManager :: create_unique_category_name($this->get_parameters()->get_user(), $parent_id, $base_name));
        $category->set_parent($parent_id);
        $category->set_user_id($this->get_parameters()->get_user());
        $category->set_type(RepositoryCategory :: TYPE_NORMAL);
        if (! $category->create())
        {
            return false;
        }
        else
        {
            $this->set_category_id_cache_id($node->getAttribute('id'), $category->get_id());
            $child_nodes = $this->dom_xpath->query('//category[parent_id=' . $node->getAttribute('id') . ']');
            foreach ($child_nodes as $child_node)
            {
                $this->process_category($child_node, $category->get_id());
            }
        }
    }

    function process_helpers($content_object_node)
    {
        $content_object_type = $this->dom_xpath->query('general/type', $content_object_node)->item(0)->nodeValue;

        if (in_array($content_object_type, RepositoryDataManager :: get_active_helper_types()))
        {
            $content_object_reference_id = convert_uudecode($this->dom_xpath->query('extended/reference_id', $content_object_node)->item(0)->nodeValue);
            if (! $this->get_content_object_id_cache_id($content_object_reference_id))
            {
                $content_object_reference_list = $this->dom_xpath->query('/export/content_objects/content_object[@id="' . $content_object_reference_id . '"]');
                if ($content_object_reference_list->length == 1)
                {
                    $this->process_content_object($content_object_reference_list->item(0));
                }
            }
        }
    }

    function update_helpers($content_object_node, $content_object)
    {
        $content_object_type = $this->dom_xpath->query('general/type', $content_object_node)->item(0)->nodeValue;

        if (in_array($content_object_type, RepositoryDataManager :: get_active_helper_types()))
        {
            $content_object_reference_id = $this->dom_xpath->query('extended/reference_id', $content_object_node)->item(0)->nodeValue;
            $content_object->set_reference($this->get_content_object_id_cache_id(convert_uudecode($content_object_reference_id)));
        }
    }

    function process_attachments($content_object_node)
    {
        $attachment_list = $this->dom_xpath->query('attachments/attachment', $content_object_node);
        foreach ($attachment_list as $attachment_node)
        {
            $id_ref = $attachment_node->getAttribute('idref');

            if (! $this->get_content_object_id_cache_id($id_ref))
            {
                $content_object_node_list = $this->dom_xpath->query('/export/content_objects/content_object[@id="' . $id_ref . '"]');
                if ($content_object_node_list->length == 1)
                {
                    $this->process_content_object($content_object_node_list->item(0));
                }
            }
        }
    }

    function create_attachments($content_object_node)
    {
        $attachment_list = $this->dom_xpath->query('attachments/attachment', $content_object_node);
        foreach ($attachment_list as $attachment_node)
        {
            $content_object_attachment = new ContentObjectAttachment();
            $content_object_attachment->set_content_object_id($this->get_content_object_id_cache_id($content_object_node->getAttribute('id')));
            $content_object_attachment->set_attachment_id($this->get_content_object_id_cache_id($attachment_node->getAttribute('idref')));
            $content_object_attachment->set_type($attachment_node->getAttribute('type'));
            $content_object_attachment->create();
        }
    }

    function process_includes($content_object_node)
    {
        $include_list = $this->dom_xpath->query('includes/include', $content_object_node);
        foreach ($include_list as $include_node)
        {
            $id_ref = $include_node->getAttribute('idref');

            if (! $this->get_content_object_id_cache_id($id_ref))
            {
                $content_object_node_list = $this->dom_xpath->query('/export/content_objects/content_object[@id="' . $id_ref . '"]');
                if ($content_object_node_list->length == 1)
                {
                    $this->process_content_object($content_object_node_list->item(0));
                }
            }
        }
    }

    function create_includes($content_object_node)
    {
        $include_list = $this->dom_xpath->query('includes/include', $content_object_node);
        foreach ($include_list as $include_node)
        {
            $content_object_include = new ContentObjectInclude();
            $content_object_include->set_content_object_id($this->get_content_object_id_cache_id($content_object_node->getAttribute('id')));
            $content_object_include->set_include_id($this->get_content_object_id_cache_id($include_node->getAttribute('idref')));
            $content_object_include->create();
        }
    }

    function process_sub_items($content_object_node)
    {
        $sub_item_list = $this->dom_xpath->query('sub_items/sub_item', $content_object_node);
        foreach ($sub_item_list as $sub_item_node)
        {
            $id_ref = $sub_item_node->getAttribute('idref');

            if (! $this->get_content_object_id_cache_id($id_ref))
            {
                $content_object_node_list = $this->dom_xpath->query('/export/content_objects/content_object[@id="' . $id_ref . '"]');
                if ($content_object_node_list->length == 1)
                {
                    $this->process_content_object($content_object_node_list->item(0));
                }
            }
        }
    }

    function create_sub_items($content_object_node)
    {
        $sub_item_list = $this->dom_xpath->query('sub_items/sub_item', $content_object_node);
        foreach ($sub_item_list as $key => $sub_item_node)
        {
            $id = $sub_item_node->getAttribute('id');

            if (! $this->get_complex_content_object_item_id_cache_id($id))
            {
                $id_ref = $sub_item_node->getAttribute('idref');
                $complex_content_object_item = ComplexContentObjectItem :: factory($this->dom_xpath->query('/export/content_objects/content_object[@id="' . $id_ref . '"]/general/type')->item(0)->nodeValue);
                $complex_content_object_item->set_ref($this->get_content_object_id_cache_id($id_ref));
                $complex_content_object_item->set_user_id(Session :: get_user_id());
                $complex_content_object_item->set_parent($this->get_content_object_id_cache_id($content_object_node->getAttribute('id')));
                $complex_content_object_item->set_display_order($key + 1);
                foreach ($complex_content_object_item->get_additional_property_names() as $additional_property)
                {
                    $complex_content_object_item->set_additional_property($additional_property, $sub_item_node->getAttribute($additional_property));
                }
                $complex_content_object_item->create();
                $this->set_complex_content_object_item_id_cache_id($id, $complex_content_object_item->get_id());
            }
        }
    }

    function process_external_sync($content_object_node)
    {
        $external_sync_node_list = $this->dom_xpath->query('external_sync', $content_object_node);

        if ($external_sync_node_list->length == 1)
        {
            $external_sync_node = $external_sync_node_list->item(0);
            $external_id = $external_sync_node->getAttribute('external_instance');
            if (! $this->get_external_instance_id_cache_id($external_id))
            {
                $external_instance_node_list = $this->dom_xpath->query('/export/external_instance[@id="' . $external_id . '"]');
                if ($external_instance_node_list->length == 1)
                {

                    $external_instance_node = $external_instance_node_list->item(0);
                    $conditions = array();
                    $conditions[] = new EqualityCondition(ExternalInstance :: PROPERTY_TYPE, $external_instance_node->getAttribute('type'));
                    $condition = new AndCondition($conditions);

                    $external_instances = RepositoryDataManager :: get_instance()->retrieve_external_instances($condition);
                    while ($external_instance = $external_instances->next_result())
                    {
                        $setting_node_list = $this->dom_xpath->query('setting', $external_instance_node);
                        $is_matching_external_instance = true;
                        foreach ($setting_node_list as $setting_node)
                        {
                            $variable = $this->dom_xpath->query('variable', $setting_node)->item(0)->nodeValue;
                            $value = $this->dom_xpath->query('value', $setting_node)->item(0)->nodeValue;

                            if ($external_instance->get_setting($variable) != $value)
                            {
                                $is_matching_external_instance = false;
                                break;
                            }
                        }
                        if (! $is_matching_external_instance)
                        {
                            continue;
                        }
                        else
                        {
                            $this->set_external_instance_id_cache_id($external_id, $external_instance->get_id());
                            break;
                        }
                    }
                }
                else
                {
                    return false;
                }
            }
            else
            {
                return true;
            }
        }
        else
        {
            return true;
        }
    }

    function create_external_sync($content_object_node, $content_object)
    {
        $external_sync_node_list = $this->dom_xpath->query('external_sync', $content_object_node);

        if ($external_sync_node_list->length == 1)
        {
            $external_sync_node = $external_sync_node_list->item(0);
            $external_id = $external_sync_node->getAttribute('external_instance');

            if ($this->get_external_instance_id_cache_id($external_id))
            {
                $external_sync = new ExternalSync();
                $external_sync->set_content_object_id($content_object->get_id());
                $external_sync->set_content_object_timestamp($content_object->get_modification_date());
                $external_sync->set_external_id($this->get_external_instance_id_cache_id($external_id));
                $external_sync->set_external_object_id($external_sync_node->getAttribute('id'));
                $external_sync->set_external_object_timestamp($external_sync_node->getAttribute('timestamp'));
                return $external_sync->create();
            }
            else
            {
                return false;
            }
        }
        else
        {
            return true;
        }
    }

    function process_content_object($content_object_node)
    {
        $content_object_parameter = new CpoContentObjectImportParameters($content_object_node);

        $this->process_attachments($content_object_node);
        $this->process_includes($content_object_node);
        $this->process_sub_items($content_object_node);
        $this->process_helpers($content_object_node);
        $this->process_external_sync($content_object_node);

        $content_object = ContentObjectImportImplementation :: launch($this, $this->dom_xpath->query('general/type', $content_object_node)->item(0)->nodeValue, $content_object_parameter);
        $this->update_helpers($content_object_node, $content_object);
        $content_object->create();

        // $this->create_content_object($content_object);
        $this->set_content_object_id_cache_id($content_object_node->getAttribute('id'), $content_object->get_id());

        $this->create_attachments($content_object_node);
        $this->create_includes($content_object_node);
        $this->create_sub_items($content_object_node);
        $this->create_external_sync($content_object_node, $content_object);
        ContentObjectImportImplementation :: post_process($this, $this->dom_xpath->query('general/type', $content_object_node)->item(0)->nodeValue, $content_object_parameter, $content_object);
    }

    function unzip()
    {
        $unzip = Filecompression :: factory();
        return $unzip->extract_file($this->get_parameters()->get_file()->get_path());
    }

    function get_xml_path()
    {
        return $this->temporary_directory . '/content_object.xml';
    }

    function get_data_path()
    {
        return $this->temporary_directory . '/data/';
    }

    function create_content_object($content_object)
    {
        $data_manager = RepositoryDataManager :: get_instance();

        if (! $this->get_object_number_created($content_object->get_object_number()))
        {
            if (! $data_manager->create_content_object($content_object, 'new'))
            {
                return false;
            }
            else
            {
                $this->set_version($content_object->get_object_number(), $content_object->get_creation_date());
                $this->set_object_number_created($content_object->get_object_number());
            }
        }
        else
        {
            if ($content_object->get_creation_date() > $this->get_version($content_object->get_object_number()))
            {
                if (! $data_manager->create_content_object($content_object, 'version'))
                {
                    return false;
                }
            }
            else
            {
                if (! $data_manager->create_content_object($content_object, 'import'))
                {
                    return false;
                }
            }
        }

        $parent_id = RepositoryRights :: get_instance()->get_user_root_id($content_object->get_owner_id());

        if (! RepositoryRights :: get_instance()->create_location_in_user_tree(RepositoryRights :: TYPE_USER_CONTENT_OBJECT, $content_object->get_id(), $parent_id, $content_object->get_owner_id()))
        {
            return false;
        }

        return true;
    }

    static function get_allowed_extensions()
    {
        return array('cpo');
    }
}
?>