<?php
namespace repository;

use repository\quota\Calculator;
use common\libraries\Filesystem;
use common\libraries\Path;
use common\libraries\FileProperties;
use common\libraries\Application;
use common\libraries\Redirect;
use common\libraries\AndCondition;
use common\libraries\EqualityCondition;
use common\libraries\Hashing;
use common\libraries\Translation;
use common\libraries\Session;
use repository\content_object\document\Document;

class DocumentContentObjectImportController extends ContentObjectImportController
{
    const FORMAT = 'document';

    function run()
    {
        if (in_array('document', RepositoryDataManager :: get_registered_types(true)))
        {
            if ($this->get_parameters()->get_document_type() == DocumentContentObjectImportForm :: DOCUMENT_UPLOAD)
            {
                $file = $this->get_parameters()->get_file();
                $calculator = new Calculator(
                        \user\DataManager :: retrieve(\user\User :: class_name(),
                                (int) $this->get_parameters()->get_user()));

                if ($calculator->get_available_user_disk_quota() < $file->get_size())
                {
                    $this->add_message(Translation :: get('InsufficientDiskQuota'), self :: TYPE_ERROR);
                    return array();
                }
            }
            else
            {
                $file = FileProperties :: from_url($this->get_parameters()->get_link());

                if ($file->get_path() && $file->get_name() && $file->get_extension())
                {
                    $calculator = new Calculator(
                            \user\DataManager :: retrieve(\user\User :: class_name(),
                                    (int) $this->get_parameters()->get_user()));

                    if ($calculator->get_available_user_disk_quota() > $file->get_size())
                    {
                        $temp_path = Path :: get_temp_path() . 'repository/import/document/' . $file->get_name_extension();

                        if (Filesystem :: copy_file($file->get_path(), $temp_path))
                        {
                            $file = FileProperties :: from_path($temp_path);
                        }
                        else
                        {
                            $this->add_message(Translation :: get('ObjectNotImported'), self :: TYPE_ERROR);
                            return array();
                        }
                    }
                    else
                    {
                        $this->add_message(Translation :: get('InsufficientDiskQuota'), self :: TYPE_ERROR);
                        return array();
                    }
                }
                else
                {
                    $this->add_message(Translation :: get('InvalidDocumentLink'), self :: TYPE_ERROR);
                    return array();
                }
            }

            $document = new Document();
            $document->set_title($file->get_name());
            $document->set_description($file->get_name());
            $document->set_owner_id($this->get_parameters()->get_user());
            $document->set_parent_id($this->get_parameters()->get_category());
            $document->set_filename($file->get_name_extension());

            $hash = md5_file($file->get_path());
            $conditions = array();
            $conditions[] = new EqualityCondition(ContentObject :: PROPERTY_OWNER_ID,
                    $this->get_parameters()->get_user());
            $conditions[] = new EqualityCondition(Document :: PROPERTY_CONTENT_HASH, $hash);
            $condtion = new AndCondition($conditions);
            $content_objects = RepositoryDataManager :: get_instance()->retrieve_active_content_objects($condtion, null,
                    Document :: get_type_name());

            if ($content_objects->size() > 0)
            {
                if ($content_objects->size() == 1)
                {
                    $content_object = $content_objects->next_result();
                    $link = Redirect :: get_link(RepositoryManager :: APPLICATION_NAME,
                            array(Application :: PARAM_ACTION => RepositoryManager :: ACTION_VIEW_CONTENT_OBJECTS,
                                    RepositoryManager :: PARAM_CONTENT_OBJECT_ID => $content_object->get_id()));
                    $this->add_message(Translation :: get('ObjectAlreadyExists', array('LINK' => $link)),
                            self :: TYPE_ERROR);
                }
                else
                {
                    $this->add_message(Translation :: get('ObjectAlreadyExistsMultipleTimes'), self :: TYPE_ERROR);
                }
            }
            else
            {
                $document->set_temporary_file_path($file->get_path());

                if ($document->create())
                {
                    $this->add_message(Translation :: get('ObjectImported'), self :: TYPE_CONFIRM);
                    return array($document->get_id());
                }
                else
                {
                    $this->add_message(Translation :: get('ObjectNotImported'), self :: TYPE_ERROR);
                }
            }
        }
        else
        {
            $this->add_message(Translation :: get('DocumentObjectNotAvailable'), self :: TYPE_WARNING);
        }
    }
}
?>