<?php
namespace repository;

use common\libraries\Translation;
use common\libraries\Path;
use repository\content_object\task\Task;
use repository\content_object\calendar_event\CalendarEvent;
use vcalendar;
use vevent;
use vtodo;

require Path :: get_plugin_path() . 'icalcreator/iCalcreator.class.php';
class IcalContentObjectImportController extends ContentObjectImportController
{
    const FORMAT = 'ical';

    private $calendar;

    private $temporary_directory;

    private $cache;

    function __construct($parameters)
    {
        parent :: __construct($parameters);
        $this->calendar = new vcalendar();
        $this->calendar->setConfig('url', $this->get_parameters()->get_file()->get_path());
        $this->calendar->parse();
        $this->calendar->sort();
    }

    function run()
    {
        if (in_array($this->get_parameters()->get_file()->get_extension(), self :: get_allowed_extensions()))
        {
            $calendar = $this->calendar;
            if (count($calendar->components) == 0)
            {
                $this->add_message(Translation :: get('NoIcalEvents'), self :: TYPE_WARNING);
            }
            else
            {
                foreach ($calendar->components as $calendar_component)
                {
                    $this->process_calendar_component($calendar_component);
                }
                $this->add_message(Translation :: get('ObjectImported'), self :: TYPE_CONFIRM);
            }
        }
        else
        {
            $this->add_message(
                    Translation :: get('UnsupportedFileFormat',
                            array('TYPES' => implode(', ', self :: get_allowed_extensions()))), self :: TYPE_ERROR);
        }

        return $this->cache;
    }

    function process_calendar_component($calendar_component)
    {
        if ($calendar_component instanceof vevent && in_array('calendar_event',
                RepositoryDataManager :: get_registered_types(true)))
        {
            $type = CalendarEvent :: get_type_name();
        }
        elseif ($calendar_component instanceof vtodo && in_array('task',
                RepositoryDataManager :: get_registered_types(true)))
        {
            $type = Task :: get_type_name();
        }
        if ($type)
        {
            $content_object_parameter = new IcalContentObjectImportParameters($calendar_component);

            $content_object = ContentObjectImportImplementation :: launch($this, $type, $content_object_parameter);

            $content_object->create();
            $this->cache[] = $content_object->get_id();
        }
    }

    static function get_allowed_extensions()
    {
        return array('ics');
    }
}
?>