<?php
namespace repository;

use common\libraries\ObjectImportSettings;
use common\libraries\Qti;
use common\libraries\BufferedObjectImport;
use common\libraries\EmptyObjectImport;
use common\libraries\Log;
use common\libraries\Filesystem;
use common\libraries\Filecompression;
use common\libraries\Translation;
use common\libraries\Path;

class QtiContentObjectImportController extends ContentObjectImportController
{
    const FORMAT = 'qti';

    private $settings = null;

    public function __construct($parameters)
    {
        parent :: __construct($parameters);
        $this->settings = new ObjectImportSettings($this->get_parameters()->get_file()->get_path(), '', '',
                $this->get_parameters()->get_user(), $this->get_parameters()->get_category(), new Log());
    }

    /**
     *
     * @return ObjectImportSettings
     */
    public function get_settings()
    {
        return $this->settings;
    }

    function run()
    {
        $result = array();
        if (in_array($this->get_parameters()->get_file()->get_extension(), self :: get_allowed_extensions()))
        {
            $zipper = Filecompression :: factory();
            $temp = $zipper->extract_file($this->get_parameters()->get_file()->get_path());

            $directory = $temp . '/';

            // $this->set_directory($directory);
            if (! file_exists($directory))
            {
                return false;
            }

            $files = $this->get_files($directory);

            foreach ($files as $path)
            {
                $object_settings = $this->get_settings()->copy($path);
                if ($import_result = $this->process($object_settings)->import_content_object())
                {
                    $result[] = $import_result;
                }
            }

            if ($temp)
            {
                Filesystem :: remove($temp);
            }
            $log = $this->get_settings()->get_log();
            if ($result)
            {
                $log->translate('QtiImportWarning', Log :: TYPE_WARNING);
            }
            // $this->add_messages($log->get_messages());
            // $this->add_warnings($log->get_warnings());
            // $this->add_errors($log->get_errors());

            $result = $result ? $result : false;
        }
        else
        {
            $this->add_message(
                    Translation :: get('UnsupportedFileFormat',
                            array('TYPES' => implode(', ', self :: get_allowed_extensions()))), self :: TYPE_ERROR);
        }

        return $result;
    }

    function process(ObjectImportSettings $settings)
    {
        if (! file_exists($settings->get_path()))
        {
            // builders may delete the file after import and cicular reference may force this function to be called
            // twice on the same file.
            $result = EmptyObjectImport :: get_instance();
        }
        else
            if ($import = QtiBuilderImport :: factory($this, $settings))
            {
                $result = $import;
            }
            else
            {
                $result = EmptyObjectImport :: get_instance();
            }

        // Note: even if we don't have a valid importer we want to record in the buffer that the import failed.
        // Otherwise we may try to reprocess the same file several times due to circular references.
        $result = new BufferedObjectImport($settings, $result);
        return $result;
    }

    protected function get_files($directory)
    {
        $files = Filesystem :: get_directory_content($directory, Filesystem :: LIST_FILES, false);
        $assessments = array();
        $questions = array();
        foreach ($files as $file)
        {
            if (Qti :: is_test_file($directory . $file))
            {
                $assessments[] = $directory . $file;
            }
            else
                if (Qti :: is_question_file($directory . $file))
                {
                    $questions[] = $directory . $file;
                }
        }
        // assessments should be imported first
        return array_merge($assessments, $questions);
    }

    static function get_allowed_extensions()
    {
        return array('zip');
    }
}
?>