<?php
namespace repository;

use repository\QtiImport;
use common\libraries\Qti;
use common\libraries\ImsQtiReader;

/**
 * Adapter between builders and importers.
 * Builders are responsible to construct a chamilo question object.
 *
 * @copyright (c) 2010 University of Geneva
 * @license GNU General Public License
 * @author laurent.opprecht@unige.ch
 */
class QtiBuilderImport
{

    public static function factory($controller, ObjectImportSettings $settings)
    {
        $path = $settings->get_path();

        if (! Qti :: is_qti_file($path))
        {
            return null;
        }
        $reader = new ImsQtiReader($path, false);
        $item = $reader->get_root();
        if ($builder = QtiBuilderBase :: factory($item, $settings))
        {
            return new self($controller, $settings, $builder);
        }
        else
        {
            return null;
        }
    }

    private $builder = null;

    private $settings = null;

    private $controller;

    public function __construct($controller, ObjectImportSettings $settings, $builder)
    {
        $this->controller = $controller;
        $this->builder = $builder;
        $this->settings = $settings;
    }

    public function get_settings()
    {
        return $this->settings;
    }

    public function get_builder()
    {
        return $this->builder;
    }

    public function get_controller()
    {
        return $this->controller;
    }

    public function import_content_object()
    {
        $result = false;
        $path = $this->get_settings()->get_path();
        $reader = new ImsQtiReader($path, false);
        $item = $reader->get_root();
        $object = $this->builder->build($item);
        return $this->save_content_object($object);
    }

    protected function save_content_object(ContentObject $object)
    {
        $object->set_owner_id($this->get_controller()->get_parameters()->get_user());
        $object->set_parent_id($this->get_controller()->get_parameters()->get_category());

        if (! $object->save())
        {
            $this->get_log()->error($object->get_errors());
            return null;
        }
        else
        {
            return $object; // ->get_id()
        }
    }
}

?>