<?php
namespace repository;

use DOMDocument;
use DOMXPath;

class ContentObjectResourceRenderer
{
    private $context;
    private $description;

    /**
     * Handle description as full html or not
     *
     * @var bool
     */
    private $full_html;

    function __construct($context, $description, $full_html = false)
    {
        $this->context = $context;
        $this->description = $description;
        $this->full_html = $full_html;
    }


    function run()
    {
        /**
         * Convert encoding to preserve multi-byte UTF-8 characters as iso-8859-1 HTML entities to avoid being read
         * incorrectly by DomDocument::loadHTML().
         *
         * Does not convert tags.
         */
        $description = mb_convert_encoding($this->description, 'html-entities', 'UTF-8');

        $this->dom_document = new DOMDocument();
        $this->dom_document->loadHTML($description);
        $this->dom_document->removeChild($this->dom_document->firstChild);
        $this->dom_xpath = new DOMXPath($this->dom_document);
        
        if(!$this->full_html)
        {
            $body_nodes = $this->dom_xpath->query('body/*');
            $fragment = $this->dom_document->createDocumentFragment();
            foreach ($body_nodes as $child)
            {
                $fragment->appendChild($child);
            }
            $this->dom_document->replaceChild($fragment, $this->dom_document->firstChild);
        }
        
        $resources = $this->dom_xpath->query('//resource');
        foreach ($resources as $resource)
        {
            $source = $resource->getAttribute('source');
            // $type = $resource->getAttribute('type');
            if (! $type)
            {
                $type = ContentObjectRendition :: VIEW_INLINE;
            }
            
            $parameters_list = $this->dom_xpath->query('@*', $resource);
            $parameters = array();
            foreach ($parameters_list as $parameter)
            {
                $parameters[$parameter->name] = $parameter->value;
            }
            
            $object = RepositoryDataManager :: get_instance()->retrieve_content_object($source);
            if (! $object instanceof ContentObject)
            {
                continue;
            }
            $rendition = new DOMDocument();
            $rendition->loadHTML(ContentObjectRenditionImplementation :: factory($object, ContentObjectRendition :: FORMAT_HTML, $type, $this)->render($parameters));
            
            $rendition_xpath = new DOMXPath($rendition);
            
            $body_nodes = $rendition_xpath->query('body/*');
            $fragment = $rendition->createDocumentFragment();
            foreach ($body_nodes as $child)
            {
                $fragment->appendChild($child);
            }
            $fragment = $this->dom_document->importNode($fragment, true);
            
            $resource->parentNode->insertBefore($fragment, $resource);
            $resource->parentNode->removeChild($resource);
        
        }
        /**
         * Return iso-8859-1 encoded HTML entities to original UTF-8 encoding.
         */
        return mb_convert_encoding($this->dom_document->saveHTML(), 'UTF-8', 'html-entities');
    }
}
?>
