<?php
namespace repository;

use common\libraries\Path;

use core\lynx\package\Package;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\BreadcrumbTrail;
use common\libraries\Utilities;
use common\libraries\EqualityCondition;
use common\libraries\AndCondition;
use common\libraries\Theme;
use common\libraries\DynamicTabsRenderer;
use common\libraries\DynamicContentTab;

class ExternalInstanceManagerCreatorComponent extends ExternalInstanceManager
{

    function run()
    {
        $trail = BreadcrumbTrail :: get_instance();
        $trail->add_help('external_instance general');
        
        if (! $this->get_user()->is_platform_admin())
        {
            $this->not_allowed();
        }
        
        $type = Request :: get(ExternalInstanceManager :: PARAM_EXTERNAL_INSTANCE_TYPE);
        if ($type && ExternalInstanceManager :: exists($type))
        {
            $external_instance = new ExternalInstance();
            $external_instance->set_type($type);
            $form = new ExternalInstanceForm(ExternalInstanceForm :: TYPE_CREATE, $external_instance, $this->get_url(array(
                    ExternalInstanceManager :: PARAM_EXTERNAL_INSTANCE_TYPE => $type)));
            if ($form->validate())
            {
                $success = $form->create_external_instance();
                $this->redirect(Translation :: get($success ? 'ObjectAdded' : 'ObjectNotAdded', array(
                        'OBJECT' => Translation :: get('ExternalInstance')), Utilities :: COMMON_LIBRARIES), ($success ? false : true), array(
                        ExternalInstanceManager :: PARAM_INSTANCE_ACTION => ExternalInstanceManager :: ACTION_BROWSE_INSTANCES));
            }
            else
            {
                $this->display_header();
                $form->display();
                $this->display_footer();
            }
        }
        else
        {
            $instance_types = $this->get_external_instance_types();
            
            if (count($instance_types['sections']) == 0)
            {
                $this->display_header();
                $this->display_warning_message(Translation :: get('NoExternalInstancesAvailable'));
                $this->display_footer();
                exit();
            }
            
            $renderer_name = Utilities :: get_classname_from_object($this, true);
            $tabs = new DynamicTabsRenderer($renderer_name);
            
            foreach ($instance_types['sections'] as $category => $category_name)
            {
                $types_html = array();
                
                foreach ($instance_types['types'][$category] as $type => $registration)
                {
                    $types_html[] = '<a href="' . $this->get_url(array(
                            ExternalInstanceManager :: PARAM_EXTERNAL_INSTANCE_TYPE => $registration->get_context())) . '"><div class="create_block" style="background-image: url(' . Theme :: get_image_path($registration->get_context()) . 'logo/48.png);">';
                    $types_html[] = Translation :: get('TypeName', null, $registration->get_context());
                    $types_html[] = '</div></a>';
                }
                
                $tabs->add_tab(new DynamicContentTab($category, $category_name, Theme :: get_image_path(Utilities :: get_namespace_parent(Utilities :: get_namespace_parent($registration->get_context()))) . 'category_' . $category . '.png', implode("\n", $types_html)));
            }
            
            $this->display_header();
            echo $tabs->render();
            $this->display_footer();
        }
    }

    function get_external_instance_types()
    {
        $active_managers = ExternalInstanceManager :: get_registered_types();
        
        $types = array();
        $sections = array();
        
        while ($active_manager = $active_managers->next_result())
        {
            $package_info = Package :: get($active_manager->get_context());
            $section = $package_info->get_category() ? $package_info->get_category() : 'various';
            
            $path = Path :: namespace_to_full_path($active_manager->get_context());
            $dom_document = new \DOMDocument();
            $dom_document->load($path);
            $dom_x_path = new \DOMXPath($dom_document);
            $multiple_nodes = $dom_x_path->query('extra\multiple');
            if ($multiple_nodes->length == 1)
            {
                $multiple_node = $multiple_nodes->item(0)->nodeValue;
                if ($multiple_node == 1)
                {
                    $multiple = true;
                }
                else
                {
                    $multiple = false;
                }
            }
            else
            {
                $multiple = false;
            }
            
            $condition = new EqualityCondition(ExternalInstance :: PROPERTY_TYPE, $active_manager->get_context());
            $count = RepositoryDataManager :: get_instance()->count_external_instances($condition);
            
            if (! $multiple && $count > 0)
            {
                continue;
            }
            
            if (! in_array($section, array_keys($sections)))
            {
                $sections[$section] = Translation :: get('Category' . Utilities :: underscores_to_camelcase($section), null, Utilities :: get_namespace_parent(Utilities :: get_namespace_parent($package_info->get_context())));
            }
            
            if (! isset($types[$section]))
            {
                $types[$section] = array();
            }
            
            $types[$section][$active_manager->get_name()] = $active_manager;
            asort($types[$section]);
        }
        
        asort($sections);
        return array('sections' => $sections, 'types' => $types);
    }
}
?>