<?php
namespace repository;

use common\libraries\Utilities;
use common\libraries\ObjectTableCellRenderer;

use application\weblcms\WeblcmsDataManager;
use application\weblcms\course\CourseDataManager;

class DefaultLinkTableCellRenderer extends ObjectTableCellRenderer
{
    protected $type;
    private $browser;

    /**
     * Constructor
     */
    function __construct($browser, $type)
    {
        $this->type = $type;
        $this->browser = $browser;
    }

    /**
     * Renders a table cell
     * 
     * @param $column ContentObjectTableColumnModel
     *            The column which should be
     *            rendered
     * @param $content_object ContentObject
     *            The learning object to render
     * @return string A HTML representation of the rendered table cell
     */
    function render_cell($column, $object)
    {
        if ($this->type == LinkBrowserTable :: TYPE_PARENTS)
        {
            $object = RepositoryDataManager :: get_instance()->retrieve_content_object($object->get_parent());
        }
        
        if ($this->type == LinkBrowserTable :: TYPE_CHILDREN)
        {
            $object = RepositoryDataManager :: get_instance()->retrieve_content_object($object->get_ref());
            if (in_array($object->get_type(), RepositoryDataManager :: get_active_helper_types()))
            {
                $object = RepositoryDataManager :: get_instance()->retrieve_content_object($object->get_reference());
            }
        }
        
        switch ($column->get_name())
        {
            case ContentObjectPublicationAttributes :: PROPERTY_APPLICATION :
                return Utilities :: underscores_to_camelcase_with_spaces($object->get_application());
            case ContentObjectPublicationAttributes :: PROPERTY_LOCATION :
                $application = $object->get_application();
                
                if ($application == 'weblcms')
                {
                    $location = $object->get_location();
                    $codes = explode("&gt;", $location);
                    $course_id = trim($codes[0]);
                    $tool = trim($codes[1]);
                    
                    $wdm = CourseDataManager :: get_instance();
                    $course = $wdm->retrieve_course($course_id);
                    return $course->get_title() . ' > ' . $tool;
                }
                
                return $object->get_location();
            case ContentObjectPublicationAttributes :: PROPERTY_PUBLICATION_DATE :
                return date('Y-m-d, H:i', $object->get_publication_date());
            case ContentObject :: PROPERTY_DESCRIPTION :
                return Utilities :: truncate_string($object->get_description(), 50);
            case ContentObject :: PROPERTY_TITLE :
                $url = $this->browser->get_url(array(
                        RepositoryManager :: PARAM_ACTION => RepositoryManager :: ACTION_VIEW_CONTENT_OBJECTS, 
                        RepositoryManager :: PARAM_CONTENT_OBJECT_ID => $object->get_id()));
                return '<a href="' . $url . '">' . Utilities :: truncate_string($object->get_title(), 50) . '</a>';
            case ContentObject :: PROPERTY_TYPE :
                return $object->get_icon_image();
            default :
                return '&nbsp;';
        }
    }

    function render_id_cell($object)
    {
        if ($this->type == LinkBrowserTable :: TYPE_PUBLICATIONS)
        {
            $link_id = $object->get_application() . '|' . $object->get_id();
        }
        else
        {
            $link_id = $object->get_id();
        }
        
        return $link_id;
    }
}
?>