<?php
namespace repository;

use common\libraries\OptionsMenuRenderer;

use common\libraries\Application;
use common\libraries\DynamicTabsRenderer;
use common\libraries\Translation;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Utilities;
use common\libraries\TreeMenuRenderer;
use HTML_Menu;
use HTML_Menu_ArrayRenderer;

class ObjectTypeMenu extends HTML_Menu
{
    const TREE_NAME = __CLASS__;
    
    /**
     * The string passed to sprintf() to format category URLs
     */
    private $type_format;
    private $category_format;
    /**
     * The array renderer used to determine the breadcrumbs.
     */
    private $array_renderer;
    private $repository_manager;

    /**
     * Creates a new category navigation menu.
     *
     * @param $owner int
     *            The ID of the owner of the categories to provide in
     *            this menu.
     * @param $current_category int
     *            The ID of the current category in the menu.
     * @param $url_format string
     *            The format to use for the URL of a category.
     *            Passed to sprintf(). Defaults to the string
     *            "?category=%s".
     * @param $extra_items array
     *            An array of extra tree items, added to the
     *            root.
     * @param $filter_count_on_types string[]
     *            - Array to define the types on which the count on the
     *            categories should be filtered
     */
    function __construct($repository_manager, $current_type = null, $type_format = '?category=%s', $current_category = null, $category_format = '?category=%s')
    {
        $this->type_format = $type_format;
        $this->category_format = $category_format;
        $this->repository_manager = $repository_manager;
        parent :: __construct($this->get_menu_items());
        $this->array_renderer = new HTML_Menu_ArrayRenderer();
        if ($current_type)
        {
            $this->forceCurrentUrl($this->get_type_url($current_type));
        }
        else
        {
            $this->forceCurrentUrl($this->get_category_url($current_category));
        }
    
    }

    /**
     * Returns the menu items.
     *
     * @param $extra_items array
     *            An array of extra tree items, added to the
     *            root.
     * @return array An array with all menu items. The structure of this array
     *         is the structure needed by PEAR::HTML_Menu, on which this
     *         class is based.
     */
    private function get_menu_items()
    {
        $menu = array();
        $menu_item = array();
        
        $type_selector = new ContentObjectTypeSelector($this->repository_manager, RepositoryDataManager :: get_registered_types());
        $categories = $type_selector->as_array();
        foreach ($categories as $category => $types)
        {
            $menu_item = array();
            $menu_item['class'] = 'category_' . $category;
            $menu_item['title'] = Translation :: get(Utilities :: underscores_to_camelcase($category));
            $menu_item['url'] = $this->repository_manager->get_url(array(
                    DynamicTabsRenderer :: PARAM_SELECTED_TAB => 'object_type', 
                    RepositoryManager :: PARAM_CONTENT_OBJECT_CATEGORY => $category, 
                    DynamicTabsRenderer :: PARAM_SELECTED_TAB => 'object_type', 
                    Application :: PARAM_ACTION => RepositoryManager :: ACTION_BROWSE_CONTENT_OBJECTS), array(
                    RepositoryManager :: PARAM_CATEGORY_ID, RepositoryManager :: PARAM_CONTENT_OBJECT_ID));
            $menu_item[OptionsMenuRenderer :: KEY_ID] = $category;
            
            $sub_menu_items = array();
            foreach ($types as $type => $name)
            {
                $sub_menu_item = array();
                $sub_menu_item['title'] = $name;
                $sub_menu_item['url'] = $this->repository_manager->get_url(array(
                        DynamicTabsRenderer :: PARAM_SELECTED_TAB => 'object_type', 
                        RepositoryManager :: PARAM_CONTENT_OBJECT_TYPE => $type, 
                        DynamicTabsRenderer :: PARAM_SELECTED_TAB => 'object_type', 
                        Application :: PARAM_ACTION => RepositoryManager :: ACTION_BROWSE_CONTENT_OBJECTS), array(
                        RepositoryManager :: PARAM_CATEGORY_ID, RepositoryManager :: PARAM_CONTENT_OBJECT_ID));
                $sub_menu_item[OptionsMenuRenderer:: KEY_ID] = $type;
                $sub_menu_item['class'] = 'type_' . $type;
                $sub_menu_items[] = $sub_menu_item;
            }
            $menu_item['sub'] = $sub_menu_items;
            
            $menu[] = $menu_item;
        }
        
        // while ($userview = $userviews->next_result())
        // {
        // $menu_item = array();
        // $menu_item['title'] = $userview->get_name();
        // $menu_item['url'] = $this->repository_manager->get_url(array(
        // RepositoryManager :: PARAM_USER_VIEW => $userview->get_id()));
        // $menu_item['class'] = '';
        // $menu_item[OptionsMenuRenderer :: KEY_ID] = $userview->get_id();
        // $menu[] = $menu_item;
        //
        // }
        //
        // $menu_item['title'] = Translation :: get('MyRepository')/* . ' (' .
        // $count . ')' */;
        // $menu_item['url'] = $this->get_category_url(0);
        //
        // if (RepositoryDataManager :: user_has_categories($this->owner))
        // {
        // $sub_menu_items = $this->get_sub_menu_items();
        // if (count($sub_menu_items) > 0)
        // {
        // $menu_item['sub'] = $sub_menu_items;
        // }
        // }
        // $menu_item['class'] = 'category';
        // $menu_item[OptionsMenuRenderer :: KEY_ID] = 0;
        // $menu[0] = $menu_item;
        return $menu;
    }

    /**
     * Gets the URL of a given category
     *
     * @param $category int
     *            The id of the category
     * @return string The requested URL
     */
    private function get_category_url($category)
    {
        // TODO: Put another class in charge of the htmlentities() invocation
        return (str_replace('__category__', $category, $this->category_format));
    }

    private function get_type_url($type)
    {
        // TODO: Put another class in charge of the htmlentities() invocation
        return (str_replace('__type__', $type, $this->type_format));
    }

    /**
     * Get the breadcrumbs which lead to the current category.
     *
     * @return array The breadcrumbs.
     */
    function get_breadcrumbs()
    {
        $trail = BreadcrumbTrail :: get_instance();
        $this->render($this->array_renderer, 'urhere');
        $breadcrumbs = $this->array_renderer->toArray();
        foreach ($breadcrumbs as $crumb)
        {
            $str = Translation :: get('MyRepository');
            if (substr($crumb['title'], 0, strlen($str)) == $str)
                continue;
            $trail->add(new Breadcrumb($crumb['url'], substr($crumb['title'], 0, strpos($crumb['title'], '('))));
        }
        return $trail;
    }

    /**
     * Renders the menu as a tree
     *
     * @return string The HTML formatted tree
     */
    function render_as_tree()
    {
        $renderer = new TreeMenuRenderer($this->get_tree_name());
        $this->render($renderer, 'sitemap');
        return $renderer->toHTML();
    }

    static function get_tree_name()
    {
        return Utilities :: get_classname_from_namespace(self :: TREE_NAME, true);
    }

}

?>