<?php
namespace repository;

use common\libraries\CommonDataManager;

use home\HomeBlockConfig;

use common\libraries\ComplexContentObjectSupport;
use common\libraries\SubselectCondition;
use common\libraries\Configuration;
use common\libraries\Utilities;
use common\libraries\EqualityCondition;
use common\libraries\WebApplication;
use common\libraries\AndCondition;
use common\libraries\OrCondition;
use common\libraries\InCondition;
use common\libraries\InequalityCondition;

use common\libraries\Registration;
use admin\AdminDataManager;
use admin\AdminManager;

use repository\content_object\learning_path_item\LearningPathItem;
use repository\content_object\document\Document;

use group\Group;
use group\GroupDataManager;

use user\UserDataManager;
use user\User;

use rights\UserEntity;
use rights\PlatformGroupEntity;

class RepositoryDataManager
{
    private static $instance;
    
    private $typeProperties;
    
    private static $applications = array();
    private static $number_of_categories;
    private static $registered_types;
    private static $helper_types;
    private static $user_has_categories;

    /**
     * Constructor.
     */
    public function __construct()
    {
        self :: $applications = array();
    }

    static function get_instance()
    {
        if (! isset(self :: $instance))
        {
            $type = Configuration :: get_instance()->get_parameter('general', 'data_manager');
            $class = __NAMESPACE__ . '\\' . Utilities :: underscores_to_camelcase($type) . 'RepositoryDataManager';
            self :: $instance = new $class();
        }
        return self :: $instance;
    }

    public static function get_registered_types($show_active_only = true)
    {
        if (! (self :: $registered_types))
        {
            $registrations = CommonDataManager :: get_registrations_by_type(__NAMESPACE__ . '\\content_object');
            $types = array();
            
            foreach ($registrations as $registration)
            {
                if (! $show_active_only || $registration->is_active())
                {
                    $types[] = $registration->get_name();
                }
            }
            
            self :: $registered_types = $types;
        }
        return self :: $registered_types;
    }

    static function get_active_helper_types()
    {
        if (! isset(self :: $helper_types))
        {
            $registrations = CommonDataManager :: get_registrations_by_type(__NAMESPACE__ . '\\content_object');
            foreach ($registrations as $registration)
            {
                if ($registration->get_category() == 'helper')
                {
                    $types[] = $registration->get_name();
                }
            }
            self :: $helper_types = $types;
        }
        return self :: $helper_types;
    }

    public static function is_extended_type($type)
    {
        $temp_class = ContentObject :: factory($type);
        
        if (! $temp_class)
        {
            return false;
        }
        
        $has_additional_properties = count($temp_class->get_additional_property_names()) > 0;
        unset($temp_class);
        return $has_additional_properties;
    }

    public static function is_content_object_editable($id)
    {
        $applications = self :: get_registered_applications();
        
        $result = false;
        foreach ($applications as $index => $application_name)
        {
            $result = call_user_func(array(
                    WebApplication :: determine_namespace($application_name) . '\\' . WebApplication :: get_application_class_name($application_name), 
                    'is_content_object_editable'), $id);
            if ($result)
            {
                return true;
            }
        }
        
        return true;
    }

    public static function content_object_is_published($id)
    {
        $applications = self :: get_registered_applications();
        $result = false;
        foreach ($applications as $index => $application_name)
        {
            $result = call_user_func(array(
                    Webapplication :: determine_namespace($application_name) . '\\' . WebApplication :: get_application_class_name($application_name), 
                    'content_object_is_published'), $id);
            if ($result)
            {
                return true;
            }
        }
        return false;
    }

    public static function any_content_object_is_published($ids)
    {
        $applications = self :: get_registered_applications();
        $result = false;
        foreach ($applications as $index => $application_name)
        {
            $result = call_user_func(array(
                    Webapplication :: determine_namespace($application_name) . '\\' . WebApplication :: get_application_class_name($application_name), 
                    'any_content_object_is_published'), $ids);
            if ($result)
            {
                return true;
            }
        }
        
        if (AdminManager :: any_content_object_is_published($ids))
        {
            return true;
        }
        
        return false;
    }

    public static function get_content_object_publication_attributes($user, $id, $type = null, $offset = null, $count = null, $order_property = null)
    {
        $applications = self :: get_registered_applications();
        $info = array();
        foreach ($applications as $application_name)
        {
            $attributes = call_user_func(array(
                    Webapplication :: determine_namespace($application_name) . '\\' . WebApplication :: get_application_class_name($application_name), 
                    'get_content_object_publication_attributes'), $id, $type, $offset, $count, $order_property);
            if (! is_null($attributes) && count($attributes) > 0)
            {
                $info = array_merge($info, $attributes);
            }
        }
        
        $attributes = AdminManager :: get_content_object_publication_attributes($id, $type, $offset, $count, $order_property);
        if (! is_null($attributes) && count($attributes) > 0)
        {
            $info = array_merge($info, $attributes);
        }
        
        return $info;
    }

    public static function get_content_object_publication_attribute($id, $application, $user)
    {
        return call_user_func(array(
                Webapplication :: determine_namespace($application) . '\\' . WebApplication :: get_application_class_name($application), 
                'get_content_object_publication_attribute'), $id);
    }

    public static function content_object_deletion_allowed($object, $type = null)
    {
        if ($object->get_owner_id() == 0)
            return true;
        
        $conditions[] = new EqualityCondition('variable', 'use_object');
        $conditions[] = new EqualityCondition('value', $object->get_id());
        $condition = new AndCondition($conditions);
        
        $blockinfos = \home\DataManager :: retrieves(HomeBlockConfig :: class_name(), $condition);
        if ($blockinfos->size() > 0)
        {
            return false;
        }
        
        if (isset($type))
        {
            if (self :: get_instance()->is_attached($object, 'version'))
            {
                return false;
            }
            $forbidden = array();
            $forbidden[] = $object->get_id();
        }
        else
        {
            if (self :: get_instance()->is_attached($object))
            {
                return false;
            }
            $children = array();
            // $children = self :: get_instance()->get_children_ids($object);
            $versions = array();
            $versions = self :: get_instance()->get_version_ids($object);
            $forbidden = array_merge($children, $versions);
        }
        
        if (self :: get_instance()->is_content_object_included($object))
        {
            return false;
        }
        
        $conditions = array();
        $conditions[] = new EqualityCondition(ComplexContentObjectItem :: PROPERTY_REF, $object->get_id());
        $conditions[] = new EqualityCondition(ComplexContentObjectItem :: PROPERTY_PARENT, $object->get_id(), ComplexContentObjectItem :: get_table_name());
        $condition = new OrCondition($conditions);
        $count_wrapper_items = self :: get_instance()->count_complex_content_object_items($condition);
        if ($count_wrapper_items > 0)
        {
            return false;
        }
        
        $wrapper_types = self :: get_active_helper_types();
        
        foreach ($wrapper_types as $wrapper_type)
        {
            $count_wrapper_items = self :: get_instance()->count_type_content_objects($wrapper_type, new EqualityCondition(LearningPathItem :: PROPERTY_REFERENCE, $object->get_id(), $wrapper_type));
            if ($count_wrapper_items > 0)
            {
                return false;
            }
        }
        
        $count_children = self :: get_instance()->count_complex_content_object_items(new EqualityCondition(ComplexContentObjectItem :: PROPERTY_PARENT, $object->get_id(), ComplexContentObjectItem :: get_table_name()));
        if ($count_children > 0)
        {
            return false;
        }
        
        return ! self :: any_content_object_is_published($forbidden);
    }

    public static function copy_complex_content_object($clo)
    {
        $clo->create_all();
        self :: copy_complex_children($clo);
        return $clo;
    }

    public static function copy_complex_children($clo)
    {
        $condition = new EqualityCondition(ComplexContentObjectItem :: PROPERTY_PARENT, $clo->get_id(), ComplexContentObjectItem :: get_table_name());
        $items = self :: get_instance()->retrieve_complex_content_object_items($condition);
        while ($item = $items->next_result())
        {
            $nitem = new ComplexContentObjectItem();
            $nitem->set_user_id($item->get_user_id());
            $nitem->set_display_order($item->get_display_order());
            $nitem->set_parent($clo->get_id());
            $nitem->set_ref($item->get_ref());
            $nitem->create();
            $lo = self :: get_instance()->retrieve_content_object($item->get_ref());
            if ($lo instanceof ComplexContentObjectSupport)
            {
                $lo->create_all();
                $nitem->set_ref($lo->get_id());
                $nitem->update();
                self :: copy_complex_content_object($lo);
            }
        }
    }

    /**
     * Determines whether a version is revertable.
     *
     * @param $object ContentObject           
     * @return boolean True if the given learning object version can be reverted
     */
    public static function content_object_revert_allowed($object)
    {
        return ! $object->is_latest_version();
    }

    /**
     * Returns the number of learning objects that match the given criteria.
     * This method has the same limitations as
     * retrieve_content_objects.
     *
     * @param $type string
     *            The type of learning objects to search for, if any. If you do
     *            not specify a type, or the type
     *            is not known in advance, you will only be able to select on
     *            default properties; also, there will be a
     *            significant performance decrease.
     * @param $condition Condition
     *            The condition to use for learning object selection, structured
     *            as a Condition object.
     *            Please consult the appropriate documentation.
     * @param $state int
     *            The state the learning objects should have. Any of the
     *            ContentObject :: STATE_* constants. A
     *            negative number means the state should be ignored. Defaults to
     *            ContentObject :: STATE_NORMAL. You can
     *            just as easily use your own condition for this; this parameter
     *            is merely for convenience, and to
     *            ensure that the function does not apply to recycled objects by
     *            default.
     * @return int The number of matching learning objects.
     */
    public static function count_publication_attributes($user, $object_id, $condition = null)
    {
        $applications = self :: get_registered_applications();
        $info = 0;
        foreach ($applications as $index => $application_name)
        {
            $info += call_user_func(array(
                    Webapplication :: determine_namespace($application_name) . '\\' . WebApplication :: get_application_class_name($application_name), 
                    'count_publication_attributes'), $user, $object_id, $condition);
        }
        
        $info += AdminManager :: count_publication_attributes($user, $object_id, $condition);
        
        return $info;
    }

    /**
     * Updates the given learning object publications learning object id.
     *
     * @param $object ContentObjectPublicationAttribute
     *            The learning object publication attribute.
     * @return boolean True if the update succceeded, false otherwise.
     */
    public static function update_content_object_publication_id($publication_attr)
    {
        return call_user_func(array(
                Webapplication :: determine_namespace($publication_attr->get_application()) . '\\' . WebApplication :: get_application_class_name($publication_attr->get_application()), 
                'update_content_object_publication_id'), $publication_attr);
    }

    /**
     * Deletes all learning objects a user_id has: Retrieves the learning
     * object(s) a user has made, deletes the
     * publications made with these object(s), and finally, deletes the object
     * itself.
     */
    public static function delete_content_object_by_user($user_id)
    {
        $content_object = self :: get_instance()->retrieve_content_object_by_user($user_id);
        while ($object = $content_object->next_result())
        {
            if (! self :: delete_content_object_publications($object))
            {
                return false;
            }
            if (! $object->delete())
            {
                return false;
            }
        }
        return true;
    }

    public static function delete_content_object_publications($object)
    {
        $applications = self :: get_registered_applications();
        foreach ($applications as $index => $application_name)
        {
            call_user_func(array(
                    Webapplication :: determine_namespace($application_name) . '\\' . WebApplication :: get_application_class_name($application_name), 
                    'delete_content_object_publications'), $object->get_id());
        }
        
        $admin = AdminDataManager :: get_instance()->delete_content_object_publications($object->get_id());
        
        return true;
    }

    public static function delete_content_object_publication($application, $publication_id)
    {
        return call_user_func(array(
                Webapplication :: determine_namespace($application) . '\\' . WebApplication :: get_application_class_name($application), 
                'delete_content_object_publication'), $publication_id);
    }

    /**
     * Checks if an identifier is a valid name for a learning object type.
     *
     * @param $name string
     *            The name.
     * @return boolean True if a valid learning object type name was passed,
     *         false otherwise.
     */
    public static function is_content_object_type_name($name)
    {
        return (preg_match('/^[a-z][a-z_]+$/', $name) > 0);
    }

    /**
     * Returns the names of the applications known to this repository
     * datamanager.
     *
     * @return array The applications.
     */
    public static function get_registered_applications()
    {
        if (! isset(self :: $applications) || count(self :: $applications) == 0)
        {
            self :: $applications = WebApplication :: load_all();
        }
        
        return self :: $applications;
    }

    public static function delete_clois_for_content_object($content_object)
    {
        $conditions[] = new EqualityCondition(ComplexContentObjectItem :: PROPERTY_REF, $content_object->get_id());
        $conditions[] = new EqualityCondition(ComplexContentObjectItem :: PROPERTY_PARENT, $content_object->get_id(), ComplexContentObjectItem :: get_table_name());
        $condition = new OrCondition($conditions);
        
        return self :: get_instance()->delete_complex_content_object_items($condition);
    }

    /**
     * Gets the number of categories the user has defined in his repository
     *
     * @param $user_id int           
     * @return int
     */
    public static function get_number_of_categories($user_id)
    {
        if (! isset(self :: $number_of_categories{$user_id}))
        {
            $condition = new EqualityCondition(RepositoryCategory :: PROPERTY_USER_ID, $user_id);
            // self :: get_instance()->number_of_categories{$user_id} = self ::
            // get_instance()->count_type_content_objects('category',
            // $condition);
            self :: $number_of_categories[$user_id] = self :: get_instance()->count_categories($condition);
        }
        return self :: $number_of_categories{$user_id};
    }

    public static function get_content_object_managers()
    {
        // $active_objects = self :: get_registered_types();
        $managers = array();
        
        // foreach ($active_objects as $active_object)
        // {
        // $active_object_managers = call_user_func(array(ContentObject ::
        // type_to_class($active_object),
        // 'get_managers'));
        // if (count($active_object_managers) > 0)
        // {
        // $managers[$active_object] = $active_object_managers;
        // }
        // }
        
        return $managers;
    }

    static function get_document_id_by_hash($hash)
    {
        $condition = new EqualityCondition(Document :: PROPERTY_HASH, $hash);
        $document = self :: get_instance()->retrieve_content_objects($condition)->next_result();
        
        if ($document)
        {
            return $document->get_id();
        }
        
        return false;
    }

    /**
     * retrieve category if the category does not exist, create a new category
     * return the id
     */
    static function get_repository_category_by_name_or_create_new($user_id, $title, $parent_id = 0, $create_in_batch = false)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(RepositoryCategory :: PROPERTY_NAME, $title);
        $conditions[] = new EqualityCondition(RepositoryCategory :: PROPERTY_USER_ID, $user_id);
        $conditions[] = new EqualityCondition(RepositoryCategory :: PROPERTY_PARENT, $parent_id);
        $condition = new AndCondition($conditions);
        
        $category = self :: get_instance()->retrieve_categories($condition)->next_result();
        if (! $category)
        {
            $category = new RepositoryCategory();
            $category->set_user_id($user_id);
            $category->set_name($title);
            $category->set_parent($parent_id);
            $category->set_type(RepositoryCategory::TYPE_NORMAL);
            
            // Create category in database
            $category->create($create_in_batch);
        }
        
        return $category->get_id();
    }

    static function retrieve_document_from_hash($user_id, $hash)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(Document :: PROPERTY_HASH, $hash, 'document');
        $conditions[] = new EqualityCondition(ContentObject :: PROPERTY_OWNER_ID, $user_id);
        $condition = new AndCondition($conditions);
        
        return self :: get_instance()->retrieve_content_object_by_condition($condition, 'document');
    }

    static function get_document_by_filename($filename)
    {
        $condition = new EqualityCondition(Document :: PROPERTY_FILENAME, $filename, 'document');
        return self :: get_instance()->retrieve_content_object_by_condition($condition, 'document');
    }

    /**
     * Checks wheter the given type is a helper type
     *
     * @param $type String           
     * @return boolean
     */
    static function is_helper_type($type)
    {
        $helper_types = self :: get_active_helper_types();
        return in_array($type, $helper_types);
    }

    /**
     *
     * @param $user User           
     * @param $object ContentObject           
     */
    static function is_object_shared_with_user($user, $object)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(ContentObjectUserShare :: PROPERTY_CONTENT_OBJECT_ID, $object->get_id());
        $conditions[] = new EqualityCondition(ContentObjectUserShare :: PROPERTY_USER_ID, $user->get_id());
        $condition = new AndCondition($conditions);
        $count = self :: get_instance()->count_content_object_user_shares($condition);
        if ($count > 0)
        {
            return true;
        }
        
        $groups = $user->get_groups(true);
        
        $conditions = array();
        $conditions[] = new EqualityCondition(ContentObjectGroupShare :: PROPERTY_CONTENT_OBJECT_ID, $object->get_id());
        $conditions[] = new InCondition(ContentObjectGroupShare :: PROPERTY_GROUP_ID, $groups);
        $condition = new AndCondition($conditions);
        $count = self :: get_instance()->count_content_object_user_shares($condition);
        if ($count > 0)
        {
            return true;
        }
        
        return false;
    }

    static function user_has_categories($user_id)
    {
        if (is_null(self :: $user_has_categories))
        {
            $condition = new EqualityCondition(RepositoryCategory :: PROPERTY_USER_ID, $user_id);
            self :: $user_has_categories = (self :: get_instance()->count_categories($condition) > 0);
        }
        
        return self :: $user_has_categories;
    }

    static function retrieve_content_objects_for_user($user_id)
    {
        $condition = new EqualityCondition(ContentObject :: PROPERTY_OWNER_ID, $user_id);
        return self :: get_instance()->retrieve_content_objects($condition);
    }

    static function get_content_object_user_shares($content_object_id, $user_id)
    {
        $shares = RepositoryRights :: get_instance()->get_share_target_entities_overview($content_object_id, RepositoryRights :: TYPE_USER_CONTENT_OBJECT, $user_id);
        $in_condition = new InCondition(User :: PROPERTY_ID, $shares[UserEntity :: ENTITY_TYPE]);
        
        return UserDataManager :: get_instance()->retrieve_users($in_condition);
    }

    static function get_content_object_group_shares($content_object_id, $user_id)
    {
        $shares = RepositoryRights :: get_instance()->get_share_target_entities_overview($content_object_id, RepositoryRights :: TYPE_USER_CONTENT_OBJECT, $user_id);
        
        $in_condition = new InCondition(Group :: PROPERTY_ID, $shares[PlatformGroupEntity :: ENTITY_TYPE]);
        
        return GroupDataManager :: get_instance()->retrieve_groups($in_condition);
    }

    static function count_content_object_user_shares($content_object_id, $user_id)
    {
        $shares = RepositoryRights :: get_instance()->get_share_target_entities_overview($content_object_id, RepositoryRights :: TYPE_USER_CONTENT_OBJECT, $user_id);
        
        return count(array_unique($shares[UserEntity :: ENTITY_TYPE]));
    }

    static function count_content_object_group_shares($content_object_id, $user_id)
    {
        $shares = RepositoryRights :: get_instance()->get_share_target_entities_overview($content_object_id, RepositoryRights :: TYPE_USER_CONTENT_OBJECT, $user_id);
        
        return count(array_unique($shares[PlatformGroupEntity :: ENTITY_TYPE]));
    }

    static function retrieve_recycled_content_objects_from_category($category_id)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(ContentObject :: PROPERTY_PARENT_ID, $category_id);
        $conditions[] = new EqualityCondition(ContentObject :: PROPERTY_STATE, ContentObject :: STATE_RECYCLED);
        $condition = new AndCondition($conditions);
        
        return self :: get_instance()->retrieve_content_objects($condition);
    }

    static function deactivate_external_instance_objects($external_instance_id, $user_id, $external_user_id)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(ExternalSync :: PROPERTY_EXTERNAL_ID, $external_instance_id);
        $conditions[] = new EqualityCondition(ExternalSync :: PROPERTY_EXTERNAL_USER_ID, $external_user_id);
        $conditions[] = new SubselectCondition(ExternalSync :: PROPERTY_CONTENT_OBJECT_ID, ContentObject :: PROPERTY_ID, ContentObject :: get_table_name(), new EqualityCondition(ContentObject :: PROPERTY_OWNER_ID, $user_id), null, RepositoryDataManager :: get_instance());
        $condition = new AndCondition($conditions);
        
        $properties = array();
        $properties[ExternalSync :: PROPERTY_STATE] = ExternalSync :: STATE_INACTIVE;
        
        return self :: get_instance()->update_external_instance_objects($condition, $properties);
    }

    static function activate_external_instance_objects($external_instance_id, $user_id, $external_user_id)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(ExternalSync :: PROPERTY_EXTERNAL_ID, $external_instance_id);
        $conditions[] = new EqualityCondition(ExternalSync :: PROPERTY_EXTERNAL_USER_ID, $external_user_id);
        $conditions[] = new SubselectCondition(ExternalSync :: PROPERTY_CONTENT_OBJECT_ID, ContentObject :: PROPERTY_ID, ContentObject :: get_table_name(), new EqualityCondition(ContentObject :: PROPERTY_OWNER_ID, $user_id), null, RepositoryDataManager :: get_instance());
        $condition = new AndCondition($conditions);
        
        $properties = array();
        $properties[ExternalSync :: PROPERTY_STATE] = ExternalSync :: STATE_ACTIVE;
        
        return self :: get_instance()->update_external_instance_objects($condition, $properties);
    
    }

    /**
     * Checks if the attachment id is attached to the given content object id
     *
     * @param $attachment_id type           
     * @param $content_object_id type           
     * @return Boolean
     */
    static function is_object_attached_to($attachment_id, $content_object_id)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(ContentObjectAttachment :: PROPERTY_ATTACHMENT_ID, $attachment_id);
        $conditions[] = new EqualityCondition(ContentObjectAttachment :: PROPERTY_CONTENT_OBJECT_ID, $content_object_id);
        $condition = new AndCondition($conditions);
        
        $number_of_attachments = self :: get_instance()->count_content_object_attachments($condition);
        if ($number_of_attachments > 0)
        {
            return true;
        }
        else
        {
            return false;
        }
    
    }

    /**
     * Recursive method to check all the attachments and includes of a content
     * object to see if the check content object
     * is attached or included in the given content object
     *
     * @param $content_object_id int           
     * @param $check_content_object_id int           
     *
     * @return boolean
     */
    static function is_attached_or_included_to($content_object_id, $check_content_object_id)
    {
        $content_object = self :: get_instance()->retrieve_content_object($content_object_id);
        
        if (self :: is_object_attached_to($check_content_object_id, $content_object_id))
        {
            return true;
        }
        
        if (self :: get_instance()->is_content_object_already_included($content_object, $check_content_object_id))
        {
            return true;
        }
        
        $attachment_ids = $content_object->get_attached_content_object_ids();
        foreach ($attachment_ids as $attachment_id)
        {
            if (self :: is_attached_or_included_to($attachment_id, $check_content_object_id))
            {
                return true;
            }
        }
        
        $included_objects = $content_object->get_included_content_objects();
        foreach ($included_objects as $included_object)
        {
            if (self :: is_attached_or_included_to($included_object->get_id(), $check_content_object_id))
            {
                return true;
            }
        }
        
        return false;
    
    }

    /**
     * Recursive method to check all the children (complex content object items)
     * of a content object to see if the check
     * content object is a child of the given content object
     *
     * @param $content_object_id int           
     * @param $check_content_object_id int           
     *
     * @return boolean
     */
    static function is_child_of_content_object($content_object_id, $check_content_object_id)
    {
        if (self :: complex_content_object_item_exists_for_ref_and_parent($check_content_object_id, $content_object_id))
        {
            return true;
        }
        
        $condition = new EqualityCondition(ComplexContentObjectItem :: PROPERTY_PARENT, $content_object_id);
        $complex_content_object_items = self :: get_instance()->retrieve_complex_content_object_items($condition);
        while ($complex_content_object_item = $complex_content_object_items->next_result())
        {
            if (self :: is_child_of_content_object($complex_content_object_item->get_ref(), $check_content_object_id))
            {
                return true;
            }
        }
        
        return false;
    }

    /**
     * Checks if there is a complex content object item for the given ref and
     * parent id
     *
     * @param $ref_id int           
     * @param $parent_id int           
     */
    static function complex_content_object_item_exists_for_ref_and_parent($ref_id, $parent_id)
    {
        $conditions = array();
        
        $conditions[] = new EqualityCondition(ComplexContentObjectItem :: PROPERTY_REF, $ref_id);
        $conditions[] = new EqualityCondition(ComplexContentObjectItem :: PROPERTY_PARENT, $parent_id);
        
        $condition = new AndCondition($conditions);
        
        return (self :: get_instance()->count_complex_content_object_items($condition) > 0);
    }

    /**
     * Deletes a category recursivly and unlinks all the contained content
     * objects
     *
     * @param $category type           
     * @param $fix_display_order type           
     * @return boolean
     */
    static function delete_category_recursive($category, $fix_display_order = true)
    {
        $repository_data_manager = self :: get_instance();
        $succes = true;
        
        // Retrieve the objects and unlink them
        $condition = new EqualityCondition(ContentObject :: PROPERTY_PARENT_ID, $category->get_id());
        $content_objects = $repository_data_manager->retrieve_content_objects($condition);
        
        while ($content_object = $content_objects->next_result())
        {
            $versions = $content_object->get_content_object_versions();
            foreach ($versions as $version)
            {
                if (! $version->delete_links())
                {
                    $succes = false;
                }
                if (! $version->move(0)) // move is needed, otherwise the rights
                                         // locations will be removed
                {
                    $succes = false;
                }
                if (! $version->recycle())
                {
                    $succes = false;
                }
            }
        }
        
        // delete the category
        $condition = new EqualityCondition(RepositoryCategory :: PROPERTY_ID, $category->get_id());
        $succes = self :: get_instance()->delete(RepositoryCategory :: get_table_name(), $condition);
        
        // the ordering should only be fixed on the top level (down levels are
        // always deleted)
        if ($fix_display_order)
        {
            // Correct the display order of the remaining categories
            self :: fix_category_display_order($category);
        }
        
        // Delete all subcategories by recursively repeating the entire process
        $categories = $repository_data_manager->retrieve_categories(new EqualityCondition(RepositoryCategory :: PROPERTY_PARENT, $category->get_id()));
        while ($category = $categories->next_result())
        {
            if (! self :: delete_category_recursive($category, false))
            {
                $succes = false;
            }
        
        }
        
        return $succes;
    }

    static function delete_share_category_recursive($category, $fix_display_order = true)
    {
        $repository_data_manager = self :: get_instance();
        $succes = true;
        
        // Remove the relations
        $condition = new EqualityCondition(SharedContentObjectRelCategory :: PROPERTY_CATEGORY_ID, $category->get_id());
        $succes = $repository_data_manager->delete_objects(SharedContentObjectRelCategory :: get_table_name(), $condition);
        
        // delete the category
        $condition = new EqualityCondition(RepositoryCategory :: PROPERTY_ID, $category->get_id());
        $succes &= self :: get_instance()->delete(RepositoryCategory :: get_table_name(), $condition);
        
        // the ordering should only be fixed on the top level (down levels are
        // always deleted)
        if ($fix_display_order)
        {
            // Correct the display order of the remaining categories
            self :: fix_category_display_order($category);
        }
        
        // Delete all subcategories by recursively repeating the entire process
        $categories = $repository_data_manager->retrieve_categories(new EqualityCondition(RepositoryCategory :: PROPERTY_PARENT, $category->get_id()));
        while ($category = $categories->next_result())
        {
            if (! self :: delete_share_category_recursive($category, false))
            {
                $succes = false;
            }
        
        }
        
        return $succes;
    }

    private static function fix_category_display_order($category)
    {
        $conditions = array();
        $conditions[] = new InequalityCondition(RepositoryCategory :: PROPERTY_DISPLAY_ORDER, InequalityCondition :: GREATER_THAN, $category->get_display_order());
        $conditions[] = new EqualityCondition(RepositoryCategory :: PROPERTY_PARENT, $category->get_parent());
        $conditions[] = new EqualityCondition(RepositoryCategory :: PROPERTY_USER_ID, $category->get_user_id());
        $condition = new AndCondition($conditions);
        
        $properties = array(
                RepositoryCategory :: PROPERTY_DISPLAY_ORDER => (self :: get_instance()->escape_column_name(RepositoryCategory :: PROPERTY_DISPLAY_ORDER) . '-1'));
        
        self :: get_instance()->update_objects(RepositoryCategory :: get_table_name(), $properties, $condition);
    }

    /**
     * Retrieves the relation object for a given user and content object
     *
     * @param $user_id type           
     * @param $content_object_id type           
     * @return DataClass
     */
    static function retrieve_shared_content_object_rel_category_for_user_and_content_object($user_id, $content_object_id)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(SharedContentObjectRelCategory :: PROPERTY_CONTENT_OBJECT_ID, $content_object_id);
        $conditions[] = new EqualityCondition(RepositoryCategory :: PROPERTY_USER_ID, $user_id, RepositoryCategory :: get_table_name(), false);
        $condition = new AndCondition($conditions);
        
        return self :: get_instance()->retrieve_shared_content_object_rel_categories($condition)->next_result();
    }

    static function deactivate_content_object_type($type)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(ContentObject :: PROPERTY_TYPE, Utilities :: get_package_name_from_namespace($type));
        $conditions[] = new InCondition(ContentObject :: PROPERTY_STATE, ContentObject :: get_active_status_types());
        $condition = new AndCondition($conditions);
        
        return self :: get_instance()->deactivate_content_object_type($condition);
    }

    static function activate_content_object_type($type)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(ContentObject :: PROPERTY_TYPE, Utilities :: get_package_name_from_namespace($type));
        $conditions[] = new InCondition(ContentObject :: PROPERTY_STATE, ContentObject :: get_inactive_status_types());
        $condition = new AndCondition($conditions);
        
        return self :: get_instance()->activate_content_object_type($condition);
    }

    static function create_unique_category_name($user_id, $parent_id, $category_name)
    {
        $index = 0;
        $old_category_name = $category_name;
        while (self :: check_category_name($user_id, $parent_id, $category_name))
        {
            $category_name = $old_category_name . ' (' . ++ $index . ')';
        }
        return $category_name;
    }

    static function check_category_name($user_id, $parent_id, $category_name)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(RepositoryCategory :: PROPERTY_NAME, $category_name);
        $conditions[] = new EqualityCondition(RepositoryCategory :: PROPERTY_PARENT, $parent_id);
        $conditions[] = new EqualityCondition(RepositoryCategory :: PROPERTY_USER_ID, $user_id);
        $conditions[] = new EqualityCondition(RepositoryCategory :: PROPERTY_TYPE, RepositoryCategory :: TYPE_NORMAL);
        $condition = new AndCondition($conditions);
        
        return RepositoryDataManager :: get_instance()->count_categories($condition) > 0;
    }
}
?>