<?php
namespace repository;

use common\libraries\DelegateComponent;
use common\libraries\CommonDataManager;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Request;
use common\libraries\Utilities;
use common\libraries\EqualityCondition;
use common\libraries\Session;
use common\libraries\ResourceManager;
use common\libraries\Translation;
use common\libraries\ActionBarRenderer;
use common\libraries\ToolbarItem;
use common\libraries\Theme;
use common\libraries\Application;
use common\libraries\BasicApplication;
use common\libraries\NotCondition;
use common\libraries\InCondition;
use common\libraries\AndCondition;
use common\libraries\OrCondition;
use common\libraries\PatternMatchCondition;

use admin\AdminDataManager;
use common\libraries\Registration;

/**
 * $Id: browser.class.php 204 2009-11-13 12:51:30Z kariboe $
 *
 * @package repository.lib.repository_manager.component
 */
/**
 * Default repository manager component which allows the user to browse through the different categories and content
 * objects in the repository.
 */
class RepositoryManagerBrowserComponent extends RepositoryManager implements DelegateComponent
{
    private $form;
    private $action_bar;

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        if ($this->get_user()->is_anonymous_user())
        {
            // TODO: anonmymous user should not be here
            return null;
        }
        else
        {
            $trail = BreadcrumbTrail :: get_instance();

            $output = $this->get_content_objects_html();

            $query = $this->get_action_bar()->get_query();
            if (isset($query) && $query != '')
            {
                $trail->add(
                        new Breadcrumb($this->get_url(),
                                Translation :: get('SearchResultsFor', null, Utilities :: COMMON_LIBRARIES) . ' ' . $query));
            }

            $session_filter = Session :: retrieve('filter');

            if ($session_filter != null && ! $session_filter == 0)
            {
                if (is_numeric($session_filter))
                {
                    $condition = new EqualityCondition(UserView :: PROPERTY_ID, $session_filter);
                    $user_view = RepositoryDataManager :: get_instance()->retrieve_user_views($condition)->next_result();
                    $trail->add(
                            new Breadcrumb($this->get_url(),
                                    Translation :: get('Filter', null, Utilities :: COMMON_LIBRARIES) . ': ' . $user_view->get_name()));
                }
                else
                    $trail->add(
                            new Breadcrumb($this->get_url(),
                                    Translation :: get('Filter', null, Utilities :: COMMON_LIBRARIES) . ': ' . Utilities :: underscores_to_camelcase(
                                            ($session_filter))));
            }

            $this->display_header();
            echo $this->get_action_bar()->as_html();
            echo $output;
            echo ResourceManager :: get_instance()->get_resource_html(
                    BasicApplication :: get_application_web_resources_javascript_path(
                            RepositoryManager :: APPLICATION_NAME) . 'repository.js');

            $this->display_footer();
        }
    }

    /**
     * Gets the table which shows the learning objects in the currently active category
     */
    private function get_content_objects_html()
    {
        $renderer = ContentObjectRenderer :: factory($this->get_renderer(), $this);
        return $renderer->as_html();
    }

    function get_action_bar()
    {
        if (! isset($this->action_bar))
        {
            $this->action_bar = new ActionBarRenderer(ActionBarRenderer :: TYPE_HORIZONTAL);

            $this->action_bar->set_search_url($this->get_url(array('category' => $this->get_parent_id())));

            $this->action_bar->add_common_action(
                    new ToolbarItem(Translation :: get('ShowAll', null, Utilities :: COMMON_LIBRARIES),
                            Theme :: get_common_image_path() . 'action_browser.png',
                            $this->get_url(array('category' => Request :: get('category'))),
                            ToolbarItem :: DISPLAY_ICON_AND_LABEL));
            $this->action_bar->add_common_action(
                    new ToolbarItem(Translation :: get('ManageCategories'),
                            Theme :: get_common_image_path() . 'action_category.png',
                            $this->get_url(
                                    array(Application :: PARAM_ACTION => RepositoryManager :: ACTION_MANAGE_CATEGORIES)),
                            ToolbarItem :: DISPLAY_ICON_AND_LABEL));
            if ($this->get_filter_type())
            {
                $this->action_bar->add_common_action(
                        new ToolbarItem(
                                Translation :: get('CreateObjectType',
                                        array(
                                                'TYPE' => Translation :: get('TypeName', null,
                                                        ContentObject :: get_content_object_type_namespace(
                                                                $this->get_filter_type())))),
                                Theme :: get_common_image_path() . 'action_create.png',
                                $this->get_url(
                                        array(
                                                Application :: PARAM_ACTION => RepositoryManager :: ACTION_CREATE_CONTENT_OBJECTS,
                                                ContentObjectTypeSelector :: PARAM_CONTENT_OBJECT_TYPE => $this->get_filter_type())),
                                ToolbarItem :: DISPLAY_ICON_AND_LABEL));
            }

            $renderers = $this->get_available_renderers();

            if (count($renderers) > 1)
            {
                foreach ($renderers as $renderer)
                {
                    $this->action_bar->add_tool_action(
                            new ToolbarItem(
                                    Translation :: get(Utilities :: underscores_to_camelcase($renderer) . 'View', null,
                                            Utilities :: COMMON_LIBRARIES),
                                    Theme :: get_image_path() . 'view_' . $renderer . '.png',
                                    $this->get_url(
                                            array(RepositoryManager :: PARAM_RENDERER => $renderer)),
                                    ToolbarItem :: DISPLAY_ICON_AND_LABEL));
                }
            }

            $this->action_bar->add_tool_action(
                    new ToolbarItem(Translation :: get('ExportCategory'),
                            Theme :: get_common_image_path() . 'action_backup.png',
                            $this->get_url(
                                    array(
                                            Application :: PARAM_ACTION => RepositoryManager :: ACTION_EXPORT_CONTENT_OBJECTS,
                                            RepositoryManager :: PARAM_CATEGORY_ID => Request::get(RepositoryManager::PARAM_CATEGORY_ID))),
                            ToolbarItem :: DISPLAY_ICON_AND_LABEL));
        }

        return $this->action_bar;
    }

    public function get_condition()
    {
        $query = $this->get_action_bar()->get_query();
        $conditions[] = new EqualityCondition(ContentObject :: PROPERTY_STATE, ContentObject :: STATE_NORMAL,
                ContentObject :: get_table_name());

        $conditions[] = new EqualityCondition(ContentObject :: PROPERTY_OWNER_ID, $this->get_user_id(),
                ContentObject :: get_table_name());

        $types = RepositoryDataManager :: get_active_helper_types();

        foreach ($types as $type)
        {
            $conditions[] = new NotCondition(
                    new EqualityCondition(ContentObject :: PROPERTY_TYPE, $type, ContentObject :: get_table_name()));
        }

        if (isset($query) && $query != '')
        {
            $or_conditions[] = new PatternMatchCondition(ContentObject :: PROPERTY_TITLE, '*' . $query . '*',
                    ContentObject :: get_table_name());
            $or_conditions[] = new PatternMatchCondition(ContentObject :: PROPERTY_DESCRIPTION, '*' . $query . '*',
                    ContentObject :: get_table_name());

            $conditions[] = new OrCondition($or_conditions);
        }

        $content_object_type = Request :: get(RepositoryManager :: PARAM_CONTENT_OBJECT_TYPE);
        if ($content_object_type)
        {
            if(!is_array($content_object_type))
            {
                $content_object_type = array($content_object_type);
            }
            $conditions[] = new InCondition(ContentObject :: PROPERTY_TYPE, $content_object_type, ContentObject :: get_table_name());
        }

        $content_object_category = Request :: get(RepositoryManager :: PARAM_CONTENT_OBJECT_CATEGORY);
        if ($content_object_category)
        {
            $type_selector = new ContentObjectTypeSelector($this, RepositoryDataManager :: get_registered_types());
            $categories = $type_selector->as_array();

            $types = array_keys($categories[$content_object_category]);
            $conditions[] = new InCondition(ContentObject :: PROPERTY_TYPE, $types, ContentObject :: get_table_name());
        }

        $user_view = Request :: get(RepositoryManager :: PARAM_USER_VIEW);
        if ($user_view)
        {
            $dm = RepositoryDataManager :: get_instance();
            $user_view_rel_content_objects = $dm->retrieve_user_view_rel_content_objects(
                    new EqualityCondition(UserViewRelContentObject :: PROPERTY_VIEW_ID, $user_view));
            while ($user_view_rel_content_object = $user_view_rel_content_objects->next_result())
            {
                if ($user_view_rel_content_object->get_visibility())
                {
                    $visible_types[] = $user_view_rel_content_object->get_content_object_type();
                }
            }

            $conditions[] = new InCondition(ContentObject :: PROPERTY_TYPE, $visible_types,
                    ContentObject :: get_table_name());
        }

        $advanced_filter_conditions = $this->get_advanced_search_form()->get_filter_conditions();

        if ($advanced_filter_conditions)
        {
            $conditions[] = $advanced_filter_conditions;
        }

        if ((! isset($query) || $query == '') && !$this->get_advanced_search_form()->get_filter_parameters())
        {
            $conditions[] = new EqualityCondition(ContentObject :: PROPERTY_PARENT_ID, $this->get_parent_id(),
                    ContentObject :: get_table_name());
        }

        $condition = new AndCondition($conditions);
        return $condition;
    }

    private function get_parent_id()
    {
        return Request :: get(RepositoryManager :: PARAM_CATEGORY_ID) ? Request :: get(
                RepositoryManager :: PARAM_CATEGORY_ID) : 0;
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add_help('repository_browser');
    }

    function is_allowed_to_create($type)
    {
        return true;
    }

    function get_allowed_content_object_types()
    {
        $types = $this->get_content_object_types(true, false);
        foreach ($types as $index => $type)
        {
            $registration = CommonDataManager :: get_registration(
                    ContentObject :: get_content_object_type_namespace($type));
            if (! $registration || ! $registration->is_active())
            {
                unset($types[$index]);
            }
        }

        return $types;
    }

    function get_filter_type()
    {
        $filter_type = $this->get_advanced_search_form()->get_type();
        if (! $filter_type)
        {
            $filter_type = Request :: get(RepositoryManager :: PARAM_CONTENT_OBJECT_TYPE, false);
        }
        return $filter_type;
    }
}
?>