<?php
namespace repository;

use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\ObjectTable;
use common\libraries\ObjectTableFormActions;
use common\libraries\ObjectTableFormAction;

class RepositoryBrowserTable extends ObjectTable
{
    const DEFAULT_NAME = 'repository_browser_table';

    /**
     * Constructor
     *
     * @see ContentObjectTable::ContentObjectTable()
     */
    function __construct($browser, $parameters, $condition)
    {
        $type = $browser->get_repository_browser()->get_advanced_search_form()->get_type();
        $model = new RepositoryBrowserTableColumnModel();
        $renderer = new RepositoryBrowserTableCellRenderer($browser);
        $data_provider = new RepositoryBrowserTableDataProvider($browser, $condition, $type);
        parent :: __construct($data_provider, RepositoryBrowserTable :: DEFAULT_NAME, $model, $renderer);
        
        $this->add_actions($browser);
        
        $this->set_additional_parameters($parameters);
        $this->set_default_row_count(20);
    }

    function add_actions($browser)
    {
        $action = new ObjectTableFormActions(__NAMESPACE__);
        
        $action->add_form_action(new ObjectTableFormAction(RepositoryManager :: ACTION_RECYCLE_CONTENT_OBJECTS, Translation :: get('RemoveSelected', null, Utilities :: COMMON_LIBRARIES)));
        $action->add_form_action(new ObjectTableFormAction(RepositoryManager :: ACTION_UNLINK_CONTENT_OBJECTS, Translation :: get('UnlinkSelected', null, Utilities :: COMMON_LIBRARIES)));
        $action->add_form_action(new ObjectTableFormAction(RepositoryManager :: ACTION_MOVE_CONTENT_OBJECTS, Translation :: get('MoveSelected', null, Utilities :: COMMON_LIBRARIES), false));
        $action->add_form_action(new ObjectTableFormAction(RepositoryManager :: ACTION_PUBLISH_CONTENT_OBJECT, Translation :: get('PublishSelected', null, Utilities :: COMMON_LIBRARIES), false));
        $action->add_form_action(new ObjectTableFormAction(RepositoryManager :: ACTION_EXPORT_CONTENT_OBJECTS, Translation :: get('ExportSelected', null, Utilities :: COMMON_LIBRARIES), false));
        $action->add_form_action(new ObjectTableFormAction(RepositoryManager :: ACTION_SHARE_CONTENT_OBJECTS, Translation :: get('ShareSelected', null, Utilities :: COMMON_LIBRARIES), false));
        $action->add_form_action(new ObjectTableFormAction(RepositoryManager :: ACTION_EDIT_METADATA, Translation :: get('AddMetadataToSelected', null, Utilities :: COMMON_LIBRARIES), false));
        
        if ($browser->get_repository_browser()->get_user()->is_platform_admin())
        {
            $action->add_form_action(new ObjectTableFormAction(RepositoryManager :: ACTION_COPY_CONTENT_OBJECT_TO_TEMPLATES, Translation :: get('CopySelectedToTemplates'), false));
        }
        
        $this->set_form_actions($action);
    }

    static function handle_table_action()
    {
        $class = Utilities :: get_classname_from_namespace(__CLASS__, true);
        $ids = self :: get_selected_ids($class);
        
        $action = Request :: post($class . '_action_value');
        if ($action == RepositoryManager :: ACTION_EDIT_CONTENT_OBJECT_RIGHTS)
        {
            Request :: set_get(RepositoryManager :: PARAM_IDENTIFIER, $ids);
        }
        else
        {
            Request :: set_get(RepositoryManager :: PARAM_CONTENT_OBJECT_ID, $ids);
        }
        
        // go directly to the share rights creation
        if ($action == RepositoryManager :: ACTION_SHARE_CONTENT_OBJECTS)
        {
            Request :: set_get(ShareManager :: PARAM_SHARE_ACTION, ShareManager :: ACTION_ADD_ENTITIES);
        }
    
    }
}
?>