<?php
namespace repository;

use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Utilities;

/**
 * $Id: comparer.class.php 204 2009-11-13 12:51:30Z kariboe $
 * @package repository.lib.repository_manager.component
 */
/**
 * Repository manager component which can be used to compare a content object.
 */
class RepositoryManagerComparerComponent extends RepositoryManager
{

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        //$trail = BreadcrumbTrail :: get_instance();


        $object_ids = Request :: post(RepositoryVersionBrowserTable :: DEFAULT_NAME . RepositoryVersionBrowserTable :: CHECKBOX_NAME_SUFFIX);

        if ($object_ids)
        {
            $object_id = $object_ids[0];
            $version_id = $object_ids[1];
        }
        else
        {
            $object_id = Request :: get(RepositoryManager :: PARAM_COMPARE_OBJECT);
            $version_id = Request :: get(RepositoryManager :: PARAM_COMPARE_VERSION);
        }

        if ($object_id && $version_id)
        {
            $object = $this->retrieve_content_object($object_id);

            if ($object->get_state() == ContentObject :: STATE_RECYCLED)
            {
                $this->force_menu_url($this->get_recycle_bin_url());
            }

            $this->display_header();

            $diff = $object->get_difference($version_id);

            $display = ContentObjectDifferenceDisplay :: factory($diff);

            echo Utilities :: add_block_hider();
            echo Utilities :: build_block_hider('compare_legend');
            echo $display->get_legend();
            echo Utilities :: build_block_hider();
            echo $display->get_diff_as_html();

            $this->display_footer();
        }
        else
        {
            $this->display_warning_page(htmlentities(Translation :: get('NoObjectSelected', array(
                    'OBJECT' => Translation :: get('ContentObject')), Utilities :: COMMON_LIBRARIES)));
        }
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add(new Breadcrumb($this->get_url(array(
                RepositoryManager :: PARAM_ACTION => RepositoryManager :: ACTION_BROWSE_CONTENT_OBJECTS)), Translation :: get('RepositoryManagerBrowserComponent')));
        $breadcrumbtrail->add_help('repository_comparer');
    }
}
?>