<?php
namespace repository;

use common\libraries\ComplexMenuSupport;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\EqualityCondition;
use common\libraries\ToolbarItem;
use common\libraries\Toolbar;
use common\libraries\Theme;
use common\libraries\ComplexContentObjectSupport;

/**
 * $Id: complex_browser_table_cell_renderer.class.php 204 2009-11-13 12:51:30Z kariboe $
 *
 * @package repository.lib.repository_manager.component.complex_browser
 */
class ComplexBrowserTableCellRenderer extends DefaultContentObjectTableCellRenderer
{

    /**
     * The repository browser component
     */
    protected $browser;

    protected $content_object;

    protected $rdm;

    protected $condition;

    /**
     * Constructor
     *
     * @param RepositoryManagerBrowserComponent $browser
     */
    function __construct($browser, $condition)
    {
        parent :: __construct();
        $this->browser = $browser;
        $this->rdm = RepositoryDataManager :: get_instance();
        $this->condition = $condition;
    }

    function retrieve_content_object($lo_id)
    {
        if (! $this->content_object || $this->content_object->get_id() != $lo_id)
        {
            $content_object = $this->rdm->retrieve_content_object($lo_id);
            $this->content_object = $content_object;
        }
        else
        {
            $content_object = $this->content_object;
        }

        return $content_object;
    }

    // Inherited
    function render_cell($column, $cloi, $content_object = null)
    {
        if ($column === ComplexBrowserTableColumnModel :: get_modification_column())
        {
            return $this->get_modification_links($cloi)->as_html();
        }

        if (! $content_object)
            $content_object = $this->retrieve_content_object($cloi->get_ref());

        switch ($column->get_name())
        {
            case ContentObject :: PROPERTY_TYPE :
                $type = $content_object->get_type();
                $icon = $content_object->get_icon_path();
                $url = '<img src="' . $icon . '" alt="' . htmlentities(
                        Translation :: get('TypeName', null, ContentObject :: get_content_object_type_namespace($type))) . '"/>';
                return $url;
            case Theme :: get_common_image('action_category', 'png', Translation :: get('Type'), null,
                    ToolbarItem :: DISPLAY_ICON) :
                return $content_object->get_icon_image(Theme :: ICON_MINI);

            case ContentObject :: PROPERTY_TITLE :
                $title = htmlspecialchars($content_object->get_title());
                $title_short = $title;
                $title_short = Utilities :: truncate_string($title_short, 53, false);

                if ($content_object instanceof ComplexContentObjectSupport)
                {
                    $title_short = '<a href="' . $this->browser->get_url(
                            array(ComplexBuilder :: PARAM_COMPLEX_CONTENT_OBJECT_ITEM_ID => $cloi->get_id())) . '">' . $title_short . '</a>';
                }
                else
                {
                    $title_short = '<a href="' . $this->browser->get_complex_content_object_item_view_url(
                            $cloi->get_id()) . '">' . $title_short . '</a>';
                }

                return $title_short;
            case ContentObject :: PROPERTY_DESCRIPTION :
                $description = $content_object->get_description();
                return Utilities :: truncate_string($description, 75);
            case 'subitems' :
                if ($cloi->is_complex())
                {
                    $condition = new EqualityCondition(ComplexContentObjectItem :: PROPERTY_PARENT, $cloi->get_ref(),
                            ComplexContentObjectItem :: get_table_name());
                    return $this->rdm->count_complex_content_object_items($condition);
                }
                return 0;
        }
    }

    /**
     * Gets the action links to display
     *
     * @param ContentObject $content_object The content object for which the action links should be returned
     * @return string A HTML representation of the action links
     */
    protected function get_modification_links($cloi, $no_move = false)
    {
        $toolbar = new Toolbar();

        // EDIT
        if ($cloi->has_right(RepositoryRights :: COLLABORATE_RIGHT))
        {
            $toolbar->add_item(
                    new ToolbarItem(Translation :: get('Edit', null, Utilities :: COMMON_LIBRARIES),
                            Theme :: get_common_image_path() . 'action_edit.png',
                            $this->browser->get_complex_content_object_item_edit_url($cloi->get_id()),
                            ToolbarItem :: DISPLAY_ICON));
        }
        else
        {
            $toolbar->add_item(
                    new ToolbarItem(Translation :: get('EditNA', null, Utilities :: COMMON_LIBRARIES),
                            Theme :: get_common_image_path() . 'action_edit_na.png', null, ToolbarItem :: DISPLAY_ICON));
        }

        $toolbar->add_item(
                new ToolbarItem(Translation :: get('Delete', null, Utilities :: COMMON_LIBRARIES),
                        Theme :: get_common_image_path() . 'action_delete.png',
                        $this->browser->get_complex_content_object_item_delete_url($cloi->get_id()),
                        ToolbarItem :: DISPLAY_ICON, true));

        if ($this->browser instanceof ComplexMenuSupport)
        {
            $toolbar->add_item(
                    new ToolbarItem(Translation :: get('ChangeParent', null, Utilities :: COMMON_LIBRARIES),
                            Theme :: get_common_image_path() . 'action_move.png',
                            $this->browser->get_complex_content_object_parent_changer_url($cloi->get_id()),
                            ToolbarItem :: DISPLAY_ICON));
        }

        $allowed = $this->check_move_allowed($cloi);

        if (! $no_move)
        {
            if ($allowed["moveup"])
            {
                $toolbar->add_item(
                        new ToolbarItem(Translation :: get('MoveUp', null, Utilities :: COMMON_LIBRARIES),
                                Theme :: get_common_image_path() . 'action_up.png',
                                $this->browser->get_complex_content_object_item_move_url($cloi->get_id(),
                                        RepositoryManager :: PARAM_DIRECTION_UP), ToolbarItem :: DISPLAY_ICON));
            }
            else
            {
                $toolbar->add_item(
                        new ToolbarItem(Translation :: get('MoveUpNotAvailable', null, Utilities :: COMMON_LIBRARIES),
                                Theme :: get_common_image_path() . 'action_up_na.png', null, ToolbarItem :: DISPLAY_ICON));
            }

            if ($allowed["movedown"])
            {
                $toolbar->add_item(
                        new ToolbarItem(Translation :: get('MoveDown', null, Utilities :: COMMON_LIBRARIES),
                                Theme :: get_common_image_path() . 'action_down.png',
                                $this->browser->get_complex_content_object_item_move_url($cloi->get_id(),
                                        RepositoryManager :: PARAM_DIRECTION_DOWN), ToolbarItem :: DISPLAY_ICON));
            }
            else
            {
                $toolbar->add_item(
                        new ToolbarItem(Translation :: get('MoveDownNotAvailable', null, Utilities :: COMMON_LIBRARIES),
                                Theme :: get_common_image_path() . 'action_down_na.png', null,
                                ToolbarItem :: DISPLAY_ICON));
            }
        }

        return $toolbar;
    }

    protected function check_move_allowed($cloi)
    {
        $moveup_allowed = true;
        $movedown_allowed = true;

        $count = $this->rdm->count_complex_content_object_items($this->condition);
        if ($count == 1)
        {
            $moveup_allowed = false;
            $movedown_allowed = false;
        }
        else
        {
            if ($cloi->get_display_order() == 1)
            {
                $moveup_allowed = false;
            }
            else
            {
                if ($cloi->get_display_order() == $count)
                {
                    $movedown_allowed = false;
                }
            }
        }

        return array('moveup' => $moveup_allowed, 'movedown' => $movedown_allowed);
    }
}
?>