<?php
namespace repository;

use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Application;
use common\libraries\Utilities;

/**
 * $Id: deleter.class.php 204 2009-11-13 12:51:30Z kariboe $
 *
 * @package repository.lib.repository_manager.component
 */
/**
 * Repository manager component which provides functionality to delete a content object from the users repository.
 */
class RepositoryManagerDeleterComponent extends RepositoryManager
{

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        $ids = Request :: get(RepositoryManager :: PARAM_CONTENT_OBJECT_ID);
        if (! empty($ids))
        {
            if (! is_array($ids))
            {
                $ids = array($ids);
            }

            $failures = 0;
            $delete_version = Request :: get(RepositoryManager :: PARAM_DELETE_VERSION);
            $permanent = Request :: get(RepositoryManager :: PARAM_DELETE_PERMANENTLY);
            $recycled = Request :: get(RepositoryManager :: PARAM_DELETE_RECYCLED);
            foreach ($ids as $object_id)
            {
                $object = $this->retrieve_content_object($object_id);
                // only owner can remove the object
                if ($object->get_owner_id() == $this->get_user_id())
                {
                    if ($delete_version)
                    {
                        if ($this->content_object_deletion_allowed($object, 'version'))
                        {
                            $object->delete_version();
                        }
                        else
                        {
                            $failures ++;
                        }
                    }
                    else
                    {
                        if ($this->content_object_deletion_allowed($object))
                        {
                            if ($permanent)
                            {
                                $versions = $object->get_content_object_versions();
                                foreach ($versions as $version)
                                {
                                    $version->delete();
                                }
                            }
                            elseif ($recycled)
                            {
                                $versions = $object->get_content_object_versions();
                                foreach ($versions as $version)
                                {
                                    $version->recycle();
                                }
                            }
                        }
                        else
                        {
                            $failures ++;
                        }
                    }
                }
                else
                {
                    $failures ++;
                }
            }

            if ($delete_version)
            {
                if ($failures)
                {
                    $message = 'SelectedVersionNotDeleted';
                }
                else
                {
                    $message = 'SelectedVersionDeleted';
                }
            }
            else
            {
                if ($failures)
                {
                    if (count($ids) == 1)
                    {
                        $message = 'ObjectNot' . ($permanent ? 'Deleted' : 'MovedToRecycleBin');
                        $parameter = array('OBJECT' => Translation :: get('ContentObject'));
                    }
                    elseif (count($ids) > $failures)
                    {
                        $message = 'SomeObjectsNot' . ($permanent ? 'Deleted' : 'MovedToRecycleBin');
                        $parameter = array('OBJECTS' => Translation :: get('ContentObjects'));
                    }
                    else
                    {
                        $message = 'ObjectsNot' . ($permanent ? 'Deleted' : 'MovedToRecycleBin');
                        $parameter = array('OBJECTS' => Translation :: get('ContentObjects'));
                    }
                }
                else
                {
                    if (count($ids) == 1)
                    {
                        $message = 'Object' . ($permanent ? 'Deleted' : 'MovedToRecycleBin');
                        $parameter = array('OBJECT' => Translation :: get('ContentObject'));
                    }
                    else
                    {
                        $message = 'Objects' . ($permanent ? 'Deleted' : 'MovedToRecycleBin');
                        $parameter = array('OBJECTS' => Translation :: get('ContentObjects'));
                    }
                }
            }

            $parameters = array();
            $parameters[Application :: PARAM_ACTION] = ($permanent ? RepositoryManager :: ACTION_BROWSE_RECYCLED_CONTENT_OBJECTS : RepositoryManager :: ACTION_BROWSE_CONTENT_OBJECTS);

            $this->redirect(Translation :: get($message, $parameter, Utilities :: COMMON_LIBRARIES),
                    ($failures ? true : false), $parameters);
        }
        else
        {
            $this->display_error_page(
                    htmlentities(Translation :: get('NoObjectSelected', null, Utilities :: COMMON_LIBRARIES)));
        }
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add(
                new Breadcrumb(
                        $this->get_url(
                                array(
                                        RepositoryManager :: PARAM_ACTION => RepositoryManager :: ACTION_BROWSE_CONTENT_OBJECTS)),
                        Translation :: get('RepositoryManagerBrowserComponent')));
        $breadcrumbtrail->add_help('repository_deleter');
    }

    function get_additional_parameters()
    {
        return array(RepositoryManager :: PARAM_CONTENT_OBJECT_ID, RepositoryManager :: PARAM_DELETE_VERSION,
                RepositoryManager :: PARAM_DELETE_PERMANENTLY, RepositoryManager :: PARAM_DELETE_RECYCLED);
    }
}
?>