<?php
namespace repository;

use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\BreadcrumbTrail;
use repository\content_object\document\Document;
use common\libraries\Utilities;

/**
 * $Id: document_downloader.class.php 204 2009-11-13 12:51:30Z kariboe $
 *
 * @package repository.lib.repository_manager.component
 */
class RepositoryManagerDocumentDownloaderComponent extends RepositoryManager
{

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        $object_id = Request :: get(RepositoryManager :: PARAM_CONTENT_OBJECT_ID);
        if (! $object_id)
        {
            $this->handle_error(
                    Translation :: get('NoObjectSelected',
                            array('OBJECT' => Translation :: get('ContentObject')), Utilities :: COMMON_LIBRARIES));
        }

        $object = $this->retrieve_content_object($object_id);
        $valid_types = array('document', 'file', 'webpage', 'page');

        if (! $object || ! in_array($object->get_type(), $valid_types))
        {
            $this->handle_error(Translation :: get('ContentObjectMustBeDocument'));
        }

        $security_code = Request :: get(ContentObject :: PARAM_SECURITY_CODE);
        if ($security_code != $object->calculate_security_code())
        {
            $this->handle_error('SecurityCodeNotValid', null, Utilities :: COMMON_LIBRARIES);
        }

        if (Request :: get('display') == 1)
        {
            $object->open_in_browser();
        }
        else
        {
            $object->send_as_download();
        }
    }

    function handle_error($error_message)
    {
        $this->display_header();
        $this->display_error_message($error_message);
        $this->display_footer();
        exit();
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add_help('repository_document_downloader');
    }

    function get_additional_parameters()
    {
        return array(RepositoryManager :: PARAM_CONTENT_OBJECT_ID);
    }
}
?>