<?php
namespace repository;

use common\libraries\Theme;
use common\libraries\ObjectTableCellRenderer;
use common\libraries\Utilities;
use common\libraries\Translation;

class ExportBrowserTableCellRenderer extends ObjectTableCellRenderer
{
    /**
     * The repository browser component
     */
    private $browser;

    /**
     * Constructor
     * @param RepositoryManagerBrowserComponent $browser
     */
    function __construct($browser)
    {
        $this->browser = $browser;
    }

    // Inherited
    function render_cell($column, $content_object)
    {
        switch ($column->get_name())
        {
            case ContentObject :: PROPERTY_TYPE :
                $type = $content_object->get_type();
                $icon = $content_object->get_icon_path();
                return '<img src="' . $icon . '" alt="' . htmlentities(Translation :: get('TypeName', null, ContentObject :: get_content_object_type_namespace($type))) . '"/>';
            case ContentObject :: PROPERTY_TITLE :
                $title = $content_object->get_title();
                return Utilities :: truncate_string($title, 53, false);
            default :
                $export_types = ContentObjectExportImplementation :: get_types_for_object(Utilities :: get_namespace_from_object($content_object));
                if (in_array($column->get_name(), $export_types))
                {
                    $this->browser->set_export_types_cache($column->get_name(), $content_object->get_id());
                    return '<img src="' . Theme :: get_common_image_path() . 'status_confirm_mini.png"/>';
                }
                else
                {
                    return '<img src="' . Theme :: get_common_image_path() . 'status_error_mini.png"/>';
                }
        }
        return parent :: render_cell($column, $content_object);
    }

    function render_id_cell($object)
    {
        return $object->get_id();
    }
}
?>