<?php
namespace repository;

use common\libraries\SortableTableFromArray;

use common\libraries\ToolbarItem;

use common\libraries\Theme;

use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\EqualityCondition;
use common\libraries\InCondition;
use common\libraries\AndCondition;
use common\libraries\Utilities;
/**
 * $Id: exporter.class.php 204 2009-11-13 12:51:30Z kariboe $
 *
 * @package repository.lib.repository_manager.component
 */

class RepositoryManagerExporterComponent extends RepositoryManager
{
    private $export_types;
    private $export_types_cache;
    private $is_exportable;

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        $content_object_ids = Request :: get(RepositoryManager :: PARAM_CONTENT_OBJECT_ID);
        $category_ids = Request :: get(RepositoryManager :: PARAM_CATEGORY_ID);
        
        if (! is_array($content_object_ids) && ! is_null($content_object_ids))
        {
            $content_object_ids = array($content_object_ids);
        }
        
        if (! is_array($category_ids) && ! is_null($category_ids))
        {
            $category_ids = array($category_ids);
        }
        
        if (count($content_object_ids) == 0 && count($category_ids) == 0)
        {
            $category_ids[] = 0;
        }
        
        // If content objects are selected then do not use the category.
        if(count($content_object_ids) > 0)
        {
            $category_ids = array();
        }
        
        if (count($content_object_ids) > 0 || count($category_ids) > 0)
        {
            $type = Request :: get(self :: PARAM_EXPORT_TYPE);
            $export_parameters = new ExportParameters($this->get_user_id(), $type, $content_object_ids, $category_ids);
            if (! $type)
            {
                $table_data = $this->export_table($export_parameters->get_content_object_ids());
                
                $table_row = array(' ', ' ', count($export_parameters->get_content_object_ids()));
                foreach (ContentObjectExport :: get_types() as $export_type)
                {
                    if ($this->is_exportable[$export_type])
                    {
                        if (count($content_object_ids))
                        {
                            $table_row[] = '<a href="' . $this->get_content_objects_exporting_url(self :: PARAM_CONTENT_OBJECT_ID, $this->get_export_types_cache($export_type), $export_type) . '">' . Theme :: get_common_image('action_export') . '</a>';
                        }
                        else
                        {
                            $table_row[] = '<a href="' . $this->get_content_objects_exporting_url(self :: PARAM_CATEGORY_ID, $category_ids, $export_type) . '">' . Theme :: get_common_image('action_export') . '</a>';
                        }
                    }
                    else
                    {
                        $table_row[] = Theme :: get_image('action_export_na', 'png', Translation :: get('ExportNotAvailable'), null, ToolbarItem :: DISPLAY_ICON, false, Utilities :: COMMON_LIBRARIES);
                    }
                }
                $table_data[] = $table_row;
                $this->display_header();
                
                $export_table = new ExportTable($table_data);
                $export_table->set_header(0, '', false);
                $export_table->set_header(1, Translation :: get('Type'), false);
                $export_table->set_header(2, Translation :: get('ShortCount'), false);
                foreach (ContentObjectExport :: get_types() as $key => $export_type)
                {
                    $export_table->set_header($key + 3, Translation :: get('ImportType' . Utilities :: underscores_to_camelcase($export_type)), false);
                }
                
                echo ($export_table->as_html());
                $this->display_footer();
            }
            else
            {
                $exporter = ContentObjectExportController :: factory($export_parameters);
                $exporter->download();
            }
        }
        else
        {
            $this->display_header();
            $this->display_error_message(Translation :: get('NoObjectsSelected', array(
                    'OBJECT' => Translation :: get('ContentObject')), Utilities :: COMMON_LIBRARIES));
            $this->display_footer();
        }
    
    }

    private function export_table($content_object_ids)
    {
        $condition = new InCondition(ContentObject :: PROPERTY_ID, $content_object_ids);
        $types = RepositoryDataManager :: get_instance()->retrieve_distinct(ContentObject :: get_table_name(), ContentObject :: PROPERTY_TYPE, $condition);
        
        $this->is_exportable = array();
        
        $table_data = array();
        foreach ($types as $type)
        {
            $type_namespace = ContentObject :: get_content_object_type_namespace($type);
            $table_row = array();
            $table_row[] = Theme :: get_image('logo/16', 'png', Translation :: get('TypeName', null, $type_namespace), null, ToolbarItem :: DISPLAY_ICON, false, $type_namespace);
            $table_row[] = Translation :: get('TypeName', null, $type_namespace);
            
            $conditions = array();
            $conditions[] = new InCondition(ContentObject :: PROPERTY_ID, $content_object_ids);
            $conditions[] = new EqualityCondition(ContentObject :: PROPERTY_TYPE, $type);
            $condition = new AndCondition($conditions);
            
            $ids = RepositoryDataManager :: get_instance()->retrieve_distinct(ContentObject :: get_table_name(), ContentObject :: PROPERTY_ID, $condition);
            $table_row[] = count($ids);
            
            foreach (ContentObjectExport :: get_types() as $export_type)
            {
                $export_types = ContentObjectExportImplementation :: get_types_for_object($type_namespace);
                if (in_array($export_type, $export_types))
                {
                    $this->set_export_types_cache($export_type, $ids);
                    $this->is_exportable[$export_type] = true;
                    $table_row[] = '<img src="' . Theme :: get_common_image_path() . 'status_confirm_mini.png"/>';
                }
                else
                {
                    $table_row[] = '<img src="' . Theme :: get_common_image_path() . 'status_error_mini.png"/>';
                }
            }
            $table_data[] = $table_row;
        }
        return $table_data;
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add_help('repository_exporter');
    }

    function get_additional_parameters()
    {
        return array(RepositoryManager :: PARAM_CONTENT_OBJECT_ID);
    }

    function get_export_types_cache($type)
    {
        return $this->export_types_cache[$type];
    }

    function set_export_types_cache($type, $values)
    {
        $this->export_types_cache[$type] = array_merge((array) $this->export_types_cache[$type], $values);
    }
}
?>