<?php
namespace repository;

use common\libraries\WebApplication;
use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\Theme;
use common\libraries\Application;
use common\libraries\Path;
use common\libraries\Display;
use common\libraries\Session;
use admin\AdminDataManager;
use admin\AdminManager;

/**
 * $Id: location_selection_publisher_wizard_page.class.php 204 2009-11-13
 * 12:51:30Z kariboe $
 *
 * @package repository.lib.repository_manager.component.publication_wizard.pages
 */

/**
 * Class for application settings page
 * Displays a form where the user can enter the installation settings
 * regarding the applications
 */
class LocationSelectionPublisherWizardPage extends PublisherWizardPage
{
    private $content_objects;
    private $type;
    private $apps;

    public function __construct($name, $parent)
    {
        parent :: __construct($name, $parent);
        $ids = Request :: get(RepositoryManager :: PARAM_CONTENT_OBJECT_ID);
        
        if (empty($ids))
        {
            Display :: error_page(Translation :: get('NoObjectSelected', array(
                    'OBJECT' => Translation :: get('ContentObject')), Utilities :: COMMON_LIBRARIES));
        }
        
        if (! is_array($ids))
            $ids = array($ids);
        
        foreach ($ids as $id)
        {
            $lo = $this->get_parent()->retrieve_content_object($id);
            
            // fail if no object exists
            if (! $lo)
            {
                Display :: error_page(Translation :: get('NoObjectSelected', array(
                        'OBJECT' => Translation :: get('ContentObject')), Utilities :: COMMON_LIBRARIES));
            }
            
            // check for USE right
            if (! ($lo->get_owner_id() == Session :: get_user_id() || RepositoryRights :: get_instance()->is_allowed_in_user_subtree(RepositoryRights :: USE_RIGHT, $lo->get_id(), RepositoryRights :: TYPE_USER_CONTENT_OBJECT, $lo->get_owner_id())))
            {
                Display :: not_allowed();
            }
            
            // don't allow publication is the content object is in the RECYCLED
            // state
            if ($lo->get_state() == ContentObject :: STATE_RECYCLED)
            {
                Display :: error_page(Translation :: get('NotAllowed', null, Utilities :: COMMON_LIBRARIES));
            }
            
            $this->content_objects[] = $lo;
            if ($this->type == null)
                $this->type = $lo->get_type();
            else
            {
                if ($this->type != $lo->get_type())
                {
                    Display :: error_page(Translation :: get('ObjectsNotSameType'));
                }
            }
        }
    }

    function get_title()
    {
        return Translation :: get('LocationSelection');
    }

    function get_info()
    {
        $html = array();
        if (count($this->content_objects) > 1)
        {
            $html[] = Translation :: get('LocationSelectionsInfo');
        }
        else
        {
            $html[] = Translation :: get('LocationSelectionInfo');
        }
        
        $html[] = '<div class="attachments" style="margin-top: 1em; background-image:url(' . Theme :: get_common_image_path() . 'place_selected.png' .')">';
        if (count($this->content_objects) > 1)
        {
            $html[] = '<div class="attachments_title">' . htmlentities(Translation :: get('SelectedObjects')) . '</div>';
        }
        else
        {
            $html[] = '<div class="attachments_title">' . htmlentities(Translation :: get('SelectedObject')) . '</div>';
        }
        Utilities :: order_content_objects_by_title($this->content_objects);
        $html[] = '<ul class="attachments_list">';
        foreach ($this->content_objects as $content_object)
        {
            $html[] = '<li><img src="' . Theme :: get_image_path(ContentObject :: get_content_object_type_namespace($content_object->get_type())) . 'logo/' . Theme :: ICON_MINI . '.png" alt="' . htmlentities(Translation :: get('TypeName', null, ContentObject :: get_content_object_type_namespace($content_object->get_type()))) . '"/> ' . $content_object->get_title() . '</li>';
        }
        $html[] = '</ul>';
        $html[] = '</div>';
        
        return implode("\n", $html);
    }

    function buildForm()
    {
        $this->_formBuilt = true;
        
        $html = '<script type="text/javascript">
							/* <![CDATA[ */
							function setCheckbox(app_name, value) {
								var d = document[\'page_locations\'];
								for (i = 0; i < d.elements.length; i++) {
									if (d.elements[i].type == "checkbox")
									{
									     if(app_name.length == null || d.elements[i].name.substr(0, app_name.length) == app_name)
									     		d.elements[i].checked = value;
									}
								}
							}
							/* ]]> */
							</script>';
        $this->addElement('html', $html);
        
        $applications = WebApplication :: load_all_from_filesystem(true, true);
        
        $this->apps = array();
        
        $location_count = 0;
        
        $adm = AdminDataManager :: get_instance();
        
        foreach ($applications as $application_name)
        {
            $application = WebApplication :: get_application_namespace($application_name) . '\\' . WebApplication :: get_application_class_name($application_name);
            $locations = $application :: get_content_object_publication_locations($this->content_objects[0], $this->get_parent()->get_user());
            $location_count += count($locations);
            
            $this->add_locations($application, $application_name, $locations);
        }
        
        $admin = new AdminManager();
        $locations = $admin->get_content_object_publication_locations($this->content_objects[0], $this->get_parent()->get_user());
        $location_count += count($locations);
        $this->add_locations($admin, 'admin', $locations);
        
        if ($location_count > 0)
        {
            $this->addElement('html', '<br /><br />');
            // $prevnext[] = $this->createElement('submit',
            // $this->getButtonName('back'), '<< '.Translation ::
            // get('Previous', null, Utilities :: COMMON_LIBRARIES));
            $prevnext[] = $this->createElement('style_submit_button', $this->getButtonName('next'), Translation :: get('Publish', null, Utilities :: COMMON_LIBRARIES), 'class="normal publish"');
            $this->addGroup($prevnext, 'buttons', '', '&nbsp;', false);
        }
        else
        {
            $this->addElement('html', '<div class="warning-message">' . Translation :: get('NoLocationsFound') . '</div>');
        }
        
        if (count($this->apps) > 1)
        {
            $this->addElement('html', '<br /><br /><a href="?" style="margin-left: 0%"  onclick="setCheckbox(\'\', true); return false;">' . Translation :: get('SelectAll', null, Utilities :: COMMON_LIBRARIES) . '</a>');
            $this->addElement('html', ' - <a href="?" onclick="setCheckbox(\'\', false); return false;">' . Translation :: get('UnselectAll', null, Utilities :: COMMON_LIBRARIES) . '</a>');
        }
        
        $this->addElement('html', '<script type="text/javascript" src="' . Path :: get(WEB_LIB_PATH) . 'libraries/resources/javascript/home_ajax.js' . '"></script>');
        
        $this->setDefaultAction('next');
        
        // $this->setDefaults($appDefaults);
    }

    function add_locations($application, $application_name, $locations)
    {
        if (count($locations) == 0)
        {
            return;
        }
        
        $this->apps[] = $application;
        
        $this->addElement('html', '<div class="block" id="block_introduction" style="background-image: url(' . Theme :: get_image_path('home') . 'block_' . $application_name . '.png);">');
        $this->addElement('html', '<div class="title"><div style="float:left;">' . Translation :: get('TypeName', null, Application :: determine_namespace($application_name)));
        $this->addElement('html', '</div><div style="float:right;"><a href="#" class="closeEl"><img class="visible" src="' . Theme :: get_common_image_path() . 'action_visible.png" /><img class="invisible" style="display: none;") src="' . Theme :: get_common_image_path() . 'action_invisible.png" /></a></div><div class="clear">&nbsp;</div></div>');
        $this->addElement('html', '<div class="description"><br />');
        
        /*
         * $application_name = Utilities ::
         * underscores_to_camelcase($application_name); $application_name =
         * strtolower($application_name);
         */
        $application :: add_publication_attributes_elements($this);
        
        foreach ($locations as $id => $location)
        {
            $cbname = $application_name . '|' . $id;
            $this->addElement('checkbox', $cbname, '', $location, array('style' => 'margin-left: 12px;'));
            $appDefaults[$cbname] = '1';
        }
        
        if (count($locations) > 1)
        {
            $this->addElement('html', '<br /><br /><a href="?" style="margin-left: 0%" onclick="setCheckbox(\'' . $application_name . '\', true); return false;">' . Translation :: get('SelectAll', null, Utilities :: COMMON_LIBRARIES) . '</a>');
            $this->addElement('html', ' - <a href="?" onclick="setCheckbox(\'' . $application_name . '\', false); return false;">' . Translation :: get('UnselectAll', null, Utilities :: COMMON_LIBRARIES) . '</a>');
        }
        $this->addElement('html', '<div style="clear: both;"></div></div></div><br />');
    }
}
?>