<?php
namespace repository;

use common\libraries\Translation;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Versionable;
use common\libraries\Theme;
use common\libraries\Filesystem;
use common\libraries\SortableTable;
use common\libraries\Utilities;

/**
 * $Id: quota_viewer.class.php 204 2009-11-13 12:51:30Z kariboe $
 *
 * @package repository.lib.repository_manager.component
 */
/**
 * Repository manager component which displays the quota to the user. This component displays two progress-bars. The
 * first one displays the used disk space and the second one the number of learning objects in the users repository.
 *
 * @author Bart Mollet
 * @author Tim De Pauw
 * @author Hans De Bisschop
 * @author Dieter De Neef
 */
class RepositoryManagerQuotaViewerComponent extends RepositoryManager
{

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        $this->display_header();
        $quotamanager = new QuotaManager($this->get_user());
        echo '<h3>' . htmlentities(Translation :: get('DiskSpace')) . '</h3>';
        echo self :: get_bar($quotamanager->get_used_disk_space_percent(), Filesystem :: format_file_size($quotamanager->get_used_disk_space()) . ' / ' . Filesystem :: format_file_size($quotamanager->get_max_disk_space()));
        echo '<div style="clear: both;">&nbsp;</div>';

        // echo '<h3>' . htmlentities(Translation :: get('NumberOfContentObjects')) . '</h3>';
        // echo self :: get_bar($quotamanager->get_used_database_space_percent(),
        // $quotamanager->get_used_database_space() . ' / ' . $quotamanager->get_max_database_space());
        // echo '<div style="clear: both;">&nbsp;</div>';

        $this->display_footer();
    }

    /**
     * Build a bar-view of the used quota.
     *
     * @param $percent float The percentage of the bar that is in use
     * @param $status string A status message which will be displayed below the bar.
     * @return string HTML representation of the requested bar.
     */
    private static function get_bar($percent, $status)
    {
        $html = '<div class="usage_information">';
        $html .= '<div class="usage_bar">';
        for($i = 0; $i < 100; $i ++)
        {
            if ($percent > $i)
            {
                if ($i >= 90)
                {
                    $class = 'very_critical';
                }
                elseif ($i >= 80)
                {
                    $class = 'critical';
                }
                else
                {
                    $class = 'used';
                }
            }
            else
            {
                $class = '';
            }
            $html .= '<div class="' . $class . '"></div>';
        }
        $html .= '</div>';
        $html .= '<div class="usage_status">' . $status . ' &ndash; ' . round($percent, 2) . ' %</div>';
        $html .= '</div>';
        return $html;
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add(new Breadcrumb($this->get_url(array(
                RepositoryManager :: PARAM_ACTION => RepositoryManager :: ACTION_BROWSE_CONTENT_OBJECTS)), Translation :: get('RepositoryManagerBrowserComponent')));
        $breadcrumbtrail->add_help('repository_quota_viewer');
    }
}
?>