<?php
namespace repository;

use common\libraries\CommonDataManager;

use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\EqualityCondition;
use common\libraries\AndCondition;
use common\libraries\Theme;
use common\libraries\Display;

use admin\AdminDataManager;
use common\libraries\Registration;

class RepositoryManagerResourceAdderComponent extends RepositoryManager
{
    const PROPERTY_URL = 'url';
    const PROPERTY_HTML = 'html';
    const PROPERTY_JSON_OEMBED = 'json+oembed';

    const PARAM_CONTENT_OBJECT_TYPE = 'content_object_type';
    const PARAM_NO_CREATE = 'no_create';

    const PARAM_BLANK = 'blank';

    function display_header()
    {
        Display :: small_header();
        $object_type = self :: PARAM_CONTENT_OBJECT_TYPE;
        $no_create = self :: PARAM_NO_CREATE;
        $javascript = <<<EOT
<script>
function set_object_type(object_type){
    var form = document.forms['createformc'];
    form.elements['$object_type'].value = object_type;
    form.elements['$no_create'].value = true;

    form.submit();
    return false;
        }
</script>
EOT;
        echo $javascript;
    }

    function display_footer()
    {
        Display :: small_footer();
    }

    function display_form($form)
    {
        $this->display_header();
        $this->display_buttons();
        $object = $form->get_content_object();

        $src = $object->get_icon_path(Theme :: ICON_BIG);
        $src = htmlspecialchars($src);

        echo '<div style="background-image: url(' . $src . ');" class="create_block">';
        echo $object->get_type_name();
        echo '</div>';

        echo '<div style="width:800px;">';
        echo $form->display();
        echo '</div>';
        $this->display_footer();
    }

    function display_message($message, $error_message = false)
    {
        $this->display_header();
        if ($error_message)
        {
            Display :: error_message($message);
        }
        else
        {
            Display :: normal_message($message);
        }
        echo $this->display_ok();
        $this->display_footer();
    }

    function display_ok()
    {
        $seconds = 3;
        $message = Translation :: get('ThisWindowWillCloseInXSeconds', array('x' => $seconds));
        Display :: normal_message($message);
        $ok = Translation :: get('Close');
        echo '<button onclick="window.close();" type="submit" name="submit" class="positive">' . $ok . '</button>';
        echo '<script>setTimeout(function(){window.close();}, ' . $seconds * 1000 . ');</script>';
    }

    function display_buttons()
    {
        $this->display_button('link');
        $this->display_button('document');
        $this->display_button('note');
    }

    function is_content_object_registered($name)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(\common\libraries\Registration :: PROPERTY_TYPE, 'content_object');
        $conditions[] = new EqualityCondition(\common\libraries\Registration :: PROPERTY_NAME, $name);
        $conditions[] = new EqualityCondition(\common\libraries\Registration :: PROPERTY_STATUS, true);
        $condition = new AndCondition($conditions);

        $registrations = CommonDataManager :: retrieves(Registration :: class_name(), $condition);
        return ! $registrations->is_empty();
    }

    function display_button($type_name)
    {
        if (! $this->is_content_object_registered($type_name))
        {
            return false;
        }
        $object = ContentObject :: factory($type_name);

        $src = $object->get_icon_path(Theme :: ICON_BIG);
        $src = htmlspecialchars($src);

        echo '<a href="#" onclick="set_object_type(\'' . $type_name . '\');return false;">';
        echo '<div style="background-image: url(' . $src . ');" class="create_block">';
        echo $object->get_type_name();
        echo '</div>';
        echo '</a>';
    }

    function create_form()
    {
        $defaults = $this->init();
        $object_type = Request :: get(self :: PARAM_CONTENT_OBJECT_TYPE);
        $object_type = $object_type ? $object_type : Request :: post(self :: PARAM_CONTENT_OBJECT_TYPE);
        if ($object_type)
        {
            $object = ContentObject :: factory($object_type);
        }
        else
            if (Request :: post('init'))
            {
                $object = ContentObject :: factory_from_resource($defaults);
            }
            else
            {
                $object = null;
            }
        $object->set_owner_id($this->get_user_id());
        if ($object)
        {
            $form = ContentObjectForm :: factory(ContentObjectForm :: TYPE_CREATE, $object, 'createformc', 'post',
                    $this->get_url());
        }
        else
        {
            $form = new AddResourceForm('add', 'post', $this->get_url(), $defaults);
        }
        $form->addElement('hidden', self :: PARAM_CONTENT_OBJECT_TYPE, $object->get_type());
        $form->addElement('hidden', self :: PARAM_NO_CREATE, ''); // we reset
                                                                  // that each
                                                                  // time
        if (! $form->getElementType(self :: PROPERTY_URL))
        {
            $url = Request :: post(self :: PROPERTY_URL);
            if (! $url)
            {
                $url = isset($defaults[self :: PROPERTY_URL]) ? $defaults[self :: PROPERTY_URL] : '';
            }
            $form->addElement('hidden', self :: PROPERTY_URL, $url);
        }
        if (! $form->getElementType(self :: PROPERTY_HTML))
        {
            $url = Request :: post(self :: PROPERTY_HTML);
            if (! $url)
            {
                $url = isset($defaults[self :: PROPERTY_HTML]) ? $defaults[self :: PROPERTY_HTML] : '';
            }
            $form->addElement('hidden', self :: PROPERTY_HTML, $url);
        } // todo add support for embeded html in document

        return $form;
    }

    function init()
    {
        if (! Request :: post('init'))
        {
            return array();
        }

        $defaults = array();

        if ($value = Request :: post(self :: PROPERTY_JSON_OEMBED))
        {
            $value = urldecode($value);
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_URL, $value);

            // make the request
            if ($data = curl_exec($ch))
            {
                $data = json_decode($data);
                foreach ($data as $key => $value)
                {
                    $defaults[$key] = $value;
                }
            }
            curl_close($ch);
        }

        if ($value = Request :: post(self :: PROPERTY_URL))
        {
            $defaults[self :: PROPERTY_URL] = urldecode($value);
        }
        if ($value = Request :: post(self :: PROPERTY_HTML))
        {
            // $value =
            // preg_replace("/%u([0-9a-f]{3,4})/i","&#x\\1;",urldecode($value));
            // $value = html_entity_decode($value, null, 'UTF-8');
            $defaults[self :: PROPERTY_HTML] = rawurldecode($value);
        }
        if ($value = Request :: post(ContentObject :: PROPERTY_TITLE))
        {
            $defaults[ContentObject :: PROPERTY_TITLE] = urldecode($value);
        }
        if ($value = Request :: post(ContentObject :: PROPERTY_DESCRIPTION))
        {
            $defaults[ContentObject :: PROPERTY_DESCRIPTION] = urldecode($value);
        }
        if ($object = ContentObject :: factory_from_resource($defaults))
        {
            $defaults[ContentObject :: PROPERTY_TITLE] = $object->get_title();
            $defaults[ContentObject :: PROPERTY_DESCRIPTION] = $object->get_description();
            $get_url = array($object, 'get_url');
            if (is_callable($get_url))
            {
                $defaults[self :: PROPERTY_URL] = call_user_func($get_url);
            }
            return $defaults;
        }

        return array();
    }

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        $form = $this->create_form();
        $this->process_form($form);
    }

    function process_form($form)
    {
        if (Request :: post(self :: PARAM_NO_CREATE))
        {
            $this->display_form($form);
            return;
        }
        if (! $form->validate())
        {
            $this->display_form($form);
            return;
        }

        if ($form->create_content_object())
        {
            $this->display_message(Translation :: get('ContentObjectCreated'));
            exit();
        }
        else
        {
            $this->display_message(Translation :: get('ContentObjectNotCreated'), true);
            exit();
        }
    }

    function get_content_object_type_creation_url($type)
    {
        return $this->get_url(array(RepositoryManager :: PARAM_CONTENT_OBJECT_TYPE => $type));
    }

    function is_allowed_to_create($type)
    {
        return true;
    }

    function get_allowed_content_object_types()
    {
        $types = $this->get_content_object_types(true, false);
        foreach ($types as $index => $type)
        {
            $registration = CommonDataManager :: get_registration(
                    ContentObject :: get_content_object_type_namespace($type));
            if (! $registration || ! $registration->is_active())
            {
                unset($types[$index]);
            }
        }

        return $types;
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add(
                new Breadcrumb(
                        $this->get_url(
                                array(
                                        RepositoryManager :: PARAM_ACTION => RepositoryManager :: ACTION_BROWSE_CONTENT_OBJECTS)),
                        Translation :: get('RepositoryManagerBrowserComponent')));
        $breadcrumbtrail->add_help('repository_creator');
    }

}

?>