<?php
namespace repository;

use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Utilities;
use common\libraries\EqualityCondition;
use common\libraries\Session;
use common\libraries\ResourceManager;
use common\libraries\ActionBarRenderer;
use common\libraries\ToolbarItem;
use common\libraries\Theme;
use common\libraries\BasicApplication;
use common\libraries\InCondition;
use common\libraries\AndCondition;
use common\libraries\OrCondition;
use common\libraries\NotCondition;
use common\libraries\ConditionProperty;
use common\libraries\Application;
use rights\PlatformGroupEntity;
use rights\UserEntity;

/**
 * $Id: shared_content_objects_browser.class.php 204 2009-11-13 12:51:30Z kariboe $
 *
 * @package repository.lib.repository_manager.component
 */
/**
 * Default repository manager component which allows the user to browse through the different categories and objects in
 * the repository.
 */
class RepositoryManagerSharedContentObjectsBrowserComponent extends RepositoryManager
{
    private $form;
    private $view;

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        $this->view = Request :: get(self :: PARAM_SHARED_VIEW);
        if (is_null($this->view))
        {
            $this->view = self :: SHARED_VIEW_OTHERS_OBJECTS;
        }

        $trail = BreadcrumbTrail :: get_instance();

        $this->action_bar = $this->get_action_bar();
        $this->form = new RepositoryFilterForm($this, $this->get_url());
        $output = $this->get_content_objects_html();

        $session_filter = Session :: retrieve('filter');

        if ($session_filter != null && ! $session_filter == 0)
        {
            if (is_numeric($session_filter))
            {
                $condition = new EqualityCondition(UserView :: PROPERTY_ID, $session_filter);
                $user_view = RepositoryDataManager :: get_instance()->retrieve_user_views($condition)->next_result();
                $trail->add(
                        new Breadcrumb($this->get_url(),
                                Translation :: get('Filter', null, Utilities :: COMMON_LIBRARIES) . ': ' . $user_view->get_name()));
            }
            else
            {
                $trail->add(
                        new Breadcrumb($this->get_url(),
                                Translation :: get('Filter', null, Utilities :: COMMON_LIBRARIES) . ': ' . Utilities :: underscores_to_camelcase(
                                        ($session_filter))));
            }
        }

        $this->display_header();

        echo $this->action_bar->as_html();
        echo '<br />' . $this->form->display() . '<br />';
        echo $output;
        echo ResourceManager :: get_instance()->get_resource_html(
                BasicApplication :: get_application_web_resources_javascript_path(RepositoryManager :: APPLICATION_NAME) . 'repository.js');

        $this->display_footer();
    }

    /**
     * Gets the table which shows the content objects
     */
    private function get_content_objects_html()
    {                        
        $parameters = $this->get_parameters(true);
        
        if($this->get_view() == RepositoryManager :: SHARED_VIEW_OTHERS_OBJECTS)
        {
            $condition = $this->get_content_objects_shared_with_me_condition();    
        }
        else
        {
            $condition = $this->get_content_objects_share_conditions(array(), $this->get_user_id());
        }

        $table = new RepositorySharedContentObjectsBrowserTable($this, $parameters, $condition);

        return $table->as_html();
    }
    
    /**
     * get the condition to retrieve content objects shared with you
     * @return Condition 
     */
    private function get_content_objects_shared_with_me_condition()
    {
        $entities = array();
        $entities[] = new UserEntity();
        $entities[] = new PlatformGroupEntity();
        
        $conditions = array();
        $conditions[] = $this->get_base_condition();
        
        $shared_content_object_ids = $this->get_shared_content_object_ids($entities);
        
        $rdm = RepositoryDataManager :: get_instance();
        
        $category_conditions = array();
        $category_conditions[] = new InCondition(
                SharedContentObjectRelCategory :: PROPERTY_CONTENT_OBJECT_ID, 
                $shared_content_object_ids, 
                SharedContentObjectRelCategory :: get_table_name()
        );
        
        //inside a category?
        $share_category = Request :: get(RepositoryManager :: PARAM_SHARED_CATEGORY_ID);
        if($share_category)
        {
            $category_conditions[] = new EqualityCondition(
                SharedContentObjectRelCategory :: PROPERTY_CATEGORY_ID, 
                $share_category, 
                SharedContentObjectRelCategory::get_table_name()
            );
        }
        else
        {
            $category_conditions[] = new EqualityCondition(
                RepositoryCategory :: PROPERTY_USER_ID, 
                $this->get_user_id(), 
                RepositoryCategory :: get_table_name()
            );
        }
        
        $category_condition = new AndCondition($category_conditions);
        
        $shared_content_objects_ids_in_categories = array();
        
        $shared_content_objects_in_categories = $rdm->retrieve_shared_content_object_rel_categories(
            $category_condition
        );
        
        while($shared_content_object_in_category = $shared_content_objects_in_categories->next_result())
        {
            $shared_content_objects_ids_in_categories[] = $shared_content_object_in_category->get_content_object_id();
        }
        
        if($share_category)
        {
            $valid_ids = $shared_content_objects_ids_in_categories;
        }
        else
        {
            $valid_ids = array_diff($shared_content_object_ids, $shared_content_objects_ids_in_categories);
        }
        
        $conditions[] = new InCondition(
            ContentObject :: PROPERTY_ID, 
            $valid_ids,
            ContentObject :: get_table_name()
        );
        
        $condition = new AndCondition($conditions);
                                
        return $condition;
        
    }
    
    protected function get_shared_content_object_ids($entities = null, $tree_identifier = null)
    {
        $retrieve_types = array(RepositoryRights :: TYPE_USER_CONTENT_OBJECT);

        $shared_locations_by_type = RepositoryRights :: get_instance()->get_location_overview_with_rights_granted(
                RepositoryManager :: APPLICATION_NAME, Session :: get_user_id(), $entities, null, $retrieve_types, 
                RepositoryRights :: TREE_TYPE_USER, $tree_identifier);

        if (empty($shared_locations_by_type))
        {
            $shared_locations_by_type[] = -1;
        }
        
        return $shared_locations_by_type[RepositoryRights :: TYPE_USER_CONTENT_OBJECT];
    }
    
    /**
     * Returns the base condition
     * 
     * @return \common\libraries\AndCondition
     */
    protected function get_base_condition()
    {
        $conditions = array();                                        
        
        $action_bar_condition = $this->action_bar->get_conditions(array(
                new ConditionProperty(ContentObject :: PROPERTY_TITLE),
                new ConditionProperty(ContentObject :: PROPERTY_DESCRIPTION)));
        if ($action_bar_condition)
        {
            $conditions[] = $action_bar_condition;
        }
        
        $filter_conditions = $this->form->get_filter_conditions();
        if ($filter_conditions)
        {
            $conditions[] = $filter_conditions;
        }  
        
        $conditions[] = new EqualityCondition(ContentObject :: PROPERTY_STATE, ContentObject :: STATE_NORMAL);
        
        return new AndCondition($conditions);
        
    }
    
    /**
     * gets the general conditions for the share browser
     * @return Condition 
     */
    private function get_content_objects_share_conditions($entities = null, $tree_identifier = null)
    {
        $shared_content_object_ids = $this->get_shared_content_object_ids($entities, $tree_identifier);
        
        $conditions = array();
        $conditions[] = $this->get_base_condition();
        
        $conditions[] = new InCondition(
            ContentObject :: PROPERTY_ID, 
            array_unique($shared_content_object_ids), 
            ContentObject :: get_table_name()
        );
        
        return new AndCondition($conditions);
    }
    
    function get_action_bar()
    {
        $action_bar = new ActionBarRenderer(ActionBarRenderer :: TYPE_HORIZONTAL);
        $action_bar->set_search_url($this->get_url());
        $action_bar->add_common_action(
                new ToolbarItem(Translation :: get('ShowAll', null, Utilities :: COMMON_LIBRARIES),
                        Theme :: get_common_image_path() . 'action_browser.png', $this->get_url(),
                        ToolbarItem :: DISPLAY_ICON_AND_LABEL));

        if ($this->view == self :: SHARED_VIEW_OTHERS_OBJECTS)
        {
            $action_bar->add_common_action(
                    new ToolbarItem(Translation :: get('ManageCategories'),
                            Theme :: get_common_image_path() . 'action_category.png',
                            $this->get_url(
                                    array(Application :: PARAM_ACTION => RepositoryManager :: ACTION_MANAGE_CATEGORIES,
                                            RepositoryManager :: PARAM_CATEGORY_TYPE => RepositoryCategory :: TYPE_SHARED)),
                            ToolbarItem :: DISPLAY_ICON_AND_LABEL));
        }

        return $action_bar;
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add(
                new Breadcrumb(
                        $this->get_url(
                                array(
                                        RepositoryManager :: PARAM_ACTION => RepositoryManager :: ACTION_BROWSE_CONTENT_OBJECTS)),
                        Translation :: get('RepositoryManagerBrowserComponent')));
        $breadcrumbtrail->add_help('repository_shared_content_object_browser');
    }

    function get_additional_parameters()
    {
        return array(self :: PARAM_SHARED_VIEW, RepositoryManager :: PARAM_SHARED_CATEGORY_ID);
    }

    function show_my_objects()
    {
        return Request :: get(self :: PARAM_SHARED_VIEW) == 1;
    }

    function get_view()
    {
        return $this->view;
    }

    function is_allowed_to_create($type)
    {
        return true;
    }
    
}
?>
