<?php
namespace repository;

use common\libraries\Request;
use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\EqualityCondition;
use common\libraries\AndCondition;
use common\libraries\FormValidator;
use common\libraries\Application;
use common\libraries\NotCondition;
use common\libraries\Breadcrumb;

/**
 * Default repository manager component which allows the user to move a share to a different share category
 * @author Pieterjan Broekaert  Hogeschool Gent
 */

class RepositoryManagerSharedContentObjectsMoverComponent extends RepositoryManager
{
    
    /**
     * Runs this component and displays its output.
     * @todo remove code duplication with repository component mover component
     */
    function run()
    {
        $ids = Request :: get(RepositoryManager :: PARAM_CONTENT_OBJECT_ID);
        if (! empty($ids))
        {
            if (! is_array($ids))
            {
                $ids = array($ids);
            }

            $this->tree[] = Translation :: get('ContentObjectsSharedWithMe');

            $this->get_categories_for_select(0, $parent);
            $form = new FormValidator('move', 'post', $this->get_url(array(
                    RepositoryManager :: PARAM_CONTENT_OBJECT_ID => $ids)));
            $form->addElement('select', RepositoryManager :: PARAM_DESTINATION_CONTENT_OBJECT_ID, 
                    Translation :: get('NewCategory'), $this->tree);
            $form->addElement('submit', 'submit', Translation :: get('Move', null, Utilities :: COMMON_LIBRARIES));
            
            if ($form->validate())
            {
                $destination = $form->exportValue(RepositoryManager :: PARAM_DESTINATION_CONTENT_OBJECT_ID);
                $failures = 0;
                foreach ($ids as $id)
                {
                    //Does this user already have a share category relation for this object?
                    $share_category_relation_object = RepositoryDataManager :: 
                            retrieve_shared_content_object_rel_category_for_user_and_content_object($this->get_user_id(), $id);
                    if($share_category_relation_object)
                    {
                        if($destination == 0)
                        {
                            if(!$share_category_relation_object->delete())
                            {
                                $failures++;
                            }
                        }
                        else
                        {
                            $share_category_relation_object->set_category_id($destination);
                            if(!$share_category_relation_object->update())
                            {
                                $failures++;
                            }
                        }                        
                    }
                    else
                    {
                        $share_category_relation_object = new SharedContentObjectRelCategory();
                        $share_category_relation_object->set_content_object_id($id);
                        $share_category_relation_object->set_category_id($destination);
                        if(!$share_category_relation_object->create())
                        {
                            $failures++;
                        }
                    }                    
                }

                if ($failures)
                {
                    if (count($ids) == 1)
                    {
                        $message = Translation :: get('ObjectNotMoved', array(
                                'OBJECT' => Translation :: get('ContentObject')), Utilities :: COMMON_LIBRARIES);
                    }
                    else
                    {
                        $message = Translation :: get('ObjectsNotMoved', array(
                                'OBJECTS' => Translation :: get('ContentObjects')), Utilities :: COMMON_LIBRARIES);
                    }
                }
                else
                {
                    if (count($ids) == 1)
                    {
                        $message = Translation :: get('ObjectMoved', array(
                                'OBJECT' => Translation :: get('ContentObject')), Utilities :: COMMON_LIBRARIES);
                    }
                    else
                    {
                        $message = Translation :: get('ObjectsMoved', array(
                                'OBJECTS' => Translation :: get('ContentObjects')), Utilities :: COMMON_LIBRARIES);
                    }
                }

                $parameters = array();
                $parameters[RepositoryManager :: PARAM_ACTION] = RepositoryManager :: ACTION_BROWSE_SHARED_CONTENT_OBJECTS;
                $parameters[RepositoryManager :: PARAM_SHARED_CATEGORY_ID] = $destination;
                $this->redirect($message, ($failures ? true : false), $parameters);
            }
            else
            {
                $this->display_header();
                echo $form->toHTML();
                $this->display_footer();
            }
        }
        else
        {
            $this->display_error_page(htmlentities(Translation :: get('NoObjectSelected', array(
                    'OBJECT' => Translation :: get('ContentObject')), Utilities :: COMMON_LIBRARIES)));
        }
    }
    /**
     * Get all categories from which a user can select a target category when
     * moving objects.
     * @param array $exclude An array of category-id's which should be excluded
     * from the resulting list.
     * @return array A list of possible categories from which a user can choose.
     * Can be used as input for a QuickForm select field.
     */

    private $level = 1;
    private $tree = array();

    private function get_categories_for_select($parent_id, $current_parent)
    {
        $conditions[] = new EqualityCondition(RepositoryCategory :: PROPERTY_PARENT, $parent_id);
        $conditions[] = new EqualityCondition(RepositoryCategory :: PROPERTY_USER_ID, $this->get_user_id());
        $conditions[] = new EqualityCondition(RepositoryCategory :: PROPERTY_TYPE, RepositoryCategory :: TYPE_SHARED);

        $condition = new AndCondition($conditions);

        $categories = $this->retrieve_categories($condition);

        $tree = array();
        while ($cat = $categories->next_result())
        {
            $this->tree[$cat->get_id()] = str_repeat('--', $this->level) . ' ' . $cat->get_name();

            if ($current_parent == $cat->get_id())
            {
                $this->tree[$cat->get_id()] .= ' (' . Translation :: get('Current', null, Utilities :: COMMON_LIBRARIES) . ')';
            }

            $this->level ++;
            $this->get_categories_for_select($cat->get_id(), $current_parent);
            $this->level --;
        }
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {

        $breadcrumbtrail->add(new Breadcrumb($this->get_url(array(
                RepositoryManager :: PARAM_ACTION => RepositoryManager :: ACTION_BROWSE_SHARED_CONTENT_OBJECTS)), 
                Translation :: get('RepositoryManagerSharedContentObjectBrowserComponent')));
        $breadcrumbtrail->add_help('share_mover');

    }
    

    function get_additional_parameters()
    {
        return array(self :: PARAM_SHARED_VIEW, RepositoryManager :: PARAM_CONTENT_OBJECT_ID);
    }
}
?>
