<?php
namespace repository;

use common\libraries\Translation;
use common\libraries\Utilities;
use common\libraries\ToolbarItem;
use common\libraries\Toolbar;
use common\libraries\Theme;

use user\UserManager;
use HTML_QuickForm;

/**
 * $Id: repository_browser_table_cell_renderer.class.php 204 2009-11-13
 * 12:51:30Z kariboe $
 *
 * @package repository.lib.repository_manager.component.browser
 */

/**
 * Cell rendere for the content object browser table
 */
class RepositoryVersionBrowserTableCellRenderer extends DefaultContentObjectTableCellRenderer
{
    /**
     * The repository browser component
     */
    private $browser;

    /**
     * Constructor
     *
     * @param $browser RepositoryManagerBrowserComponent
     */
    function __construct($browser)
    {
        parent :: __construct();
        $this->browser = $browser;
    }

    // Inherited
    function render_cell($column, $content_object)
    {
        if ($column === RepositoryVersionBrowserTableColumnModel :: get_modification_column())
        {
            return $this->get_modification_links($content_object);
        }

        switch ($column->get_name())
        {
            case ContentObject :: PROPERTY_TITLE :
                $title = parent :: render_cell($column, $content_object);
                $title_short = Utilities :: truncate_string($title, 53, false);
                return '<a href="' . htmlentities($this->browser->get_content_object_viewing_url($content_object)) . '" title="' . $title . '">' . $title_short . '</a>';
            case Translation :: get('CompareWith') :
                return HTML_QuickForm :: createElement('radio', 'B', null, null, 'B' . $content_object->get_id())->toHtml();
            case Translation :: get('User', null, UserManager :: APPLICATION_NAME) :
                return $content_object->get_owner_fullname();
        }
        return parent :: render_cell($column, $content_object);
    }

    /**
     * Gets the action links to display
     *
     * @param $content_object ContentObject
     *            The content object for which the
     *            action links should be returned
     * @return string A HTML representation of the action links
     */
    private function get_modification_links($content_object)
    {
        $toolbar = new Toolbar();

        // delete only for owner
        if ($content_object->get_owner_id() == $this->browser->get_user_id())
        {
            $remove_url = $this->browser->get_content_object_deletion_url($content_object, 'version');
            if ($remove_url)
            {
                $toolbar->add_item(new ToolbarItem(Translation :: get('Delete', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_remove.png', $remove_url, ToolbarItem :: DISPLAY_ICON));
            }
            else
            {
                $toolbar->add_item(new ToolbarItem(Translation :: get('DeleteNotAvailable', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_remove_na.png', null, ToolbarItem :: DISPLAY_ICON));
            }
        }

        // revert if collaborate right or owner
        if (($content_object->get_owner_id() == $this->browser->get_user_id() || RepositoryRights :: get_instance()->is_allowed_in_user_subtree(RepositoryRights :: COLLABORATE_RIGHT, $content_object->get_id(), RepositoryRights :: TYPE_USER_CONTENT_OBJECT, $content_object->get_owner_id())))
        {
            $revert_url = $this->browser->get_content_object_revert_url($content_object, 'version');
            if ($revert_url)
            {
                $toolbar->add_item(new ToolbarItem(Translation :: get('Revert', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_revert.png', $revert_url, ToolbarItem :: DISPLAY_ICON));
            }
            else
            {
                $toolbar->add_item(new ToolbarItem(Translation :: get('RevertNotAvailable', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_revert_na.png', null, ToolbarItem :: DISPLAY_ICON));
            }
        }

        return $toolbar->as_html();
    }
}
?>