<?php
namespace repository;

use common\libraries\Utilities;
use repository\RepositoryManager;
use common\libraries\Breadcrumb;
use common\libraries\Translation;

/**
 * Creator for share rights
 *
 * @author Pieterjan Broekaert
 * @author Sven Vanpoucke
 */
class ShareManagerCreateComponent extends ShareManager
{

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        $ids = $this->get_content_object_ids();
        if ($ids)
        {
            if (! is_array($ids))
            {
                $ids = array($ids);
            }
            
            $share_form = ContentObjectShareForm :: factory(ContentObjectShareForm :: TYPE_CREATE, $ids, $this->get_user(), $this->get_url());
            
            if ($share_form->validate())
            {
                $succes = $share_form->create_content_object_share();
                
                $message = $succes ? Translation :: get('ObjectShared') : Translation :: get('ObjectNotShared', array(
                        'OBJECT' => Translation :: get('ContentObject')), Utilities :: COMMON_LIBRARIES);
                
                $this->redirect($message, ! $succes, array(self :: PARAM_SHARE_ACTION => self :: ACTION_BROWSE));
            }
            else
            {
                $this->display_header();
                
                echo $this->display_content_objects();
                $share_form->display();
                
                $this->display_footer();
            }
        }
        else
        {
            $this->display_error_page(Translation :: get('NoObjectsSelected', array(
                    'OBJECTS' => Translation :: get('ContentObjects')), Utilities :: COMMON_LIBRARIES));
        }
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add(new Breadcrumb($this->get_url(array(self :: PARAM_SHARE_ACTION => self :: ACTION_BROWSE)), Translation :: get('ShareManagerBrowserComponent')));
        
        $breadcrumbtrail->add_help('repository_content_object_share_rights_creator');
    }

    function get_additional_parameters()
    {
        return array(RepositoryManager :: PARAM_CONTENT_OBJECT_ID);
    }

}

?>
