<?php

namespace repository;

use common\libraries\Utilities;
use common\libraries\Breadcrumb;
use common\libraries\Request;
use common\libraries\Translation;

/**
 * Updater component for shared content objects
 *
 * @author Pieterjan Broekaert
 * @author Sven Vanpoucke
 */
class ShareManagerUpdateComponent extends ShareManager
{

    function run()
    {
        $ids = $this->get_content_object_ids();
        
        $target_users = Request :: get(ShareManager :: PARAM_TARGET_USERS);
        $target_groups = Request :: get(ShareManager :: PARAM_TARGET_GROUPS);
        
        if (($target_users || $target_groups))
        {
            if (! is_array($ids))
            {
                $ids = array($ids);
            }
            
            if ($target_users && ! is_array($target_users))
            {
                $target_users = array($target_users);
            }
            
            if ($target_groups && ! is_array($target_groups))
            {
                $target_groups = array($target_groups);
            }
            
            $share_form = ContentObjectShareForm :: factory(ContentObjectShareForm :: TYPE_EDIT, $ids, $this->get_user(), $this->get_url());
            
            if (count($target_users) + count($target_groups) == 1 && count($ids) == 1)
            {
                $share_form->set_default_rights($target_users, $target_groups);
            }
            
            if ($share_form->validate())
            {
                $succes = $share_form->update_content_object_share($target_users, $target_groups);
                
                $message = $succes ? Translation :: get('ObjectShared') : Translation :: get('ObjectNotShared', array(
                        'OBJECT' => Translation :: get('ContentObject')), Utilities :: COMMON_LIBRARIES);
                
                $this->redirect($message, ! $succes, array(self :: PARAM_SHARE_ACTION => self :: ACTION_BROWSE));
            }
            else
            {
                $this->display_header();
                
                echo $this->display_content_objects();
                $share_form->display();
                
                $this->display_footer();
            }
        }
        else
        {
            $this->display_error_page(Translation :: get('NoObjectsSelected', array(
                    'OBJECTS' => Translation :: get('ContentObjects')), Utilities :: COMMON_LIBRARIES));
        }
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add(new Breadcrumb($this->get_url(array(self :: PARAM_SHARE_ACTION => self :: ACTION_BROWSE)), Translation :: get('ShareManagerBrowserComponent')));
        
        $breadcrumbtrail->add_help('repository_content_object_share_rights_creator');
    }

    function get_additional_parameters()
    {
        return array(ShareManager :: PARAM_TARGET_GROUPS, ShareManager :: PARAM_TARGET_USERS);
    }

}

?>