<?php
namespace repository;

use common\libraries\DynamicTabsRenderer;
use common\libraries\Translation;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Utilities;
use common\libraries\EqualityCondition;
use common\libraries\OptionsMenuRenderer;
use common\libraries\TreeMenuRenderer;
use HTML_Menu;
use HTML_Menu_ArrayRenderer;
use common\libraries\ObjectTableOrder;

class UserViewMenu extends HTML_Menu
{
    const TREE_NAME = __CLASS__;
    
    /**
     * The string passed to sprintf() to format category URLs
     */
    private $urlFmt;
    /**
     * The array renderer used to determine the breadcrumbs.
     */
    private $array_renderer;
    private $repository_manager;

    function __construct($repository_manager, $current_category = null, $url_format = '?category=%s')
    {
        $this->urlFmt = $url_format;
        $this->repository_manager = $repository_manager;
        parent :: __construct($this->get_menu_items());
        $this->array_renderer = new HTML_Menu_ArrayRenderer();
        $this->forceCurrentUrl($this->get_category_url($current_category));
    }

    /**
     * Returns the menu items.
     * @return array An array with all menu items.
     */
    private function get_menu_items()
    {
        $menu = array();
        $menu_item = array();
        
        $condition = new EqualityCondition(UserView :: PROPERTY_USER_ID, $this->repository_manager->get_user_id());
        $userviews = RepositoryDataManager :: get_instance()->retrieve_user_views($condition);
        
        $userview = array();
        $userview['title'] = Translation :: get('UserViews');
        $userview['url'] = $this->repository_manager->get_browse_user_views_url();
        $userview['class'] = 'userview';
        $menu[] = $userview;
        
        while ($userview = $userviews->next_result())
        {
            $menu_item = array();
            $menu_item['title'] = $userview->get_name();
            $menu_item['url'] = $this->repository_manager->get_url(array(
                    RepositoryManager :: PARAM_USER_VIEW => $userview->get_id(), 
                    DynamicTabsRenderer :: PARAM_SELECTED_TAB => 'userview'));
            $menu_item['class'] = '';
            $menu_item[OptionsMenuRenderer :: KEY_ID] = $userview->get_id();
            $menu[] = $menu_item;
        
        }
        //        
        //        $menu_item['title'] = Translation :: get('MyRepository')/* . ' (' . $count . ')' */;
        //        $menu_item['url'] = $this->get_category_url(0);
        //        
        //        if (RepositoryDataManager :: user_has_categories($this->owner))
        //        {
        //            $sub_menu_items = $this->get_sub_menu_items();
        //            if (count($sub_menu_items) > 0)
        //            {
        //                $menu_item['sub'] = $sub_menu_items;
        //            }
        //        }
        //        $menu_item['class'] = 'category';
        //        $menu_item[OptionsMenuRenderer :: KEY_ID] = 0;
        //        $menu[0] = $menu_item;
        return $menu;
    }

    /**
     * Gets the URL of a given category
     * @param int $category The id of the category
     * @return string The requested URL
     */
    private function get_category_url($category)
    {
        // TODO: Put another class in charge of the htmlentities() invocation
        return htmlentities(sprintf($this->urlFmt, $category));
    }

    /**
     * Get the breadcrumbs which lead to the current category.
     * @return array The breadcrumbs.
     */
    function get_breadcrumbs()
    {
        $trail = BreadcrumbTrail :: get_instance();
        $this->render($this->array_renderer, 'urhere');
        $breadcrumbs = $this->array_renderer->toArray();
        foreach ($breadcrumbs as $crumb)
        {
            $str = Translation :: get('MyRepository');
            if (substr($crumb['title'], 0, strlen($str)) == $str)
                continue;
            $trail->add(new Breadcrumb($crumb['url'], substr($crumb['title'], 0, strpos($crumb['title'], '('))));
        }
        return $trail;
    }

    /**
     * Renders the menu as a tree
     * @return string The HTML formatted tree
     */
    function render_as_tree()
    {
        $renderer = new TreeMenuRenderer($this->get_tree_name());
        $this->render($renderer, 'sitemap');
        return $renderer->toHTML();
    }

    static function get_tree_name()
    {
        return Utilities :: get_classname_from_namespace(self :: TREE_NAME, true);
    }

}

?>