<?php

namespace repository;

use common\libraries\Translation;
use common\libraries\EqualityCondition;
use common\libraries\WebserviceHandler;
use common\libraries\Utilities;
use common\libraries\SuccessRestMessage;
use common\libraries\AndCondition;
use common\libraries\Request;

class ContentObjectAttachmentDeleteWebserviceHandler extends WebserviceHandler
{

    function run()
    {
        $content_object_id = Request :: get(ContentObjectAttachment :: PROPERTY_CONTENT_OBJECT_ID);
        $attachment_id = Request :: get(ContentObjectAttachment :: PROPERTY_ATTACHMENT_ID);
        $translation = $this->get_object_translation();
        
        if (empty($content_object_id) && empty($attachment_id))
        {
            return new SuccessRestMessage(false, Translation :: get('ObjectNotFound', null, Utilities :: COMMON_LIBRARIES));
        }
        
        if (! $this->is_allowed_to_delete_objects($content_object_id, $attachment_id))
        {
            return new SuccessRestMessage(false, Translation :: get('NotAllowed', null, Utilities :: COMMON_LIBRARIES));
        }
        
        $conditions = array();
        if ($content_object_id)
        {
            $conditions[] = new EqualityCondition(ContentObjectAttachment :: PROPERTY_CONTENT_OBJECT_ID, $content_object_id);
        }
        if ($attachment_id)
        {
            $conditions[] = new EqualityCondition(ContentObjectAttachment :: PROPERTY_ATTACHMENT_ID, $attachment_id);
        }
        $condition = new AndCondition($conditions);
        
        $success = RepositoryDataManager :: get_instance()->delete_content_object_attachments($condition);
        
        if (! $success)
        {
            return new SuccessRestMessage(false, Translation :: get('FailedToDeleteObject', array(
                    'OBJECT' => $translation, 'REASON' => implode(', ', $object->get_errors())), Utilities :: COMMON_LIBRARIES));
        }
        
        return new SuccessRestMessage(true, Translation :: get('ObjectDeleted', array('OBJECT' => $translation), Utilities :: COMMON_LIBRARIES));
    }

    public function get_object_translation()
    {
        return Translation :: get('ContentObjectAttachment');
    }

    function is_allowed_to_delete_objects($content_object_id, $attachment_id)
    {
        if ($this->get_user()->is_platform_admin())
        {
            return true;
        }
        $rdm = RepositoryDataManager :: get_instance();
        if ($content_object_id)
        {
            $content_object = $rdm->retrieve_content_object($content_object_id);
            if ($content_object->get_owner_id() != $this->get_user_id())
            {
                return false;
            }
        }
        if ($attachment_id)
        {
            $attachment = $rdm->retrieve_content_object($attachment_id);
            if ($attachment->get_owner_id() != $this->get_user_id())
            {
                return false;
            }
        }
        return true;
    }

}

?>
