<?php

namespace repository;

use common\libraries\Translation;
use common\libraries\WebserviceHandler;
use common\libraries\SuccessRestMessage;
use common\libraries\Utilities;
use common\libraries\DataClass;

class ContentObjectIncludeCreateWebserviceHandler extends WebserviceHandler
{

    function run()
    {
        $data = $this->get_data();
        
        $properties = $data[self :: PROPERTIES][DataClass :: PROPERTIES_DEFAULT];
        if (empty($properties['content_object_id']) || empty($properties['include_id']))
        {
            return new SuccessRestMessage(false, Translation :: get('DefaultPropertiesCanNotBeNull', null, Utilities :: COMMON_LIBRARIES));
        }
        
        $content_object = RepositoryDataManager :: get_instance()->retrieve_content_object($properties['content_object_id']);
        
        if (empty($content_object))
        {
            return new SuccessRestMessage(false, Translation :: get('ObjectNotFound', null, Utilities :: COMMON_LIBRARIES));
        }
        
        if ($this->is_allowed_to_create_include($content_object, $properties['include_id']))
        {
            $content_object->include_content_object($properties['include_id']);
            return new SuccessRestMessage(true, Translation :: get('IncludeCreated', null, Utilities :: COMMON_LIBRARIES));
        }
        
        return new SuccessRestMessage(false, Translation :: get('NotAllowed', null, Utilities :: COMMON_LIBRARIES));
    }

    function is_allowed_to_create_include($content_object, $include_id)
    {
        if ($this->get_user()->is_platform_admin())
        {
            return true;
        }
        if ($content_object->get_owner_id() != $this->get_user_id())
        {
            return false;
        }
        $included_object = RepositoryDataManager :: get_instance()->retrieve_content_object($include_id);
        return $included_object->get_owner_id() == $this->get_user_id();
    }

}

?>
