<?php

namespace repository;

use common\libraries\Translation;
use common\libraries\WebserviceHandler;
use common\libraries\SuccessRestMessage;
use common\libraries\Utilities;
use common\libraries\Request;

class ContentObjectIncludeDeleteWebserviceHandler extends WebserviceHandler
{

    function run()
    {
        $content_object_id = Request :: get('content_object_id');
        $include_id = Request :: get('include_id');
        
        if (empty($content_object_id) && empty($include_id))
        {
            return new SuccessRestMessage(false, Translation :: get('ObjectNotFound', null, Utilities :: COMMON_LIBRARIES));
        }
        
        if ($content_object_id && $include_id)
        {
            $content_object = RepositoryDataManager :: get_instance()->retrieve_content_object($content_object_id);
            if ($this->is_allowed_to_delete_include($content_object))
            {
                $success = $content_object->exclude_content_object($include_id);
            }
        }
        else
        {
            if ($content_object_id)
            {
                $content_object = RepositoryDataManager :: get_instance()->retrieve_content_object($content_object_id);
                if ($this->is_allowed_to_delete_include($content_object))
                {
                    $success = RepositoryDataManager :: get_instance()->delete_content_object_includes($content_object, true);
                }
            }
            else
            {
                $content_object = RepositoryDataManager :: get_instance()->retrieve_content_object($include_id);
                if ($this->is_allowed_to_delete_include($content_object))
                {
                    $success = RepositoryDataManager :: get_instance()->delete_content_object_includes($content_object);
                }
            }
        }
        
        if (! $success)
        {
            return new SuccessRestMessage(false, Translation :: get('FailedToDeleteObject', null, Utilities :: COMMON_LIBRARIES));
        }
        
        return new SuccessRestMessage(true, Translation :: get('IncludeDeleted', null, Utilities :: COMMON_LIBRARIES));
    }

    private function is_allowed_to_delete_include($content_object)
    {
        return ($this->get_user()->is_platform_admin() || $content_object->get_owner_id() == $this->get_user_id());
    }

}

?>
