<?php
namespace repository;

use common\libraries\Translation;
use common\libraries\WebserviceHandler;
use common\libraries\Request;
use common\libraries\Utilities;
use common\libraries\SuccessRestMessage;

class ContentObjectIncludeGetListWebserviceHandler extends WebserviceHandler
{

    function run()
    {
        $content_object_id = Request :: get('content_object_id');
        $include_id = Request :: get('include_id');
        $translation = Translation :: get('ContentObjectIncludes');
        
        if (empty($content_object_id) && empty($include_id))
        {
            return new SuccessRestMessage(false, Translation :: get('NoObjectsFound', array('OBJECTS' => $translation), Utilities :: COMMON_LIBRARIES));
        }
        
        if ($content_object_id)
        {
            $object = RepositoryDataManager :: get_instance()->retrieve_content_object($content_object_id);
            if ($object)
            {
                if (! $this->is_allowed_to_retrieve_includes($object))
                {
                    return new SuccessRestMessage(false, Translation :: get('NotAllowed', null, Utilities :: COMMON_LIBRARIES));
                }
                $includes = $object->get_included_content_objects();
            }
        }
        elseif ($include_id)
        {
            $object = RepositoryDataManager :: get_instance()->retrieve_content_object($include_id);
            if ($object)
            {
                if (! $this->is_allowed_to_retrieve_includes($object))
                {
                    return new SuccessRestMessage(false, Translation :: get('NotAllowed', null, Utilities :: COMMON_LIBRARIES));
                }
                $includes = RepositoryDataManager :: get_instance()->retrieve_objects_in_which_object_is_included($object)->as_array();
            }
        }
        
        if (count($includes) < 1)
        {
            return new SuccessRestMessage(true, Translation :: get('NoObjectsFound', array('OBJECTS' => $translation), Utilities :: COMMON_LIBRARIES));
        }
        else
        {
            return $includes;
        }
    }

    private function is_allowed_to_retrieve_includes($content_object)
    {
        return ($this->get_user()->is_platform_admin() || $content_object->get_owner_id() == $this->get_user_id());
    }
}
?>