<?php
namespace repository\quota;

use repository\quota\Calculator;

use common\libraries\Theme;
use common\libraries\ToolbarItem;
use common\libraries\PlatformSetting;
use common\libraries\ActionBarRenderer;
use common\libraries\NotAllowedException;
use common\libraries\Filesystem;
use common\libraries\Utilities;
use common\libraries\Translation;

class CreatorComponent extends Manager
{
    private $calculator;

    function run()
    {
        $this->calculator = new Calculator($this->get_user());
        if (! $this->calculator->request_allowed())
        {
            throw new NotAllowedException();
        }

        $request = new Request();
        $request->set_user_id($this->get_user_id());

        $form = new RequestForm($request, $this->get_url(array(self :: PARAM_ACTION => self :: ACTION_CREATE)));

        if ($form->validate())
        {
            $values = $form->exportValues();

            $request->set_quota($values[Request :: PROPERTY_QUOTA] * pow(1024, 2));
            $request->set_motivation($values[Request :: PROPERTY_MOTIVATION]);
            $request->set_decision(Request :: DECISION_PENDING);
            $request->set_creation_date(time());

            $success = $request->create();

            $parameters = array();
            $parameters[self :: PARAM_ACTION] = self :: ACTION_BROWSE;

            $this->redirect(Translation :: get($success ? 'ObjectCreated' : 'ObjectNotCreated', array(
                    'OBJECT' => Translation :: get('Request')), Utilities :: COMMON_LIBRARIES), ($success ? false : true), $parameters);
        }
        else
        {
            $this->display_header();
            echo $this->get_action_bar()->as_html();
            $form->display();
            $this->display_footer();
        }
    }

    function get_action_bar()
    {
        $action_bar = new ActionBarRenderer(ActionBarRenderer :: TYPE_HORIZONTAL);

        $allow_upgrade = PlatformSetting :: get('allow_upgrade', __NAMESPACE__);
        $maximum_user_disk_space = PlatformSetting :: get('maximum_user', __NAMESPACE__);

        if ($this->calculator->upgrade_allowed())
        {
            $action_bar->add_common_action(new ToolbarItem(Translation :: get('UpgradeQuota'), Theme :: get_image_path() . 'action/upgrade.png', $this->get_url(array(
                    self :: PARAM_ACTION => self :: ACTION_UPGRADE))));
        }

        $action_bar->add_tool_action(new ToolbarItem(Translation :: get('BackToOverview'), Theme :: get_image_path() . 'action/browser.png', $this->get_url(array(
                self :: PARAM_ACTION => self :: ACTION_BROWSE))));

        return $action_bar;
    }
}
?>