<?php
namespace rights;

use repository\ContentObject;
use repository\RepositoryRights;

use common\libraries\Mdb2Database;
use common\libraries\EqualityCondition;
use common\libraries\AndCondition;
use common\libraries\OrCondition;
use common\libraries\PatternMatchCondition;
use common\libraries\InequalityCondition;
use common\libraries\NotCondition;
use common\libraries\SubselectCondition;
use common\libraries\InCondition;
use common\libraries\ConditionTranslator;
use common\libraries\Mdb2ResultSet;
use common\libraries\Utilities;

use user\UserDataManager;
use user\UserRightsTemplate;

use group\GroupDataManager;
use group\GroupRightsTemplate;

/**
 * $Id: database_rights_data_manager.class.php 235 2009-11-16 12:08:00Z scaramanga $
 *
 * @package rights.lib.data_manager
 */

/**
 * This is a data manager that uses a database for storage. It was written for MySQL, but should be compatible with most
 * SQL flavors.
 *
 * @author Tim De Pauw
 * @author Bart Mollet
 * @author Hans De Bisschop
 */
class Mdb2RightsDataManager extends Mdb2Database implements RightsDataManagerInterface
{

    function initialize()
    {
        parent :: initialize();
        $this->set_prefix('rights_');
    }

    function update_rights_template_right_location($rights_templaterightlocation)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(RightsTemplateRightLocation :: PROPERTY_RIGHT_ID,
                $rights_templaterightlocation->get_right_id());
        $conditions[] = new EqualityCondition(RightsTemplateRightLocation :: PROPERTY_LOCATION_ID,
                $rights_templaterightlocation->get_rights_template_id());
        $condition = new AndCondition($conditions);

        return $this->update($rights_templaterightlocation, $condition);
    }

    function delete_rights_template_right_location($rights_template_right_location)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(RightsTemplateRightLocation :: PROPERTY_RIGHT_ID,
                $rights_template_right_location->get_right_id());
        $conditions[] = new EqualityCondition(RightsTemplateRightLocation :: PROPERTY_RIGHTS_TEMPLATE_ID,
                $rights_template_right_location->get_rights_template_id());
        $conditions[] = new EqualityCondition(RightsTemplateRightLocation :: PROPERTY_LOCATION_ID,
                $rights_template_right_location->get_location_id());
        $condition = new AndCondition($conditions);

        return $this->delete(RightsTemplateRightLocation :: get_table_name(), $condition);
    }

    function delete_rights_template_right_locations($condition)
    {
        return $this->delete_objects(RightsTemplateRightLocation :: get_table_name(), $condition);
    }

    function retrieve_template($template_id)
    {
        $this->set_prefix('rights_');
        $condition = new EqualityCondition(RightsTemplate :: PROPERTY_ID, $template_id);
        return $this->retrieve_object(RightsTemplate :: get_table_name(), $condition);

    }

    // Inherited.
    function create_location($location)
    {
        $this->set_prefix('rights_');
        return $this->create($location);
    }

    function create_right($right)
    {
        return $this->create($right);
    }

    function create_rights_template($rights_template)
    {
        $this->set_prefix('rights_');

        return $this->create($rights_template);
    }

    function create_type_template($type_template)
    {
        $this->set_prefix('rights_');

        return $this->create($type_template);
    }

    function create_rights_template_right_location($rights_template_right_location)
    {
        return $this->create($rights_template_right_location);
    }

    function retrieve_location_id_from_location_string($location)
    {
        $condition = new PatternMatchCondition(Location :: PROPERTY_NAME, $location);
        return $this->retrieve_object(Location :: get_table_name(), $condition, array(), Location :: CLASS_NAME);
    }

    /**
     * retrieves the rights_template and right location
     *
     * @param $right_id int
     * @param $rights_template_id int
     * @param $location_id int
     * @return RightsTemplateRightLocation
     */
    function retrieve_rights_template_right_location($right_id, $rights_template_id, $location_id)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(RightsTemplateRightLocation :: PROPERTY_RIGHT_ID, $right_id);
        $conditions[] = new EqualityCondition(RightsTemplateRightLocation :: PROPERTY_RIGHTS_TEMPLATE_ID,
                $rights_template_id);
        $conditions[] = new EqualityCondition(RightsTemplateRightLocation :: PROPERTY_LOCATION_ID, $location_id);
        $condition = new AndCondition($conditions);

        return $this->retrieve_object(RightsTemplateRightLocation :: get_table_name(), $condition, array(),
                RightsTemplateRightLocation :: CLASS_NAME);
    }

    function retrieve_rights_templates($condition = null, $offset = null, $max_objects = null, $order_by = null)
    {
        $this->set_prefix('rights_');

        return $this->retrieve_objects(RightsTemplate :: get_table_name(), $condition, $offset, $max_objects, $order_by,
                RightsTemplate :: CLASS_NAME);
    }

    function retrieve_type_templates($condition = null, $offset = null, $max_objects = null, $order_by = null)
    {
        $this->set_prefix('rights_');

        return $this->retrieve_objects(TypeTemplate :: get_table_name(), $condition, $offset, $max_objects, $order_by,
                TypeTemplate :: CLASS_NAME);
    }

    function retrieve_location($id)
    {
        $condition = new EqualityCondition(Location :: PROPERTY_ID, $id);
        return $this->retrieve_object(Location :: get_table_name(), $condition, array(), Location :: CLASS_NAME);
    }

    function retrieve_right($id)
    {
        $condition = new EqualityCondition(Right :: PROPERTY_ID, $id);
        return $this->retrieve_object(Right :: get_table_name(), $condition, array(), Right :: CLASS_NAME);
    }

    function retrieve_rights_template($id)
    {
        $this->set_prefix('rights_');

        $condition = new EqualityCondition(RightsTemplate :: PROPERTY_ID, $id);
        return $this->retrieve_object(RightsTemplate :: get_table_name(), $condition, array(), RightsTemplate :: CLASS_NAME);
    }

    function retrieve_type_template($id)
    {
        $this->set_prefix('rights_');

        $condition = new EqualityCondition(TypeTemplate :: PROPERTY_ID, $id);
        return $this->retrieve_object(TypeTemplate :: get_table_name(), $condition, array(), TypeTemplate :: CLASS_NAME);
    }

    function retrieve_rights($condition = null, $offset = null, $max_objects = null, $order_by = null)
    {
        return $this->retrieve_objects(Right :: get_table_name(), $condition, $offset, $max_objects, $order_by,
                Right :: CLASS_NAME);
    }

    function retrieve_locations($condition = null, $offset = null, $max_objects = null, $order_by = null)
    {
        return $this->retrieve_objects(Location :: get_table_name(), $condition, $offset, $max_objects, $order_by,
                Location :: CLASS_NAME);
    }

    function count_locations($condition = null)
    {
        return $this->count_objects(Location :: get_table_name(), $condition);
    }

    function count_rights_templates($condition = null)
    {
        $this->set_prefix('rights_');

        return $this->count_objects(RightsTemplate :: get_table_name(), $condition);
    }

    function count_type_templates($condition = null)
    {
        $this->set_prefix('rights_');

        return $this->count_objects(TypeTemplate :: get_table_name(), $condition);
    }

    function update_location($location)
    {
        $condition = new EqualityCondition(Location :: PROPERTY_ID, $location->get_id());
        return $this->update($location, $condition);
    }

    function add_nested_values($location, $previous_visited, $number_of_elements = 1)
    {
        // Update all necessary left-values
        $conditions = array();
        $conditions[] = new EqualityCondition(Location :: PROPERTY_APPLICATION, $location->get_application());
        $conditions[] = new EqualityCondition(Location :: PROPERTY_TREE_TYPE, $location->get_tree_type());
        $conditions[] = new EqualityCondition(Location :: PROPERTY_TREE_IDENTIFIER, $location->get_tree_identifier());
        $conditions[] = new InequalityCondition(Location :: PROPERTY_LEFT_VALUE, InequalityCondition :: GREATER_THAN,
                $previous_visited);
        $condition = new AndCondition($conditions);

        $properties = array(
                Location :: PROPERTY_LEFT_VALUE => $this->escape_column_name(Location :: PROPERTY_LEFT_VALUE) . ' + ' . $this->quote(
                        $number_of_elements * 2));
        $res = $this->update_objects(Location :: get_table_name(), $properties, $condition);

        if (! $res)
        {
            return false;
        }

        // Update all necessary right-values
        $conditions = array();
        $conditions[] = new EqualityCondition(Location :: PROPERTY_APPLICATION, $location->get_application());
        $conditions[] = new EqualityCondition(Location :: PROPERTY_TREE_TYPE, $location->get_tree_type());
        $conditions[] = new EqualityCondition(Location :: PROPERTY_TREE_IDENTIFIER, $location->get_tree_identifier());
        $conditions[] = new InequalityCondition(Location :: PROPERTY_RIGHT_VALUE, InequalityCondition :: GREATER_THAN,
                $previous_visited);
        $condition = new AndCondition($conditions);

        $properties = array(
                Location :: PROPERTY_RIGHT_VALUE => $this->escape_column_name(Location :: PROPERTY_RIGHT_VALUE) . ' + ' . $this->quote(
                        $number_of_elements * 2));
        $res = $this->update_objects(Location :: get_table_name(), $properties, $condition);

        if (! $res)
        {
            return false;
        }

        return true;
    }

    function delete_location_nodes($location)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(Location :: PROPERTY_APPLICATION, $location->get_application());
        $conditions[] = new EqualityCondition(Location :: PROPERTY_TREE_TYPE, $location->get_tree_type());
        $conditions[] = new EqualityCondition(Location :: PROPERTY_TREE_IDENTIFIER, $location->get_tree_identifier());
        $conditions[] = new InequalityCondition(Location :: PROPERTY_LEFT_VALUE,
                InequalityCondition :: GREATER_THAN_OR_EQUAL, $location->get_left_value());
        $conditions[] = new InequalityCondition(Location :: PROPERTY_LEFT_VALUE,
                InequalityCondition :: LESS_THAN_OR_EQUAL, $location->get_right_value());
        $condition = new AndCondition($conditions);

        return $this->delete_objects(Location :: get_table_name(), $condition);
    }

    function delete_nested_values($location)
    {
        $delta = $location->get_right_value() - $location->get_left_value() + 1;

        // Update all necessary nested-values
        $conditions = array();
        $conditions[] = new EqualityCondition(Location :: PROPERTY_APPLICATION, $location->get_application());
        $conditions[] = new EqualityCondition(Location :: PROPERTY_TREE_TYPE, $location->get_tree_type());
        $conditions[] = new EqualityCondition(Location :: PROPERTY_TREE_IDENTIFIER, $location->get_tree_identifier());
        $conditions[] = new InequalityCondition(Location :: PROPERTY_LEFT_VALUE, InequalityCondition :: GREATER_THAN,
                $location->get_left_value());
        $condition = new AndCondition($conditions);

        $properties = array();
        $properties[Location :: PROPERTY_LEFT_VALUE] = $this->escape_column_name(Location :: PROPERTY_LEFT_VALUE) . ' - ' . $this->quote(
                $delta);
        $properties[Location :: PROPERTY_RIGHT_VALUE] = $this->escape_column_name(Location :: PROPERTY_RIGHT_VALUE) . ' - ' . $this->quote(
                $delta);
        $res = $this->update_objects(Location :: get_table_name(), $properties, $condition);

        if (! $res)
        {
            return false;
        }

        // Update some more nested-values
        $conditions = array();
        $conditions[] = new EqualityCondition(Location :: PROPERTY_APPLICATION, $location->get_application());
        $conditions[] = new EqualityCondition(Location :: PROPERTY_TREE_TYPE, $location->get_tree_type());
        $conditions[] = new EqualityCondition(Location :: PROPERTY_TREE_IDENTIFIER, $location->get_tree_identifier());
        $conditions[] = new InequalityCondition(Location :: PROPERTY_LEFT_VALUE, InequalityCondition :: LESS_THAN,
                $location->get_left_value());
        $conditions[] = new InequalityCondition(Location :: PROPERTY_RIGHT_VALUE, InequalityCondition :: GREATER_THAN,
                $location->get_right_value());
        $condition = new AndCondition($conditions);

        $properties = array(
                Location :: PROPERTY_RIGHT_VALUE => $this->escape_column_name(Location :: PROPERTY_RIGHT_VALUE) . ' - ' . $this->quote(
                        $delta));
        $res = $this->update_objects(Location :: get_table_name(), $properties, $condition);

        if (! $res)
        {
            return false;
        }

        return true;
    }

    function move_location($location, $new_parent_id, $new_previous_id = 0)
    {
        // Check some things first to avoid trouble
        if ($new_previous_id)
        {
            // Don't let people move an element behind itself
            // No need to spawn an error, since we're just not doing anything
            if ($new_previous_id == $location->get_id())
            {
                return true;
            }

            $new_previous = $this->retrieve_location($new_previous_id);
            // TODO: What if location $new_previous_id doesn't exist ? Return error.
            $new_parent_id = $new_previous->get_parent();
        }
        else
        {
            // No parent ID was set ... problem !
            if ($new_parent_id == 0)
            {
                return false;
            }
            // Move the location underneath one of it's children ?
            // I think not ... Return error
            if ($location->is_parent_of($new_parent_id))
            {
                return false;
            }
            // Move an element underneath itself ?
            // No can do ... just ignore and return true
            if ($new_parent_id == $location->get_id())
            {
                return true;
            }
            // Try to retrieve the data of the parent element
            $new_parent = $this->retrieve_location($new_parent_id);
            // TODO: What if this is an invalid location ? Return error.

            if (! $new_parent)
            {
                return false;
            }
        }

        $number_of_elements = ($location->get_right_value() - $location->get_left_value() + 1) / 2;
        $previous_visited = $new_previous_id ? $new_previous->get_right_value() : $new_parent->get_left_value();

        // Update the nested values so we can actually add the element
        // Return false if this failed
        if (! $this->add_nested_values($location, $previous_visited, $number_of_elements))
        {
            return false;
        }

        // Now we can update the actual parent_id
        // Return false if this failed
        $location = $this->retrieve_location($location->get_id());
        $location->set_parent($new_parent_id);
        if (! $location->update())
        {
            return false;
        }

        // Update the left/right values of those elements that are being moved
        // First get the offset we need to add to the left/right values
        // if $newPrevId is given we need to get the right value,
        // otherwise the left since the left/right has changed
        // because we already updated it up there. We need to get them again.
        // We have to do that anyway, to have the proper new left/right values
        if ($new_previous_id)
        {
            $temp = $this->retrieve_location($new_previous_id);
            // TODO: What if $temp doesn't exist ? Return error.
            $calculate_width = $temp->get_right_value();
        }
        else
        {
            $temp = $this->retrieve_location($new_parent_id);
            // TODO: What if $temp doesn't exist ? Return error.
            $calculate_width = $temp->get_left_value();
        }

        // Get the element that is being moved again, since the left and
        // right might have changed by the add-call

        $location = $this->retrieve_location($location->get_id());
        // TODO: What if $location doesn't exist ? Return error.
        // Calculate the offset of the element to to the spot where it should go
        // correct the offset by one, since it needs to go inbetween!
        $offset = $calculate_width - $location->get_left_value() + 1;

        // Do the actual update
        $conditions = array();
        $conditions[] = new EqualityCondition(Location :: PROPERTY_APPLICATION, $location->get_application());
        $conditions[] = new EqualityCondition(Location :: PROPERTY_TREE_TYPE, $location->get_tree_type());
        $conditions[] = new EqualityCondition(Location :: PROPERTY_TREE_IDENTIFIER, $location->get_tree_identifier());
        $conditions[] = new InequalityCondition(Location :: PROPERTY_LEFT_VALUE, InequalityCondition :: GREATER_THAN,
                ($location->get_left_value() - 1));
        $conditions[] = new InequalityCondition(Location :: PROPERTY_RIGHT_VALUE, InequalityCondition :: LESS_THAN,
                ($location->get_right_value() + 1));
        $condition = new AndCondition($conditions);

        $properties = array();
        $properties[Location :: PROPERTY_LEFT_VALUE] = $this->escape_column_name(Location :: PROPERTY_LEFT_VALUE) . ' + ' . $this->quote(
                $offset);
        $properties[Location :: PROPERTY_RIGHT_VALUE] = $this->escape_column_name(Location :: PROPERTY_RIGHT_VALUE) . ' + ' . $this->quote(
                $offset);
        $res = $this->update_objects(Location :: get_table_name(), $properties, $condition);

        if (! $res)
        {
            return false;
        }

        // Remove the subtree where the location was before
        if (! $this->delete_nested_values($location))
        {
            return false;
        }

        return true;
    }

    function update_rights_template($rights_template)
    {
        $condition = new EqualityCondition(RightsTemplate :: PROPERTY_ID, $rights_template->get_id());
        return $this->update($rights_template, $condition);
    }

    function update_type_template($type_template)
    {
        $condition = new EqualityCondition(TypeTemplate :: PROPERTY_ID, $type_template->get_id());
        return $this->update($type_template, $condition);
    }

    function delete_rights_template($rights_template)
    {
        // Delete all rights_template_right_locations for that specific rights_template
        $condition = new EqualityCondition(RightsTemplateRightLocation :: PROPERTY_RIGHTS_TEMPLATE_ID,
                $rights_template->get_id());
        $this->delete_rights_template_right_locations($condition);

        // Delete all links between this rights_template and users
        // Code comes here ...
        $udm = UserDataManager :: get_instance();

        $condition = new EqualityCondition(UserRightsTemplate :: PROPERTY_RIGHTS_TEMPLATE_ID, $rights_template->get_id());
        $udm->delete_user_rights_templates($condition);

        // Delete all links between this rights_template and groups
        // Code comes here ...
        $gdm = GroupDataManager :: get_instance();

        $condition = new EqualityCondition(GroupRightsTemplate :: PROPERTY_RIGHTS_TEMPLATE_ID,
                $rights_template->get_id());
        $gdm->delete_group_rights_templates($condition);

        // Delete the actual rights_template

        $condition = new EqualityCondition(RightsTemplate :: PROPERTY_ID, $rights_template->get_id());
        return $this->delete(RightsTemplate :: get_table_name(), $condition);
    }

    function delete_type_template($type_template)
    {
        // // Delete all type_template_right_locations for that specific rights_template
        // $condition = new EqualityCondition(TypeTemplateRightLocation :: PROPERTY_TYPE_TEMPLATE_ID,
        // $type_template->get_id());
        // $this->delete_type_template_right_locations($condition);
        // Delete the actual type_template
        $condition = new EqualityCondition(TypeTemplate :: PROPERTY_ID, $type_template->get_id());
        return $this->delete(TypeTemplate :: get_table_name(), $condition);
    }

    function delete_locations($condition = null)
    {
        return $this->delete_objects(Location :: get_table_name(), $condition);
    }

    function delete_orphaned_rights_template_right_locations()
    {
        $conditions = array();
        $conditions[] = new NotCondition(
                new SubselectCondition(RightsTemplateRightLocation :: PROPERTY_LOCATION_ID, Location :: PROPERTY_ID,
                        Location :: get_table_name()));
        $conditions[] = new NotCondition(
                new SubselectCondition(RightsTemplateRightLocation :: PROPERTY_RIGHTS_TEMPLATE_ID,
                        RightsTemplate :: PROPERTY_ID, RightsTemplate :: get_table_name()));
        $condition = new OrCondition($conditions);

        return $this->delete_objects(RightsTemplateRightLocation :: get_table_name(), $condition);
    }

    function retrieve_shared_content_objects_for_user($user_id, $rights)
    {
        $subcondition = new EqualityCondition(Location :: PROPERTY_TYPE, RepositoryRights :: TYPE_USER_CONTENT_OBJECT);
        $conditions[] = new SubSelectcondition(UserRightLocation :: PROPERTY_LOCATION_ID, Location :: PROPERTY_ID,
                Location :: get_table_name(), $subcondition);
        $conditions[] = new EqualityCondition(UserRightLocation :: PROPERTY_USER_ID, $user_id);
        $conditions[] = new InCondition(UserRightLocation :: PROPERTY_RIGHT_ID, $rights);
        $conditions[] = new EqualityCondition(UserRightLocation :: PROPERTY_VALUE, 1);
        $condition = new AndCondition($conditions);

        return $this->retrieve_objects(UserRightLocation :: get_table_name(), $condition, null, null, array(),
                UserRightLocation :: CLASS_NAME);
    }

    function retrieve_shared_content_objects_for_groups($group_ids, $rights)
    {
        $subcondition = new EqualityCondition(Location :: PROPERTY_TYPE, RepositoryRights :: TYPE_USER_CONTENT_OBJECT);
        $conditions[] = new SubSelectcondition(GroupRightLocation :: PROPERTY_LOCATION_ID, Location :: PROPERTY_ID,
                Location :: get_table_name(), $subcondition);
        $conditions[] = new InCondition(GroupRightLocation :: PROPERTY_GROUP_ID, $group_ids);
        $conditions[] = new InCondition(GroupRightLocation :: PROPERTY_RIGHT_ID, $rights);
        $conditions[] = new EqualityCondition(GroupRightLocation :: PROPERTY_VALUE, 1);
        $condition = new AndCondition($conditions);

        return $this->retrieve_objects(GroupRightLocation :: get_table_name(), $condition, null, null, array(),
                GroupRightLocation :: CLASS_NAME);
    }

    function create_user_right_location($user_right_location)
    {
        return $this->create($user_right_location);
    }

    function create_group_right_location($group_right_location)
    {
        return $this->create($group_right_location);
    }

    function delete_user_right_location($user_right_location)
    {
        $condition = new EqualityCondition(UserRightLocation :: PROPERTY_ID, $user_right_location->get_id());
        return $this->delete(UserRightLocation :: get_table_name(), $condition);
    }

    function delete_group_right_location($group_right_location)
    {
        $condition = new EqualityCondition(GroupRightLocation :: PROPERTY_ID, $group_right_location->get_id());
        return $this->delete(GroupRightLocation :: get_table_name(), $condition);
    }

    function update_user_right_location($user_right_location)
    {
        $condition = new EqualityCondition(UserRightLocation :: PROPERTY_ID, $user_right_location->get_id());
        return $this->update($user_right_location, $condition);
    }

    function update_group_right_location($group_right_location)
    {
        $condition = new EqualityCondition(GroupRightLocation :: PROPERTY_ID, $group_right_location->get_id());
        return $this->update($group_right_location, $condition);
    }

    function retrieve_user_right_location($right_id, $user_id, $location_id)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(UserRightLocation :: PROPERTY_RIGHT_ID, $right_id);
        $conditions[] = new EqualityCondition(UserRightLocation :: PROPERTY_USER_ID, $user_id);
        $conditions[] = new EqualityCondition(UserRightLocation :: PROPERTY_LOCATION_ID, $location_id);
        $condition = new AndCondition($conditions);

        return $this->retrieve_object(UserRightLocation :: get_table_name(), $condition, null,
                UserRightLocation :: CLASS_NAME);
    }

    function retrieve_group_right_location($right_id, $group_id, $location_id)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(GroupRightLocation :: PROPERTY_RIGHT_ID, $right_id);
        $conditions[] = new EqualityCondition(GroupRightLocation :: PROPERTY_GROUP_ID, $group_id);
        $conditions[] = new EqualityCondition(GroupRightLocation :: PROPERTY_LOCATION_ID, $location_id);
        $condition = new AndCondition($conditions);

        return $this->retrieve_object(GroupRightLocation :: get_table_name(), $condition, null,
                GroupRightLocation :: CLASS_NAME);
    }

    function retrieve_user_right_locations($condition = null, $offset = null, $max_objects = null, $order_by = null)
    {
        return $this->retrieve_objects(UserRightLocation :: get_table_name(), $condition, $offset, $max_objects,
                $order_by);
    }

    function retrieve_group_right_locations($condition = null, $offset = null, $max_objects = null, $order_by = null)
    {
        return $this->retrieve_objects(GroupRightLocation :: get_table_name(), $condition, $offset, $max_objects,
                $order_by);
    }

    function retrieve_rights_template_right_locations($condition = null, $offset = null, $max_objects = null, $order_by = null)
    {
        return $this->retrieve_objects(RightsTemplateRightLocation :: get_table_name(), $condition, $offset,
                $max_objects, $order_by, RightsTemplateRightLocation :: CLASS_NAME);
    }

    /**
     * retrieves the rights_template and right location
     *
     * @param $right_id int
     * @param $rights_template_id int
     * @param $application int
     * @param $tree_type int
     * @param $type int
     * @return TypeTemplateRightLocation
     */
    function retrieve_type_template_right_location($right_id, $type_template_id, $application, $tree_type, $type)
    {
        $conditions = array();
        $conditions[] = new EqualityCondition(TypeTemplateRightLocation :: PROPERTY_RIGHT_ID, $right_id);
        $conditions[] = new EqualityCondition(TypeTemplateRightLocation :: PROPERTY_TYPE_TEMPLATE_ID, $type_template_id);
        $conditions[] = new EqualityCondition(TypeTemplateRightLocation :: PROPERTY_APPLICATION, $application);
        $conditions[] = new EqualityCondition(TypeTemplateRightLocation :: PROPERTY_TREE_TYPE, $tree_type);
        $conditions[] = new EqualityCondition(TypeTemplateRightLocation :: PROPERTY_TYPE, $type);
        $condition = new AndCondition($conditions);

        return $this->retrieve_object(TypeTemplateRightLocation :: get_table_name(), $condition, array(),
                TypeTemplateRightLocation :: CLASS_NAME);
    }

    function retrieve_type_template_right_locations($condition = null, $offset = null, $max_objects = null, $order_by = null)
    {
        return $this->retrieve_objects(TypeTemplateRightLocation :: get_table_name(), $condition, $offset, $max_objects,
                $order_by, TypeTemplateRightLocation :: CLASS_NAME);
    }

    // NEW FUNCTIONS

    function retrieve_rights_location($context, $condition = null, $offset = null, $max_objects = null, $order_by = null)
    {
        $this->set_prefix($context . '_');
        $rights_location = $this->retrieve_object(RightsLocation :: get_table_name(), $condition, array(),
                RightsLocation :: CLASS_NAME);

        if ($rights_location)
        {
            $rights_location->set_context($context);
        }
        return $rights_location;

    }

    function retrieve_rights_location_entity_right($context, $right, $entity_id, $entity_type, $location_id)
    {
        $this->set_prefix($context . '_');
        $conditions[] = new EqualityCondition(RightsLocationEntityRight :: PROPERTY_ENTITY_ID, $entity_id);
        $conditions[] = new EqualityCondition(RightsLocationEntityRight :: PROPERTY_ENTITY_TYPE, $entity_type);
        $conditions[] = new EqualityCondition(RightsLocationEntityRight :: PROPERTY_LOCATION_ID, $location_id);
        $conditions[] = new EqualityCondition(RightsLocationEntityRight :: PROPERTY_RIGHT_ID, $right);
        $condition = new AndCondition($conditions);

        $rights_location_entity_right = $this->retrieve_object(RightsLocationEntityRight :: get_table_name(),
                $condition, array(), RightsLocationEntityRight :: CLASS_NAME);

        if ($rights_location_entity_right)
        {
            $rights_location_entity_right->set_context($context);
        }
        return $rights_location_entity_right;
    }

    function retrieve_rights_location_entity_right_by_id($context, $id)
    {
        $this->set_prefix($context . '_');
        $condition = new EqualityCondition(RightsLocationEntityRight :: PROPERTY_ID, $id);

        $rights_location_entity_right = $this->retrieve_object(RightsLocationEntityRight :: get_table_name(),
                $condition, array(), RightsLocationEntityRight :: CLASS_NAME);

        if ($rights_location_entity_right)
        {
            $rights_location_entity_right->set_context($context);
        }
        return $rights_location_entity_right;
    }

    function retrieve_rights_locations($context, $condition = null, $offset = null, $max_objects = null, $order_by = null)
    {
        $this->set_prefix($context . '_');
        return $this->retrieve_objects(RightsLocation :: get_table_name(), $condition, $offset, $max_objects, $order_by,
                RightsLocation :: CLASS_NAME);
    }

    function count_rights_locations($context, $condition = null)
    {
        $this->set_prefix($context . '_');
        return $this->count_objects(RightsLocation :: get_table_name(), $condition);
    }

    function create_rights_location($location)
    {
        $orig_context = $this->get_prefix();
        $context = $location->get_context();
        $this->set_prefix($context . '_');
        $succes = $this->create($location);
        $this->set_prefix($orig_context);
        return $succes;
    }

    function update_rights_location($location)
    {
        $context = $location->get_context();
        $this->set_prefix($context . '_');
        $condition = new EqualityCondition(RightsLocation :: PROPERTY_ID, $location->get_id());
        return $this->update($location, $condition);
    }

    function delete_rights_location($location)
    {
        $context = $location->get_context();
        $this->set_prefix($context . '_');
        $condition = new EqualityCondition(RightsLocation :: PROPERTY_ID, $location->get_id());
        return $this->delete($location->get_table_name(), $condition);
    }

    /**
     * Removes the entity rights linked to a location
     *
     * @param $location <type>
     * @return <type>
     */
    function delete_rights_location_entity_rights($location, $entity_type = null, $entity_id = null, $right_id = null)
    {
        $context = $location->get_context();
        $this->set_prefix($context . '_');
        $condition = new EqualityCondition(RightsLocationEntityRight :: PROPERTY_LOCATION_ID, $location->get_id());

        $conditions = array();
        if ($entity_type != null)
        {
            $conditions[] = new EqualityCondition(RightsLocationEntityRight :: PROPERTY_ENTITY_TYPE, $entity_type);
        }
        if ($entity_id != null)
        {
            $conditions[] = new EqualityCondition(RightsLocationEntityRight :: PROPERTY_ENTITY_ID, $entity_id);
        }
        if ($right_id != null)
        {
            $conditions[] = new EqualityCondition(RightsLocationEntityRight :: PROPERTY_RIGHT_ID, $right_id);
        }

        if (count($conditions) > 0)
        {
            $conditions[] = $condition;
            $condition = new AndCondition($conditions);
        }

        return $this->delete(RightsLocationEntityRight :: get_table_name(), $condition);
    }

    function delete_rights_location_entity_right($entity_right)
    {
        $context = $entity_right->get_context();
        $this->set_prefix($context . '_');
        $conditions[] = new EqualityCondition(RightsLocationEntityRight :: PROPERTY_LOCATION_ID,
                $entity_right->get_location_id());
        $conditions[] = new EqualityCondition(RightsLocationEntityRight :: PROPERTY_RIGHT_ID,
                $entity_right->get_right_id());
        $conditions[] = new EqualityCondition(RightsLocationEntityRight :: PROPERTY_ENTITY_ID,
                $entity_right->get_entity_id());
        $conditions[] = new EqualityCondition(RightsLocationEntityRight :: PROPERTY_ENTITY_TYPE,
                $entity_right->get_entity_type());

        $condition = new AndCondition($conditions);

        return $this->delete(RightsLocationEntityRight :: get_table_name(), $condition);
    }

    /*
     * retrieves the rights set on a location
     */

    function retrieve_rights_location_rights($context, $condition = null, $offset = null, $max_objects = null, $order_by = null)
    {
        $this->set_prefix($context . '_');
        return $this->retrieve_objects(RightsLocationEntityRight :: get_table_name(), $condition, $offset, $max_objects,
                $order_by, RightsLocationEntityRight :: CLASS_NAME);
    }

    function retrieve_identifiers_with_right_granted($right_id, $context, $entities_condition, $condition,
            $parent_has_right, $offset = null, $max_objects = null)
    {
        $this->set_prefix($context . '_');

        $translator = ConditionTranslator :: factory($this);

        $rights_location_entity_right_alias = $this->get_alias(RightsLocationEntityRight :: get_table_name());
        $rights_location_alias = $this->get_alias(RightsLocation :: get_table_name());

        $query = 'SELECT ' . $this->escape_column_name(RightsLocation :: PROPERTY_IDENTIFIER, $rights_location_alias);
        $query .= ' FROM ' . $this->escape_table_name(RightsLocation :: get_table_name()) . ' as ' . $rights_location_alias;

        if (! $parent_has_right)
        {

            $query .= ' JOIN ' . $this->escape_table_name(RightsLocationEntityRight :: get_table_name()) . ' as ' . $rights_location_entity_right_alias;
            $query .= ' ON ' . $this->escape_column_name(RightsLocation :: PROPERTY_ID, $rights_location_alias) . '=' . $this->escape_column_name(
                    RightsLocationEntityRight :: PROPERTY_LOCATION_ID, $rights_location_entity_right_alias);
            if ($right_id)
            {
                $query .= ' AND ' . $this->escape_column_name(RightsLocationEntityRight :: PROPERTY_RIGHT_ID,
                        $rights_location_entity_right_alias) . '=' . $right_id;
            }
        }
        else // if the parent has the right, only the rights of the non inheriting children should be checked; The
             // inheriting children automaticly have the right.
             // Todo: check performance union vs left join
        {
            // inheriting children
            $conditions = array();
            $conditions[] = $condition;
            $conditions[] = new EqualityCondition(RightsLocation :: PROPERTY_INHERIT, 1,
                    RightsLocation :: get_table_name());
            $inheriting_condition = new AndCondition($conditions);

            $query .= $translator->render_query($inheriting_condition);

            $query .= ' UNION ';

            // non inheriting children
            $query .= ' SELECT ' . $this->escape_column_name(RightsLocation :: PROPERTY_IDENTIFIER,
                    $rights_location_alias);
            $query .= ' FROM ' . $this->escape_table_name(RightsLocation :: get_table_name()) . ' as ' . $rights_location_alias;
            $query .= ' JOIN ' . $this->escape_table_name(RightsLocationEntityRight :: get_table_name()) . ' as ' . $rights_location_entity_right_alias;
            $query .= ' ON ' . $this->escape_column_name(RightsLocation :: PROPERTY_ID, $rights_location_alias) . '=' . $this->escape_column_name(
                    RightsLocationEntityRight :: PROPERTY_LOCATION_ID, $rights_location_entity_right_alias);
            $query .= ' AND ' . $this->escape_column_name(RightsLocation :: PROPERTY_INHERIT, $rights_location_alias) . '= 0';
            $query .= ' AND ' . $this->escape_column_name(RightsLocationEntityRight :: PROPERTY_RIGHT_ID,
                    $rights_location_entity_right_alias) . '=' . $right_id;
        }

        $query .= $translator->render_query($condition);
        $query .= ' AND ' . $entities_condition;

        return $this->retrieve_object_set($query, RightsLocation :: get_table_name(), null, $offset, $max_objects);
    }

    function retrieve_location_overview_with_rights_granted_in_tree($context, $condition, $entities_condition,
            $offset = null, $max_objects = null)
    {

        $rights_location_entity_right_alias = $this->get_alias(RightsLocationEntityRight :: get_table_name());
        $rights_location_alias = $this->get_alias(RightsLocation :: get_table_name());

        $query .= ' SELECT ' . $this->escape_column_name(RightsLocation :: PROPERTY_TYPE, $rights_location_alias) . ', ' . $this->escape_column_name(
                RightsLocation :: PROPERTY_IDENTIFIER, $rights_location_alias);
        $query .= ' FROM ' . $this->escape_table_name(RightsLocation :: get_table_name()) . ' as ' . $rights_location_alias;
        $query .= ' JOIN ' . $this->escape_table_name(RightsLocationEntityRight :: get_table_name()) . ' as ' . $rights_location_entity_right_alias;
        $query .= ' ON ' . $this->escape_column_name(RightsLocation :: PROPERTY_ID, $rights_location_alias) . '=' . $this->escape_column_name(
                RightsLocationEntityRight :: PROPERTY_LOCATION_ID, $rights_location_entity_right_alias);

        if (! is_null($entities_condition) && ! is_null($condition))
        {
            $conditions[] = $entities_condition;
            $conditions[] = $condition;
            $condition = new AndCondition($conditions);
        }
        else
        {
            if (! is_null($entities_condition))
            {
                $condition = $entities_condition;
            }
        }

        return $this->retrieve_object_set($query, RightsLocation :: get_table_name(), $condition, $offset, $max_objects);
    }

    public function retrieve_location_overview_with_rights_granted($context, $condition, $entities_condition,
            $offset = null, $max_objects = null)
    {
        $this->set_prefix($context . '_');

        $rights_location_entity_right_alias = $this->get_alias(RightsLocationEntityRight :: get_table_name());
        $rights_location_alias = $this->get_alias(RightsLocation :: get_table_name());

        $query = 'SELECT ' . $this->escape_column_name(RightsLocation :: PROPERTY_TYPE, $rights_location_alias) . ', ' . $this->escape_column_name(
                RightsLocation :: PROPERTY_IDENTIFIER, $rights_location_alias);
        $query .= ' FROM ' . $this->escape_table_name(RightsLocationEntityRight :: get_table_name()) . ' as ' . $rights_location_entity_right_alias;
        $query .= ' JOIN ' . $this->escape_table_name(RightsLocation :: get_table_name()) . ' as ' . $rights_location_alias;
        $query .= ' ON ' . $this->escape_column_name(RightsLocation :: PROPERTY_ID, $rights_location_alias) . '=' . $this->escape_column_name(
                RightsLocationEntityRight :: PROPERTY_LOCATION_ID, $rights_location_entity_right_alias);

        if (! is_null($entities_condition) && ! is_null($condition))
        {
            $conditions[] = $entities_condition;
            $conditions[] = $condition;
            $condition = new AndCondition($conditions);
        }
        else
        {
            if (! is_null($entities_condition))
            {
                $condition = $entities_condition;
            }
        }

        return $this->retrieve_object_set($query, RightsLocation :: get_table_name(), $condition, $offset, $max_objects);

    }

    public function count_location_overview_with_rights_granted($context, $condition, $entities_condition)
    {
        $this->set_prefix($context . '_');

        $rights_location_entity_right_alias = $this->get_alias(RightsLocationEntityRight :: get_table_name());
        $rights_location_alias = $this->get_alias(RightsLocation :: get_table_name());

        $query = 'SELECT COUNT( DISTINCT ' . $this->escape_column_name(RightsLocation :: PROPERTY_IDENTIFIER,
                $rights_location_alias) . ')';
        $query .= ' FROM ' . $this->escape_table_name(RightsLocationEntityRight :: get_table_name()) . ' as ' . $rights_location_entity_right_alias;
        $query .= ' JOIN ' . $this->escape_table_name(RightsLocation :: get_table_name()) . ' as ' . $rights_location_alias;
        $query .= ' ON ' . $this->escape_column_name(RightsLocation :: PROPERTY_ID, $rights_location_alias) . '=' . $this->escape_column_name(
                RightsLocationEntityRight :: PROPERTY_LOCATION_ID, $rights_location_entity_right_alias);

        if (! is_null($entities_condition) && ! is_null($condition))
        {
            $conditions[] = $entities_condition;
            $conditions[] = $condition;
            $condition = new AndCondition($conditions);
        }
        else
        {
            if (! is_null($entities_condition))
            {
                $condition = $entities_condition;
            }
        }

        return $this->count_result_set($query, RightsLocation :: get_table_name(), $condition);

    }

    private $location_by_identifiers_cache;

    function retrieve_rights_location_by_identifier($context, $type, $identifier, $tree_identifier = '0',
            $tree_type = self :: TREE_TYPE_ROOT)
    {
        $key = $context . $type . $identifier . $tree_identifier . $tree_type;

        if (is_null($this->location_by_identifiers_cache[$key]))
        {
            $conditions = array();
            $conditions[] = new EqualityCondition(Location :: PROPERTY_TREE_TYPE, $tree_type);
            $conditions[] = new EqualityCondition(Location :: PROPERTY_TREE_IDENTIFIER, $tree_identifier);
            $conditions[] = new EqualityCondition(Location :: PROPERTY_IDENTIFIER, $identifier);

            if ($type != null)
            {
                $conditions[] = new EqualityCondition(Location :: PROPERTY_TYPE, $type);
            }

            $condition = new AndCondition($conditions);
            $location = $this->retrieve_rights_location($context, $condition, 0, 1);

            if (! $location)
            {
                return false;
            }

            $this->location_by_identifiers_cache[$key] = $location;
            $this->location_by_id_cache[$context][$location->get_id()] = $location;
        }

        return $this->location_by_identifiers_cache[$key];
    }

    private $location_by_id_cache;

    function retrieve_rights_location_by_id($context, $location_id)
    {

        if (is_null($this->location_by_id_cache[$context][$location_id]))
        {
            $condition = new EqualityCondition(Location :: PROPERTY_ID, $location_id);
            $location = $this->retrieve_rights_location($context, $condition, 0, 1);

            if (! $location)
            {
                return null;
            }

            $this->location_by_id_cache[$context][$location_id] = $location;
            $key = $context . $location->get_type() . $location->get_identifier() . $location->get_tree_identifier() . $location->get_tree_type();
            $this->location_by_identifiers_cache[$key] = $location;
        }

        return $this->location_by_id_cache[$context][$location_id];
    }

    private $granted_rights_cache;

    /**
     * Retrieves the granted rights for a location
     *
     * @param $location <type>
     * @param $enities_condition <type>
     * @return <type>
     */
    function retrieve_granted_rights_array($location, $entities_condition)
    {
        $hash = (is_object($entities_condition) ? spl_object_hash($entities_condition) : md5($entities_condition));

        if (is_null($this->granted_rights_cache[$location->get_context()][$location->get_id()][$hash]))
        {
            $this->set_prefix($location->get_context() . '_');

            // first retrieve the parent lowest in the tree before a parent that doesnt inherit.
            // This way we dont check parent from who the location doesn't inherit
            // this is done in a separate query instead of a subquery for performance reasons
            // (a correlated subquery is executed for every row in the outer query)

            $rights_location_entity_right_alias = $this->get_alias(RightsLocationEntityRight :: get_table_name());
            $rights_location_alias = $this->get_alias(RightsLocation :: get_table_name());

            $query = 'SELECT ' . $rights_location_entity_right_alias . '.' . RightsLocationEntityRight :: PROPERTY_RIGHT_ID;

            $query .= ' FROM ' . $this->escape_table_name(RightsLocation :: get_table_name()) . ' as ' . $rights_location_alias;
            $query .= ' JOIN ' . $this->escape_table_name(RightsLocationEntityRight :: get_table_name()) . ' as ' . $rights_location_entity_right_alias;
            $query .= ' ON ' . $this->escape_column_name(RightsLocation :: PROPERTY_ID, $rights_location_alias) . '=' . $this->escape_column_name(
                    RightsLocationEntityRight :: PROPERTY_LOCATION_ID, $rights_location_entity_right_alias);

            $condition_translator = ConditionTranslator :: factory($this);
            $condition = new EqualityCondition(RightsLocation :: PROPERTY_ID, $location->get_id(),
                    RightsLocation :: get_table_name());

            $query .= ' ' . $condition_translator->render_query($condition, true);

            if (! is_string($entities_condition))
            {
                $entities_condition = $condition_translator->render_query($entities_condition, false);
            }
            $query .= ' AND ' . $entities_condition;

            $result_set = $this->retrieve_result($query, RightsLocation :: get_table_name());

            $granted_rights = array();

            while ($result = $result_set->fetchRow(MDB2_FETCHMODE_ASSOC))
            {
                $granted_rights[] = $result[RightsLocationEntityRight :: PROPERTY_RIGHT_ID];
            }

            if ($location->inherits())
            {
                $parent_location = $this->retrieve_rights_location_by_id($location->get_context(),
                        $location->get_parent_id());
                if ($parent_location)
                {
                    $parent_rights = $this->retrieve_granted_rights_array($parent_location, $entities_condition);
                    $granted_rights = array_merge($granted_rights, $parent_rights);
                }
            }
            $this->granted_rights_cache[$location->get_context()][$location->get_id()][$hash] = $granted_rights;
        }
        return $this->granted_rights_cache[$location->get_context()][$location->get_id()][$hash];
    }

    // private $granted_rights_parent_location_cache;

    // /**
    // * Retrieves all the rights of the locations parent and his parents
    // * @param <type> $location
    // * @param <type> $entities_condition
    // * @return <type>
    // */
    // private function retrieve_granted_rights_parent_location_array($location, $entities_condition)
    // {
    // if (is_null($this->granted_rights_parent_location_cache[$location->get_context()][$location->get_parent_id()]))
    // {
    // $this->set_prefix($location->get_context() . '_');
    //
    // $max_inheriting_parent_id_left_value = $this->retrieve_first_parent_left_value_no_inherit($location);
    //
    // $rights_location_entity_right_alias = $this->get_alias(RightsLocationEntityRight :: get_table_name());
    // $rights_location_alias = $this->get_alias(RightsLocation :: get_table_name());
    //
    // $query = 'SELECT ' . $rights_location_entity_right_alias . '.' . RightsLocationEntityRight :: PROPERTY_RIGHT_ID;
    //
    // $query .= ' FROM ' . $this->escape_table_name(RightsLocation :: get_table_name()) .
    // ' as ' . $rights_location_alias;
    // $query .= ' JOIN ' . $this->escape_table_name(RightsLocationEntityRight :: get_table_name()) .
    // ' as ' . $rights_location_entity_right_alias;
    // $query .= ' ON ' . $this->escape_column_name(RightsLocation :: PROPERTY_ID, $rights_location_alias) .
    // '=' . $this->escape_column_name(RightsLocationEntityRight :: PROPERTY_LOCATION_ID,
    // $rights_location_entity_right_alias);
    //
    // $location_conditions[] = new EqualityCondition(RightsLocation :: PROPERTY_TREE_IDENTIFIER,
    // $location->get_tree_identifier());
    // $location_conditions[] = new EqualityCondition(RightsLocation :: PROPERTY_TREE_TYPE,
    // $location->get_tree_type());
    // $location_conditions[] = new InequalityCondition(RightsLocation :: PROPERTY_LEFT_VALUE,
    // InequalityCondition::LESS_THAN_OR_EQUAL, $location->get_left_value());
    // $location_conditions[] = new InequalityCondition(RightsLocation :: PROPERTY_RIGHT_VALUE,
    // InequalityCondition::GREATER_THAN_OR_EQUAL, $location->get_right_value());
    // $location_conditions[] = new InequalityCondition(RightsLocation :: PROPERTY_LEFT_VALUE,
    // InequalityCondition::GREATER_THAN_OR_EQUAL, $max_inheriting_parent_id_left_value);
    //
    //
    // $conditions[] = new AndCondition($location_conditions);
    // $conditions[] = $entities_condition;
    //
    // $condition = new AndCondition($conditions);
    //
    // $result_set = $this->retrieve_object_set($query, RightsLocation :: get_table_name(), $condition);
    //
    // $granted_rights = array();
    // while ($result = $result_set->next_result(false))
    // {
    // $granted_rights[] = $result[RightsLocationEntityRight :: PROPERTY_RIGHT_ID];
    // }
    //
    // $this->granted_rights_parent_location_cache[$location->get_context()][$location->get_id()] = $granted_rights;
    // }
    // return $this->granted_rights_parent_location_cache[$location->get_context()][$location->get_id()];
    // }

    // //todo: better name?
    //
    // private $non_inheriting_parent_cache;
    // /*
    // * Retrieves the left_value of the first parent of a node that no longer inherits from its parent
    // */
    //
    // private function retrieve_first_parent_left_value_no_inherit($node)
    // {
    // if (is_null($this->non_inheriting_parent_cache[$node->get_id]))
    // {
    // $context = $node->get_context();
    // $this->set_prefix($context . '_');
    // $rights_location_alias = $this->get_alias(RightsLocation :: get_table_name());
    //
    // $query = 'SELECT MAX( ' . $this->escape_column_name(RightsLocation :: PROPERTY_LEFT_VALUE) . ' )';
    // $query .= ' FROM ' . $this->escape_table_name(RightsLocation :: get_table_name());
    //
    // $conditions[] = new EqualityCondition(RightsLocation :: PROPERTY_TREE_IDENTIFIER, $node->get_tree_identifier());
    // $conditions[] = new EqualityCondition(RightsLocation :: PROPERTY_TREE_TYPE, $node->get_tree_type());
    // $conditions[] = new InequalityCondition(RightsLocation :: PROPERTY_LEFT_VALUE,
    // InequalityCondition::LESS_THAN_OR_EQUAL, $node->get_left_value());
    // $conditions[] = new InequalityCondition(RightsLocation :: PROPERTY_RIGHT_VALUE,
    // InequalityCondition::GREATER_THAN_OR_EQUAL, $node->get_right_value());
    // $conditions[] = new EqualityCondition(RightsLocation :: PROPERTY_INHERIT, 0);
    // $condition = new AndCondition($conditions);
    //
    // $translator = ConditionTranslator :: factory($this);
    // $query .= $translator->render_query($condition);
    // $res = $this->query($query);
    //
    // $row = array_values($res->fetchRow(MDB2_FETCHMODE_ASSOC));
    //
    // $res->free();
    //
    // $this->non_inheriting_parent_cache[$node->get_id()] = $row[0];
    // }
    //
    // return $this->non_inheriting_parent_cache[$node->get_id()];
    // }

    function retrieve_locked_parent($context, $condition)
    {
        $this->set_prefix($context . '_');
        $query = 'SELECT *, MAX( ' . $this->escape_column_name(RightsLocation :: PROPERTY_LEFT_VALUE) . ' ) as max_left';
        $query .= ' FROM ' . $this->escape_table_name(RightsLocation :: get_table_name()) . ' as ' . $this->get_alias(
                RightsLocation :: get_table_name());

        $locked_parent_set = $this->retrieve_object_set($query, RightsLocation :: get_table_name(), $condition);
        $locked_parent = $locked_parent_set->next_result();
        if ($locked_parent->get_id() == null)
        {
            return null;
        }
        else
            return $locked_parent;
    }

    private $target_entities_cache;

    /**
     * Retrieves the entities (type and id) that have the given right granted
     *
     * @param $context <type>
     * @param $right_id <type>
     * @param $location <type>
     * @return <array> two dimensional array: type => id
     */
    function retrieve_target_entities_array($right_id, $context, $location)
    {
        if (is_null($location) && !is_object($location))
        {
            return array();
        }

        if (is_null($this->target_entities_cache[$context][$right_id][$location->get_id()]))
        {
            $this->set_prefix($location->get_context() . '_');

            // first retrieve the parent lowest in the tree before a parent that doesnt inherit.
            // This way we dont check parent from who the location doesn't inherit
            // this is done in a separate query instead of a subquery for performance reasons
            // (a correlated subquery is executed for every row in the outer query)
            // $parent_id_left_value = $this->retrieve_first_parent_left_value_no_inherit($location);

            $rights_location_entity_right_alias = $this->get_alias(RightsLocationEntityRight :: get_table_name());
            $rights_location_alias = $this->get_alias(RightsLocation :: get_table_name());

            $query = 'SELECT ' . $rights_location_entity_right_alias . '.' . RightsLocationEntityRight :: PROPERTY_ENTITY_TYPE;
            $query .= ' , ' . $rights_location_entity_right_alias . '.' . RightsLocationEntityRight :: PROPERTY_ENTITY_ID;

            $query .= ' FROM ' . $this->escape_table_name(RightsLocation :: get_table_name()) . ' as ' . $rights_location_alias;
            $query .= ' JOIN ' . $this->escape_table_name(RightsLocationEntityRight :: get_table_name()) . ' as ' . $rights_location_entity_right_alias;
            $query .= ' ON ' . $this->escape_column_name(RightsLocation :: PROPERTY_ID, $rights_location_alias) . '=' . $this->escape_column_name(
                    RightsLocationEntityRight :: PROPERTY_LOCATION_ID, $rights_location_entity_right_alias);

            if (! is_null($right_id))
            {
                $conditions[] = new EqualityCondition(RightsLocation :: PROPERTY_ID, $location->get_id());

                $conditions[] = new EqualityCondition(RightsLocationEntityRight :: PROPERTY_RIGHT_ID, $right_id,
                        RightsLocationEntityRight :: get_table_name());

                $condition = new AndCondition($conditions);
            }
            else
            {
                $condition = new EqualityCondition(RightsLocation :: PROPERTY_ID, $location->get_id());
            }

            $result_set = $this->retrieve_result($query, RightsLocation :: get_table_name(), $condition);

            $target_entities = array();
            while ($result = $result_set->fetchRow(MDB2_FETCHMODE_ASSOC))
            {
                $target_entities[$result[RightsLocationEntityRight :: PROPERTY_ENTITY_TYPE]][] = $result[RightsLocationEntityRight :: PROPERTY_ENTITY_ID];
            }

            if ($location->inherits())
            {
                $parent_location = $this->retrieve_rights_location_by_id($location->get_context(),
                        $location->get_parent_id());
                $parent_entities = $this->retrieve_target_entities_array($right_id, $context, $parent_location);
                foreach ($parent_entities as $type => $id_array)
                {
                    if ($target_entities[$type])
                    {
                        $target_entities[$type] = array_merge($parent_entities[$type], $target_entities[$type]);
                    }
                    else
                    {
                        $target_entities[$type] = $parent_entities[$type];
                    }
                }
            }
            $this->target_entities_cache[$context][$right_id][$location->get_id()] = $target_entities;
        }
        return $this->target_entities_cache[$context][$right_id][$location->get_id()];
    }

    // NESTED TREE OVERRIDE FOR TABLES IN CONTEXTS
    function nested_tree_count_children($node, $recursive = false, $condition = null)
    {
        $context = $node->get_context();
        $this->set_prefix($context . '_');
        return parent :: nested_tree_count_children($node, $recursive, $condition);
    }

    function nested_tree_get_children($node, $recursive = false, $condition = null)
    {
        $context = $node->get_context();
        $this->set_prefix($context . '_');
        return parent :: nested_tree_get_children($node, $recursive, $condition);
    }

    function nested_tree_count_parents($node, $include_object = false, $condition = null)
    {
        $context = $node->get_context();
        $this->set_prefix($context . '_');
        return parent :: nested_tree_count_parents($node, $include_object, $condition);
    }

    function nested_tree_get_parents($node, $recursive = false, $include_object = false, $condition = null)
    {
        $context = $node->get_context();
        $this->set_prefix($context . '_');
        return parent :: nested_tree_get_parents($node, $recursive, $include_object, $condition);
    }

    function nested_tree_count_sibblings($node, $include_object = false, $condition = null)
    {
        $context = $node->get_context();
        $this->set_prefix($context . '_');
        return parent :: nested_tree_count_sibblings($node, $include_object, $condition);
    }

    function nested_tree_get_sibblings($node, $include_object = false, $condition = null)
    {
        $context = $node->get_context();
        $this->set_prefix($context . '_');
        return parent :: nested_tree_get_sibblings($node, $include_object, $condition);
    }

    public function nested_tree_retrieve_node($node, $id)
    {
        $context = $node->get_context();
        $this->set_prefix($context . '_');
        return parent :: nested_tree_retrieve_node($node, $id);
    }

    public function nested_tree_retrieve_parent_from_node($node)
    {
        $context = $node->get_context();
        $this->set_prefix($context . '_');
        return parent :: nested_tree_retrieve_parent_from_node($node);
    }

    function nested_tree_add_nested_values($node, $previous_visited, $number_of_elements = 1, $condition = null)
    {
        $context = $node->get_context();
        $this->set_prefix($context . '_');
        return parent :: nested_tree_add_nested_values($node, $previous_visited, $number_of_elements, $condition);
    }

    function nested_tree_delete_nested_values($node, $condition)
    {
        $context = $node->get_context();
        $this->set_prefix($context . '_');
        return parent :: nested_tree_delete_nested_values($node, $condition);
    }

}

?>