<?php
namespace rights;

use common\libraries\Utilities;
use common\libraries\Configuration;
use common\libraries\EqualityCondition;
use common\libraries\InCondition;
use common\libraries\AndCondition;
use common\libraries\ObjectTableOrder;

/**
 * $Id: rights_data_manager.class.php 157 2009-11-10 13:44:02Z vanpouckesven $
 *
 * @package rights.lib
 * @author Hans de Bisschop This is a skeleton for a data manager for the Rights application.
 * @author Hans De Bisschop
 * @author Dieter De Neef
 */
class RightsDataManager
{
    /**
     * Instance of this class for the singleton pattern.
     */
    private static $instance;

    /**
     * Uses a singleton pattern and a factory pattern to return the data manager. The configuration determines which
     * data manager class is to be instantiated.
     *
     * @return RightsDataManager The data manager.
     */
    static function get_instance()
    {
        if (! isset(self :: $instance))
        {
            $type = Configuration :: get_instance()->get_parameter('general', 'data_manager');
            $class = __NAMESPACE__ . '\\' . Utilities :: underscores_to_camelcase($type) . 'RightsDataManager';
            self :: $instance = new $class();
        }
        return self :: $instance;
    }

    static function retrieve_rights_location_rights_for_location($context, $location_id, $rights)
    {
        if (! is_array($rights))
        {
            $rights = array($rights);
        }
        $conditions[] = new EqualityCondition(RightsLocationEntityRight :: PROPERTY_LOCATION_ID, $location_id);
        $conditions[] = new InCondition(RightsLocationEntityRight :: PROPERTY_RIGHT_ID, $rights);

        $condition = new AndCondition($conditions);

        // order by entity_type to avoid invalid data when looping the rights
        $order = new ObjectTableOrder(RightsLocationEntityRight :: PROPERTY_ENTITY_TYPE, SORT_ASC);

        return self :: get_instance()->retrieve_rights_location_rights($context, $condition, null, null, $order);
    }

}
?>