<?php
namespace rights;

use help\HelpItem;

use common\libraries\Request;
use common\libraries\Theme;
use common\libraries\Display;
use common\libraries\ToolbarItem;
use common\libraries\Toolbar;
use common\libraries\PatternMatchCondition;
use common\libraries\BreadcrumbTrail;
use common\libraries\ActionBarRenderer;
use common\libraries\Translation;
use common\libraries\ActionBarSearchForm;

/**
 * $Id: browser.class.php 214 2009-11-13 13:57:37Z vanpouckesven $
 *
 * @package rights.lib.rights_template_manager.component
 */
/**
 * Weblcms component which allows the user to manage his or her user subscriptions
 */
class RightsTemplateManagerBrowserComponent extends RightsTemplateManager
{
    private $action_bar;

    /**
     * Runs this component and displays its output.
     */
    function run()
    {

        if (! $this->get_user()->is_platform_admin())
        {
            $this->display_header();
            Display :: error_message(Translation :: get("NotAllowed"));
            $this->display_footer();
            exit();
        }

        $this->action_bar = $this->get_action_bar();
        $output = $this->get_user_html();

        $this->display_header();
        echo '<br />' . $this->action_bar->as_html() . '<br />';
        echo $output;
        $this->display_footer();
    }

    function get_user_html()
    {
        $parameters = $this->get_parameters();
        $parameters[ActionBarSearchForm :: PARAM_SIMPLE_SEARCH_QUERY] = $this->action_bar->get_query();

        $table = new RightsTemplateBrowserTable($this, $parameters, $this->get_condition());

        $html = array();
        $html[] = '<div style="float: right; width: 100%;">';
        $html[] = $table->as_html();
        $html[] = '</div>';

        return implode($html, "\n");
    }

    function get_condition()
    {
        $query = $this->action_bar->get_query();
        if (isset($query) && $query != '')
        {
            $condition = new PatternMatchCondition(HelpItem :: PROPERTY_NAME, '*' . $query . '*');
        }

        return $condition;
    }

    function get_rights_template()
    {
        return (Request :: get(RightsTemplateManager :: PARAM_RIGHTS_TEMPLATE_ID) ? Request :: get(
                RightsTemplateManager :: PARAM_RIGHTS_TEMPLATE_ID) : 0);
    }

    function get_action_bar()
    {
        $action_bar = new ActionBarRenderer(ActionBarRenderer :: TYPE_HORIZONTAL);

        $action_bar->set_search_url(
                $this->get_url(
                        array(RightsTemplateManager :: PARAM_RIGHTS_TEMPLATE_ID => $this->get_rights_template())));
        $action_bar->add_common_action(
                new ToolbarItem(Translation :: get('NewRightsTemplate'),
                        Theme :: get_image_path() . 'action_add_template.png',
                        $this->get_url(
                                array(
                                        RightsTemplateManager :: PARAM_RIGHTS_TEMPLATE_ACTION => RightsTemplateManager :: ACTION_CREATE_RIGHTS_TEMPLATE)),
                        ToolbarItem :: DISPLAY_ICON_AND_LABEL));
        // $action_bar->add_tool_action(new ToolbarItem(Translation :: get('ManageRights'), Theme ::
        // get_common_image_path() . 'action_rights.png', $this->get_url(array(RightsTemplateManager ::
        // PARAM_RIGHTS_TEMPLATE_ACTION => RightsTemplateManager :: ACTION_CONFIGURE_RIGHTS_TEMPLATES)), ToolbarItem ::
        // DISPLAY_ICON_AND_LABEL));

        return $action_bar;
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add_help('rights_templates_browser');
    }
}
?>