<?php
namespace user;

use common\libraries\Translation;

use common\libraries\DataClassRetrievesParameters;
use common\libraries\AjaxManager;
use common\libraries\JsonAjaxResult;
use common\libraries\Path;
use common\libraries\AdvancedElementFinderElements;
use common\libraries\AdvancedElementFinderElement;
use common\libraries\Request;
use common\libraries\AndCondition;
use common\libraries\ObjectTableOrder;
use common\libraries\Utilities;

/**
 * Feed to return users
 *
 * @author Sven Vanpoucke
 * @package application.weblcms
 */
class UserAjaxUsersFeed extends AjaxManager
{
    const PARAM_SEARCH_QUERY = 'query';
    const PARAM_OFFSET = 'offset';
    
    const PROPERTY_TOTAL_ELEMENTS = 'total_elements';
    const PROPERTY_ELEMENTS = 'elements';
    
    private $user_count = 0;

    /**
     * Returns the required parameters
     *
     * @return string[]
     */
    function required_parameters()
    {
        return array();
    }

    /**
     * Runs this ajax component
     */
    function run()
    {
        $result = new JsonAjaxResult();
        
        $search_query = Request :: post(self :: PARAM_SEARCH_QUERY);
        
        $elements = $this->get_elements();
        
        $elements = $elements->as_array();
        
        $result->set_property(self :: PROPERTY_ELEMENTS, $elements);
        $result->set_property(self :: PROPERTY_TOTAL_ELEMENTS, $this->user_count);
        
        $result->display();
    }

    /**
     * Returns all the elements for this feed
     *
     * @return AdvancedElementFinderElements
     */
    private function get_elements()
    {
        $elements = new AdvancedElementFinderElements();
        
        // Add user category
        $user_category = new AdvancedElementFinderElement('users', 'category', Translation :: get('Users'), Translation :: get('Users'));
        $elements->add_element($user_category);
        
        $users = $this->retrieve_users();
        if ($users)
        {
            while ($user = $users->next_result())
            {
                $user_category->add_child($this->get_element_for_user($user));
            }
        }
        
        return $elements;
    }

    /**
     * Retrieves the users from the course (direct subscribed and group
     * subscribed)
     *
     * @return ResultSet
     */
    private function retrieve_users()
    {
        $search_query = Request :: post(self :: PARAM_SEARCH_QUERY);
        
        // Set the conditions for the search query
        if ($search_query && $search_query != '')
        {
            $conditions[] = Utilities :: query_to_condition($search_query, array(User :: PROPERTY_USERNAME, 
                    User :: PROPERTY_FIRSTNAME, User :: PROPERTY_LASTNAME));
        }
        
        // Combine the conditions
        $count = count($conditions);
        if ($count > 1)
        {
            $condition = new AndCondition($conditions);
        }
        
        if ($count == 1)
        {
            $condition = $conditions[0];
        }
        
        $this->user_count = DataManager :: count(User :: class_name(), $condition);
        $parameters = new DataClassRetrievesParameters($condition, 100, $this->get_offset(), array(
                new ObjectTableOrder(User :: PROPERTY_LASTNAME), new ObjectTableOrder(User :: PROPERTY_FIRSTNAME)));
        
        return DataManager :: retrieves(User :: class_name(), $parameters);
    }

    /**
     * Returns the selected offset
     *
     * @return int
     */
    protected function get_offset()
    {
        $offset = Request :: post(self :: PARAM_OFFSET);
        if (! isset($offset) || is_null($offset))
        {
            $offset = 0;
        }
        
        return $offset;
    }

    /**
     * Returns the advanced element finder element for the given user
     *
     * @param $user User           
     *
     * @return AdvancedElementFinderElement
     */
    protected function get_element_for_user($user)
    {
        return new AdvancedElementFinderElement('user_' . $user->get_id(), 'type type_user', $user->get_fullname(), $user->get_official_code());
    }

}

?>