<?php
namespace user;

use common\libraries\NewObjectTableCellRendererActionsColumnSupport;
use common\libraries\Utilities;
use common\libraries\Translation;
use common\libraries\Toolbar;
use common\libraries\ToolbarItem;
use common\libraries\Theme;
use common\libraries\PlatformSetting;

use reporting\ReportingManager;

/**
 * Cell renderer for the user object browser table
 */
class AdminUserBrowserTableCellRenderer extends DefaultUserTableCellRenderer
{
    // Inherited
    function render_cell($column, $user)
    {
        // Add special features here
        switch ($column->get_name())
        {
            case User :: PROPERTY_OFFICIAL_CODE :
                return $user->get_official_code();
            // Exceptions that need post-processing go here ...
            case User :: PROPERTY_STATUS :
               /* if ($user->get_platformadmin() == '1')
                {
                    return Translation :: get('PlatformAdministrator');
                }*/
                if ($user->get_status() == '1')
                {
                    return Translation :: get('CourseAdmin');
                }
                else
                {
                    return Translation :: get('Student');
                }
            case User :: PROPERTY_PLATFORMADMIN :
                return Utilities :: display_true_false_icon($user->get_platformadmin());
            case User :: PROPERTY_ACTIVE :
                return Utilities :: display_true_false_icon($user->get_active());
        }

        return parent :: render_cell($column, $user);
    }

    /**
     * Gets the action links to display
     *
     * @param $user The user for which the action links should be returned
     * @return string A HTML representation of the action links
     */
    function get_object_actions($user)
    {
        $toolbar = new Toolbar();

        if (UserRights :: is_allowed_in_users_subtree(UserRights :: EDIT_RIGHT, $user->get_id()))
        {
            $toolbar->add_item(new ToolbarItem(Translation :: get('Edit', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_edit.png', $this->get_object_table()->get_component()->get_user_editing_url($user), ToolbarItem :: DISPLAY_ICON));
            $toolbar->add_item(new ToolbarItem(Translation :: get('ManageRightsTemplates', null, 'rights'), Theme :: get_common_image_path() . 'action_rights.png', $this->get_object_table()->get_component()->get_manage_user_rights_url($user), ToolbarItem :: DISPLAY_ICON));

            // deprecated:
            // $toolbar->add_item(new ToolbarItem(Translation ::
            // get('ManageRights'), Theme :: get_common_image_path() .
            // 'action_rights.png', $this->get_object_table()->get_component()->get_url(array(
            // UserManager :: PARAM_ACTION => UserManager :: ACTION_EDIT_RIGHTS,
            // UserManager :: PARAM_USER_USER_ID => $user->get_id())),
            // ToolbarItem :: DISPLAY_ICON));

            $params = array();
            $params[ReportingManager :: PARAM_USER_ID] = $user->get_id();
            $toolbar->add_item(new ToolBarItem(Translation :: get('Detail'), Theme :: get_common_image_path() . 'action_details.png', $this->get_object_table()->get_component()->get_user_detail_url($user->get_id()), ToolbarItem :: DISPLAY_ICON));

            $toolbar->add_item(new ToolBarItem(Translation :: get('Report'), Theme :: get_common_image_path() . 'action_reporting.png', $this->get_object_table()->get_component()->get_url(array(
                    UserManager :: PARAM_ACTION => UserManager :: ACTION_REPORTING,
                    UserManager :: PARAM_USER_USER_ID => $user->get_id())), ToolbarItem :: DISPLAY_ICON));

            $toolbar->add_item(new ToolBarItem(Translation :: get('ViewQuota'), Theme :: get_common_image_path() . 'action_browser.png', $this->get_object_table()->get_component()->get_url(array(
                    UserManager :: PARAM_ACTION => UserManager :: ACTION_VIEW_QUOTA,
                    UserManager :: PARAM_USER_USER_ID => $user->get_id())), ToolbarItem :: DISPLAY_ICON));

            if (PlatformSetting :: get('active_online_email_editor'))
            {
                $toolbar->add_item(new ToolBarItem(Translation :: get('SendEmail'), Theme :: get_common_image_path() . 'action_email.png', $this->get_object_table()->get_component()->get_email_user_url($user), ToolbarItem :: DISPLAY_ICON));

            }
        }

        $toolbar->add_item(new ToolBarItem(Translation :: get('Metadata', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_metadata.png', $this->get_object_table()->get_component()->get_edit_metadata_url($user), ToolbarItem :: DISPLAY_ICON));

        if ($user->get_id() != \common\libraries\Session :: get_user_id())
        {
            if (UserDataManager :: user_deletion_allowed($user) && UserRights :: is_allowed_in_users_subtree(UserRights :: DELETE_RIGHT, $user->get_id()))
            {
                $toolbar->add_item(new ToolBarItem(Translation :: get('Delete', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_delete.png', $this->get_object_table()->get_component()->get_user_delete_url($user), ToolbarItem :: DISPLAY_ICON, true));
            }
            else
            {
                $toolbar->add_item(new ToolBarItem(Translation :: get('DeleteNA', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_delete_na.png', null, ToolbarItem :: DISPLAY_ICON));
            }

            if (UserRights :: is_allowed_in_users_subtree(UserRights :: EDIT_RIGHT, $user->get_id()))
            {
                $toolbar->add_item(new ToolBarItem(Translation :: get('LoginAsUser'), Theme :: get_common_image_path() . 'action_login.png', $this->get_object_table()->get_component()->get_change_user_url($user), ToolbarItem :: DISPLAY_ICON));
            }
        }
        else
        {
            $toolbar->add_item(new ToolBarItem(Translation :: get('DeleteNA', null, Utilities :: COMMON_LIBRARIES), Theme :: get_common_image_path() . 'action_delete_na.png', null, ToolbarItem :: DISPLAY_ICON));
        }

        return $toolbar->as_html();
    }
}
?>
