<?php
namespace user;

use common\libraries\Utilities;
use common\libraries\Translation;
use common\libraries\Request;
use common\libraries\AdministrationComponent;
use common\libraries\Breadcrumb;
use common\libraries\Display;
use common\libraries\BreadcrumbTrail;
use common\libraries\Application;

/**
 * $Id: creator.class.php 211 2009-11-13 13:28:39Z vanpouckesven $
 * @package user.lib.user_manager.component
 */

class UserManagerCreatorComponent extends UserManager implements AdministrationComponent
{

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        $user = $this->get_user();
        $user_id = $user->get_id();

        if (! $user->is_platform_admin())
        {
            $this->display_header();
            Display :: error_message(Translation :: get("NotAllowed", null, Utilities :: COMMON_LIBRARIES));
            $this->display_footer();
            exit();
        }
        $user = new User();
        $user->set_platformadmin(0);
        $user->set_password(1);

        $user_info = $this->get_user();
        $user->set_creator_id($user_info->get_id());

        $form = new UserForm(UserForm :: TYPE_CREATE, $user, $this->get_user(), $this->get_url());

        if ($form->validate())
        {
            $success = $form->create_user();
            if ($success == 1)
            {
                $this->redirect(Translation :: get($success ? 'UserCreated' : 'UserNotCreated'), ($success ? false : true), array(
                        Application :: PARAM_ACTION => UserManager :: ACTION_BROWSE_USERS));

            }
            else
            {
                Request :: set_get('error_message', Translation :: get('UsernameNotAvailable'));
                $this->display_header();
                $form->display();
                $this->display_footer();
            }
        }
        else
        {
            $this->display_header();
            $form->display();
            $this->display_footer();
        }
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add(new Breadcrumb($this->get_url(array(
                UserManager :: PARAM_ACTION => UserManager :: ACTION_BROWSE_USERS)), Translation :: get('UserManagerAdminUserBrowserComponent')));
        $breadcrumbtrail->add_help('user_creator');
    }

}
?>