<?php

namespace user;

use common\libraries\Request;
use tracking\Event;
use common\libraries\PlatformSetting;
use common\libraries\Application;
use home\HomeManager;
use common\libraries\Redirect;

/**
 * @package user.lib.user_manager.component
 * @author Sven Vanpoucke
 */
class UserManagerLoginComponent extends UserManager
{
    
    const PARAM_LOGIN = 'login';
    const PARAM_PASSWORD = 'password';
    const PARAM_LOGIN_FAILED = 'loginFailed';
    const PARAM_REQUEST_URI = 'request_uri';

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        $login = Request :: post(self :: PARAM_LOGIN);
        $password = Request :: post(self :: PARAM_PASSWORD);
        $user = UserDataManager :: login($login, $password);
        if ($user instanceof User)
        {
            \common\libraries\Session :: register('_uid', $user->get_id());
            Event :: trigger('login', self :: APPLICATION_NAME, array('server' => $_SERVER, 'user' => $user));
            
            $request_uri = \common\libraries\Session :: retrieve(self :: PARAM_REQUEST_URI);
            
            if ($request_uri)
            {
                $request_uris = explode("/", $request_uri);
                $request_uri = array_pop($request_uris);
                \common\libraries\Session :: unregister(self :: PARAM_REQUEST_URI);
                Redirect :: write_header($request_uri);
            }
            
            $application_after_login = PlatformSetting :: get('page_after_login');
            
            if ($application_after_login == 'home')
            {
                $type = Redirect :: TYPE_CORE;
            }
            else
            {
                $type = Redirect :: TYPE_APPLICATION;
            }
            Redirect :: link($application_after_login, array(), array(), false, $type);
            
        }
        else
        {
            \common\libraries\Session :: unregister('_uid');
            $parameters = array(self :: PARAM_LOGIN_FAILED => true);
            $this->redirect($user, false, $parameters, array(), false, Redirect :: TYPE_LINK, Redirect :: TYPE_INDEX);
        }
    }

}

?>