<?php
namespace user;

use common\libraries\Versionable;
use common\libraries\Filesystem;
use common\libraries\Translation;
use common\libraries\Request;
use common\libraries\Theme;
use common\libraries\Display;
use common\libraries\ToolbarItem;
use common\libraries\Toolbar;
use common\libraries\AdministrationComponent;
use common\libraries\Breadcrumb;
use common\libraries\BreadcrumbTrail;
use common\libraries\Utilities;
use common\libraries\ActionBarRenderer;
use common\libraries\Application;
use common\libraries\SortableTable;

use repository\RepositoryDataManager;
use repository\QuotaManager;
use repository\ContentObject;

/**
 * $Id: quota_viewer.class.php 211 2009-11-13 13:28:39Z vanpouckesven $
 *
 * @package user.lib.user_manager.component
 */
/**
 * User manager component which displays the quota to the user. This component displays two progress-bars. The first one
 * displays the used disk space and the second one the number of learning objects in the users user.
 *
 * @author Bart Mollet
 * @author Tim De Pauw
 * @author Hans De Bisschop
 * @author Dieter De Neef
 */
class UserManagerQuotaViewerComponent extends UserManager implements AdministrationComponent
{
    private $selected_user;

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        if (! $this->get_user()->is_platform_admin())
        {
            $this->display_header();
            Display :: error_message(Translation :: get("NotAllowed", null, Utilities :: COMMON_LIBRARIES));
            $this->display_footer();
            exit();
        }
        $selected_user_id = Request :: get(UserManager :: PARAM_USER_USER_ID);
        if (! $selected_user_id)
        {
            $this->selected_user = $this->get_user();
        }
        else
        {
            $this->selected_user = UserDataManager :: get_instance()->retrieve_user($selected_user_id);
        }

        $this->display_header();

        $this->display_action_bar();

        $quotamanager = new QuotaManager($this->selected_user);
        echo '<h3>' . htmlentities(Translation :: get('DiskSpace')) . '</h3>';
        echo self :: get_bar($quotamanager->get_used_disk_space_percent(), Filesystem :: format_file_size($quotamanager->get_used_disk_space()) . ' / ' . Filesystem :: format_file_size($quotamanager->get_max_disk_space()));
        echo '<div style="clear: both;">&nbsp;</div>';
        echo '<h3>' . htmlentities(Translation :: get('NumberOfContentObjects')) . '</h3>';
        echo self :: get_bar($quotamanager->get_used_database_space_percent(), $quotamanager->get_used_database_space() . ' / ' . $quotamanager->get_max_database_space());
        echo '<div style="clear: both;">&nbsp;</div>';

        $this->display_footer();
    }

    private function display_action_bar()
    {
        $action_bar = new ActionBarRenderer(ActionBarRenderer :: TYPE_HORIZONTAL);

        $action_bar->add_common_action(new ToolbarItem(Translation :: get('EditUser'), Theme :: get_common_image_path() . 'action_edit.png', $this->get_url(array(
                Application :: PARAM_ACTION => UserManager :: ACTION_UPDATE_USER,
                UserManager :: PARAM_USER_USER_ID => $this->selected_user->get_id())), ToolbarItem :: DISPLAY_ICON_AND_LABEL));

        echo $action_bar->as_html();
    }

    /**
     * Build a bar-view of the used quota.
     *
     * @param $percent float The percentage of the bar that is in use
     * @param $status string A status message which will be displayed below the bar.
     * @return string HTML representation of the requested bar.
     */
    private static function get_bar($percent, $status)
    {
        $html = '<div class="usage_information">';
        $html .= '<div class="usage_bar">';
        for($i = 0; $i < 100; $i ++)
        {
            if ($percent > $i)
            {
                if ($i >= 90)
                {
                    $class = 'very_critical';
                }
                elseif ($i >= 80)
                {
                    $class = 'critical';
                }
                else
                {
                    $class = 'used';
                }
            }
            else
            {
                $class = '';
            }
            $html .= '<div class="' . $class . '"></div>';
        }
        $html .= '</div>';
        $html .= '<div class="usage_status">' . $status . ' &ndash; ' . round($percent, 2) . ' %</div>';
        $html .= '</div>';
        return $html;
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add(new Breadcrumb($this->get_url(array(
                UserManager :: PARAM_ACTION => UserManager :: ACTION_BROWSE_USERS)), Translation :: get('UserManagerAdminUserBrowserComponent')));
        $breadcrumbtrail->add_help('user_quota_viewer');
    }

    function get_additional_parameters()
    {
        return array(UserManager :: PARAM_USER_USER_ID);
    }
}
?>