<?php
namespace user;

use common\libraries\CommonDataManager;

use common\libraries\Utilities;
use common\libraries\WebApplication;
use common\libraries\Translation;
use common\libraries\Request;
use common\libraries\Theme;
use common\libraries\CoreApplication;
use common\libraries\EqualityCondition;
use common\libraries\AndCondition;
use common\libraries\BreadcrumbTrail;
use common\libraries\ResourceManager;
use common\libraries\Header;
use common\libraries\DynamicVisualTabsRenderer;
use common\libraries\DynamicVisualTab;
use common\libraries\Path;
use common\libraries\Application;
use common\libraries\Setting;

use common\extensions\dynamic_form_manager\DynamicFormManager;
use admin\ConfigurationForm;
use admin\AdminDataManager;
use admin\AdminManager;

/**
 * $Id: user_settings.class.php 211 2009-11-13 13:28:39Z vanpouckesven $
 *
 * @package user.lib.user_manager.component
 */

class UserManagerUserSettingsComponent extends UserManager
{
    const PARAM_CONTEXT = 'context';

    private $tabs;

    /**
     * Runs this component and displays its output.
     */
    function run()
    {
        Header :: set_section('my_account');

        $context = Request :: get(self :: PARAM_CONTEXT);

        if (! $context)
        {
            $context = AdminManager :: APPLICATION_NAME;
        }

        $form = new ConfigurationForm($context, 'config', 'post', $this->get_url(array(
                self :: PARAM_CONTEXT => $context)), true);

        if ($form->validate())
        {
            $success = $form->update_user_settings();
            $this->redirect(Translation :: get($success ? 'ConfigurationUpdated' : 'ConfigurationNotUpdated'), ($success ? false : true), array(
                    Application :: PARAM_ACTION => UserManager :: ACTION_USER_SETTINGS,
                    self :: PARAM_CONTEXT => $context));
        }
        else
        {
            $this->display_header();

            if (! $context)
            {
                echo '<div class="normal-message">' . Translation :: get('SelectApplicationToConfigure') . '</div><br />';
            }

            $tabs = new DynamicVisualTabsRenderer(Utilities :: get_classname_from_namespace(__NAMESPACE__, true), $form->toHtml());
            $setting_contexts = CommonDataManager :: retrieve_setting_contexts(new EqualityCondition(Setting :: PROPERTY_USER_SETTING, 1));

            foreach ($setting_contexts as $setting_context)
            {
                $package_url = $this->get_url(array( // Application :: PARAM_ACTION => AdminManager ::
                                                     // ACTION_CONFIGURE_PLATFORM,
                        Application :: PARAM_ACTION => UserManager :: ACTION_USER_SETTINGS,
                        AdminManager :: PARAM_CONTEXT => $setting_context));
                $is_current_tab = ($context === $setting_context);
                $tab = new DynamicVisualTab($setting_context, Translation :: get('TypeName', null, $setting_context), Theme :: get_image_path($setting_context) . 'logo/22.png', $package_url, $is_current_tab);
                $tabs->add_tab($tab);
            }

            echo $tabs->render();
            $this->display_footer();
        }
    }

    function display_header()
    {
        parent :: display_header();

        $actions[] = UserManager :: ACTION_VIEW_ACCOUNT;
        $actions[] = UserManager :: ACTION_USER_SETTINGS;

        $form_builder = new DynamicFormManager($this, UserManager :: APPLICATION_NAME, 'account_fields', DynamicFormManager :: TYPE_EXECUTER);
        $dynamic_form = $form_builder->get_form();
        if (count($dynamic_form->get_elements()) > 0)
        {
            $actions[] = UserManager :: ACTION_ADDITIONAL_ACCOUNT_INFORMATION;
        }

        $this->tabs = new DynamicVisualTabsRenderer('account');

        foreach ($actions as $action)
        {
            $selected = ($action == 'user_settings' ? true : false);

            $label = htmlentities(Translation :: get(Utilities :: underscores_to_camelcase($action) . 'Title'));
            $link = $this->get_url(array(UserManager :: PARAM_ACTION => $action));

            $this->tabs->add_tab(new DynamicVisualTab($action, $label, Theme :: get_image_path() . 'place_' . $action . '.png', $link, $selected));
        }
        echo $this->tabs->header();
        echo $this->tabs->body_header();
    }

    function display_footer()
    {
        $html[] = '<script type="text/javascript">';
        $html[] = '$(document).ready(function() {';
        $html[] = '$(\':checkbox\').iphoneStyle({ checkedLabel: \'' . Translation :: get('ConfirmOn', null, Utilities :: COMMON_LIBRARIES) . '\', uncheckedLabel: \'' . Translation :: get('ConfirmOff', null, Utilities :: COMMON_LIBRARIES) . '\'});';
        $html[] = '});';
        $html[] = '</script>';
        $html[] = $this->tabs->body_footer();
        $html[] = $this->tabs->footer();

        echo implode("\n", $html);

        parent :: display_footer();
    }

    function add_additional_breadcrumbs(BreadcrumbTrail $breadcrumbtrail)
    {
        $breadcrumbtrail->add_help('user_settings');
    }

}
?>